@@ -77,6 +77,30 @@ struct GNUNET_TIME_Absolute start_time;
  */
 static struct GNUNET_CONTAINER_MultiHashMap *denominations;
 
+/**
+ * Results about denominations, cached per-transaction, maps row/serial ID's
+ * to `const struct TALER_EXCHANGEDB_DenominationKeyInformation`.
+ */
+static struct GNUNET_CONTAINER_MultiUuidmap *denominations_by_serial;
+
+/**
+ * Helper to convert a serial/row id to a uuid for the lookup
+ * in a uuid hash table.
+ *
+ * @param serial serial id of entry
+ * @param[out] uuid uuid to write
+ */
+static void
+serial_to_uuid (
+  uint64_t serial,
+  struct GNUNET_Uuid *uuid)
+{
+  uuid->value[0] = serial;
+  uuid->value[1] = serial >> 32;
+  uuid->value[2] = 0;
+  uuid->value[3] = 0;
+}
+
 
 /**
  * Function called with the results of iterate_denomination_info(),
@@ -84,12 +108,14 @@ static struct GNUNET_CONTAINER_MultiHashMap *denominations;
  * to our hash table.
  *
  * @param cls closure, NULL
+ * @param denom_serial table row of the denomaination
  * @param denom_pub public key, sometimes NULL (!)
  * @param issue issuing information with value, fees and other info about the denomination.
  */
 static void
 add_denomination (
   void *cls,
+  uint64_t denom_serial,
   const struct TALER_DenominationPublicKey *denom_pub,
   const struct TALER_EXCHANGEDB_DenominationKeyInformation *issue)
 {
@@ -118,6 +144,7 @@ add_denomination (
 #endif
   {
     struct TALER_EXCHANGEDB_DenominationKeyInformation *i;
+    struct GNUNET_Uuid uuid;
 
     i = GNUNET_new (struct TALER_EXCHANGEDB_DenominationKeyInformation);
     *i = *issue;
@@ -126,6 +153,12 @@ add_denomination (
                                                       &issue->denom_hash.hash,
                                                       i,
                                                       GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_ONLY));
+    serial_to_uuid (denom_serial, &uuid);
+    GNUNET_assert (GNUNET_OK ==
+                   GNUNET_CONTAINER_multiuuidmap_put (denominations_by_serial,
+                                                      &uuid,
+                                                      i,
+                                                      GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_ONLY));
   }
 }
 
@@ -141,6 +174,10 @@ TALER_ARL_get_denomination_info_by_hash (
   {
     denominations = GNUNET_CONTAINER_multihashmap_create (256,
                                                           GNUNET_NO);
+    if (NULL  == denominations_by_serial)
+      denominations_by_serial = GNUNET_CONTAINER_multiuuidmap_create (256,
+                                                                      GNUNET_NO);
+
     qs = TALER_ARL_edb->iterate_denomination_info (TALER_ARL_edb->cls,
                                                    &add_denomination,
                                                    NULL);
@@ -166,9 +203,11 @@ TALER_ARL_get_denomination_info_by_hash (
   /* maybe database changed since we last iterated, give it one more shot */
   {
     struct TALER_EXCHANGEDB_DenominationKeyInformation issue;
+    uint64_t denom_serial;
 
     qs = TALER_ARL_edb->get_denomination_info (TALER_ARL_edb->cls,
                                                dh,
+                                               &denom_serial,
                                                &issue);
     if (qs <= 0)
     {
@@ -179,7 +218,9 @@ TALER_ARL_get_denomination_info_by_hash (
                     TALER_B2S (dh));
       return qs;
     }
+
     add_denomination (NULL,
+                      denom_serial,
                       NULL,
                       &issue);
   }
@@ -203,6 +244,89 @@ TALER_ARL_get_denomination_info_by_hash (
 }
 
 
+enum GNUNET_DB_QueryStatus
+TALER_ARL_get_denomination_info_by_serial (
+  uint64_t denom_serial,
+  const struct TALER_EXCHANGEDB_DenominationKeyInformation **issuep)
+{
+  enum GNUNET_DB_QueryStatus qs;
+  struct GNUNET_Uuid uuid;
+
+  serial_to_uuid (denom_serial, &uuid);
+
+  if (NULL == denominations_by_serial)
+  {
+    denominations_by_serial = GNUNET_CONTAINER_multiuuidmap_create (256,
+                                                                    GNUNET_NO);
+    if (NULL == denominations)
+      denominations = GNUNET_CONTAINER_multihashmap_create (256,
+                                                            GNUNET_NO);
+
+    qs = TALER_ARL_edb->iterate_denomination_info (TALER_ARL_edb->cls,
+                                                   &add_denomination,
+                                                   NULL);
+    if (0 > qs)
+    {
+      GNUNET_break (0);
+      *issuep = NULL;
+      return qs;
+    }
+  }
+  {
+    const struct TALER_EXCHANGEDB_DenominationKeyInformation *i;
+
+    i = GNUNET_CONTAINER_multiuuidmap_get (denominations_by_serial,
+                                           &uuid);
+    if (NULL != i)
+    {
+      /* cache hit */
+      *issuep = i;
+      return GNUNET_DB_STATUS_SUCCESS_ONE_RESULT;
+    }
+  }
+  /* maybe database changed since we last iterated, give it one more shot */
+  {
+    struct TALER_EXCHANGEDB_DenominationKeyInformation issue;
+
+    qs = TALER_ARL_edb->get_denomination_by_serial (TALER_ARL_edb->cls,
+                                                    denom_serial,
+                                                    &issue);
+    if (qs <= 0)
+    {
+      GNUNET_break (qs >= 0);
+      if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
+        GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                    "Denomination with serial %lu not found\n",
+                    denom_serial);
+      return qs;
+    }
+
+    add_denomination (NULL,
+                      denom_serial,
+                      NULL,
+                      &issue);
+  }
+
+  {
+    const struct TALER_EXCHANGEDB_DenominationKeyInformation *i;
+
+    i = GNUNET_CONTAINER_multiuuidmap_get (denominations_by_serial,
+                                           &uuid);
+    if (NULL != i)
+    {
+      /* cache hit */
+      *issuep = i;
+      return GNUNET_DB_STATUS_SUCCESS_ONE_RESULT;
+    }
+  }
+  /* We found more keys, but not the denomination we are looking for :-( */
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Denomination with serial %lu not found\n",
+              denom_serial);
+  return GNUNET_DB_STATUS_SUCCESS_NO_RESULTS;
+}
+
+
 enum GNUNET_DB_QueryStatus
 TALER_ARL_get_denomination_info (
   const struct TALER_DenominationPublicKey *denom_pub,
