@@ -144,6 +144,18 @@ TALER_ARL_get_denomination_info_by_hash (
   const struct TALER_DenominationHashP *dh,
   const struct TALER_EXCHANGEDB_DenominationKeyInformation **issuep);
 
+/**
+ * Obtain information about a @a denomination by its serial
+ *
+ * @param serial row id of the denomination to look up
+ * @param[out] issuep set to detailed information about @a denom_pub, NULL if not found, must
+ *                 NOT be freed by caller
+ * @return transaction status code
+ */
+enum GNUNET_DB_QueryStatus
+TALER_ARL_get_denomination_info_by_serial (
+  uint64_t serial,
+  const struct TALER_EXCHANGEDB_DenominationKeyInformation **issuep);
 
 /**
  * Obtain information about a @a denom_pub.
