@@ -55,15 +55,11 @@ add_deposit_confirmation (
     json_t *pub;
     json_t *sig;
 
-    pub = GNUNET_JSON_PACK (
-      GNUNET_JSON_pack_data_auto (NULL,
-                                  &dc->coin_pubs[i]));
+    pub = GNUNET_JSON_from_data_auto (&dc->coin_pubs[i]);
     GNUNET_assert (0 ==
                    json_array_append_new (coin_pubs_json,
                                           pub));
-    sig = GNUNET_JSON_PACK (
-      GNUNET_JSON_pack_data_auto (NULL,
-                                  &dc->coin_sigs[i]));
+    sig = GNUNET_JSON_from_data_auto (&dc->coin_sigs[i]);
     GNUNET_assert (0 ==
                    json_array_append_new (coin_sigs_json,
                                           sig));
