@@ -13,8 +13,6 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-
-
 #include "platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
@@ -27,39 +25,43 @@
 #include "taler-auditor-httpd_emergency-by-count-get.h"
 
 /**
-* Add emergency-by-count to the list.
-*
-* @param[in,out] cls a `json_t *` array to extend
-* @param serial_id location of the @a dc in the database
-* @param dc struct of inconsistencies
-* @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop iterating
-*/
+ * Add emergency-by-count to the list.
+ *
+ * @param[in,out] cls a `json_t *` array to extend
+ * @param dc struct of inconsistencies
+ * @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop iterating
+ */
 static enum GNUNET_GenericReturnValue
 process_emergency_by_count (
   void *cls,
-  uint64_t serial_id,
   const struct TALER_AUDITORDB_EmergenciesByCount *dc)
 {
   json_t *list = cls;
   json_t *obj;
 
   obj = GNUNET_JSON_PACK (
-
-    GNUNET_JSON_pack_uint64 ("row_id", serial_id),
-    GNUNET_JSON_pack_data_auto ("denompub_h", &dc->denompub_h),
-    GNUNET_JSON_pack_int64 ("num_issued", dc->num_issued),
-    GNUNET_JSON_pack_int64 ("num_known", dc->num_known),
-    TALER_JSON_pack_amount ("risk", &dc->risk),
-    TALER_JSON_pack_time_abs_human ("start", dc->start),
-    TALER_JSON_pack_time_abs_human ("deposit_end", dc->deposit_end),
-    TALER_JSON_pack_amount ("value", &dc->value)
-
+    GNUNET_JSON_pack_uint64 ("row_id",
+                             dc->row_id),
+    GNUNET_JSON_pack_data_auto ("denompub_h",
+                                &dc->denompub_h),
+    GNUNET_JSON_pack_int64 ("num_issued",
+                            dc->num_issued),
+    GNUNET_JSON_pack_int64 ("num_known",
+                            dc->num_known),
+    TALER_JSON_pack_amount ("risk",
+                            &dc->risk),
+    TALER_JSON_pack_time_abs_human ("start",
+                                    dc->start),
+    TALER_JSON_pack_time_abs_human ("deposit_end",
+                                    dc->deposit_end),
+    TALER_JSON_pack_amount ("value",
+                            &dc->value),
+    GNUNET_JSON_pack_bool ("suppressed",
+                           dc->suppressed)
     );
   GNUNET_break (0 ==
                 json_array_append_new (list,
                                        obj));
-
-
   return GNUNET_OK;
 }
 
@@ -75,6 +77,9 @@ TAH_EMERGENCY_BY_COUNT_handler_get (
 {
   json_t *ja;
   enum GNUNET_DB_QueryStatus qs;
+  int64_t limit = -20;
+  uint64_t offset;
+  bool return_suppressed = false;
 
   (void) rh;
   (void) connection_cls;
@@ -89,34 +94,29 @@ TAH_EMERGENCY_BY_COUNT_handler_get (
                                        TALER_EC_GENERIC_DB_SETUP_FAILED,
                                        NULL);
   }
-  ja = json_array ();
-  GNUNET_break (NULL != ja);
-
-  int64_t limit = -20;
-  uint64_t offset;
-
   TALER_MHD_parse_request_snumber (connection,
                                    "limit",
                                    &limit);
-
   if (limit < 0)
     offset = INT64_MAX;
   else
     offset = 0;
-
   TALER_MHD_parse_request_number (connection,
                                   "offset",
                                   &offset);
-
-  bool return_suppressed = false;
-  const char *ret_s = MHD_lookup_connection_value (connection,
-                                                   MHD_GET_ARGUMENT_KIND,
-                                                   "return_suppressed");
-  if (ret_s != NULL && strcmp (ret_s, "true") == 0)
   {
-    return_suppressed = true;
+    const char *ret_s
+      = MHD_lookup_connection_value (connection,
+                                     MHD_GET_ARGUMENT_KIND,
+                                     "return_suppressed");
+    if (ret_s != NULL && strcmp (ret_s, "true") == 0)
+    {
+      return_suppressed = true;
+    }
   }
 
+  ja = json_array ();
+  GNUNET_break (NULL != ja);
   qs = TAH_plugin->get_emergency_by_count (
     TAH_plugin->cls,
     limit,
@@ -124,7 +124,6 @@ TAH_EMERGENCY_BY_COUNT_handler_get (
     return_suppressed,
     &process_emergency_by_count,
     ja);
-
   if (0 > qs)
   {
     GNUNET_break (GNUNET_DB_STATUS_HARD_ERROR == qs);
