@@ -45,16 +45,26 @@ process_reserves (
   obj = GNUNET_JSON_PACK (
     GNUNET_JSON_pack_int64 ("auditor_reserves_rowid",
                             dc->auditor_reserves_rowid),
-    GNUNET_JSON_pack_data_auto ("reserve_pub", &dc->reserve_pub),
-    TALER_JSON_pack_amount ("reserve_balance", &dc->reserve_balance),
-    TALER_JSON_pack_amount ("reserve_loss", &dc->reserve_loss),
-    TALER_JSON_pack_amount ("withdraw_fee_balance", &dc->withdraw_fee_balance),
-    TALER_JSON_pack_amount ("close_fee_balance", &dc->close_fee_balance),
-    TALER_JSON_pack_amount ("purse_fee_balance", &dc->purse_fee_balance),
-    TALER_JSON_pack_amount ("open_fee_balance", &dc->open_fee_balance),
-    TALER_JSON_pack_amount ("history_fee_balance", &dc->history_fee_balance),
-    TALER_JSON_pack_time_abs_human ("expiration_date", dc->expiration_date),
-    GNUNET_JSON_pack_string ("origin_account", dc->origin_account)
+    GNUNET_JSON_pack_data_auto ("reserve_pub",
+                                &dc->reserve_pub),
+    TALER_JSON_pack_amount ("reserve_balance",
+                            &dc->reserve_balance),
+    TALER_JSON_pack_amount ("reserve_loss",
+                            &dc->reserve_loss),
+    TALER_JSON_pack_amount ("withdraw_fee_balance",
+                            &dc->withdraw_fee_balance),
+    TALER_JSON_pack_amount ("close_fee_balance",
+                            &dc->close_fee_balance),
+    TALER_JSON_pack_amount ("purse_fee_balance",
+                            &dc->purse_fee_balance),
+    TALER_JSON_pack_amount ("open_fee_balance",
+                            &dc->open_fee_balance),
+    TALER_JSON_pack_amount ("history_fee_balance",
+                            &dc->history_fee_balance),
+    TALER_JSON_pack_time_abs_human ("expiration_date",
+                                    dc->expiration_date),
+    TALER_JSON_pack_full_payto ("origin_account",
+                                dc->origin_account)
     );
   GNUNET_break (0 ==
                 json_array_append_new (list,
