@@ -13,8 +13,6 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-
-
 #include "platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
@@ -26,32 +24,33 @@
 #include "taler-auditor-httpd.h"
 #include "taler-auditor-httpd_wire-format-inconsistency-get.h"
 
+
 /**
-* Add wire-format-inconsistency to the list.
-*
-* @param[in,out] cls a `json_t *` array to extend
-* @param serial_id location of the @a dc in the database
-* @param dc struct of inconsistencies
-* @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop iterating
-*/
+ * Add wire-format-inconsistency to the list.
+ *
+ * @param[in,out] cls a `json_t *` array to extend
+ * @param dc struct of inconsistencies
+ * @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop iterating
+ */
 static enum GNUNET_GenericReturnValue
 process_wire_format_inconsistency (
   void *cls,
-  uint64_t serial_id,
   const struct TALER_AUDITORDB_WireFormatInconsistency *dc)
 {
   json_t *list = cls;
   json_t *obj;
 
   obj = GNUNET_JSON_PACK (
-
-    GNUNET_JSON_pack_int64 ("row_id", serial_id),
-    TALER_JSON_pack_amount ("amount", &dc->amount),
-    GNUNET_JSON_pack_int64 ("wire_offset", dc->wire_offset),
-    GNUNET_JSON_pack_data_auto ("diagnostic", dc->diagnostic),
-    GNUNET_JSON_pack_bool ("suppressed", dc->suppressed)
-
-
+    GNUNET_JSON_pack_uint64 ("row_id",
+                             dc->row_id),
+    TALER_JSON_pack_amount ("amount",
+                            &dc->amount),
+    GNUNET_JSON_pack_uint64 ("wire_offset",
+                             dc->wire_offset),
+    GNUNET_JSON_pack_string ("diagnostic",
+                             dc->diagnostic),
+    GNUNET_JSON_pack_bool ("suppressed",
+                           dc->suppressed)
     );
   GNUNET_break (0 ==
                 json_array_append_new (list,
@@ -73,6 +72,9 @@ TAH_WIRE_FORMAT_INCONSISTENCY_handler_get (
 {
   json_t *ja;
   enum GNUNET_DB_QueryStatus qs;
+  int64_t limit = -20;
+  uint64_t offset;
+  bool return_suppressed = false;
 
   (void) rh;
   (void) connection_cls;
@@ -87,34 +89,29 @@ TAH_WIRE_FORMAT_INCONSISTENCY_handler_get (
                                        TALER_EC_GENERIC_DB_SETUP_FAILED,
                                        NULL);
   }
-  ja = json_array ();
-  GNUNET_break (NULL != ja);
-
-  int64_t limit = -20;
-  uint64_t offset;
-
   TALER_MHD_parse_request_snumber (connection,
                                    "limit",
                                    &limit);
-
   if (limit < 0)
     offset = INT64_MAX;
   else
     offset = 0;
-
   TALER_MHD_parse_request_number (connection,
                                   "offset",
                                   &offset);
-
-  bool return_suppressed = false;
-  const char *ret_s = MHD_lookup_connection_value (connection,
-                                                   MHD_GET_ARGUMENT_KIND,
-                                                   "return_suppressed");
-  if (ret_s != NULL && strcmp (ret_s, "true") == 0)
   {
-    return_suppressed = true;
+    const char *ret_s = MHD_lookup_connection_value (connection,
+                                                     MHD_GET_ARGUMENT_KIND,
+                                                     "return_suppressed");
+    if ( (NULL != ret_s) &&
+         (0 == strcmp (ret_s, "true")) )
+    {
+      return_suppressed = true;
+    }
   }
 
+  ja = json_array ();
+  GNUNET_break (NULL != ja);
   qs = TAH_plugin->get_wire_format_inconsistency (
     TAH_plugin->cls,
     limit,
@@ -122,7 +119,6 @@ TAH_WIRE_FORMAT_INCONSISTENCY_handler_get (
     return_suppressed,
     &process_wire_format_inconsistency,
     ja);
-
   if (0 > qs)
   {
     GNUNET_break (GNUNET_DB_STATUS_HARD_ERROR == qs);
@@ -137,6 +133,6 @@ TAH_WIRE_FORMAT_INCONSISTENCY_handler_get (
   return TALER_MHD_REPLY_JSON_PACK (
     connection,
     MHD_HTTP_OK,
-    GNUNET_JSON_pack_array_steal ("wire-format-inconsistency",
+    GNUNET_JSON_pack_array_steal ("wire_format_inconsistency",
                                   ja));
 }
