@@ -106,9 +106,7 @@ static struct Table tables[] = {
   { .rt = TALER_EXCHANGEDB_RT_EXCHANGE_SIGN_KEYS},
   { .rt = TALER_EXCHANGEDB_RT_SIGNKEY_REVOCATIONS},
   { .rt = TALER_EXCHANGEDB_RT_KNOWN_COINS},
-  { .rt = TALER_EXCHANGEDB_RT_REFRESH_COMMITMENTS},
-  { .rt = TALER_EXCHANGEDB_RT_REFRESH_REVEALED_COINS},
-  { .rt = TALER_EXCHANGEDB_RT_REFRESH_TRANSFER_KEYS},
+  { .rt = TALER_EXCHANGEDB_RT_REFRESH},
   { .rt = TALER_EXCHANGEDB_RT_BATCH_DEPOSITS},
   { .rt = TALER_EXCHANGEDB_RT_COIN_DEPOSITS},
   { .rt = TALER_EXCHANGEDB_RT_REFUNDS},
