@@ -815,9 +815,9 @@ wire_transfer_information_cb (
     }
   }
   /* Obtain coin's transaction history */
-  /* FIXME: could use 'start' mechanism to only fetch transactions
-     we did not yet process, instead of going over them
-     again and again.*/
+  /* FIXME-Optimization: could use 'start' mechanism to only fetch
+     transactions we did not yet process, instead of going over them again and
+     again.*/
 
   {
     struct TALER_Amount balance;
@@ -1055,6 +1055,7 @@ get_wire_fee (struct AggregationContext *ac,
   struct WireFeeInfo *pos;
   struct TALER_MasterSignatureP master_sig;
   enum GNUNET_DB_QueryStatus qs;
+  uint64_t rowid;
 
   /* Check if fee is already loaded in cache */
   for (pos = ac->fee_head; NULL != pos; pos = pos->next)
@@ -1078,6 +1079,7 @@ get_wire_fee (struct AggregationContext *ac,
       TALER_ARL_edb->get_wire_fee (TALER_ARL_edb->cls,
                                    method,
                                    timestamp,
+                                   &rowid,
                                    &wfi->start_date,
                                    &wfi->end_date,
                                    &wfi->fees,
@@ -1130,7 +1132,7 @@ get_wire_fee (struct AggregationContext *ac,
                                  wfi->start_date))
   {
     struct TALER_AUDITORDB_FeeTimeInconsistency ftib = {
-      .problem_row_id = 0, /* FIXME: fetch above! */
+      .problem_row_id = rowid,
       .diagnostic = (char *) "start date before previous end date",
       .time = wfi->start_date.abs_time,
       .type = (char *) method
@@ -1152,7 +1154,7 @@ get_wire_fee (struct AggregationContext *ac,
                                  wfi->end_date))
   {
     struct TALER_AUDITORDB_FeeTimeInconsistency ftia = {
-      .problem_row_id = 0, /* FIXME: fetch above! */
+      .problem_row_id = rowid,
       .diagnostic = (char *) "end date date after next start date",
       .time = wfi->end_date.abs_time,
       .type = (char *) method
