@@ -58,7 +58,7 @@ static struct GNUNET_TIME_Relative idle_reserve_expiration_time;
  * Checkpointing our progress for reserves.
  */
 static TALER_ARL_DEF_PP (reserves_reserve_in_serial_id);
-static TALER_ARL_DEF_PP (reserves_reserve_out_serial_id);
+static TALER_ARL_DEF_PP (reserves_withdraw_serial_id);
 static TALER_ARL_DEF_PP (reserves_reserve_recoup_serial_id);
 static TALER_ARL_DEF_PP (reserves_reserve_open_serial_id);
 static TALER_ARL_DEF_PP (reserves_reserve_close_serial_id);
@@ -255,7 +255,7 @@ struct ReserveSummary
 
   /**
    * Sum of all outgoing transfers during this transaction (includes fees).
-   * Updated only in #handle_reserve_out().
+   * Updated only in #handle_withdrawals().
    */
   struct TALER_Amount total_out;
 
@@ -512,8 +512,14 @@ handle_reserve_in (
  *
  * @param cls our `struct ReserveContext`
  * @param rowid unique serial ID for the refresh session in our DB
- * @param h_blind_ev blinded hash of the coin's public key
- * @param denom_pub public denomination key of the deposited coin
+ * @param num_evs number of elements in @e h_blind_evs
+ * @param h_blind_evs array @e num_evs of blinded hashes of the coin's public keys
+ * @param denom_serials array @e num_evs of serial ID's of denominations in our DB
+ * @param h_planchets running hash over all hashes of blinded planchets in the original withdraw request
+ * @param blinding_seed the master seed used for CS denominations; might be NULL
+ * @param age_proof_required true if the withdraw request required an age proof.
+ * @param max_age if @e age_proof_required is true, the maximum age that was set on the coins.
+ * @param noreveal_index if @e age_proof_required is true, the index that was returned by the exchange for the reveal phase.
  * @param reserve_pub public key of the reserve
  * @param reserve_sig signature over the withdraw operation
  * @param execution_date when did the wallet withdraw the coin
@@ -521,11 +527,17 @@ handle_reserve_in (
  * @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop
  */
 static enum GNUNET_GenericReturnValue
-handle_reserve_out (
+handle_withdrawals (
   void *cls,
   uint64_t rowid,
-  const struct TALER_BlindedCoinHashP *h_blind_ev,
-  const struct TALER_DenominationPublicKey *denom_pub,
+  size_t num_evs,
+  const struct TALER_BlindedCoinHashP *h_blind_evs,
+  const uint64_t *denom_serials,
+  const struct TALER_HashBlindedPlanchetsP *h_planchets,
+  const struct TALER_BlindingMasterSeedP *blinding_seed,
+  bool age_proof_required,
+  uint8_t max_age,
+  uint8_t noreveal_index,
   const struct TALER_ReservePublicKeyP *reserve_pub,
   const struct TALER_ReserveSignatureP *reserve_sig,
   struct GNUNET_TIME_Timestamp execution_date,
@@ -534,80 +546,116 @@ handle_reserve_out (
   struct ReserveContext *rc = cls;
   struct ReserveSummary *rs;
   const struct TALER_EXCHANGEDB_DenominationKeyInformation *issue;
+  struct TALER_Amount auditor_amount;
+  struct TALER_Amount auditor_fee;
   struct TALER_Amount auditor_amount_with_fee;
   enum GNUNET_DB_QueryStatus qs;
-  struct TALER_DenominationHashP h_denom_pub;
 
   /* should be monotonically increasing */
-  GNUNET_assert (rowid >= TALER_ARL_USE_PP (reserves_reserve_out_serial_id));
-  TALER_ARL_USE_PP (reserves_reserve_out_serial_id) = rowid + 1;
+  GNUNET_assert (rowid >= TALER_ARL_USE_PP (reserves_withdraw_serial_id));
+  TALER_ARL_USE_PP (reserves_withdraw_serial_id) = rowid + 1;
 
-  /* lookup denomination pub data (make sure denom_pub is valid, establish fees);
-     initializes wsrd.h_denomination_pub! */
-  qs = TALER_ARL_get_denomination_info (denom_pub,
-                                        &issue,
-                                        &h_denom_pub);
-  if (0 > qs)
+  GNUNET_assert (GNUNET_OK == TALER_amount_set_zero (TALER_ARL_currency,
+                                                     &auditor_amount));
+  GNUNET_assert (GNUNET_OK == TALER_amount_set_zero (TALER_ARL_currency,
+                                                     &auditor_fee));
+  GNUNET_assert (GNUNET_OK == TALER_amount_set_zero (TALER_ARL_currency,
+                                                     &auditor_amount_with_fee));
+
+  for (size_t i = 0; i < num_evs; i++)
   {
-    GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
-    if (GNUNET_DB_STATUS_HARD_ERROR == qs)
-      GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  "Hard database error trying to get denomination %s (%s) from database!\n",
-                  TALER_B2S (denom_pub),
-                  TALER_amount2s (amount_with_fee));
-    rc->qs = qs;
-    return GNUNET_SYSERR;
-  }
-  if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
-  {
-    report_row_inconsistency ("withdraw",
-                              rowid,
-                              "denomination key not found");
-    if (global_qs < 0)
-      return GNUNET_SYSERR;
-    return GNUNET_OK;
-  }
-
-  /* check that execution date is within withdraw range for denom_pub  */
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "Checking withdraw timing: %llu, expire: %llu, timing: %llu\n",
-              (unsigned long long) issue->start.abs_time.abs_value_us,
-              (unsigned long long) issue->expire_withdraw.abs_time.abs_value_us,
-              (unsigned long long) execution_date.abs_time.abs_value_us);
-  if (GNUNET_TIME_timestamp_cmp (issue->start,
-                                 >,
-                                 execution_date) ||
-      GNUNET_TIME_timestamp_cmp (issue->expire_withdraw,
-                                 <,
-                                 execution_date))
-  {
-    struct TALER_AUDITORDB_DenominationKeyValidityWithdrawInconsistency dkvwi ={
-      .problem_row_id = rowid,
-      .execution_date = execution_date.abs_time,
-      .denompub_h = *&h_denom_pub,
-      .reserve_pub = *reserve_pub
-    };
-
-    qs =
-      TALER_ARL_adb->insert_denomination_key_validity_withdraw_inconsistency (
-        TALER_ARL_adb->cls,
-        &dkvwi);
-
-    if (qs < 0)
+    /* lookup denomination pub data (make sure denom_pub is valid, establish fees);
+       initializes wsrd.h_denomination_pub! */
+    qs = TALER_ARL_get_denomination_info_by_serial (denom_serials[i],
+                                                    &issue);
+    if (0 > qs)
     {
       GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+      if (GNUNET_DB_STATUS_HARD_ERROR == qs)
+        GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                    "Hard database error trying to get denomination by serial %lu (%s) from database!\n",
+                    denom_serials[i],
+                    GNUNET_h2s (&h_planchets->hash));
       rc->qs = qs;
       return GNUNET_SYSERR;
     }
+    if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
+    {
+      report_row_inconsistency ("withdraw",
+                                rowid,
+                                "denomination key not found");
+      if (global_qs < 0)
+        return GNUNET_SYSERR;
+      return GNUNET_OK;
+    }
+
+    /* check that execution date is within withdraw range for denom_pub  */
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+                "Checking withdraw timing: %llu, expire: %llu, timing: %llu\n",
+                (unsigned long long) issue->start.abs_time.abs_value_us,
+                (unsigned long
+                 long) issue->expire_withdraw.abs_time.abs_value_us,
+                (unsigned long long) execution_date.abs_time.abs_value_us);
+    if (GNUNET_TIME_timestamp_cmp (issue->start,
+                                   >,
+                                   execution_date) ||
+        GNUNET_TIME_timestamp_cmp (issue->expire_withdraw,
+                                   <,
+                                   execution_date))
+    {
+      struct TALER_AUDITORDB_DenominationKeyValidityWithdrawInconsistency
+        dkvwi ={
+        .problem_row_id = rowid,
+        .execution_date = execution_date.abs_time,
+        .denompub_h = issue->denom_hash,
+        .reserve_pub = *reserve_pub
+      };
+
+      qs =
+        TALER_ARL_adb->insert_denomination_key_validity_withdraw_inconsistency (
+          TALER_ARL_adb->cls,
+          &dkvwi);
+
+      if (qs < 0)
+      {
+        GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+        rc->qs = qs;
+        return GNUNET_SYSERR;
+      }
+    }
+    TALER_ARL_amount_add (&auditor_amount,
+                          &auditor_amount,
+                          &issue->value);
+    TALER_ARL_amount_add (&auditor_fee,
+                          &auditor_fee,
+                          &issue->fees.withdraw);
+    {
+      struct TALER_Amount issue_amount_with_fee;
+
+      TALER_ARL_amount_add (&issue_amount_with_fee,
+                            &issue->value,
+                            &issue->fees.withdraw);
+      TALER_ARL_amount_add (&auditor_amount_with_fee,
+                            &auditor_amount_with_fee,
+                            &issue_amount_with_fee);
+    }
   }
 
   /* check reserve_sig (first: setup remaining members of wsrd) */
   if (GNUNET_OK !=
-      TALER_wallet_withdraw_verify (&h_denom_pub,
-                                    amount_with_fee,
-                                    h_blind_ev,
-                                    reserve_pub,
-                                    reserve_sig))
+      TALER_wallet_withdraw_verify (
+        &auditor_amount,
+        &auditor_fee,
+        h_planchets,
+        blinding_seed,
+        age_proof_required
+          ? &issue->age_mask
+          : NULL,
+        age_proof_required
+          ? max_age
+          : 0,
+        reserve_pub,
+        reserve_sig))
   {
     struct TALER_AUDITORDB_BadSigLosses bsl = {
       .problem_row_id = rowid,
@@ -632,9 +680,6 @@ handle_reserve_out (
     return GNUNET_OK;     /* exit function here, we cannot add this to the legitimate withdrawals */
   }
 
-  TALER_ARL_amount_add (&auditor_amount_with_fee,
-                        &issue->value,
-                        &issue->fees.withdraw);
   if (0 !=
       TALER_amount_cmp (&auditor_amount_with_fee,
                         amount_with_fee))
@@ -1718,15 +1763,17 @@ verify_reserve_balance (void *cls,
 #define CHECK_DB() do {                                       \
           if (qs < 0) {                                       \
             GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs); \
-            return qs;                                        \
+            goto cleanup;                                     \
           }                                                   \
           if (global_qs < 0) {                                \
             GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == global_qs); \
-            return global_qs;                                        \
+            qs = global_qs;                                          \
+            goto cleanup;                                            \
           }                                                          \
           if (rc.qs < 0) {                                           \
             GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == rc.qs);     \
-            return rc.qs;                                            \
+            qs = rc.qs;                                              \
+            goto cleanup;                                            \
           }                                                          \
 } while (0)
 
@@ -1752,7 +1799,7 @@ analyze_reserves (void *cls)
   qs = TALER_ARL_adb->get_auditor_progress (
     TALER_ARL_adb->cls,
     TALER_ARL_GET_PP (reserves_reserve_in_serial_id),
-    TALER_ARL_GET_PP (reserves_reserve_out_serial_id),
+    TALER_ARL_GET_PP (reserves_withdraw_serial_id),
     TALER_ARL_GET_PP (reserves_reserve_recoup_serial_id),
     TALER_ARL_GET_PP (reserves_reserve_open_serial_id),
     TALER_ARL_GET_PP (reserves_reserve_close_serial_id),
@@ -1777,7 +1824,7 @@ analyze_reserves (void *cls)
                 (unsigned long long) TALER_ARL_USE_PP (
                   reserves_reserve_in_serial_id),
                 (unsigned long long) TALER_ARL_USE_PP (
-                  reserves_reserve_out_serial_id),
+                  reserves_withdraw_serial_id),
                 (unsigned long long) TALER_ARL_USE_PP (
                   reserves_reserve_recoup_serial_id),
                 (unsigned long long) TALER_ARL_USE_PP (
@@ -1825,8 +1872,8 @@ analyze_reserves (void *cls)
   CHECK_DB ();
   qs = TALER_ARL_edb->select_withdrawals_above_serial_id (
     TALER_ARL_edb->cls,
-    TALER_ARL_USE_PP (reserves_reserve_out_serial_id),
-    &handle_reserve_out,
+    TALER_ARL_USE_PP (reserves_withdraw_serial_id),
+    &handle_withdrawals,
     &rc);
   CHECK_DB ();
   qs = TALER_ARL_edb->select_recoup_above_serial_id (
@@ -1876,8 +1923,6 @@ analyze_reserves (void *cls)
   CHECK_DB ();
   GNUNET_break (0 ==
                 GNUNET_CONTAINER_multihashmap_size (rc.reserves));
-  GNUNET_CONTAINER_multihashmap_destroy (rc.reserves);
-  GNUNET_CONTAINER_multihashmap_destroy (rc.revoked);
 
   qs = TALER_ARL_adb->insert_balance (
     TALER_ARL_adb->cls,
@@ -1898,7 +1943,7 @@ analyze_reserves (void *cls)
   if (0 > qs)
   {
     GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
-    return qs;
+    goto cleanup;
   }
 
   qs = TALER_ARL_adb->update_balance (
@@ -1920,13 +1965,13 @@ analyze_reserves (void *cls)
   if (0 > qs)
   {
     GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
-    return qs;
+    goto cleanup;
   }
 
   qs = TALER_ARL_adb->insert_auditor_progress (
     TALER_ARL_adb->cls,
     TALER_ARL_SET_PP (reserves_reserve_in_serial_id),
-    TALER_ARL_SET_PP (reserves_reserve_out_serial_id),
+    TALER_ARL_SET_PP (reserves_withdraw_serial_id),
     TALER_ARL_SET_PP (reserves_reserve_recoup_serial_id),
     TALER_ARL_SET_PP (reserves_reserve_open_serial_id),
     TALER_ARL_SET_PP (reserves_reserve_close_serial_id),
@@ -1939,12 +1984,12 @@ analyze_reserves (void *cls)
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                 "Failed to update auditor DB, not recording progress\n");
     GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
-    return qs;
+    goto cleanup;
   }
   qs = TALER_ARL_adb->update_auditor_progress (
     TALER_ARL_adb->cls,
     TALER_ARL_SET_PP (reserves_reserve_in_serial_id),
-    TALER_ARL_SET_PP (reserves_reserve_out_serial_id),
+    TALER_ARL_SET_PP (reserves_withdraw_serial_id),
     TALER_ARL_SET_PP (reserves_reserve_recoup_serial_id),
     TALER_ARL_SET_PP (reserves_reserve_open_serial_id),
     TALER_ARL_SET_PP (reserves_reserve_close_serial_id),
@@ -1957,7 +2002,7 @@ analyze_reserves (void *cls)
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                 "Failed to update auditor DB, not recording progress\n");
     GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
-    return qs;
+    goto cleanup;
   }
 
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
@@ -1965,7 +2010,7 @@ analyze_reserves (void *cls)
               (unsigned long long) TALER_ARL_USE_PP (
                 reserves_reserve_in_serial_id),
               (unsigned long long) TALER_ARL_USE_PP (
-                reserves_reserve_out_serial_id),
+                reserves_withdraw_serial_id),
               (unsigned long long) TALER_ARL_USE_PP (
                 reserves_reserve_recoup_serial_id),
               (unsigned long long) TALER_ARL_USE_PP (
@@ -1978,7 +2023,11 @@ analyze_reserves (void *cls)
                 reserves_account_merges_serial_id),
               (unsigned long long) TALER_ARL_USE_PP (
                 reserves_history_requests_serial_id));
-  return GNUNET_DB_STATUS_SUCCESS_ONE_RESULT;
+  qs = GNUNET_DB_STATUS_SUCCESS_ONE_RESULT;
+cleanup:
+  GNUNET_CONTAINER_multihashmap_destroy (rc.reserves);
+  GNUNET_CONTAINER_multihashmap_destroy (rc.revoked);
+  return qs;
 }
 
 
