@@ -168,6 +168,11 @@ static TALER_ARL_DEF_AB (total_misattribution_in);
  */
 static TALER_ARL_DEF_AB (total_wire_in);
 
+/**
+ * Total amount credited to exchange accounts via KYCAUTH
+ */
+static TALER_ARL_DEF_AB (total_kycauth_in);
+
 /**
  * Total wire credit fees charged to the exchange account.
  */
@@ -336,15 +341,18 @@ rollback_and_reset (void)
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Serialization issue, trying again\n");
   TALER_ARL_adb->rollback (TALER_ARL_adb->cls);
-  GNUNET_CONTAINER_multihashmap_iterate (in_map,
-                                         &free_rii,
-                                         NULL);
-  GNUNET_CONTAINER_multihashmap_destroy (in_map);
-  in_map = NULL;
   for (unsigned int max_retries = 3; max_retries>0; max_retries--)
   {
     enum GNUNET_DB_QueryStatus qs;
 
+    if (NULL != in_map)
+    {
+      GNUNET_CONTAINER_multihashmap_iterate (in_map,
+                                             &free_rii,
+                                             NULL);
+      GNUNET_CONTAINER_multihashmap_destroy (in_map);
+      in_map = NULL;
+    }
     qs = begin_transaction ();
     if (GNUNET_DB_STATUS_HARD_ERROR == qs)
       break;
@@ -372,6 +380,7 @@ commit (enum GNUNET_DB_QueryStatus qs)
   qs = TALER_ARL_adb->update_balance (
     TALER_ARL_adb->cls,
     TALER_ARL_SET_AB (total_wire_in),
+    TALER_ARL_SET_AB (total_kycauth_in),
     TALER_ARL_SET_AB (total_wire_credit_fees),
     TALER_ARL_SET_AB (total_bad_amount_in_plus),
     TALER_ARL_SET_AB (total_bad_amount_in_minus),
@@ -382,6 +391,7 @@ commit (enum GNUNET_DB_QueryStatus qs)
   qs = TALER_ARL_adb->insert_balance (
     TALER_ARL_adb->cls,
     TALER_ARL_SET_AB (total_wire_in),
+    TALER_ARL_SET_AB (total_kycauth_in),
     TALER_ARL_SET_AB (total_wire_credit_fees),
     TALER_ARL_SET_AB (total_bad_amount_in_plus),
     TALER_ARL_SET_AB (total_bad_amount_in_minus),
@@ -704,6 +714,7 @@ process_credits (void *cls);
 static void
 conclude_account (struct WireAccount *wa)
 {
+  GNUNET_assert (NULL == wa->chh);
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Reconciling CREDIT processing of account `%s'\n",
               wa->ai->section_name);
@@ -741,8 +752,19 @@ analyze_credit (
   struct ReserveInInfo *rii;
   struct GNUNET_HashCode key;
 
-  GNUNET_assert (TALER_BANK_CT_RESERVE ==
-                 credit_details->type);
+  switch (credit_details->type)
+  {
+  case TALER_BANK_CT_RESERVE:
+    break;
+  case TALER_BANK_CT_KYCAUTH:
+    TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_kycauth_in),
+                          &TALER_ARL_USE_AB (total_kycauth_in),
+                          &credit_details->amount);
+    return true;
+  case TALER_BANK_CT_WAD:
+    GNUNET_break (0); /* FIXME: Wad not yet supported */
+    return false;
+  }
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Analyzing bank CREDIT #%llu at %s of %s with Reserve-pub %s\n",
               (unsigned long long) credit_details->serial_id,
@@ -1068,6 +1090,7 @@ process_credits (void *cls)
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "pass `%s'\n",
               wa->ai->auth->details.basic.password);
+  GNUNET_assert (NULL == wa->chh);
   wa->chh = TALER_BANK_credit_history (ctx,
                                        wa->ai->auth,
                                        wa->wire_off_in,
@@ -1137,6 +1160,7 @@ begin_transaction (void)
   qs = TALER_ARL_adb->get_balance (
     TALER_ARL_adb->cls,
     TALER_ARL_GET_AB (total_wire_in),
+    TALER_ARL_GET_AB (total_kycauth_in),
     TALER_ARL_GET_AB (total_wire_credit_fees),
     TALER_ARL_GET_AB (total_bad_amount_in_plus),
     TALER_ARL_GET_AB (total_bad_amount_in_minus),
@@ -1238,6 +1262,20 @@ db_notify (void *cls,
 
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Received notification to wake wire helper\n");
+  /* If there are accounts we are still processing, abort
+     the HTTP requests so we can start afresh. */
+  for (struct WireAccount *wa = wa_head;
+       NULL != wa;
+       wa = wa->next)
+  {
+    if (NULL != wa->chh)
+    {
+      TALER_BANK_credit_history_cancel (wa->chh);
+      wa->chh = NULL;
+    }
+    conclude_account (wa);
+  }
+
   if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS !=
       begin_transaction ())
   {
