@@ -1782,6 +1782,20 @@ db_notify (void *cls,
 
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Received notification to wake wire helper\n");
+  /* If there are accounts we are still processing, abort
+     the HTTP requests so we can start afresh. */
+  for (struct WireAccount *wa = wa_head;
+       NULL != wa;
+       wa = wa->next)
+  {
+    if (NULL != wa->dhh)
+    {
+      TALER_BANK_debit_history_cancel (wa->dhh);
+      wa->dhh = NULL;
+    }
+    check_exchange_wire_out (wa);
+  }
+
   if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS !=
       begin_transaction ())
   {
