@@ -62,22 +62,23 @@ bad_sig_losses_cb (void *cls,
 {
   struct BadSigLossesContext *dcc = cls;
   struct PostgresClosure *pg = dcc->pg;
-  GNUNET_log (GNUNET_ERROR_TYPE_INFO, "---found badsiglosses...\n");
-  GNUNET_log (GNUNET_ERROR_TYPE_INFO, "---num_results: %u\n", num_results);
 
   for (unsigned int i = 0; i < num_results; i++)
   {
-    uint64_t serial_id;
     struct TALER_AUDITORDB_BadSigLosses dc;
     struct GNUNET_PQ_ResultSpec rs[] = {
       GNUNET_PQ_result_spec_uint64 ("row_id",
-                                    &serial_id),
+                                    &dc.row_id),
+      GNUNET_PQ_result_spec_uint64 ("problem_row_id",
+                                    &dc.problem_row_id),
       GNUNET_PQ_result_spec_string ("operation",
                                     &dc.operation),
       TALER_PQ_RESULT_SPEC_AMOUNT ("loss",
                                    &dc.loss),
       GNUNET_PQ_result_spec_auto_from_type ("operation_specific_pub",
                                             &dc.operation_specific_pub),
+      GNUNET_PQ_result_spec_bool ("suppressed",
+                                  &dc.suppressed),
       GNUNET_PQ_result_spec_end
     };
     enum GNUNET_GenericReturnValue rval;
@@ -93,7 +94,6 @@ bad_sig_losses_cb (void *cls,
     }
     dcc->qs = i + 1;
     rval = dcc->cb (dcc->cb_cls,
-                    serial_id,
                     &dc);
     GNUNET_PQ_cleanup_result (rs);
     if (GNUNET_OK != rval)
@@ -108,27 +108,23 @@ TAH_PG_get_bad_sig_losses (
   int64_t limit,
   uint64_t offset,
   bool return_suppressed,
-  bool filter_spec_pub,
-  struct GNUNET_CRYPTO_EddsaPublicKey op_spec_pub,
+  const struct GNUNET_CRYPTO_EddsaPublicKey *op_spec_pub,
   const char *op,
   TALER_AUDITORDB_BadSigLossesCallback cb,
   void *cb_cls)
 {
   struct PostgresClosure *pg = cls;
   uint64_t plimit = (uint64_t) ((limit < 0) ? -limit : limit);
-  /*if true, does not filter for an operation specific key*/
-  bool any_spec_pub = ! filter_spec_pub;
-  /*if true, does not filter for an operation*/
-  bool any_op = (NULL == op) ? true : false;
-  const char *o = (NULL == op) ? "" : op;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&offset),
     GNUNET_PQ_query_param_bool (return_suppressed),
     GNUNET_PQ_query_param_uint64 (&plimit),
-    GNUNET_PQ_query_param_bool (any_spec_pub),
-    GNUNET_PQ_query_param_auto_from_type (&op_spec_pub),
-    GNUNET_PQ_query_param_bool (any_op),
-    GNUNET_PQ_query_param_string (o),
+    NULL == op_spec_pub
+    ? GNUNET_PQ_query_param_null ()
+    : GNUNET_PQ_query_param_auto_from_type (op_spec_pub),
+    NULL == op
+    ? GNUNET_PQ_query_param_null ()
+    : GNUNET_PQ_query_param_string (op),
     GNUNET_PQ_query_param_end
   };
   struct BadSigLossesContext dcc = {
@@ -142,14 +138,16 @@ TAH_PG_get_bad_sig_losses (
            "auditor_bad_sig_losses_get_desc",
            "SELECT"
            " row_id"
+           ",problem_row_id"
            ",operation"
            ",loss"
            ",operation_specific_pub"
+           ",suppressed"
            " FROM auditor_bad_sig_losses"
            " WHERE (row_id < $1)"
-           " AND ($2 OR suppressed is false)"
-           " AND ($4 OR operation_specific_pub = $5)"
-           " AND ($6 OR operation = $7)"
+           " AND ($2 OR NOT suppressed)"
+           " AND ($4::BYTEA IS NULL OR operation_specific_pub = $4)"
+           " AND ($5::TEXT IS NULL OR operation = $5)"
            " ORDER BY row_id DESC"
            " LIMIT $3"
            );
@@ -157,25 +155,27 @@ TAH_PG_get_bad_sig_losses (
            "auditor_bad_sig_losses_get_asc",
            "SELECT"
            " row_id"
+           ",problem_row_id"
            ",operation"
            ",loss"
            ",operation_specific_pub"
+           ",suppressed"
            " FROM auditor_bad_sig_losses"
            " WHERE (row_id > $1)"
-           " AND ($2 OR suppressed is false)"
-           " AND ($4 OR operation_specific_pub = $5)"
-           " AND ($6 OR operation = $7)"
+           " AND ($2 OR NOT suppressed)"
+           " AND ($4::BYTEA IS NULL OR operation_specific_pub = $4)"
+           " AND ($5::TEXT IS NULL OR operation = $5)"
            " ORDER BY row_id ASC"
            " LIMIT $3"
            );
-  qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
-                                             (limit > 0)
-                                             ? "auditor_bad_sig_losses_get_asc"
-                                             : "auditor_bad_sig_losses_get_desc",
-                                             params,
-                                             &bad_sig_losses_cb,
-                                             &dcc);
-
+  qs = GNUNET_PQ_eval_prepared_multi_select (
+    pg->conn,
+    (limit > 0)
+    ? "auditor_bad_sig_losses_get_asc"
+    : "auditor_bad_sig_losses_get_desc",
+    params,
+    &bad_sig_losses_cb,
+    &dcc);
   if (qs > 0)
     return dcc.qs;
   GNUNET_break (GNUNET_DB_STATUS_HARD_ERROR != qs);
