@@ -13,9 +13,8 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-
-#ifndef SRC_PG_GET_BAD_SIG_LOSSES_H
-#define SRC_PG_GET_BAD_SIG_LOSSES_H
+#ifndef PG_GET_BAD_SIG_LOSSES_H
+#define PG_GET_BAD_SIG_LOSSES_H
 
 #include "taler_util.h"
 #include "taler_json_lib.h"
@@ -28,7 +27,6 @@
  * @param limit number of records to return, negative for descending
  * @param offset table row to start from, exclusive, direction determined by @a limit
  * @param return_suppressed should suppressed rows be returned anyway?
- * @param filter_spec_pub filter by @a op_spec_pub
  * @param op_spec_pub public key to filter by; FIXME: replace by pointer
  * @param op operation to filter by
  * @param cb function to call with results
@@ -41,8 +39,7 @@ TAH_PG_get_bad_sig_losses (
   int64_t limit,
   uint64_t offset,
   bool return_suppressed,
-  bool filter_spec_pub,
-  struct GNUNET_CRYPTO_EddsaPublicKey op_spec_pub,
+  const struct GNUNET_CRYPTO_EddsaPublicKey *op_spec_pub,
   const char *op,
   TALER_AUDITORDB_BadSigLossesCallback cb,
   void *cb_cls);
