@@ -65,11 +65,8 @@ balances_cb (void *cls,
 
   for (unsigned int i = 0; i < num_results; i++)
   {
-    uint64_t serial_id;
     struct TALER_AUDITORDB_Balances dc;
     struct GNUNET_PQ_ResultSpec rs[] = {
-      GNUNET_PQ_result_spec_uint64 ("row_id",
-                                    &serial_id),
       GNUNET_PQ_result_spec_string ("balance_key",
                                     &dc.balance_key),
       TALER_PQ_RESULT_SPEC_AMOUNT ("balance_value",
@@ -89,7 +86,6 @@ balances_cb (void *cls,
     }
     dcc->qs = i + 1;
     rval = dcc->cb (dcc->cb_cls,
-                    serial_id,
                     &dc);
     GNUNET_PQ_cleanup_result (rs);
     if (GNUNET_OK != rval)
@@ -101,21 +97,15 @@ balances_cb (void *cls,
 enum GNUNET_DB_QueryStatus
 TAH_PG_get_balances (
   void *cls,
-  int64_t limit,
-  uint64_t offset,
   const char *balance_key,
   TALER_AUDITORDB_BalancesCallback cb,
   void *cb_cls)
 {
   struct PostgresClosure *pg = cls;
-  bool any_balance = (NULL == balance_key);
-  uint64_t plimit = (uint64_t) ((limit < 0) ? -limit : limit);
-  const char *bk = (any_balance) ? "" : balance_key;
   struct GNUNET_PQ_QueryParam params[] = {
-    GNUNET_PQ_query_param_uint64 (&offset),
-    GNUNET_PQ_query_param_uint64 (&plimit),
-    GNUNET_PQ_query_param_bool (any_balance),
-    GNUNET_PQ_query_param_string (bk),
+    NULL == balance_key
+    ? GNUNET_PQ_query_param_null ()
+    : GNUNET_PQ_query_param_string (balance_key),
     GNUNET_PQ_query_param_end
   };
   struct BalancesContext dcc = {
@@ -126,34 +116,16 @@ TAH_PG_get_balances (
   enum GNUNET_DB_QueryStatus qs;
 
   PREPARE (pg,
-           "auditor_balances_get_desc",
+           "auditor_balances_get",
            "SELECT"
-           " row_id,"
-           " balance_key,"
-           " balance_value"
+           " balance_key"
+           ",balance_value"
            " FROM auditor_balances"
-           " WHERE (row_id < $1)"
-           "   AND ($3 OR balance_key = $4)"
-           " ORDER BY row_id DESC"
-           " LIMIT $2"
-           );
-  PREPARE (pg,
-           "auditor_balances_get_asc",
-           "SELECT"
-           " row_id,"
-           " balance_key,"
-           " balance_value"
-           " FROM auditor_balances"
-           " WHERE (row_id > $1)"
-           "   AND ($3 OR balance_key = $4)"
-           " ORDER BY row_id ASC"
-           " LIMIT $2"
+           " WHERE ($1::TEXT IS NULL OR balance_key = $1)"
            );
   qs = GNUNET_PQ_eval_prepared_multi_select (
     pg->conn,
-    (limit > 0)
-    ? "auditor_balances_get_asc"
-    : "auditor_balances_get_desc",
+    "auditor_balances_get",
     params,
     &balances_cb,
     &dcc);
