@@ -68,14 +68,18 @@ misattribution_in_inconsistency_cb (void *cls,
 
   for (unsigned int i = 0; i < num_results; i++)
   {
-    uint64_t serial_id;
     struct TALER_AUDITORDB_MisattributionInInconsistency dc;
     struct GNUNET_PQ_ResultSpec rs[] = {
-      GNUNET_PQ_result_spec_uint64 ("row_id", &serial_id),
-      TALER_PQ_RESULT_SPEC_AMOUNT ("amount", &dc.amount),
-      GNUNET_PQ_result_spec_uint64 ("bank_row", &dc.bank_row),
-      GNUNET_PQ_result_spec_auto_from_type ("reserve_pub", &dc.reserve_pub),
-      GNUNET_PQ_result_spec_bool ("suppressed", &dc.suppressed),
+      GNUNET_PQ_result_spec_uint64 ("row_id",
+                                    &dc.row_id),
+      TALER_PQ_RESULT_SPEC_AMOUNT ("amount",
+                                   &dc.amount),
+      GNUNET_PQ_result_spec_uint64 ("bank_row",
+                                    &dc.bank_row),
+      GNUNET_PQ_result_spec_auto_from_type ("reserve_pub",
+                                            &dc.reserve_pub),
+      GNUNET_PQ_result_spec_bool ("suppressed",
+                                  &dc.suppressed),
       GNUNET_PQ_result_spec_end
     };
     enum GNUNET_GenericReturnValue rval;
@@ -91,7 +95,6 @@ misattribution_in_inconsistency_cb (void *cls,
     }
     dcc->qs = i + 1;
     rval = dcc->cb (dcc->cb_cls,
-                    serial_id,
                     &dc);
     GNUNET_PQ_cleanup_result (rs);
     if (GNUNET_OK != rval)
@@ -105,14 +108,12 @@ TAH_PG_get_misattribution_in_inconsistency (
   void *cls,
   int64_t limit,
   uint64_t offset,
-  bool return_suppressed,             // maybe not needed
+  bool return_suppressed,
   TALER_AUDITORDB_MisattributionInInconsistencyCallback cb,
   void *cb_cls)
 {
-
-  uint64_t plimit = (uint64_t) ((limit < 0) ? -limit : limit);
-
   struct PostgresClosure *pg = cls;
+  uint64_t plimit = (uint64_t) ((limit < 0) ? -limit : limit);
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&offset),
     GNUNET_PQ_query_param_bool (return_suppressed),
@@ -129,42 +130,39 @@ TAH_PG_get_misattribution_in_inconsistency (
   PREPARE (pg,
            "auditor_misattribution_in_inconsistency_get_desc",
            "SELECT"
-           " row_id,"
-           " amount,"
-           " bank_row,"
-           " reserve_pub,"
-           " suppressed"
+           " row_id"
+           ",amount"
+           ",bank_row"
+           ",reserve_pub"
+           ",suppressed"
            " FROM auditor_misattribution_in_inconsistency"
            " WHERE (row_id < $1)"
-           " AND ($2 OR suppressed is false)"
+           " AND ($2 OR NOT suppressed)"
            " ORDER BY row_id DESC"
            " LIMIT $3"
            );
   PREPARE (pg,
            "auditor_misattribution_in_inconsistency_get_asc",
            "SELECT"
-           " row_id,"
-           " amount,"
-           " bank_row,"
-           " reserve_pub,"
-           " suppressed"
+           " row_id"
+           ",amount"
+           ",bank_row"
+           ",reserve_pub"
+           ",suppressed"
            " FROM auditor_misattribution_in_inconsistency"
            " WHERE (row_id > $1)"
-           " AND ($2 OR suppressed is false)"
+           " AND ($2 OR NOT suppressed)"
            " ORDER BY row_id ASC"
            " LIMIT $3"
            );
-  qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
-                                             (limit > 0)
-                                             ?
-                                             "auditor_misattribution_in_inconsistency_get_asc"
-                                             :
-                                             "auditor_misattribution_in_inconsistency_get_desc",
-                                             params,
-                                             &misattribution_in_inconsistency_cb
-                                             ,
-                                             &dcc);
-
+  qs = GNUNET_PQ_eval_prepared_multi_select (
+    pg->conn,
+    (limit > 0)
+    ? "auditor_misattribution_in_inconsistency_get_asc"
+    : "auditor_misattribution_in_inconsistency_get_desc",
+    params,
+    &misattribution_in_inconsistency_cb,
+    &dcc);
   if (qs > 0)
     return dcc.qs;
   GNUNET_break (GNUNET_DB_STATUS_HARD_ERROR != qs);
