@@ -53,6 +53,7 @@ TAH_PG_insert_deposit_confirmation (
     GNUNET_PQ_query_param_auto_from_type (&dc->master_sig),
     GNUNET_PQ_query_param_end
   };
+  enum GNUNET_DB_QueryStatus qs;
 
   PREPARE (pg,
            "auditor_deposit_confirmation_insert",
@@ -71,7 +72,9 @@ TAH_PG_insert_deposit_confirmation (
            ",exchange_pub"
            ",master_sig"                  /* master_sig could be normalized... */
            ") VALUES ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13);");
-  return GNUNET_PQ_eval_prepared_non_select (pg->conn,
-                                             "auditor_deposit_confirmation_insert",
-                                             params);
+  qs = GNUNET_PQ_eval_prepared_non_select (pg->conn,
+                                           "auditor_deposit_confirmation_insert",
+                                           params);
+  GNUNET_PQ_cleanup_query_params_closures (params);
+  return qs;
 }
