@@ -29,16 +29,16 @@ TAH_PG_insert_wire_format_inconsistency (
     TALER_PQ_query_param_amount (pg->conn,
                                  &dc->amount),
     GNUNET_PQ_query_param_uint64 (&dc->wire_offset),
-    GNUNET_PQ_query_param_auto_from_type (&dc->diagnostic),
+    GNUNET_PQ_query_param_string (dc->diagnostic),
     GNUNET_PQ_query_param_end
   };
 
   PREPARE (pg,
            "auditor_wire_format_inconsistency_insert",
            "INSERT INTO auditor_wire_format_inconsistency "
-           "(amount,"
-           " wire_offset,"
-           " diagnostic"
+           "(amount"
+           ",wire_offset"
+           ",diagnostic"
            ") VALUES ($1,$2,$3);"
            );
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
