@@ -118,7 +118,10 @@ TAH_PG_select_historic_reserve_revenue (
   void *cb_cls)
 {
   struct PostgresClosure *pg = cls;
+  uint64_t ulimit = (limit > 0) ? limit : -limit;
   struct GNUNET_PQ_QueryParam params[] = {
+    GNUNET_PQ_query_param_uint64 (&offset),
+    GNUNET_PQ_query_param_uint64 (&ulimit),
     GNUNET_PQ_query_param_end
   };
   enum GNUNET_DB_QueryStatus qs;
@@ -128,20 +131,36 @@ TAH_PG_select_historic_reserve_revenue (
     .pg = pg
   };
 
-  // FIXME: use limit/offset!
   PREPARE (pg,
-           "auditor_historic_reserve_summary_select",
+           "auditor_historic_reserve_summary_select_inc",
            "SELECT"
            " row_id"
            ",start_date"
            ",end_date"
            ",reserve_profits"
-           " FROM auditor_historic_reserve_summary");
-  qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
-                                             "auditor_historic_reserve_summary_select",
-                                             params,
-                                             &historic_reserve_revenue_cb,
-                                             &hrc);
+           " FROM auditor_historic_reserve_summary"
+           " WHERE row_id > $1"
+           " ORDER BY row_id ASC"
+           " LIMIT $2");
+  PREPARE (pg,
+           "auditor_historic_reserve_summary_select_dec",
+           "SELECT"
+           " row_id"
+           ",start_date"
+           ",end_date"
+           ",reserve_profits"
+           " FROM auditor_historic_reserve_summary"
+           " WHERE row_id < $1"
+           " ORDER BY row_id DESC"
+           " LIMIT $2");
+  qs = GNUNET_PQ_eval_prepared_multi_select (
+    pg->conn,
+    limit > 0
+    ? "auditor_historic_reserve_summary_select_inc"
+    : "auditor_historic_reserve_summary_select_dec",
+    params,
+    &historic_reserve_revenue_cb,
+    &hrc);
   if (0 >= qs)
     return qs;
   return hrc.qs;
