@@ -26,6 +26,7 @@
 #include "taler_bank_service.h"
 #include "taler_mhd_lib.h"
 #include <gnunet/gnunet_mhd_compat.h>
+#include <gnunet/gnunet_mhd_lib.h>
 #include "fakebank.h"
 #include "fakebank_bank_testing_register.h"
 
@@ -39,36 +40,36 @@ TALER_FAKEBANK_bank_testing_register_ (
   void **con_cls)
 {
   struct ConnectionContext *cc = *con_cls;
-  enum GNUNET_JSON_PostResult pr;
+  enum GNUNET_MHD_PostResult pr;
   json_t *json;
   MHD_RESULT res;
 
   if (NULL == cc)
   {
     cc = GNUNET_new (struct ConnectionContext);
-    cc->ctx_cleaner = &GNUNET_JSON_post_parser_cleanup;
+    cc->ctx_cleaner = &GNUNET_MHD_post_parser_cleanup;
     *con_cls = cc;
   }
-  pr = GNUNET_JSON_post_parser (REQUEST_BUFFER_MAX,
-                                connection,
-                                &cc->ctx,
-                                upload_data,
-                                upload_data_size,
-                                &json);
+  pr = GNUNET_MHD_post_parser (REQUEST_BUFFER_MAX,
+                               connection,
+                               &cc->ctx,
+                               upload_data,
+                               upload_data_size,
+                               &json);
   switch (pr)
   {
-  case GNUNET_JSON_PR_OUT_OF_MEMORY:
+  case GNUNET_MHD_PR_OUT_OF_MEMORY:
     GNUNET_break (0);
     return MHD_NO;
-  case GNUNET_JSON_PR_CONTINUE:
+  case GNUNET_MHD_PR_CONTINUE:
     return MHD_YES;
-  case GNUNET_JSON_PR_REQUEST_TOO_LARGE:
+  case GNUNET_MHD_PR_REQUEST_TOO_LARGE:
     GNUNET_break (0);
     return MHD_NO;
-  case GNUNET_JSON_PR_JSON_INVALID:
+  case GNUNET_MHD_PR_JSON_INVALID:
     GNUNET_break (0);
     return MHD_NO;
-  case GNUNET_JSON_PR_SUCCESS:
+  case GNUNET_MHD_PR_SUCCESS:
     break;
   }
 
