@@ -28,6 +28,7 @@
 #include "taler_mhd_lib.h"
 #include <gnunet/gnunet_mhd_compat.h>
 #include "fakebank.h"
+#include "fakebank_twg_history.h"
 #include "fakebank_common_lookup.h"
 #include "fakebank_common_lp.h"
 #include "fakebank_common_parser.h"
@@ -288,7 +289,7 @@ finish:
                                    0);
   }
   {
-    json_t *h = hc->history;
+    json_t *jh = hc->history;
 
     hc->history = NULL;
     return TALER_MHD_REPLY_JSON_PACK (
@@ -299,7 +300,7 @@ finish:
         acc_payto_uri),
       GNUNET_JSON_pack_array_steal (
         "outgoing_transactions",
-        h));
+        jh));
   }
 }
 
@@ -454,7 +455,8 @@ TALER_FAKEBANK_twg_get_credit_history_ (
   {
     json_t *trans;
 
-    if (T_CREDIT != pos->type)
+    if ( (T_CREDIT != pos->type) &&
+         (T_AUTH != pos->type) )
     {
       GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                   "Unexpected DEBIT transaction #%llu for account `%s'\n",
@@ -466,17 +468,59 @@ TALER_FAKEBANK_twg_get_credit_history_ (
         pos = pos->next_in;
       continue;
     }
-    trans = GNUNET_JSON_PACK (
-      GNUNET_JSON_pack_uint64 ("row_id",
-                               pos->row_id),
-      GNUNET_JSON_pack_timestamp ("date",
-                                  pos->date),
-      TALER_JSON_pack_amount ("amount",
-                              &pos->amount),
-      GNUNET_JSON_pack_string ("debit_account",
-                               pos->debit_account->payto_uri),
-      GNUNET_JSON_pack_data_auto ("reserve_pub",
-                                  &pos->subject.credit.reserve_pub));
+    switch (pos->type)
+    {
+    case T_DEBIT:
+      GNUNET_assert (0);
+      break;
+    case T_WAD:
+      trans = GNUNET_JSON_PACK (
+        GNUNET_JSON_pack_string ("type",
+                                 "WAD"),
+        GNUNET_JSON_pack_uint64 ("row_id",
+                                 pos->row_id),
+        GNUNET_JSON_pack_timestamp ("date",
+                                    pos->date),
+        TALER_JSON_pack_amount ("amount",
+                                &pos->amount),
+        GNUNET_JSON_pack_string ("debit_account",
+                                 pos->debit_account->payto_uri),
+        GNUNET_JSON_pack_string ("origin_exchange_url",
+                                 pos->subject.wad.origin_base_url),
+        GNUNET_JSON_pack_data_auto ("wad_id",
+                                    &pos->subject.wad.wad_id));
+      break;
+    case T_CREDIT:
+      trans = GNUNET_JSON_PACK (
+        GNUNET_JSON_pack_string ("type",
+                                 "RESERVE"),
+        GNUNET_JSON_pack_uint64 ("row_id",
+                                 pos->row_id),
+        GNUNET_JSON_pack_timestamp ("date",
+                                    pos->date),
+        TALER_JSON_pack_amount ("amount",
+                                &pos->amount),
+        GNUNET_JSON_pack_string ("debit_account",
+                                 pos->debit_account->payto_uri),
+        GNUNET_JSON_pack_data_auto ("reserve_pub",
+                                    &pos->subject.credit.reserve_pub));
+      break;
+    case T_AUTH:
+      trans = GNUNET_JSON_PACK (
+        GNUNET_JSON_pack_string ("type",
+                                 "KYCAUTH"),
+        GNUNET_JSON_pack_uint64 ("row_id",
+                                 pos->row_id),
+        GNUNET_JSON_pack_timestamp ("date",
+                                    pos->date),
+        TALER_JSON_pack_amount ("amount",
+                                &pos->amount),
+        GNUNET_JSON_pack_string ("debit_account",
+                                 pos->debit_account->payto_uri),
+        GNUNET_JSON_pack_data_auto ("account_pub",
+                                    &pos->subject.auth.account_pub));
+      break;
+    }
     GNUNET_assert (NULL != trans);
     GNUNET_assert (0 ==
                    json_array_append_new (hc->history,
@@ -521,7 +565,7 @@ finish:
                                    0);
   }
   {
-    json_t *h = hc->history;
+    json_t *jh = hc->history;
 
     hc->history = NULL;
     return TALER_MHD_REPLY_JSON_PACK (
@@ -532,6 +576,6 @@ finish:
         acc_payto_uri),
       GNUNET_JSON_pack_array_steal (
         "incoming_transactions",
-        h));
+        jh));
   }
 }
