@@ -22,9 +22,8 @@
  * @author Marcello Stanisci
  * @author Christian Grothoff
  */
-// TODO:
-// - use more than one 'client' bank account
-// - also add taler-exchange-transfer to simulate outgoing payments
+// FIXME: support use of more than one 'client' bank account
+// FIXME: add taler-exchange-transfer to simulate outgoing payments
 #include "platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <microhttpd.h>
@@ -214,7 +213,7 @@ run (void *cls,
     GNUNET_asprintf (&create_reserve_label,
                      "createreserve-%u",
                      j);
-    // TODO: vary user accounts more...
+    // FIXME: vary user accounts more...
     all_commands[1 + j]
       = TALER_TESTING_cmd_admin_add_incoming_retry (
           TALER_TESTING_cmd_admin_add_incoming (add_label (
@@ -488,9 +487,9 @@ main (int argc,
     return EXIT_INVALIDARGUMENT;
   }
   if (NULL == exchange_bank_section)
-    exchange_bank_section = "exchange-account-1";
+    exchange_bank_section = (char *) "exchange-account-1";
   if (NULL == loglev)
-    loglev = "INFO";
+    loglev = (char *) "INFO";
   GNUNET_log_setup ("taler-bank-benchmark",
                     loglev,
                     logfile);
