@@ -320,16 +320,11 @@ run (void *cls,
                                     MHD_HTTP_OK,
                                     NULL));
         unit[3] =
-          TALER_TESTING_cmd_refresh_reveal_with_retry (
-            TALER_TESTING_cmd_refresh_reveal (rl,
-                                              ml,
-                                              MHD_HTTP_OK));
-        unit[4] =
-          TALER_TESTING_cmd_refresh_link_with_retry (
-            TALER_TESTING_cmd_refresh_link ("link",
-                                            rl,
-                                            MHD_HTTP_OK));
-        unit[5] = TALER_TESTING_cmd_end ();
+          TALER_TESTING_cmd_melt_reveal_with_retry (
+            TALER_TESTING_cmd_melt_reveal (rl,
+                                           ml,
+                                           MHD_HTTP_OK));
+        unit[4] = TALER_TESTING_cmd_end ();
       }
       else
         unit[2] = TALER_TESTING_cmd_end ();
