@@ -21,6 +21,7 @@
 #include <platform.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_util_lib.h>
+#include <microhttpd.h>
 #include "taler_json_lib.h"
 #include "taler_exchange_service.h"
 
@@ -187,6 +188,7 @@ kyc_wallet_cb (
                                        CFG_exchange_url,
                                        &h_payto,
                                        &pk,
+                                       0,
                                        TALER_EXCHANGE_KLPT_NONE,
                                        GNUNET_TIME_UNIT_ZERO,
                                        &kyc_status_cb,
