@@ -660,6 +660,7 @@ commit_aggregation (struct AggregationUnit *au)
         db_plugin,
         &attribute_key,
         &au->h_normalized_payto,
+        false, /* aggregation doesn't apply to wallets */
         &evaluate_rules,
         au);
       if (NULL != au->ru)
@@ -801,6 +802,7 @@ evaluate_rules (
         db_plugin,
         &attribute_key,
         &au->h_normalized_payto,
+        false, /* aggregation does not apply to wallets */
         &evaluate_rules,
         au);
       if (NULL != au->ru)
@@ -1199,6 +1201,7 @@ run_aggregation (void *cls)
                          &au->h_full_payto);
   TALER_full_payto_normalize_and_hash (au->payto_uri,
                                        &au->h_normalized_payto);
+  GNUNET_break (! TALER_payto_is_wallet (au->payto_uri.full_payto));
   do_aggregate (au);
 }
 
@@ -1314,8 +1317,8 @@ drain_kyc_alerts (void *cls)
       db_plugin->rollback (db_plugin->cls);
       GNUNET_free (au);
       GNUNET_assert (NULL == task);
-      task = GNUNET_SCHEDULER_add_now (&drain_kyc_alerts,
-                                       NULL);
+      global_ret = EXIT_FAILURE;
+      GNUNET_SCHEDULER_shutdown ();
       return;
     case GNUNET_DB_STATUS_SOFT_ERROR:
       db_plugin->rollback (db_plugin->cls);
@@ -1326,10 +1329,7 @@ drain_kyc_alerts (void *cls)
       return;
     case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
       GNUNET_free (au);
-      qs = db_plugin->commit (db_plugin->cls);
-      if (qs < 0)
-        GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                    "Failed to commit KYC drain\n");
+      db_plugin->rollback (db_plugin->cls);
       GNUNET_assert (NULL == task);
       task = GNUNET_SCHEDULER_add_now (&run_shard,
                                        NULL);
