@@ -32,17 +32,17 @@
 #include "taler_templating_lib.h"
 #include "taler_mhd_lib.h"
 #include "taler-exchange-httpd_withdraw.h"
-#include "taler-exchange-httpd_age-withdraw_reveal.h"
 #include "taler-exchange-httpd_aml-attributes-get.h"
 #include "taler-exchange-httpd_aml-decision.h"
 #include "taler-exchange-httpd_aml-statistics-get.h"
+#include "taler-exchange-httpd_aml-transfer-get.h"
 #include "taler-exchange-httpd_aml-measures-get.h"
 #include "taler-exchange-httpd_auditors.h"
 #include "taler-exchange-httpd_batch-deposit.h"
+#include "taler-exchange-httpd_blinding-prepare.h"
 #include "taler-exchange-httpd_coins_get.h"
 #include "taler-exchange-httpd_config.h"
 #include "taler-exchange-httpd_contract.h"
-#include "taler-exchange-httpd_csr.h"
 #include "taler-exchange-httpd_deposits_get.h"
 #include "taler-exchange-httpd_extensions.h"
 #include "taler-exchange-httpd_keys.h"
@@ -55,9 +55,8 @@
 #include "taler-exchange-httpd_kyc-webhook.h"
 #include "taler-exchange-httpd_aml-decision.h"
 #include "taler-exchange-httpd_legitimization-measures-get.h"
-#include "taler-exchange-httpd_link.h"
 #include "taler-exchange-httpd_management.h"
-#include "taler-exchange-httpd_melt.h"
+#include "taler-exchange-httpd_melt_v27.h"
 #include "taler-exchange-httpd_metrics.h"
 #include "taler-exchange-httpd_mhd.h"
 #include "taler-exchange-httpd_purses_create.h"
@@ -67,7 +66,6 @@
 #include "taler-exchange-httpd_purses_merge.h"
 #include "taler-exchange-httpd_recoup.h"
 #include "taler-exchange-httpd_recoup-refresh.h"
-#include "taler-exchange-httpd_refreshes_reveal.h"
 #include "taler-exchange-httpd_refund.h"
 #include "taler-exchange-httpd_reserves_attest.h"
 #include "taler-exchange-httpd_reserves_close.h"
@@ -76,6 +74,8 @@
 #include "taler-exchange-httpd_reserves_history.h"
 #include "taler-exchange-httpd_reserves_open.h"
 #include "taler-exchange-httpd_reserves_purse.h"
+#include "taler-exchange-httpd_reveal-withdraw.h"
+#include "taler-exchange-httpd_reveal-melt.h"
 #include "taler-exchange-httpd_spa.h"
 #include "taler-exchange-httpd_terms.h"
 #include "taler-exchange-httpd_transfers_get.h"
@@ -376,10 +376,7 @@ handle_post_coins (struct TEH_RequestContext *rc,
     CoinOpHandler handler;
 
   } h[] = {
-    {
-      .op = "melt",
-      .handler = &TEH_handler_melt
-    },
+#if FIXME_9828
     {
       .op = "recoup",
       .handler = &TEH_handler_recoup
@@ -388,6 +385,7 @@ handle_post_coins (struct TEH_RequestContext *rc,
       .op = "recoup-refresh",
       .handler = &TEH_handler_recoup_refresh
     },
+#endif
     {
       .op = "refund",
       .handler = &TEH_handler_refund
@@ -460,10 +458,6 @@ handle_get_coins (struct TEH_RequestContext *rc,
                      "history"))
       return TEH_handler_coins_get (rc,
                                     &coin_pub);
-    if (0 == strcmp (args[1],
-                     "link"))
-      return TEH_handler_link (rc,
-                               &coin_pub);
   }
   return TALER_MHD_reply_with_error (rc->connection,
                                      MHD_HTTP_NOT_FOUND,
@@ -610,6 +604,14 @@ handle_get_aml (struct TEH_RequestContext *rc,
       .op = "measures",
       .handler = &TEH_handler_aml_measures_get
     },
+    {
+      .op = "transfers-credit",
+      .handler = &TEH_handler_aml_transfer_credit_get
+    },
+    {
+      .op = "transfers-debit",
+      .handler = &TEH_handler_aml_transfer_debit_get
+    },
     {
       .op = NULL,
       .handler = NULL
@@ -709,46 +711,6 @@ handle_get_aml (struct TEH_RequestContext *rc,
 }
 
 
-/**
- * Handle a "/age-withdraw/$ACH/reveal" POST request.  Parses the "ACH"
- * hash of the commitment from a previous call to
- * /reserves/$reserve_pub/age-withdraw
- *
- * @param rc request context
- * @param root uploaded JSON data
- * @param args array of additional options
- * @return MHD result code
- */
-static MHD_RESULT
-handle_post_age_withdraw (struct TEH_RequestContext *rc,
-                          const json_t *root,
-                          const char *const args[2])
-{
-  struct TALER_AgeWithdrawCommitmentHashP ach;
-
-  if (0 != strcmp ("reveal", args[1]))
-    return r404 (rc->connection,
-                 args[1]);
-
-  if (GNUNET_OK !=
-      GNUNET_STRINGS_string_to_data (args[0],
-                                     strlen (args[0]),
-                                     &ach,
-                                     sizeof (ach)))
-  {
-    GNUNET_break_op (0);
-    return TALER_MHD_reply_with_error (rc->connection,
-                                       MHD_HTTP_BAD_REQUEST,
-                                       TALER_EC_GENERIC_RESERVE_PUB_MALFORMED,
-                                       args[0]);
-  }
-
-  return TEH_handler_age_withdraw_reveal (rc,
-                                          &ach,
-                                          root);
-}
-
-
 /**
  * Signature of functions that handle operations on reserves.
  *
@@ -791,14 +753,6 @@ handle_post_reserves (struct TEH_RequestContext *rc,
     ReserveOpHandler handler;
 
   } h[] = {
-    {
-      .op = "batch-withdraw",
-      .handler = &TEH_handler_batch_withdraw
-    },
-    {
-      .op = "age-withdraw",
-      .handler = &TEH_handler_age_withdraw
-    },
     {
       .op = "purse",
       .handler = &TEH_handler_reserves_purse
@@ -1699,20 +1653,20 @@ handle_mhd_request (void *cls,
       .handler.post = &TEH_handler_batch_deposit,
       .nargs = 0
     },
-    /* request R, used in clause schnorr withdraw and refresh */
+    /* request R's input for Clause-Schnorr signatures in batches */
     {
-      .url = "csr-melt",
+      .url = "blinding-prepare",
       .method = MHD_HTTP_METHOD_POST,
-      .handler.post = &TEH_handler_csr_melt,
+      .handler.post = &TEH_handler_blinding_prepare,
       .nargs = 0
     },
+    /* withdraw request, available since v26 of the API */
     {
-      .url = "csr-withdraw",
+      .url = "withdraw",
       .method = MHD_HTTP_METHOD_POST,
-      .handler.post = &TEH_handler_csr_withdraw,
+      .handler.post = &TEH_handler_withdraw,
       .nargs = 0
     },
-    /* Withdrawing coins / interaction with reserves */
     {
       .url = "reserves",
       .method = MHD_HTTP_METHOD_GET,
@@ -1726,11 +1680,19 @@ handle_mhd_request (void *cls,
       .handler.post = &handle_post_reserves,
       .nargs = 2
     },
+    /* reveal-withdraw operation, introduced with v26 */
     {
-      .url = "age-withdraw",
+      .url = "reveal-withdraw",
       .method = MHD_HTTP_METHOD_POST,
-      .handler.post = &handle_post_age_withdraw,
-      .nargs = 2
+      .handler.post = &TEH_handler_reveal_withdraw,
+      .nargs = 0
+    },
+    /* reveal-melt operation, introduced with v27 */
+    {
+      .url = "reveal-melt",
+      .method = MHD_HTTP_METHOD_POST,
+      .handler.post = &TEH_handler_reveal_melt,
+      .nargs = 0
     },
     {
       .url = "reserves-attest",
@@ -1758,12 +1720,12 @@ handle_mhd_request (void *cls,
       .nargs = 2,
       .nargs_is_upper_bound = true
     },
-    /* refreshes/$RCH/reveal */
+    /* melting operation, introduced with v26 */
     {
-      .url = "refreshes",
+      .url = "melt",
       .method = MHD_HTTP_METHOD_POST,
-      .handler.post = &TEH_handler_reveal,
-      .nargs = 2
+      .handler.post = &TEH_handler_melt_v27,
+      .nargs = 0
     },
     /* tracking transfers */
     {
@@ -1845,6 +1807,13 @@ handle_mhd_request (void *cls,
       .handler.get = &TEH_handler_kyc_info,
       .nargs = 1
     },
+    {
+      .url = "kyc-upload",
+      .method = MHD_HTTP_METHOD_POST,
+      .handler.post = &TEH_handler_kyc_upload,
+      .nargs = 1,
+      .nargs_is_upper_bound = true
+    },
     {
       .url = "kyc-webhook",
       .method = MHD_HTTP_METHOD_POST,
@@ -2127,56 +2096,6 @@ handle_mhd_request (void *cls,
       return ret;
     }
   }
-  /* FIXME: Why is this handled separately? Fix or justify! */
-  if (0 == strncmp (url,
-                    "/kyc-upload/",
-                    strlen ("/kyc-upload/")))
-  {
-    if (0 == strcasecmp (method,
-                         MHD_HTTP_METHOD_OPTIONS))
-    {
-      GNUNET_async_scope_restore (&old_scope);
-      return TALER_MHD_reply_cors_preflight (connection);
-    }
-    if (0 != strcasecmp (method,
-                         MHD_HTTP_METHOD_POST))
-    {
-      MHD_RESULT ret;
-      struct MHD_Response *reply;
-
-      reply = TALER_MHD_make_error (TALER_EC_GENERIC_METHOD_INVALID,
-                                    method);
-      GNUNET_break (MHD_YES ==
-                    MHD_add_response_header (reply,
-                                             MHD_HTTP_HEADER_ALLOW,
-                                             MHD_HTTP_METHOD_POST));
-      ret = MHD_queue_response (connection,
-                                MHD_HTTP_METHOD_NOT_ALLOWED,
-                                reply);
-      MHD_destroy_response (reply);
-      GNUNET_async_scope_restore (&old_scope);
-      return ret;
-    }
-    {
-      MHD_RESULT ret;
-
-      ret = TEH_handler_kyc_upload (rc,
-                                    &url[strlen ("/kyc-upload/")],
-                                    upload_data_size,
-                                    upload_data);
-      if (GNUNET_OK !=
-          TEH_plugin->preflight (TEH_plugin->cls))
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                    "Handler %s left open database transaction behind!\n",
-                    url);
-        GNUNET_assert (0);
-      }
-      GNUNET_async_scope_restore (&old_scope);
-      return ret;
-    }
-  }
-
 
   /* No handler matches, generate not found */
   {
@@ -2373,7 +2292,10 @@ exchange_serve_process_config (const char *cfg_fn)
                                             "STEFAN_LIN",
                                             &TEH_stefan_lin))
   {
-    GNUNET_break (0);
+    GNUNET_log_config_invalid (GNUNET_ERROR_TYPE_ERROR,
+                               "exchange",
+                               "STEFAN_LIN",
+                               "must be a floating point");
     return GNUNET_SYSERR;
   }
 
@@ -2738,6 +2660,7 @@ do_shutdown (void *cls)
   TEH_resume_keys_requests (true);
   TEH_batch_deposit_cleanup ();
   TEH_withdraw_cleanup ();
+  TEH_melt_v27_cleanup ();
   TEH_reserves_close_cleanup ();
   TEH_reserves_purse_cleanup ();
   TEH_purses_merge_cleanup ();
