@@ -153,6 +153,7 @@ aml_trigger_callback (
     adc->response = MHD_create_response_from_buffer_static (
       0,
       "");
+    TALER_MHD_add_global_headers (adc->response);
   }
 
   GNUNET_assert (NULL != adc->response);
@@ -177,9 +178,12 @@ TEH_handler_post_aml_decision (
   const char *new_measures = NULL;
   bool to_investigate;
   struct GNUNET_TIME_Timestamp decision_time;
+  struct GNUNET_TIME_Timestamp attributes_expiration
+    = GNUNET_TIME_UNIT_ZERO_TS;
   const json_t *new_rules;
   const json_t *events = NULL;
   const json_t *properties = NULL;
+  const json_t *attributes = NULL;
   struct TALER_FullPayto payto_uri = {
     .full_payto = NULL
   };
@@ -209,8 +213,8 @@ TEH_handler_post_aml_decision (
                                      &properties),
       NULL),
     GNUNET_JSON_spec_mark_optional (
-      GNUNET_JSON_spec_object_const ("events",
-                                     &events),
+      GNUNET_JSON_spec_array_const ("events",
+                                    &events),
       NULL),
     GNUNET_JSON_spec_bool ("keep_investigating",
                            &to_investigate),
@@ -218,10 +222,19 @@ TEH_handler_post_aml_decision (
                                  &officer_sig),
     GNUNET_JSON_spec_timestamp ("decision_time",
                                 &decision_time),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_timestamp ("attributes_expiration",
+                                  &attributes_expiration),
+      NULL),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_object_const ("attributes",
+                                     &attributes),
+      NULL),
     GNUNET_JSON_spec_end ()
   };
   struct GNUNET_TIME_Timestamp expiration_time;
   json_t *jmeasures = NULL;
+  bool is_wallet;
 
   if (NULL == adc)
   {
@@ -289,7 +302,9 @@ TEH_handler_post_aml_decision (
         new_measures,
         to_investigate,
         officer_pub,
-        &officer_sig))
+        &officer_sig,
+        attributes_expiration,
+        attributes))
   {
     GNUNET_break_op (0);
     ret = TALER_MHD_reply_with_error (
@@ -313,7 +328,8 @@ TEH_handler_post_aml_decision (
   }
 
   expiration_time = TALER_KYCLOGIC_rules_get_expiration (lrs);
-  if (NULL != new_measures)
+  if ( (NULL != new_measures) &&
+       (0 != strlen (new_measures)) )
   {
     jmeasures
       = TALER_KYCLOGIC_get_jmeasures (lrs,
@@ -339,6 +355,22 @@ TEH_handler_post_aml_decision (
     struct GNUNET_TIME_Timestamp last_date;
     bool invalid_officer = true;
     bool unknown_account = false;
+    struct GNUNET_HashCode h_attr = { 0 };
+    size_t eas = 0;
+    void *ea = NULL;
+    const char *form_id = NULL;
+
+    if (NULL != attributes)
+    {
+      form_id = json_string_value (json_object_get (attributes,
+                                                    "FORM_ID"));
+      TALER_json_hash (attributes,
+                       &h_attr);
+      TALER_CRYPTO_kyc_attributes_encrypt (&TEH_attribute_key,
+                                           attributes,
+                                           &ea,
+                                           &eas);
+    }
 
     for (size_t i = 0; i<num_events; i++)
     {
@@ -372,10 +404,18 @@ TEH_handler_post_aml_decision (
                                           &officer_sig,
                                           num_events,
                                           sevents,
+                                          form_id,
+                                          eas, /* enc_attributes_size*/
+                                          ea, /* enc_attributes*/
+                                          NULL != attributes
+                                          ? &h_attr
+                                          : NULL, /* attributes_hash */
+                                          attributes_expiration,
                                           &invalid_officer,
                                           &unknown_account,
                                           &last_date,
-                                          &legi_measure_serial_id);
+                                          &legi_measure_serial_id,
+                                          &is_wallet);
     json_decref (jmeasures);
     if (qs <= 0)
     {
@@ -442,6 +482,7 @@ TEH_handler_post_aml_decision (
         &rc->async_scope_id,
         instant_ms,
         &h_payto,
+        is_wallet,
         &aml_trigger_callback,
         adc
         );
