@@ -49,6 +49,7 @@
  *    NULL if no properties were set
  * @param to_investigate true if AML staff should look at the account
  * @param is_active true if this is the currently active decision about the account
+ * @param is_wallet true if the @a h_payto is for a wallet
  * @param account_rules current active rules for the account
  */
 static void
@@ -62,6 +63,7 @@ record_cb (
   const json_t *jproperties,
   bool to_investigate,
   bool is_active,
+  bool is_wallet,
   const json_t *account_rules)
 {
   json_t *records = cls;
@@ -73,6 +75,8 @@ record_cb (
       GNUNET_JSON_PACK (
         GNUNET_JSON_pack_data_auto ("h_payto",
                                     h_payto),
+        GNUNET_JSON_pack_bool ("is_wallet",
+                               is_wallet),
         GNUNET_JSON_pack_int64 ("rowid",
                                 row_id),
         GNUNET_JSON_pack_allow_null (
@@ -142,33 +146,6 @@ TEH_handler_aml_decisions_get (
                                "investigation",
                                TALER_EXCHANGE_YNA_ALL,
                                &investigation_filter);
-  {
-    enum GNUNET_DB_QueryStatus qs;
-
-    qs = TEH_plugin->test_aml_officer (TEH_plugin->cls,
-                                       officer_pub);
-    switch (qs)
-    {
-    case GNUNET_DB_STATUS_HARD_ERROR:
-    case GNUNET_DB_STATUS_SOFT_ERROR:
-      GNUNET_break (0);
-      return TALER_MHD_reply_with_error (
-        rc->connection,
-        MHD_HTTP_INTERNAL_SERVER_ERROR,
-        TALER_EC_GENERIC_DB_FETCH_FAILED,
-        "test_aml_officer");
-    case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
-      GNUNET_break_op (0);
-      return TALER_MHD_reply_static (
-        rc->connection,
-        MHD_HTTP_FORBIDDEN,
-        NULL,
-        NULL,
-        0);
-    case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
-      break;
-    }
-  }
   {
     json_t *records;
     enum GNUNET_DB_QueryStatus qs;
