@@ -479,7 +479,7 @@ check_request_idempotent (
                    rc->connection,
                    MHD_HTTP_INTERNAL_SERVER_ERROR,
                    TALER_EC_GENERIC_DB_FETCH_FAILED,
-                   "get_withdraw_info"));
+                   "do_check_deposit_idempotent"));
     return true;
   }
   if ( (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs) ||
@@ -904,10 +904,8 @@ bdc_phase_parse (struct BatchDepositContext *bdc,
                                  &bd->wire_salt),
     GNUNET_JSON_spec_fixed_auto ("merchant_pub",
                                  &bd->merchant_pub),
-    GNUNET_JSON_spec_mark_optional ( /* since v22, we are compatible */
-      GNUNET_JSON_spec_fixed_auto ("merchant_sig",
-                                   &bd->merchant_sig),
-      NULL),
+    GNUNET_JSON_spec_fixed_auto ("merchant_sig",
+                                 &bd->merchant_sig),
     GNUNET_JSON_spec_fixed_auto ("h_contract_terms",
                                  &bd->h_contract_terms),
     GNUNET_JSON_spec_mark_optional (
@@ -954,12 +952,11 @@ bdc_phase_parse (struct BatchDepositContext *bdc,
       return;
     }
   }
-  if ( (! GNUNET_is_zero (&bd->merchant_sig)) &&
-       (GNUNET_OK !=
-        TALER_merchant_contract_verify (
-          &bd->h_contract_terms,
-          &bd->merchant_pub,
-          &bd->merchant_sig)) )
+  if (GNUNET_OK !=
+      TALER_merchant_contract_verify (
+        &bd->h_contract_terms,
+        &bd->merchant_pub,
+        &bd->merchant_sig))
   {
     GNUNET_break_op (0);
     GNUNET_JSON_parse_free (spec);
@@ -1042,7 +1039,7 @@ bdc_phase_parse (struct BatchDepositContext *bdc,
                    "coins"));
     return;
   }
-  if (TALER_MAX_FRESH_COINS < bd->num_cdis)
+  if (TALER_MAX_COINS < bd->num_cdis)
   {
     GNUNET_break_op (0);
     GNUNET_JSON_parse_free (spec);
