@@ -150,7 +150,8 @@ compile_transaction_history (
       {
         const struct TALER_EXCHANGEDB_MeltListEntry *melt =
           pos->details.melt;
-        const struct TALER_AgeCommitmentHash *phac = NULL;
+        const struct TALER_AgeCommitmentHash *phac;
+        const struct TALER_BlindingMasterSeedP *pbs;
 
 #if ENABLE_SANITY_CHECKS
         TEH_METRICS_num_verifications[TEH_MT_SIGNATURE_EDDSA]++;
@@ -170,11 +171,12 @@ compile_transaction_history (
         }
 #endif
 
-        /* Age restriction is optional.  We communicate a NULL value to
-         * JSON_PACK below */
-        if (! melt->no_age_commitment)
-          phac = &melt->h_age_commitment;
-
+        phac = (melt->no_age_commitment)
+                ? NULL
+                :  &melt->h_age_commitment;
+        pbs = melt->no_blinding_seed
+                ? NULL
+                : &melt->blinding_seed;
         if (0 !=
             json_array_append_new (
               history,
@@ -187,6 +189,11 @@ compile_transaction_history (
                                         &melt->melt_fee),
                 GNUNET_JSON_pack_data_auto ("rc",
                                             &melt->rc),
+                GNUNET_JSON_pack_data_auto ("refresh_seed",
+                                            &melt->refresh_seed),
+                GNUNET_JSON_pack_allow_null (
+                  GNUNET_JSON_pack_data_auto ("blinding_seed",
+                                              pbs)),
                 GNUNET_JSON_pack_allow_null (
                   GNUNET_JSON_pack_data_auto ("h_age_commitment",
                                               phac)),
