@@ -264,5 +264,5 @@ TEH_common_purse_deposit_free_coin (struct TEH_PurseDepositedCoin *coin)
 {
   TALER_denom_sig_free (&coin->cpi.denom_sig);
   if (! coin->cpi.no_age_commitment)
-    GNUNET_free (coin->age_commitment.keys); /* Only the keys have been allocated */
+    GNUNET_free (coin->age_commitment.pubs); /* Only the keys have been allocated */
 }
