@@ -40,6 +40,11 @@
  */
 #define EXTRA_CHECK 0
 
+/**
+ * Enable extra logging that may include sensitive data?
+ */
+#define DEBUG 1
+
 
 struct TEH_KycMeasureRunContext
 {
@@ -84,11 +89,6 @@ struct TEH_KycMeasureRunContext
    */
   json_t *jmeasures;
 
-  /**
-   * KYC measure the client is (trying to) satisfy.
-   */
-  uint32_t measure_index;
-
   /**
    * Handle to an external process that evaluates the
    * need to run AML on the account.
@@ -100,6 +100,15 @@ struct TEH_KycMeasureRunContext
    */
   struct GNUNET_SCHEDULER_Task *async_task;
 
+  /**
+   * KYC measure the client is (trying to) satisfy.
+   */
+  uint32_t measure_index;
+
+  /**
+   * True if @e account_id is for a wallet.
+   */
+  bool is_wallet;
 };
 
 
@@ -160,6 +169,7 @@ kyc_aml_finished (
   struct TEH_KycMeasureRunContext *kat = cls;
   enum GNUNET_DB_QueryStatus qs;
   struct GNUNET_AsyncScopeSave old_scope;
+  enum TALER_EXCHANGEDB_PersistProgramResultStatus pprs;
 
   kat->kyc_aml = NULL;
   if (NULL != kat->async_task)
@@ -177,7 +187,8 @@ kyc_aml_finished (
     TEH_plugin,
     kat->process_row,
     &kat->account_id,
-    apr);
+    apr,
+    &pprs);
   switch (qs)
   {
   case GNUNET_DB_STATUS_HARD_ERROR:
@@ -193,6 +204,19 @@ kyc_aml_finished (
   case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
     break;
   }
+  switch (pprs)
+  {
+  case TALER_EXCHANGEDB_PPRS_OK:
+    break;
+  case TALER_EXCHANGEDB_PPRS_BAD_OUTCOME:
+    GNUNET_break (0);
+    kat->cb (kat->cb_cls,
+             TALER_EC_EXCHANGE_KYC_AML_PROGRAM_MALFORMED_RESULT,
+             "persist_aml_program_result");
+    TEH_kyc_run_measure_cancel (kat);
+    GNUNET_async_scope_restore (&old_scope);
+    return;
+  }
   switch (apr->status)
   {
   case TALER_KYCLOGIC_AMLR_FAILURE:
@@ -216,6 +240,7 @@ kyc_aml_finished (
       = TEH_kyc_fallback (
           &kat->scope,
           &kat->account_id,
+          kat->is_wallet,
           kat->process_row,
           kat->fallback_name,
           &fallback_result_cb,
@@ -281,6 +306,7 @@ TEH_kyc_store_attributes (
   unsigned int birthday = 0;
   size_t eas = 0;
   void *ea = NULL;
+  const char *form_id = NULL;
 
   if (TEH_age_restriction_enabled)
   {
@@ -306,8 +332,11 @@ TEH_kyc_store_attributes (
       }
     }
   }
+
   if (NULL != new_attributes)
   {
+    form_id = json_string_value (json_object_get (new_attributes,
+                                                  "FORM_ID"));
     TALER_CRYPTO_kyc_attributes_encrypt (&TEH_attribute_key,
                                          new_attributes,
                                          &ea,
@@ -322,6 +351,7 @@ TEH_kyc_store_attributes (
     provider_legitimization_id,
     birthday,
     expiration,
+    form_id,
     eas,
     ea);
   GNUNET_free (ea);
@@ -352,6 +382,7 @@ TEH_kyc_run_measure_for_attributes (
   const struct GNUNET_AsyncScopeId *scope,
   uint64_t process_row,
   const struct TALER_NormalizedPaytoHashP *account_id,
+  bool is_wallet,
   TEH_KycMeasureRunContextCallback cb,
   void *cb_cls)
 {
@@ -362,6 +393,7 @@ TEH_kyc_run_measure_for_attributes (
   kat->scope = *scope;
   kat->process_row = process_row;
   kat->account_id = *account_id;
+  kat->is_wallet = is_wallet;
   kat->cb = cb;
   kat->cb_cls = cb_cls;
   qs = TEH_plugin->lookup_active_legitimization (
@@ -377,15 +409,27 @@ TEH_kyc_run_measure_for_attributes (
     TEH_kyc_run_measure_cancel (kat);
     return NULL;
   case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
-    GNUNET_break (0);
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "No active legitimization for %llu\n",
+                (unsigned long long) process_row);
     TEH_kyc_run_measure_cancel (kat);
     return NULL;
   case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
     break;
   }
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Running AML program on for current measures\n");
+#if DEBUG
+  json_dumpf (kat->jmeasures,
+              stderr,
+              JSON_INDENT (2));
+  fprintf (stderr,
+           "\n");
+#endif
   {
     struct TALER_EXCHANGEDB_HistoryBuilderContext hbc = {
       .account = &kat->account_id,
+      .is_wallet = kat->is_wallet,
       .db_plugin = TEH_plugin,
       .attribute_key = &TEH_attribute_key
     };
@@ -393,6 +437,7 @@ TEH_kyc_run_measure_for_attributes (
     kat->kyc_aml
       = TALER_KYCLOGIC_run_aml_program (
           kat->jmeasures,
+          kat->is_wallet,
           kat->measure_index,
           &TALER_EXCHANGEDB_current_attributes_builder,
           &hbc,
@@ -440,6 +485,7 @@ TEH_kyc_run_measure_directly (
   const struct GNUNET_AsyncScopeId *scope,
   const struct TALER_KYCLOGIC_Measure *instant_ms,
   const struct TALER_NormalizedPaytoHashP *account_id,
+  bool is_wallet,
   TEH_KycMeasureRunContextCallback cb,
   void *cb_cls)
 {
@@ -456,6 +502,7 @@ TEH_kyc_run_measure_directly (
   kat->measure_index = 0;
   kat->scope = *scope;
   kat->account_id = *account_id;
+  kat->is_wallet = is_wallet;
   kat->cb = cb;
   kat->cb_cls = cb_cls;
 
@@ -517,12 +564,14 @@ TEH_kyc_run_measure_directly (
   {
     struct TALER_EXCHANGEDB_HistoryBuilderContext hbc = {
       .account = &kat->account_id,
+      .is_wallet = kat->is_wallet,
       .db_plugin = TEH_plugin,
       .attribute_key = &TEH_attribute_key
     };
 
     kat->kyc_aml
       = TALER_KYCLOGIC_run_aml_program3 (
+          kat->is_wallet,
           instant_ms,
           &TALER_EXCHANGEDB_current_attributes_builder,
           &hbc,
@@ -659,6 +708,7 @@ handle_aml_fallback_result (
     bool unknown_account;
     struct GNUNET_TIME_Timestamp last_date;
     uint64_t legitimization_measure_serial_id;
+    bool is_wallet;
 
     qs = TEH_plugin->insert_aml_decision (
       TEH_plugin->cls,
@@ -676,10 +726,16 @@ handle_aml_fallback_result (
       NULL, /* decider_sig */
       apr->details.success.num_events,
       apr->details.success.events,
+      NULL, /* form_id */
+      0, /* enc_attributes_size*/
+      NULL, /* enc_attributes*/
+      NULL, /* attributes_hash */
+      GNUNET_TIME_UNIT_ZERO_TS, /* attributes_expiration_time */
       &invalid_officer,
       &unknown_account,
       &last_date,
-      &legitimization_measure_serial_id);
+      &legitimization_measure_serial_id,
+      &is_wallet);
   }
 
   if (qs < 0)
@@ -729,6 +785,7 @@ struct TEH_KycAmlFallback*
 TEH_kyc_fallback (
   const struct GNUNET_AsyncScopeId *scope,
   const struct TALER_NormalizedPaytoHashP *account_id,
+  bool is_wallet,
   uint64_t orig_requirement_row,
   const char *fallback_measure,
   TEH_KycAmlFallbackCallback cb,
@@ -756,6 +813,7 @@ TEH_kyc_fallback (
   {
     struct TALER_EXCHANGEDB_HistoryBuilderContext hbc = {
       .account = &fb->account_id,
+      .is_wallet = is_wallet,
       .db_plugin = TEH_plugin,
       .attribute_key = &TEH_attribute_key
     };
@@ -765,6 +823,7 @@ TEH_kyc_fallback (
       = TALER_KYCLOGIC_run_aml_program2 (
           kcc.prog_name,
           kcc.context,
+          is_wallet,
           &TALER_EXCHANGEDB_current_attributes_builder,
           &hbc,
           &TALER_EXCHANGEDB_current_rule_builder,
@@ -965,6 +1024,11 @@ struct TEH_LegitimizationCheckHandle
    */
   bool have_merchant_pub;
 
+  /**
+   * Is our @e h_payto for a wallet?
+   */
+  bool is_wallet;
+
   /**
    * Set to true if the merchant public key does not
    * match the public key we have on file for this
@@ -1135,6 +1199,8 @@ setup_legitimization_check (
   lch->et = et;
   lch->payto_uri.full_payto
     = GNUNET_strdup (payto_uri.full_payto);
+  lch->is_wallet
+    = TALER_payto_is_wallet (payto_uri.full_payto);
   lch->h_payto = *h_payto;
   if (NULL != account_pub)
   {
@@ -1359,9 +1425,6 @@ current_rules_cb (
     lch->lcr.kyc.ok = true;
     lch->lcr.expiration_date
       = TALER_KYCLOGIC_rules_get_expiration (lrs);
-    memset (&lch->lcr.next_threshold,
-            0,
-            sizeof (struct TALER_Amount));
     /* return success! */
     lch->async_task
       = GNUNET_SCHEDULER_add_now (
@@ -1386,9 +1449,9 @@ current_rules_cb (
       &lch->scope,
       instant_ms,
       &lch->h_payto,
+      lch->is_wallet,
       &legi_check_aml_trigger_cb,
-      lch
-      );
+      lch);
     if (NULL == lch->kat)
     {
       GNUNET_break (0);
@@ -1604,12 +1667,23 @@ legitimization_check_run (
     }
   }
 
+  /* NOTE-CG: I don't recall why we need to make this distinction
+     and re-fetch the rules this way. The main difference is that
+     we fetch the "legitimization_outcome_last_row" on the true
+     path, but we could presumably fetch it above as well. Not
+     doing another transaction would seem more efficient. So why
+     exactly do we do this here? */
   if (NULL != lrs)
   {
+    /* Stop the current transaction and start a new
+       asynchronous task with a new transaction to
+       fetch the rules for the account. */
     TEH_plugin->rollback (TEH_plugin->cls);
+    TALER_KYCLOGIC_rules_free (lrs);
     lch->ru = TALER_EXCHANGEDB_update_rules (TEH_plugin,
                                              &TEH_attribute_key,
                                              &lch->h_payto,
+                                             lch->is_wallet,
                                              &current_rules_cb,
                                              lch);
   }
@@ -1617,6 +1691,8 @@ legitimization_check_run (
   {
     struct TALER_EXCHANGEDB_RuleUpdaterResult rur = { 0 };
 
+    /* Simplified case, just default rules apply, we can
+       continue in this transaction */
     current_rules_cb (lch,
                       &rur);
   }
