@@ -26,6 +26,7 @@
 #include <jansson.h>
 #include <microhttpd.h>
 #include "taler_json_lib.h"
+#include "taler_kyclogic_lib.h"
 #include "taler_mhd_lib.h"
 #include "taler-exchange-httpd.h"
 
@@ -85,6 +86,7 @@ TEH_kyc_store_attributes (
  * @param scope the HTTP request logging scope
  * @param process_row legitimization process the data provided is about
  * @param account_id account the the data provided is about
+ * @param is_wallet true if @a account_id is a wallet
  * @param cb function to call with the result
  * @param cb_cls closure for @a cb
  * @return handle to cancel the operation
@@ -95,6 +97,7 @@ TEH_kyc_run_measure_for_attributes (
   const struct GNUNET_AsyncScopeId *scope,
   uint64_t process_row,
   const struct TALER_NormalizedPaytoHashP *account_id,
+  bool is_wallet,
   TEH_KycMeasureRunContextCallback cb,
   void *cb_cls);
 
@@ -111,6 +114,7 @@ TEH_kyc_run_measure_for_attributes (
  * @param scope the HTTP request logging scope
  * @param instant_ms instant measure to run
  * @param account_id account affected by the measure
+ * @param is_wallet true if @a account_id is for a wallet
  * @param cb function to call with the result
  * @param cb_cls closure for @a cb
  * @return handle to cancel the operation
@@ -120,6 +124,7 @@ TEH_kyc_run_measure_directly (
   const struct GNUNET_AsyncScopeId *scope,
   const struct TALER_KYCLOGIC_Measure *instant_ms,
   const struct TALER_NormalizedPaytoHashP *account_id,
+  bool is_wallet,
   TEH_KycMeasureRunContextCallback cb,
   void *cb_cls);
 
@@ -161,6 +166,7 @@ typedef void
  *
  * @param scope the HTTP request logging scope
  * @param account_id account to activate fallback for
+ * @param is_wallet true if @a account_id is for a wallet
  * @param orig_requirement_row original requirement
  *    row that now triggered the fallback
  * @param fallback_measure fallback to activate
@@ -173,6 +179,7 @@ struct TEH_KycAmlFallback *
 TEH_kyc_fallback (
   const struct GNUNET_AsyncScopeId *scope,
   const struct TALER_NormalizedPaytoHashP *account_id,
+  bool is_wallet,
   uint64_t orig_requirement_row,
   const char *fallback_measure,
   TEH_KycAmlFallbackCallback cb,
