@@ -95,7 +95,8 @@ TEH_make_coin_known (const struct TALER_CoinPublicInfo *coin,
         &coin->coin_pub,
         &prev_denom.pub,
         &prev_denom.sig);
-
+      TALER_denom_pub_free (&prev_denom.pub);
+      TALER_denom_sig_free (&prev_denom.sig);
       return GNUNET_DB_STATUS_HARD_ERROR;
     }
   case TALER_EXCHANGEDB_CKS_AGE_CONFLICT_EXPECTED_NULL:
