@@ -23,22 +23,36 @@
 
 #include <microhttpd.h>
 #include "taler_exchangedb_plugin.h"
+#include "taler-exchange-httpd_metrics.h"
 #include <gnunet/gnunet_mhd_compat.h>
 
 
+/**
+ * How often should we retry a transaction before giving up
+ * (for transactions resulting in serialization/dead locks only).
+ *
+ * The current value is likely too high for production. We might want to
+ * benchmark good values once we have a good database setup.  The code is
+ * expected to work correctly with any positive value, albeit inefficiently if
+ * we too aggressively force clients to retry the HTTP request merely because
+ * we have database serialization issues.
+ */
+#define MAX_TRANSACTION_COMMIT_RETRIES 100
+
+
 /**
  * Ensure coin is known in the database, and handle conflicts and errors.
  *
  * @param coin the coin to make known
  * @param connection MHD request context
- * @param session database session and transaction to use
+ * @param[out] known_coin_id set to the unique ID for the coin in the DB
  * @param[out] mhd_ret set to MHD status on error
  * @return transaction status, negative on error (@a mhd_ret will be set in this case)
  */
 enum GNUNET_DB_QueryStatus
 TEH_make_coin_known (const struct TALER_CoinPublicInfo *coin,
                      struct MHD_Connection *connection,
-                     struct TALER_EXCHANGEDB_Session *session,
+                     uint64_t *known_coin_id,
                      MHD_RESULT *mhd_ret);
 
 
@@ -52,7 +66,6 @@ TEH_make_coin_known (const struct TALER_CoinPublicInfo *coin,
  *
  * @param cls closure
  * @param connection MHD request which triggered the transaction
- * @param session database session to use
  * @param[out] mhd_ret set to MHD response status for @a connection,
  *             if transaction failed (!)
  * @return transaction status
@@ -60,7 +73,6 @@ TEH_make_coin_known (const struct TALER_CoinPublicInfo *coin,
 typedef enum GNUNET_DB_QueryStatus
 (*TEH_DB_TransactionCallback)(void *cls,
                               struct MHD_Connection *connection,
-                              struct TALER_EXCHANGEDB_Session *session,
                               MHD_RESULT *mhd_ret);
 
 
@@ -73,7 +85,8 @@ typedef enum GNUNET_DB_QueryStatus
  *
  * @param connection MHD connection to run @a cb for, can be NULL
  * @param name name of the transaction (for debugging)
- * @param[out] mhd_ret set to MHD response code, if transaction failed;
+ * @param mt type of the requests, for metric generation
+ * @param[out] mhd_ret set to MHD response code, if transaction failed (returned #GNUNET_SYSERR);
  *             NULL if we are not running with a @a connection and thus
  *             must not queue MHD replies
  * @param cb callback implementing transaction logic
@@ -83,6 +96,7 @@ typedef enum GNUNET_DB_QueryStatus
 enum GNUNET_GenericReturnValue
 TEH_DB_run_transaction (struct MHD_Connection *connection,
                         const char *name,
+                        enum TEH_MetricTypeRequest mt,
                         MHD_RESULT *mhd_ret,
                         TEH_DB_TransactionCallback cb,
                         void *cb_cls);
