@@ -386,7 +386,7 @@ dwc_cleaner (struct TEH_RequestContext *rc)
 {
   struct DepositWtidContext *ctx = rc->rh_ctx;
 
-  GNUNET_assert (GNUNET_NO == ctx->suspended);
+  GNUNET_assert (GNUNET_YES != ctx->suspended);
   if (NULL != ctx->eh)
   {
     TEH_plugin->event_listen_cancel (TEH_plugin->cls,
