@@ -283,6 +283,24 @@ TEH_keys_denomination_by_hash_from_state (
   struct MHD_Connection *conn,
   MHD_RESULT *mret);
 
+
+/**
+ * Look up the issue for a denom public key using a given @a ksh.  This allows
+ * requesting multiple denominations with the same @a ksh which thus will
+ * remain valid until the next call to #TEH_keys_denomination_by_hash() or
+ * #TEH_keys_get_state() or #TEH_keys_exchange_sign().
+ *
+ * @param ksh key state state to look in
+ * @param denom_serial serial ID of the denomination in the table
+ * @return the denomination key issue,
+ *         or NULL if @a denom_serial could not be found
+ */
+struct TEH_DenominationKey *
+TEH_keys_denomination_by_serial_from_state (
+  const struct TEH_KeyStateHandle *ksh,
+  uint64_t denom_serial);
+
+
 /**
  * Information needed to create a blind signature.
  */
@@ -360,13 +378,36 @@ TEH_keys_denomination_cs_r_pub (
  * @return #TALER_EC_NONE on success
  */
 enum TALER_ErrorCode
-TEH_keys_denomination_cs_batch_r_pub (
+TEH_keys_denomination_cs_batch_r_pub_simple (
   unsigned int cdds_length,
   const struct TEH_CsDeriveData cdds[static cdds_length],
   bool for_melt,
   struct GNUNET_CRYPTO_CSPublicRPairP r_pubs[static cdds_length]);
 
 
+/**
+ * Request to derive a bunch of CS @a r_pubs using the
+ * denominations and nonces from @a cdds.
+ *
+ * @param ksh keys state to load the keys from
+ * @param num number of input elements
+ * @param h_denom_pubs array @a num of hashes of keys to sign with
+ * @param nonces array @a num of nonces to use
+ * @param for_melt true if this is for a melt operation
+ * @param[out] r_pubs array where to write the result; must be of length @a num
+ * @param[out] err_idx in case of error, the index into @e cdds that caused it
+ * @return #TALER_EC_NONE on success
+ */
+enum TALER_ErrorCode
+TEH_keys_denomination_cs_batch_r_pub (
+  const struct TEH_KeyStateHandle *ksh,
+  size_t num,
+  const struct TALER_DenominationHashP h_denom_pubs[static num],
+  const struct GNUNET_CRYPTO_CsSessionNonce nonces[static num],
+  bool for_melt,
+  struct GNUNET_CRYPTO_CSPublicRPairP r_pubs[static num],
+  size_t *err_idx);
+
 /**
  * Revoke the public key associated with @a h_denom_pub.
  * This function should be called AFTER the database was
