@@ -70,6 +70,33 @@ struct KycPoller
    */
   struct TALER_EXCHANGEDB_RuleUpdater *ru;
 
+  /**
+   * Current legitimization rule set, owned by callee.  Will be NULL on error
+   * or for default rules. Will not contain skip rules and not be expired.
+   */
+  struct TALER_KYCLOGIC_LegitimizationRuleSet *lrs;
+
+  /**
+   * Handle for async KYC processing.
+   */
+  struct TEH_KycMeasureRunContext *kat;
+
+  /**
+   * Response to return, NULL if none yet.
+   */
+  struct MHD_Response *response;
+
+  /**
+   * Set to access token for a KYC process by the account,
+   * if @e have_token is true.
+   */
+  struct TALER_AccountAccessTokenP access_token;
+
+  /**
+   * Payto hash of the account matching @a access_token.
+   */
+  struct TALER_NormalizedPaytoHashP h_payto;
+
   /**
    * #MHD_HTTP_HEADER_IF_NONE_MATCH Etag value sent by the client.  0 for none
    * (or malformed).
@@ -87,24 +114,6 @@ struct KycPoller
    */
   struct GNUNET_TIME_Absolute timeout;
 
-  /**
-   * Set to access token for a KYC process by the account,
-   * if @e have_token is true.
-   */
-  struct TALER_AccountAccessTokenP access_token;
-
-  /**
-   * Payto hash of the account matching @a access_token.
-   */
-  struct TALER_NormalizedPaytoHashP h_payto;
-
-
-  /**
-   * Current legitimization rule set, owned by callee.  Will be NULL on error
-   * or for default rules. Will not contain skip rules and not be expired.
-   */
-  struct TALER_KYCLOGIC_LegitimizationRuleSet *lrs;
-
   /**
    *
    */
@@ -115,25 +124,20 @@ struct KycPoller
    */
   uint64_t legitimization_outcome_last_row;
 
-  /**
-   * True if we are still suspended.
-   */
-  bool suspended;
-
-  /**
-   * Handle for async KYC processing.
-   */
-  struct TEH_KycMeasureRunContext *kat;
-
   /**
    * HTTP status code to use with @e response.
    */
   unsigned int response_code;
 
   /**
-   * Response to return, NULL if none yet.
+   * True if our @e h_payto is for a wallet.
    */
-  struct MHD_Response *response;
+  bool is_wallet;
+
+  /**
+   * True if we are still suspended.
+   */
+  bool suspended;
 
 };
 
@@ -390,6 +394,53 @@ resume_with_reply (struct KycPoller *kyp,
         ename);
       return;
     }
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Found required check `%s' with program `%s'\n",
+                check_name,
+                prog_name);
+    if (NULL != context)
+    {
+      json_dumpf (context,
+                  stderr,
+                  JSON_INDENT (2));
+      fprintf (stderr,
+               "\n");
+    }
+    /* Check if requirement is a duplicate, and in that case do
+       not return it */
+    {
+      bool duplicate = false;
+
+      for (size_t off = 0; off < i; off++)
+      {
+        json_t *have = json_array_get (measures,
+                                       off);
+        if ( (1 ==
+              json_equal (json_object_get (have,
+                                           "check_name"),
+                          json_object_get (mi,
+                                           "check_name")) ) &&
+             (1 ==
+              json_equal (json_object_get (have,
+                                           "check_name"),
+                          json_object_get (mi,
+                                           "check_name")) ) &&
+             (1 ==
+              json_equal (json_object_get (have,
+                                           "check_name"),
+                          json_object_get (mi,
+                                           "check_name")) ) )
+        {
+          /* Duplicate requirement, do not return again */
+          duplicate = true;
+          break;
+        }
+      }
+      if (duplicate)
+      {
+        continue;
+      }
+    }
     kri = TALER_KYCLOGIC_measure_to_requirement (
       check_name,
       prog_name,
@@ -458,6 +509,7 @@ current_rules_cb (
   enum GNUNET_DB_QueryStatus qs;
   uint64_t legitimization_measure_last_row;
   json_t *jmeasures;
+  json_t *vmeasures;
 
   kyp->ru = NULL;
   if (TALER_EC_NONE != rur->ec)
@@ -474,12 +526,21 @@ current_rules_cb (
     = rur->lrs;
   kyp->legitimization_outcome_last_row
     = rur->legitimization_outcome_last_row;
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "LRS is for the account uses %s\n",
+              NULL == kyp->lrs
+              ? "default rules"
+              : "custom rules");
 
+  /* Check if there is an unfinished legitimization measure */
   qs = TEH_plugin->lookup_kyc_status_by_token (
     TEH_plugin->cls,
     &kyp->access_token,
     &legitimization_measure_last_row,
     &jmeasures);
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "lookup_kyc_status_by_token returned %d\n",
+              (int) qs);
   if (qs < 0)
   {
     GNUNET_break (0);
@@ -493,7 +554,8 @@ current_rules_cb (
   if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
   {
     jmeasures
-      = TALER_KYCLOGIC_zero_measures (kyp->lrs);
+      = TALER_KYCLOGIC_zero_measures (kyp->lrs,
+                                      kyp->is_wallet);
     if (NULL == jmeasures)
     {
       qs = TEH_plugin->commit (TEH_plugin->cls);
@@ -519,7 +581,12 @@ current_rules_cb (
                                 )));
       return;
     }
-
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Making applicable zero-measures for %s under current rules active\n",
+                kyp->is_wallet ? "wallets" : "accounts");
+    json_dumpf (jmeasures,
+                stderr,
+                JSON_INDENT (2));
     qs = TEH_plugin->insert_active_legitimization_measure (
       TEH_plugin->cls,
       &kyp->access_token,
@@ -594,6 +661,7 @@ current_rules_cb (
                                             NULL,
                                             MHD_RESPMEM_PERSISTENT);
     add_nocache_header (resp);
+    TALER_MHD_add_global_headers (resp);
     GNUNET_break (MHD_YES ==
                   MHD_add_response_header (resp,
                                            MHD_HTTP_HEADER_ETAG,
@@ -606,11 +674,13 @@ current_rules_cb (
   }
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Generating success reply to kyc-info query\n");
+  vmeasures = TALER_KYCLOGIC_voluntary_measures (kyp->lrs);
   resume_with_reply (kyp,
                      legitimization_measure_last_row,
                      kyp->legitimization_outcome_last_row,
                      jmeasures,
-                     TALER_KYCLOGIC_voluntary_measures (kyp->lrs));
+                     vmeasures);
+  json_decref (vmeasures);
   json_decref (jmeasures);
 }
 
@@ -684,7 +754,8 @@ TEH_handler_kyc_info (
     qs = TEH_plugin->lookup_h_payto_by_access_token (
       TEH_plugin->cls,
       &kyp->access_token,
-      &kyp->h_payto);
+      &kyp->h_payto,
+      &kyp->is_wallet);
     if (qs < 0)
     {
       GNUNET_break (0);
@@ -732,6 +803,7 @@ TEH_handler_kyc_info (
   kyp->ru = TALER_EXCHANGEDB_update_rules (TEH_plugin,
                                            &TEH_attribute_key,
                                            &kyp->h_payto,
+                                           kyp->is_wallet,
                                            &current_rules_cb,
                                            kyp);
   kyp->suspended = true;
