@@ -22,14 +22,6 @@
 #include "taler-exchange-httpd_common_kyc.h"
 #include "taler-exchange-httpd_kyc-upload.h"
 
-/**
- * Size of the MHD post processor upload buffer.  Rather large, as we expect
- * large documents. Note that we *additionally* do stream processing, so the
- * actual uploads can be larger and are bounded (globally) by
- * #TALER_MHD_REQUEST_BUFFER_MAX.
- */
-#define UPLOAD_BUFFER_SIZE (1024 * 1024)
-
 
 /**
  * Context used for processing the KYC upload req
@@ -73,11 +65,6 @@ struct UploadContext
    */
   struct MHD_Response *response;
 
-  /**
-   * Our post processor.
-   */
-  struct MHD_PostProcessor *pp;
-
   /**
    * Request we are processing.
    */
@@ -91,37 +78,7 @@ struct UploadContext
   /**
    * Uploaded data, in JSON.
    */
-  json_t *result;
-
-  /**
-   * Last key in upload.
-   */
-  char *last_key;
-
-  /**
-   * Name of the file, possibly NULL.
-   */
-  char *filename;
-
-  /**
-   * Content type, possibly NULL.
-   */
-  char *content_type;
-
-  /**
-   * Current upload data.
-   */
-  char *curr_buf;
-
-  /**
-   * Size of @e curr_buf allocation.
-   */
-  size_t buf_size;
-
-  /**
-   * Number of bytes of actual data in @a curr_buf.
-   */
-  size_t buf_pos;
+  const json_t *result;
 
 };
 
@@ -152,81 +109,6 @@ TEH_kyc_upload_cleanup ()
 }
 
 
-/**
- * Check if the upload data is in binary and thus
- * must be base32-encoded.
- *
- * @param uc upload context with data to eval
- */
-static bool
-is_binary (const struct UploadContext *uc)
-{
-  if (NULL != memchr (uc->curr_buf,
-                      '\0',
-                      uc->buf_pos))
-    return true;
-  if (NULL != uc->filename)
-    return true; /* we always encode all files */
-  if (NULL == uc->content_type)
-    return false; /* fingers crossed */
-  if (0 == strncmp (uc->content_type,
-                    "text/",
-                    strlen ("text/")))
-    return false; /* good */
-  return true;
-}
-
-
-/**
- * Finish processing the data in @a uc under the current
- * key.
- *
- * @param[in,out] uc upload context with key to process
- */
-static void
-finish_key (struct UploadContext *uc)
-{
-  json_t *val;
-
-  if (NULL == uc->last_key)
-    return; /* nothing to do */
-  if (is_binary (uc))
-  {
-    val = GNUNET_JSON_PACK (
-      GNUNET_JSON_pack_allow_null (
-        GNUNET_JSON_pack_string ("filename",
-                                 uc->filename)),
-      GNUNET_JSON_pack_allow_null (
-        GNUNET_JSON_pack_string ("content_type",
-                                 uc->content_type)),
-      GNUNET_JSON_pack_data_varsize ("data",
-                                     uc->curr_buf,
-                                     uc->buf_pos)
-      );
-  }
-  else
-  {
-    val = GNUNET_JSON_PACK (
-      GNUNET_JSON_pack_allow_null (
-        GNUNET_JSON_pack_string ("content_type",
-                                 uc->content_type)),
-      GNUNET_JSON_pack_string ("text",
-                               uc->curr_buf));
-  }
-  GNUNET_assert (0 ==
-                 json_object_set_new (uc->result,
-                                      uc->last_key,
-                                      val));
-  GNUNET_free (uc->last_key);
-  GNUNET_free (uc->filename);
-  GNUNET_free (uc->content_type);
-  memset (uc->curr_buf,
-          0,
-          uc->buf_pos);
-  uc->buf_pos = 0;
-}
-
-
 /**
  * Function called to clean up upload context.
  *
@@ -247,89 +129,10 @@ upload_cleaner (struct TEH_RequestContext *rc)
     MHD_destroy_response (uc->response);
     uc->response = NULL;
   }
-  MHD_destroy_post_processor (uc->pp);
-  GNUNET_free (uc->filename);
-  GNUNET_free (uc->content_type);
-  GNUNET_free (uc->last_key);
-  GNUNET_free (uc->curr_buf);
-  json_decref (uc->result);
   GNUNET_free (uc);
 }
 
 
-/**
- * Iterator over key-value pairs where the value
- * may be made available in increments and/or may
- * not be zero-terminated.  Used for processing
- * POST data.
- *
- * @param cls user-specified closure
- * @param kind type of the value, always #MHD_POSTDATA_KIND when called from MHD
- * @param key 0-terminated key for the value, NULL if not known. This value
- *            is never NULL for url-encoded POST data.
- * @param filename name of the uploaded file, NULL if not known
- * @param content_type mime-type of the data, NULL if not known
- * @param transfer_encoding encoding of the data, NULL if not known
- * @param data pointer to @a size bytes of data at the
- *              specified offset
- * @param off offset of data in the overall value
- * @param size number of bytes in @a data available
- * @return #MHD_YES to continue iterating,
- *         #MHD_NO to abort the iteration
- */
-static enum MHD_Result
-post_helper (void *cls,
-             enum MHD_ValueKind kind,
-             const char *key,
-             const char *filename,
-             const char *content_type,
-             const char *transfer_encoding,
-             const char *data,
-             uint64_t off,
-             size_t size)
-{
-  struct UploadContext *uc = cls;
-
-  if ( (NULL != uc->last_key) &&
-       (0 != strcmp (key,
-                     uc->last_key)) )
-    finish_key (uc);
-  if (NULL == uc->last_key)
-  {
-    uc->last_key = GNUNET_strdup (key);
-    if (NULL != filename)
-      uc->filename = GNUNET_strdup (filename);
-    if (NULL != content_type)
-      uc->content_type = GNUNET_strdup (content_type);
-  }
-  if (size > uc->buf_size - uc->buf_pos)
-  {
-    char *tmp;
-    size_t tgt;
-
-    tgt = uc->buf_size * 2;
-    if (tgt >= GNUNET_MAX_MALLOC_CHECKED - 1)
-      tgt = GNUNET_MAX_MALLOC_CHECKED - 1;
-    if (tgt < size + uc->buf_pos)
-      tgt = size + uc->buf_pos;
-    if (tgt >= GNUNET_MAX_MALLOC_CHECKED - 1)
-      return MHD_NO;
-    tmp = GNUNET_malloc (tgt + 1); /* for 0-termination */
-    memcpy (tmp,
-            uc->curr_buf,
-            uc->buf_pos);
-    GNUNET_free (uc->curr_buf);
-    uc->buf_size = tgt;
-    uc->curr_buf = tmp;
-  }
-  memcpy (uc->curr_buf + uc->buf_pos,
-          data,
-          size);
-  uc->buf_pos += size;
-  return MHD_YES;
-}
-
-
 /**
  * Function called after the KYC-AML trigger is done.
  *
@@ -381,11 +184,11 @@ aml_trigger_callback (
 MHD_RESULT
 TEH_handler_kyc_upload (
   struct TEH_RequestContext *rc,
-  const char *id,
-  size_t *upload_data_size,
-  const char *upload_data)
+  const json_t *root,
+  const char *const args[1])
 {
   struct UploadContext *uc = rc->rh_ctx;
+  const char *id = args[0];
 
   if (NULL == uc)
   {
@@ -394,26 +197,9 @@ TEH_handler_kyc_upload (
 
     uc = GNUNET_new (struct UploadContext);
     uc->rc = rc;
-    uc->pp = MHD_create_post_processor (
-      rc->connection,
-      UPLOAD_BUFFER_SIZE,
-      &post_helper,
-      uc);
-    if (NULL == uc->pp)
-    {
-      GNUNET_break (0);
-      GNUNET_free (uc);
-      return TALER_MHD_reply_with_error (
-        rc->connection,
-        MHD_HTTP_INTERNAL_SERVER_ERROR,
-        TALER_EC_GENERIC_ALLOCATION_FAILURE,
-        "MHD_create_post_processor");
-    }
-    uc->result = json_object ();
-    GNUNET_assert (NULL != uc->result);
+    uc->result = root;
     rc->rh_ctx = uc;
     rc->rh_cleaner = &upload_cleaner;
-
     slash = strchr (id, '-');
     if (NULL == slash)
     {
@@ -451,7 +237,11 @@ TEH_handler_kyc_upload (
         TALER_EC_GENERIC_PARAMETER_MALFORMED,
         "ID is malformed");
     }
-    return MHD_YES;
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "/kyc-upload received form submission\n");
+    json_dumpf (root,
+                stderr,
+                JSON_INDENT (2));
   }
   if (NULL != uc->response)
   {
@@ -460,18 +250,6 @@ TEH_handler_kyc_upload (
                                uc->response);
 
   }
-  if (0 != *upload_data_size)
-  {
-    MHD_RESULT mres;
-
-    mres = MHD_post_process (uc->pp,
-                             upload_data,
-                             *upload_data_size);
-    *upload_data_size = 0;
-    return mres;
-  }
-  finish_key (uc);
-  GNUNET_assert (NULL == uc->kat);
 
   {
     uint64_t legi_process_row;
@@ -484,6 +262,7 @@ TEH_handler_kyc_upload (
     const char *error_message;
     char *form_name;
     enum TALER_ErrorCode ec;
+    bool is_wallet;
 
     qs = TEH_plugin->lookup_completed_legitimization (
       TEH_plugin->cls,
@@ -491,6 +270,7 @@ TEH_handler_kyc_upload (
       uc->measure_index,
       &uc->access_token,
       &h_payto,
+      &is_wallet,
       &jmeasures,
       &is_finished,
       &enc_attributes_len,
@@ -505,7 +285,8 @@ TEH_handler_kyc_upload (
         &uc->access_token,
         &h_payto,
         &jmeasures,
-        &is_finished);
+        &is_finished,
+        &is_wallet);
     if (qs < 0)
     {
       GNUNET_break (0);
@@ -622,6 +403,7 @@ TEH_handler_kyc_upload (
       &rc->async_scope_id,
       legi_process_row,
       &h_payto,
+      is_wallet,
       &aml_trigger_callback,
       uc);
     if (NULL == uc->kat)
