@@ -45,7 +45,7 @@ struct DelWireContext
   /**
    * Payto:// URI this is about.
    */
-  const char *payto_uri;
+  struct TALER_FullPayto payto_uri;
 
   /**
    * Timestamp for checking against replay attacks.
@@ -146,8 +146,8 @@ TEH_handler_management_post_wire_disable (
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_fixed_auto ("master_sig_del",
                                  &awc.master_sig),
-    TALER_JSON_spec_payto_uri ("payto_uri",
-                               &awc.payto_uri),
+    TALER_JSON_spec_full_payto_uri ("payto_uri",
+                                    &awc.payto_uri),
     GNUNET_JSON_spec_timestamp ("validity_end",
                                 &awc.validity_end),
     GNUNET_JSON_spec_end ()
