@@ -34,20 +34,17 @@ enum TEH_MetricTypeRequest
   TEH_MT_REQUEST_OTHER = 0,
   TEH_MT_REQUEST_DEPOSIT = 1,
   TEH_MT_REQUEST_WITHDRAW = 2,
-  TEH_MT_REQUEST_AGE_WITHDRAW = 3,
-  TEH_MT_REQUEST_MELT = 4,
-  TEH_MT_REQUEST_PURSE_CREATE = 5,
-  TEH_MT_REQUEST_PURSE_MERGE = 6,
-  TEH_MT_REQUEST_RESERVE_PURSE = 7,
-  TEH_MT_REQUEST_PURSE_DEPOSIT = 8,
-  TEH_MT_REQUEST_IDEMPOTENT_DEPOSIT = 9,
-  TEH_MT_REQUEST_IDEMPOTENT_WITHDRAW = 10,
-  TEH_MT_REQUEST_IDEMPOTENT_AGE_WITHDRAW = 11,
-  TEH_MT_REQUEST_IDEMPOTENT_MELT = 12,
-  TEH_MT_REQUEST_IDEMPOTENT_BATCH_WITHDRAW = 13,
-  TEH_MT_REQUEST_BATCH_DEPOSIT = 14,
-  TEH_MT_REQUEST_POLICY_FULFILLMENT = 15,
-  TEH_MT_REQUEST_COUNT = 16 /* MUST BE LAST! */
+  TEH_MT_REQUEST_MELT = 3,
+  TEH_MT_REQUEST_PURSE_CREATE = 4,
+  TEH_MT_REQUEST_PURSE_MERGE = 5,
+  TEH_MT_REQUEST_RESERVE_PURSE = 6,
+  TEH_MT_REQUEST_PURSE_DEPOSIT = 7,
+  TEH_MT_REQUEST_IDEMPOTENT_DEPOSIT = 8,
+  TEH_MT_REQUEST_IDEMPOTENT_WITHDRAW = 9,
+  TEH_MT_REQUEST_IDEMPOTENT_MELT = 10,
+  TEH_MT_REQUEST_BATCH_DEPOSIT = 11,
+  TEH_MT_REQUEST_POLICY_FULFILLMENT = 12,
+  TEH_MT_REQUEST_COUNT = 13 /* MUST BE LAST! */
 };
 
 /**
@@ -57,12 +54,10 @@ enum TEH_MetricTypeSuccess
 {
   TEH_MT_SUCCESS_DEPOSIT = 0,
   TEH_MT_SUCCESS_WITHDRAW = 1,
-  TEH_MT_SUCCESS_AGE_WITHDRAW = 2,
-  TEH_MT_SUCCESS_BATCH_WITHDRAW = 3,
-  TEH_MT_SUCCESS_MELT = 4,
-  TEH_MT_SUCCESS_REFRESH_REVEAL = 5,
-  TEH_MT_SUCCESS_AGE_WITHDRAW_REVEAL = 6,
-  TEH_MT_SUCCESS_COUNT = 7 /* MUST BE LAST! */
+  TEH_MT_SUCCESS_MELT = 2,
+  TEH_MT_SUCCESS_REFRESH_REVEAL = 3,
+  TEH_MT_SUCCESS_WITHDRAW_REVEAL = 4,
+  TEH_MT_SUCCESS_COUNT = 5 /* MUST BE LAST! */
 };
 
 /**
@@ -96,9 +91,9 @@ extern unsigned long long TEH_METRICS_num_requests[TEH_MT_REQUEST_COUNT];
 extern unsigned long long TEH_METRICS_num_success[TEH_MT_SUCCESS_COUNT];
 
 /**
- * Number of coins withdrawn in a batch-withdraw request
+ * Number of coins withdrawn in a withdraw request
  */
-extern unsigned long long TEH_METRICS_batch_withdraw_num_coins;
+extern unsigned long long TEH_METRICS_withdraw_num_coins;
 
 /**
  * Number of serialization errors encountered when
