@@ -500,7 +500,7 @@ TEH_handler_purses_create (
   }
   pcc.num_coins = json_array_size (deposits);
   if ( (0 == pcc.num_coins) ||
-       (pcc.num_coins > TALER_MAX_FRESH_COINS) )
+       (pcc.num_coins > TALER_MAX_COINS) )
   {
     GNUNET_break_op (0);
     GNUNET_JSON_parse_free (spec);
