@@ -115,17 +115,25 @@ TEH_handler_purses_delete (
   {
     /* Possible minor optimization: integrate notification with
        transaction above... */
-    struct TALER_PurseEventP rep = {
-      .header.size = htons (sizeof (rep)),
+    struct TALER_PurseEventP rep_deposited = {
+      .header.size = htons (sizeof (rep_deposited)),
       .header.type = htons (TALER_DBEVENT_EXCHANGE_PURSE_DEPOSITED),
       .purse_pub = purse_pub
     };
-
+    struct TALER_PurseEventP rep_merged = {
+      .header.size = htons (sizeof (rep_merged)),
+      .header.type = htons (TALER_DBEVENT_EXCHANGE_PURSE_MERGED),
+      .purse_pub = purse_pub
+    };
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                 "Notifying about purse deletion %s\n",
                 TALER_B2S (&purse_pub));
     TEH_plugin->event_notify (TEH_plugin->cls,
-                              &rep.header,
+                              &rep_deposited.header,
+                              NULL,
+                              0);
+    TEH_plugin->event_notify (TEH_plugin->cls,
+                              &rep_merged.header,
                               NULL,
                               0);
   }
