@@ -362,7 +362,7 @@ TEH_handler_purses_deposit (
   pcc.num_coins = (unsigned int) json_array_size (deposits);
   if ( (0 == pcc.num_coins) ||
        (((size_t) pcc.num_coins) != json_array_size (deposits)) ||
-       (pcc.num_coins > TALER_MAX_FRESH_COINS) )
+       (pcc.num_coins > TALER_MAX_COINS) )
   {
     GNUNET_break_op (0);
     return TALER_MHD_reply_with_error (connection,
