@@ -66,9 +66,9 @@ struct RecoupContext
   const struct TALER_CoinSpendSignatureP *coin_sig;
 
   /**
-   * Unique ID of the withdraw operation in the reserves_out table.
+   * Unique ID of the withdraw operation in the withdraw table.
    */
-  uint64_t reserve_out_serial_id;
+  uint64_t withdraw_serial_id;
 
   /**
    * Unique ID of the coin in the known_coins table.
@@ -115,7 +115,7 @@ recoup_transaction (void *cls,
   pc->now = GNUNET_TIME_timestamp_get ();
   qs = TEH_plugin->do_recoup (TEH_plugin->cls,
                               &pc->reserve_pub,
-                              pc->reserve_out_serial_id,
+                              pc->withdraw_serial_id,
                               pc->coin_bks,
                               &pc->coin->coin_pub,
                               pc->known_coin_id,
@@ -169,6 +169,7 @@ recoup_transaction (void *cls,
  * @param exchange_vals values contributed by the exchange
  *         during withdrawal
  * @param coin_bks blinding data of the coin (to be checked)
+ * @param h_planchets The hash of the commitment of the original withdraw request
  * @param nonce coin's nonce if CS is used
  * @param coin_sig signature of the coin
  * @return MHD result code
@@ -177,8 +178,9 @@ static MHD_RESULT
 verify_and_execute_recoup (
   struct MHD_Connection *connection,
   const struct TALER_CoinPublicInfo *coin,
-  const struct TALER_ExchangeWithdrawValues *exchange_vals,
+  const struct TALER_ExchangeBlindingValues *exchange_vals,
   const union GNUNET_CRYPTO_BlindingSecretP *coin_bks,
+  const struct TALER_HashBlindedPlanchetsP *h_planchets,
   const union GNUNET_CRYPTO_BlindSessionNonce *nonce,
   const struct TALER_CoinSpendSignatureP *coin_sig)
 {
@@ -312,10 +314,11 @@ verify_and_execute_recoup (
   {
     enum GNUNET_DB_QueryStatus qs;
 
-    qs = TEH_plugin->get_reserve_by_h_blind (TEH_plugin->cls,
-                                             &pc.h_coin_ev,
-                                             &pc.reserve_pub,
-                                             &pc.reserve_out_serial_id);
+    qs = TEH_plugin->get_reserve_by_h_planchets (
+      TEH_plugin->cls,
+      h_planchets,
+      &pc.reserve_pub,
+      &pc.withdraw_serial_id);
     if (0 > qs)
     {
       GNUNET_break (0);
@@ -323,7 +326,7 @@ verify_and_execute_recoup (
         connection,
         MHD_HTTP_INTERNAL_SERVER_ERROR,
         TALER_EC_GENERIC_DB_FETCH_FAILED,
-        "get_reserve_by_h_blind");
+        "get_reserve_by_commitment");
     }
     if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
     {
@@ -380,7 +383,8 @@ TEH_handler_recoup (struct MHD_Connection *connection,
   struct TALER_CoinPublicInfo coin;
   union GNUNET_CRYPTO_BlindingSecretP coin_bks;
   struct TALER_CoinSpendSignatureP coin_sig;
-  struct TALER_ExchangeWithdrawValues exchange_vals;
+  struct TALER_ExchangeBlindingValues exchange_vals;
+  struct TALER_HashBlindedPlanchetsP h_planchets;
   union GNUNET_CRYPTO_BlindSessionNonce nonce;
   bool no_nonce;
   struct GNUNET_JSON_Specification spec[] = {
@@ -388,7 +392,9 @@ TEH_handler_recoup (struct MHD_Connection *connection,
                                  &coin.denom_pub_hash),
     TALER_JSON_spec_denom_sig ("denom_sig",
                                &coin.denom_sig),
-    TALER_JSON_spec_exchange_withdraw_values ("ewv",
+    GNUNET_JSON_spec_fixed_auto ("h_planchets",
+                                 &h_planchets),
+    TALER_JSON_spec_exchange_blinding_values ("ewv",
                                               &exchange_vals),
     GNUNET_JSON_spec_fixed_auto ("coin_blind_key_secret",
                                  &coin_bks),
@@ -423,6 +429,7 @@ TEH_handler_recoup (struct MHD_Connection *connection,
                                      &coin,
                                      &exchange_vals,
                                      &coin_bks,
+                                     &h_planchets,
                                      no_nonce
                                      ? NULL
                                      : &nonce,
