@@ -76,33 +76,150 @@ compile_reserve_history (
         }
         break;
       }
-    case TALER_EXCHANGEDB_RO_WITHDRAW_COIN:
+    case TALER_EXCHANGEDB_RO_WITHDRAW_COINS:
       {
-        const struct TALER_EXCHANGEDB_CollectableBlindcoin *withdraw
+        const struct TALER_EXCHANGEDB_Withdraw *withdraw
           = pos->details.withdraw;
+        struct TALER_Amount withdraw_fee;
+        struct TEH_KeyStateHandle *ksh;
 
-        if (0 !=
-            json_array_append_new (
-              json_history,
-              GNUNET_JSON_PACK (
-                GNUNET_JSON_pack_string ("type",
-                                         "WITHDRAW"),
-                GNUNET_JSON_pack_data_auto ("reserve_sig",
-                                            &withdraw->reserve_sig),
-                GNUNET_JSON_pack_data_auto ("h_coin_envelope",
-                                            &withdraw->h_coin_envelope),
-                GNUNET_JSON_pack_data_auto ("h_denom_pub",
-                                            &withdraw->denom_pub_hash),
-                TALER_JSON_pack_amount ("withdraw_fee",
-                                        &withdraw->withdraw_fee),
-                TALER_JSON_pack_amount ("amount",
-                                        &withdraw->amount_with_fee))))
+        GNUNET_assert (GNUNET_OK ==
+                       TALER_amount_set_zero (
+                         TEH_currency,
+                         &withdraw_fee));
+
+        /*
+         * We need to calculate the fees for the withdraw.
+         * Therefore, we need to get access to the key state.
+         */
+        ksh = TEH_keys_get_state ();
+        if (NULL == ksh)
         {
           GNUNET_break (0);
           json_decref (json_history);
           return NULL;
         }
+
+        for (size_t i = 0; i < withdraw->num_coins; i++)
+        {
+          /* Find the denomination and accumulate the fee */
+          {
+            struct TEH_DenominationKey *dk;
+            dk = TEH_keys_denomination_by_hash_from_state (
+              ksh,
+              &withdraw->denom_pub_hashes[i],
+              NULL,
+              NULL);
+
+            if (NULL == dk)
+            {
+              GNUNET_break (0);
+              json_decref (json_history);
+              return NULL;
+            }
+
+            if (0 > TALER_amount_add (&withdraw_fee,
+                                      &withdraw_fee,
+                                      &dk->meta.fees.withdraw))
+            {
+              GNUNET_break (0);
+              json_decref (json_history);
+              return NULL;
+            }
+          }
+        }
+
+        /* Prepare the entry for the history */
+        {
+          json_t *j_entry = GNUNET_JSON_PACK (
+            GNUNET_JSON_pack_string (
+              "type",
+              "WITHDRAW"),
+            GNUNET_JSON_pack_data_auto (
+              "reserve_sig",
+              &withdraw->reserve_sig),
+            GNUNET_JSON_pack_data_auto (
+              "planchets_h",
+              &withdraw->planchets_h),
+            GNUNET_JSON_pack_uint64 (
+              "num_coins",
+              withdraw->num_coins),
+            TALER_JSON_pack_array_of_data (
+              "denom_pub_hashes",
+              withdraw->num_coins,
+              withdraw->denom_pub_hashes,
+              sizeof(withdraw->denom_pub_hashes[0])),
+            TALER_JSON_pack_amount (
+              "withdraw_fee",
+              &withdraw_fee),
+            TALER_JSON_pack_amount (
+              "amount",
+              &withdraw->amount_with_fee)
+            );
+
+          if (! withdraw->no_blinding_seed)
+          {
+            if (0!=
+                json_object_update_new (
+                  j_entry,
+                  GNUNET_JSON_PACK (
+                    GNUNET_JSON_pack_data_auto (
+                      "blinding_seed",
+                      &withdraw->blinding_seed))))
+            {
+              GNUNET_break (0);
+              json_decref (json_history);
+              return NULL;
+            }
+            if (0!=
+                json_object_update_new (
+                  j_entry,
+                  GNUNET_JSON_PACK (
+                    TALER_JSON_pack_array_of_data (
+                      "cs_r_values",
+                      withdraw->num_cs_r_values,
+                      withdraw->cs_r_values,
+                      sizeof(withdraw->cs_r_values[0])))))
+            {
+              GNUNET_break (0);
+              json_decref (json_history);
+              return NULL;
+            }
+          }
+          if (withdraw->age_proof_required)
+          {
+            if (0 !=
+                json_object_update_new (
+                  j_entry,
+                  GNUNET_JSON_PACK (
+                    GNUNET_JSON_pack_uint64 (
+                      "noreveal_index",
+                      withdraw->noreveal_index),
+                    GNUNET_JSON_pack_data_auto (
+                      "selected_h",
+                      &withdraw->selected_h),
+                    GNUNET_JSON_pack_uint64 (
+                      "max_age",
+                      withdraw->max_age))))
+            {
+              GNUNET_break (0);
+              json_decref (json_history);
+              return NULL;
+            }
+          }
+
+          if (0 !=
+              json_array_append_new (
+                json_history,
+                j_entry))
+          {
+            GNUNET_break (0);
+            json_decref (json_history);
+            return NULL;
+          }
+        }
       }
+
       break;
     case TALER_EXCHANGEDB_RO_RECOUP_COIN:
       {
@@ -323,7 +440,6 @@ compile_reserve_history (
       break;
     }
   }
-
   return json_history;
 }
 
@@ -458,6 +574,8 @@ TEH_handler_reserves_history (
                    (unsigned long long) etag_out);
   if (etag_in == etag_out)
   {
+    TEH_plugin->free_reserve_history (TEH_plugin->cls,
+                                      rh);
     return TEH_RESPONSE_reply_not_modified (rc->connection,
                                             etagp,
                                             &add_response_headers,
