@@ -31,13 +31,13 @@
  * What is the default batch size we use for credit history
  * requests with the bank.  See `batch_size` below.
  */
-#define DEFAULT_BATCH_SIZE (4 * 1024)
+#define DEFAULT_BATCH_SIZE 32
 
 /**
  * How often will we retry a request (given certain
  * HTTP status codes) before giving up?
  */
-#define MAX_RETRIES 16
+#define MAX_RETRIES 3
 
 /**
  * Information about our work shard.
