@@ -37,6 +37,7 @@ CREATE FUNCTION exchange_do_deposit(
   IN ina_coin_pub BYTEA[],
   IN ina_coin_sig BYTEA[],
   IN ina_amount_with_fee taler_amount[],
+  IN in_total_amount taler_amount,
   OUT out_exchange_timestamp INT8,
   OUT out_insufficient_balance_coin_index INT4, -- index of coin with bad balance, NULL if none
   OUT out_conflict BOOL
@@ -100,6 +101,7 @@ INSERT INTO batch_deposits
   ,wire_target_h_payto
   ,policy_details_serial_id
   ,policy_blocked
+  ,total_amount
   )
   VALUES
   (in_shard
@@ -114,7 +116,8 @@ INSERT INTO batch_deposits
   ,in_wire_salt
   ,in_wire_target_h_payto
   ,in_policy_details_serial_id
-  ,in_policy_blocked)
+  ,in_policy_blocked
+  ,in_total_amount)
   ON CONFLICT DO NOTHING -- for CONFLICT ON (merchant_pub, h_contract_terms)
   RETURNING
     batch_deposit_serial_id
