@@ -22,6 +22,9 @@ CREATE FUNCTION exchange_do_insert_aml_decision(
   IN in_decision_time INT8,
   IN in_expiration_time INT8,
   IN in_properties TEXT, -- can be NULL
+  IN in_kyc_attributes_enc BYTEA, -- can be NULL
+  IN in_kyc_attributes_hash BYTEA, -- can be NULL
+  IN in_kyc_attributes_expiration INT8, -- can be NULL
   IN in_new_rules TEXT,
   IN in_to_investigate BOOLEAN,
   IN in_new_measure_name TEXT, -- can be NULL
@@ -31,14 +34,19 @@ CREATE FUNCTION exchange_do_insert_aml_decision(
   IN in_decider_sig BYTEA, -- can be NULL
   IN in_notify_s TEXT,
   IN ina_events TEXT[],
+  IN in_form_name TEXT, -- can be NULL
   OUT out_invalid_officer BOOLEAN,
   OUT out_account_unknown BOOLEAN,
   OUT out_last_date INT8,
-  OUT out_legitimization_measure_serial_id INT8)
+  OUT out_legitimization_measure_serial_id INT8,
+  OUT out_payto_uri TEXT)
 LANGUAGE plpgsql
 AS $$
 DECLARE
   my_outcome_serial_id INT8;
+  my_legitimization_process_serial_id INT8;
+  my_kyc_attributes_serial_id INT8;
+  my_rec RECORD;
   my_access_token BYTEA;
   my_i INT4;
   ini_event TEXT;
@@ -93,7 +101,8 @@ ELSE
 END IF;
 
 SELECT access_token
-  INTO my_access_token
+      ,payto_uri
+  INTO my_rec
   FROM wire_targets
  WHERE h_normalized_payto=in_h_normalized_payto;
 
@@ -105,7 +114,7 @@ THEN
     out_account_unknown=TRUE;
     RETURN;
   END IF;
-
+  out_payto_uri = in_payto_uri;
   INSERT INTO wire_targets
     (wire_target_h_payto
     ,h_normalized_payto
@@ -116,6 +125,9 @@ THEN
     ,in_payto_uri)
     RETURNING access_token
       INTO my_access_token;
+ELSE
+  my_access_token = my_rec.access_token;
+  out_payto_uri = my_rec.payto_uri;
 END IF;
 
 -- Did KYC measures get prescribed?
@@ -151,6 +163,8 @@ THEN
   -- end if for where we had in_jmeasures
 END IF;
 
+RAISE NOTICE 'marking legi measures of % as finished except for %', my_access_token, out_legitimization_measure_serial_id;
+
 -- AML decision: mark all other active measures finished!
 UPDATE legitimization_measures
   SET is_finished=TRUE
@@ -188,6 +202,57 @@ INSERT INTO legitimization_outcomes
   INTO
     my_outcome_serial_id;
 
+IF in_kyc_attributes_enc IS NOT NULL
+THEN
+  IF in_kyc_attributes_hash IS NULL OR in_kyc_attributes_expiration IS NULL
+  THEN
+    RAISE EXCEPTION 'Got in_kyc_attributes_hash without hash or expiration.';
+  END IF;
+  IF in_decider_pub IS NULL
+  THEN
+    RAISE EXCEPTION 'Got in_kyc_attributes_hash without in_decider_pub.';
+  END IF;
+  -- Simulate a legi process for attribute insertion by AML Officer
+  INSERT INTO legitimization_processes
+    (h_payto
+    ,start_time
+    ,expiration_time
+    ,provider_name
+    ,provider_user_id
+    ,finished
+    ) VALUES
+    (in_h_normalized_payto
+    ,in_decision_time
+    -- Process starts and finishes instantly
+    ,in_decision_time
+    ,'aml-officer'
+    ,in_decider_pub
+    ,TRUE
+    )
+    RETURNING legitimization_process_serial_id
+    INTO my_legitimization_process_serial_id;
+  -- Now we can insert the attribute!
+  INSERT INTO kyc_attributes
+    (h_payto
+    ,collection_time
+    ,expiration_time
+    ,form_name
+    ,by_aml_officer
+    ,encrypted_attributes
+    ,legitimization_serial
+    ) VALUES
+    (in_h_normalized_payto
+    ,in_decision_time
+    ,in_kyc_attributes_expiration
+    ,in_form_name
+    ,TRUE
+    ,in_kyc_attributes_enc
+    ,my_legitimization_process_serial_id
+    )
+    RETURNING kyc_attributes_serial_id
+    INTO my_kyc_attributes_serial_id;
+END IF;
+
 IF in_decider_pub IS NOT NULL
 THEN
   INSERT INTO aml_history
@@ -196,12 +261,16 @@ THEN
     ,justification
     ,decider_pub
     ,decider_sig
+    ,kyc_attributes_hash
+    ,kyc_attributes_serial_id
     ) VALUES
     (in_h_normalized_payto
     ,my_outcome_serial_id
     ,in_justification
     ,in_decider_pub
     ,in_decider_sig
+    ,in_kyc_attributes_hash
+    ,my_kyc_attributes_serial_id
   );
 END IF;
 
@@ -233,5 +302,5 @@ EXECUTE FORMAT (
 END $$;
 
 
-COMMENT ON FUNCTION exchange_do_insert_aml_decision(TEXT, BYTEA, BYTEA, INT8, INT8, TEXT, TEXT, BOOLEAN, TEXT, TEXT, TEXT, BYTEA, BYTEA, TEXT, TEXT[])
+COMMENT ON FUNCTION exchange_do_insert_aml_decision(TEXT, BYTEA, BYTEA, INT8, INT8, TEXT, BYTEA, BYTEA, INT8, TEXT, BOOLEAN, TEXT, TEXT, TEXT, BYTEA, BYTEA, TEXT, TEXT[], TEXT)
   IS 'Checks whether the AML officer is eligible to make AML decisions and if so inserts the decision into the table';
