@@ -23,7 +23,9 @@ CREATE FUNCTION exchange_do_lookup_kyc_requirement_by_row(
   OUT out_reserve_pub BYTEA, -- NULL allowed
   OUT out_access_token BYTEA, -- NULL if 'out_not_found'
   OUT out_jrules TEXT, -- NULL allowed
+  OUT out_payto TEXT, -- NULL allowed
   OUT out_not_found BOOLEAN,
+  OUT out_rule_gen INT8, -- NULL allowed
   OUT out_aml_review BOOLEAN, -- NULL allowed
   OUT out_kyc_required BOOLEAN)
 LANGUAGE plpgsql
@@ -36,6 +38,7 @@ BEGIN
 -- Find the access token and the current account public key.
 SELECT access_token
       ,target_pub
+      ,payto_uri
   INTO my_wtrec
   FROM wire_targets
  WHERE h_normalized_payto=in_h_normalized_payto;
@@ -48,6 +51,7 @@ THEN
 END IF;
 out_not_found = FALSE;
 
+out_payto = my_wtrec.payto_uri;
 out_account_pub = my_wtrec.target_pub;
 out_access_token = my_wtrec.access_token;
 
@@ -64,6 +68,7 @@ out_kyc_required = FOUND;
 -- Only one should ever be active per account.
 SELECT jnew_rules
       ,to_investigate
+      ,outcome_serial_id
   INTO my_lorec
   FROM legitimization_outcomes
  WHERE h_payto=in_h_normalized_payto
@@ -73,6 +78,7 @@ IF FOUND
 THEN
   out_jrules=my_lorec.jnew_rules;
   out_aml_review=my_lorec.to_investigate;
+  out_rule_gen=my_lorec.outcome_serial_id;
 END IF;
 
 -- Check most recent reserve_in wire transfer, we also
