@@ -37,20 +37,57 @@ TALER_EXCHANGEDB_persist_aml_program_result (
   struct TALER_EXCHANGEDB_Plugin *plugin,
   uint64_t process_row,
   const struct TALER_NormalizedPaytoHashP *account_id,
-  const struct TALER_KYCLOGIC_AmlProgramResult *apr)
+  const struct TALER_KYCLOGIC_AmlProgramResult *apr,
+  enum TALER_EXCHANGEDB_PersistProgramResultStatus *ret_pprs)
 {
   enum GNUNET_DB_QueryStatus qs;
   json_t *jmeasures = NULL;
   struct TALER_KYCLOGIC_LegitimizationRuleSet *lrs = NULL;
 
-  if (NULL != apr->details.success.new_measures)
+  GNUNET_assert (NULL != ret_pprs);
+
+  *ret_pprs = TALER_EXCHANGEDB_PPRS_OK;
+
+  if ( (TALER_KYCLOGIC_AMLR_SUCCESS == apr->status) &&
+       (NULL != apr->details.success.new_measures) )
   {
     lrs = TALER_KYCLOGIC_rules_parse (apr->details.success.new_rules);
-    GNUNET_assert (NULL != lrs);
+    if (NULL == lrs)
+    {
+      qs = plugin->insert_aml_program_failure (
+        plugin->cls,
+        process_row,
+        account_id,
+        "Failed to parse AML program output",
+        TALER_EC_EXCHANGE_KYC_AML_PROGRAM_MALFORMED_RESULT);
+      GNUNET_break (qs > 0);
+      return qs;
+    }
     jmeasures = TALER_KYCLOGIC_get_jmeasures (
       lrs,
       apr->details.success.new_measures);
-    GNUNET_assert (NULL != jmeasures);
+    if (NULL == jmeasures)
+    {
+      char *err;
+
+      GNUNET_break (0);
+      GNUNET_asprintf (&err,
+                       "Failed to find measures `%s' specified in AML program output",
+                       apr->details.success.new_measures);
+      GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                  "AML program specified invalid measures `%s'\n",
+                  apr->details.success.new_measures);
+      qs = plugin->insert_aml_program_failure (
+        plugin->cls,
+        process_row,
+        account_id,
+        err,
+        TALER_EC_EXCHANGE_KYC_AML_PROGRAM_MALFORMED_RESULT);
+      *ret_pprs = TALER_EXCHANGEDB_PPRS_BAD_OUTCOME;
+      GNUNET_free (err);
+      GNUNET_break (qs > 0);
+      return qs;
+    }
   }
 
   qs = plugin->clear_aml_lock (
@@ -74,6 +111,7 @@ TALER_EXCHANGEDB_persist_aml_program_result (
       bool unknown_account;
       struct GNUNET_TIME_Timestamp last_date;
       uint64_t legitimization_measure_serial_id;
+      bool is_wallet;
 
       qs = plugin->insert_aml_decision (
         plugin->cls,
@@ -91,10 +129,16 @@ TALER_EXCHANGEDB_persist_aml_program_result (
         NULL, /* decider_sig */
         apr->details.success.num_events,
         apr->details.success.events,
+        NULL, /* form ID */
+        0, /* enc_attributes_size*/
+        NULL, /* enc_attributes*/
+        NULL, /* attributes_hash */
+        GNUNET_TIME_UNIT_ZERO_TS, /* attributes_expiration_time */
         &invalid_officer,
         &unknown_account,
         &last_date,
-        &legitimization_measure_serial_id);
+        &legitimization_measure_serial_id,
+        &is_wallet);
       GNUNET_break (qs > 0);
       goto cleanup;
     }
@@ -181,6 +225,11 @@ struct TALER_EXCHANGEDB_RuleUpdater
    * Counter used to limit recursion depth.
    */
   unsigned int depth;
+
+  /**
+   * True if @e account is for a wallet.
+   */
+  bool is_wallet;
 };
 
 
@@ -267,6 +316,7 @@ aml_result_callback (
   struct TALER_EXCHANGEDB_RuleUpdater *ru = cls;
   enum GNUNET_DB_QueryStatus qs;
   enum GNUNET_GenericReturnValue res;
+  enum TALER_EXCHANGEDB_PersistProgramResultStatus pprs;
 
   ru->amlh = NULL;
   res = ru->plugin->start (ru->plugin->cls,
@@ -284,7 +334,8 @@ aml_result_callback (
     ru->plugin,
     0LLU, /* 0: no existing legitimization process, creates new row */
     &ru->account,
-    apr);
+    apr,
+    &pprs);
   switch (qs)
   {
   case GNUNET_DB_STATUS_HARD_ERROR:
@@ -308,6 +359,16 @@ aml_result_callback (
     /* normal case */
     break;
   }
+  switch (pprs)
+  {
+  case TALER_EXCHANGEDB_PPRS_OK:
+    break;
+  case TALER_EXCHANGEDB_PPRS_BAD_OUTCOME:
+    fail_update (ru,
+                 TALER_EC_EXCHANGE_KYC_AML_PROGRAM_MALFORMED_RESULT,
+                 "persist_aml_program_result");
+    return;
+  }
   switch (apr->status)
   {
   case TALER_KYCLOGIC_AMLR_SUCCESS:
@@ -407,6 +468,7 @@ run_measure (struct TALER_EXCHANGEDB_RuleUpdater *ru,
   {
     struct TALER_EXCHANGEDB_HistoryBuilderContext hbc = {
       .account = &ru->account,
+      .is_wallet = ru->is_wallet,
       .db_plugin = ru->plugin,
       .attribute_key = &ru->attribute_key
     };
@@ -458,6 +520,7 @@ run_measure (struct TALER_EXCHANGEDB_RuleUpdater *ru,
                 m->prog_name);
     GNUNET_assert (NULL == ru->t);
     ru->amlh = TALER_KYCLOGIC_run_aml_program3 (
+      ru->is_wallet,
       m,
       &TALER_EXCHANGEDB_current_attributes_builder,
       &hbc,
@@ -643,6 +706,7 @@ TALER_EXCHANGEDB_update_rules (
   struct TALER_EXCHANGEDB_Plugin *plugin,
   const struct TALER_AttributeEncryptionKeyP *attribute_key,
   const struct TALER_NormalizedPaytoHashP *account,
+  bool is_wallet,
   TALER_EXCHANGEDB_CurrentRulesCallback cb,
   void *cb_cls)
 {
@@ -652,6 +716,7 @@ TALER_EXCHANGEDB_update_rules (
   ru->plugin = plugin;
   ru->attribute_key = *attribute_key;
   ru->account = *account;
+  ru->is_wallet = is_wallet;
   ru->cb = cb;
   ru->cb_cls = cb_cls;
   ru->t = GNUNET_SCHEDULER_add_now (&fetch_latest_rules,
