@@ -16,7 +16,7 @@
 /**
  * @file exchangedb/perf_deposits_get_ready.c
  * @brief benchmark for deposits_get_ready
-git  * @author Joseph Xu
+ * @author Joseph Xu
  */
 #include "platform.h"
 #include "taler_exchangedb_lib.h"
@@ -161,6 +161,7 @@ create_denom_key_pair (unsigned int size,
   if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
       plugin->get_denomination_info (plugin->cls,
                                      &dki.issue.denom_hash,
+                                     NULL,
                                      &issue2))
   {
     GNUNET_break (0);
@@ -206,7 +207,7 @@ run (void *cls)
     .cipher = GNUNET_CRYPTO_BSA_RSA,
     .rc = 0
   };
-  struct TALER_ExchangeWithdrawValues alg_values = {
+  struct TALER_ExchangeBlindingValues alg_values = {
     .blinding_inputs = &bi
   };
 
@@ -369,39 +370,33 @@ run (void *cls)
                    TALER_amount_set_zero (CURRENCY,
                                           &cbc.withdraw_fee));
     {
-      bool found;
       bool nonce_reuse;
       bool balance_ok;
       bool age_ok;
-      bool conflict;
-      bool denom_unknown;
+      bool idempotent;
+      uint16_t noreveal_index;
       struct TALER_Amount reserve_balance;
       uint16_t allowed_minimum_age;
-      uint64_t ruuid;
+      uint32_t reserve_birthday;
       struct GNUNET_TIME_Timestamp now;
+      struct TALER_EXCHANGEDB_Withdraw withdraw =  {
+        .amount_with_fee = value,
+        .reserve_pub = reserve_pub,
+      };
 
       now = GNUNET_TIME_timestamp_get ();
       FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
-              plugin->do_batch_withdraw (plugin->cls,
-                                         now,
-                                         &reserve_pub,
-                                         &value,
-                                         true,
-                                         &found,
-                                         &balance_ok,
-                                         &reserve_balance,
-                                         &age_ok,
-                                         &allowed_minimum_age,
-                                         &ruuid));
-      FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
-              plugin->do_batch_withdraw_insert (plugin->cls,
-                                                NULL,
-                                                &cbc,
-                                                now,
-                                                ruuid,
-                                                &denom_unknown,
-                                                &conflict,
-                                                &nonce_reuse));
+              plugin->do_withdraw (plugin->cls,
+                                   &withdraw,
+                                   &now,
+                                   &balance_ok,
+                                   &reserve_balance,
+                                   &age_ok,
+                                   &allowed_minimum_age,
+                                   &reserve_birthday,
+                                   &idempotent,
+                                   &noreveal_index,
+                                   &nonce_reuse));
     }
     {
       /* ENSURE_COIN_KNOWN */
