@@ -158,6 +158,7 @@ create_denom_key_pair (unsigned int size,
   if (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
       plugin->get_denomination_info (plugin->cls,
                                      &dki.issue.denom_hash,
+                                     NULL,
                                      &issue2))
   {
     GNUNET_break (0);
@@ -220,7 +221,7 @@ run (void *cls)
     .cipher = GNUNET_CRYPTO_BSA_RSA,
     .rc = 0
   };
-  struct TALER_ExchangeWithdrawValues alg_values = {
+  struct TALER_ExchangeBlindingValues alg_values = {
     .blinding_inputs = &bi
   };
   struct GNUNET_TIME_Relative times = GNUNET_TIME_UNIT_ZERO;
