@@ -164,7 +164,7 @@ TEH_PG_begin_revolving_shard (void *cls,
                                       end_row),
         GNUNET_PQ_result_spec_end
       };
-      /* Used in #postgres_begin_revolving_shard() */
+
       PREPARE (pg,
                "get_open_revolving_shard",
                "SELECT"
@@ -194,9 +194,9 @@ TEH_PG_begin_revolving_shard (void *cls,
         return qs;
       case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
         {
-          enum GNUNET_DB_QueryStatus qs;
+          enum GNUNET_DB_QueryStatus qsz;
           struct GNUNET_TIME_Timestamp now;
-          struct GNUNET_PQ_QueryParam params[] = {
+          struct GNUNET_PQ_QueryParam iparams[] = {
             GNUNET_PQ_query_param_string (job_name),
             GNUNET_PQ_query_param_timestamp (&now),
             GNUNET_PQ_query_param_uint32 (start_row),
@@ -205,8 +205,6 @@ TEH_PG_begin_revolving_shard (void *cls,
           };
 
           now = GNUNET_TIME_timestamp_get ();
-
-          /* Used in #postgres_begin_revolving_shard() */
           PREPARE (pg,
                    "reclaim_revolving_shard",
                    "UPDATE revolving_work_shards"
@@ -215,10 +213,10 @@ TEH_PG_begin_revolving_shard (void *cls,
                    " WHERE job_name=$1"
                    "   AND start_row=$3"
                    "   AND end_row=$4");
-          qs = GNUNET_PQ_eval_prepared_non_select (pg->conn,
-                                                   "reclaim_revolving_shard",
-                                                   params);
-          switch (qs)
+          qsz = GNUNET_PQ_eval_prepared_non_select (pg->conn,
+                                                    "reclaim_revolving_shard",
+                                                    iparams);
+          switch (qsz)
           {
           case GNUNET_DB_STATUS_HARD_ERROR:
             GNUNET_break (0);
