@@ -41,14 +41,13 @@ TEH_PG_do_deposit (
   const struct TALER_CoinSpendPublicKeyP *coin_pubs[GNUNET_NZL (bd->num_cdis)];
   const struct TALER_CoinSpendSignatureP *coin_sigs[GNUNET_NZL (bd->num_cdis)];
   struct TALER_Amount amounts_with_fee[GNUNET_NZL (bd->num_cdis)];
+  struct TALER_Amount total_amount;
   struct TALER_NormalizedPaytoHashP h_normalized_payto;
   struct GNUNET_PQ_QueryParam params[] = {
     /* data for batch_deposits */
     GNUNET_PQ_query_param_uint64 (&deposit_shard),
     GNUNET_PQ_query_param_auto_from_type (&bd->merchant_pub),
-    GNUNET_is_zero (&bd->merchant_sig)
-    ? GNUNET_PQ_query_param_null ()
-    : GNUNET_PQ_query_param_auto_from_type (&bd->merchant_sig),
+    GNUNET_PQ_query_param_auto_from_type (&bd->merchant_sig),
     GNUNET_PQ_query_param_timestamp (&bd->wallet_timestamp),
     GNUNET_PQ_query_param_timestamp (exchange_timestamp),
     GNUNET_PQ_query_param_timestamp (&bd->refund_deadline),
@@ -76,6 +75,8 @@ TEH_PG_do_deposit (
     TALER_PQ_query_param_array_amount (bd->num_cdis,
                                        amounts_with_fee,
                                        pg->conn),
+    TALER_PQ_query_param_amount (pg->conn,
+                                 &total_amount),
     GNUNET_PQ_query_param_end
   };
   bool no_time;
@@ -94,6 +95,7 @@ TEH_PG_do_deposit (
   };
   enum GNUNET_DB_QueryStatus qs;
 
+  GNUNET_assert (0 < bd->num_cdis);
   TALER_full_payto_normalize_and_hash (bd->receiver_wire_account,
                                        &h_normalized_payto);
   for (unsigned int i = 0; i < bd->num_cdis; i++)
@@ -101,6 +103,17 @@ TEH_PG_do_deposit (
     const struct TALER_EXCHANGEDB_CoinDepositInformation *cdi
       = &bd->cdis[i];
 
+    if (0 == i)
+    {
+      total_amount = cdi->amount_with_fee;
+    }
+    else
+    {
+      GNUNET_assert (0 <=
+                     TALER_amount_add (&total_amount,
+                                       &total_amount,
+                                       &cdi->amount_with_fee));
+    }
     amounts_with_fee[i] = cdi->amount_with_fee;
     coin_pubs[i] = &cdi->coin.coin_pub;
     coin_sigs[i] = &cdi->csig;
@@ -116,7 +129,7 @@ TEH_PG_do_deposit (
            ",out_insufficient_balance_coin_index AS insufficient_balance_coin_index"
            ",out_conflict AS conflicted"
            " FROM exchange_do_deposit"
-           " ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18);")
+           " ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18,$19);")
   ;
   qs = GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                  "call_deposit",
