@@ -30,7 +30,7 @@
  *
  * @param cls the `struct PostgresClosure` with the plugin-specific state
  * @param reserve_pub public key of the reserve to credit
- * @param reserve_out_serial_id row in the reserves_out table justifying the recoup
+ * @param withdraw_serial_id row in the withdraw table justifying the recoup
  * @param coin_bks coin blinding key secret to persist
  * @param coin_pub public key of the coin being recouped
  * @param known_coin_id row of the @a coin_pub in the known_coins table
@@ -44,7 +44,7 @@ enum GNUNET_DB_QueryStatus
 TEH_PG_do_recoup (
   void *cls,
   const struct TALER_ReservePublicKeyP *reserve_pub,
-  uint64_t reserve_out_serial_id,
+  uint64_t withdraw_serial_id,
   const union GNUNET_CRYPTO_BlindingSecretP *coin_bks,
   const struct TALER_CoinSpendPublicKeyP *coin_pub,
   uint64_t known_coin_id,
