@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -17,6 +17,7 @@
  * @file exchangedb/pg_do_recoup_refresh.c
  * @brief Implementation of the do_recoup_refresh function for Postgres
  * @author Christian Grothoff
+ * @author Özgür Kesim
  */
 #include "platform.h"
 #include "taler_error_codes.h"
@@ -29,7 +30,7 @@ enum GNUNET_DB_QueryStatus
 TEH_PG_do_recoup_refresh (
   void *cls,
   const struct TALER_CoinSpendPublicKeyP *old_coin_pub,
-  uint64_t rrc_serial,
+  uint64_t refresh_id,
   const union GNUNET_CRYPTO_BlindingSecretP *coin_bks,
   const struct TALER_CoinSpendPublicKeyP *coin_pub,
   uint64_t known_coin_id,
@@ -41,7 +42,7 @@ TEH_PG_do_recoup_refresh (
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_auto_from_type (old_coin_pub),
-    GNUNET_PQ_query_param_uint64 (&rrc_serial),
+    GNUNET_PQ_query_param_uint64 (&refresh_id),
     GNUNET_PQ_query_param_auto_from_type (coin_bks),
     GNUNET_PQ_query_param_auto_from_type (coin_pub),
     GNUNET_PQ_query_param_uint64 (&known_coin_id),
