@@ -37,8 +37,8 @@ TEH_PG_ensure_coin_known (void *cls,
   struct PostgresClosure *pg = cls;
   enum GNUNET_DB_QueryStatus qs;
   bool existed;
-  bool is_denom_pub_hash_null = false;
-  bool is_age_hash_null = false;
+  bool no_denom_pub_hash;
+  bool no_age_commitment_hash;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_auto_from_type (&coin->coin_pub),
     GNUNET_PQ_query_param_auto_from_type (&coin->denom_pub_hash),
@@ -56,11 +56,11 @@ TEH_PG_ensure_coin_known (void *cls,
     GNUNET_PQ_result_spec_allow_null (
       GNUNET_PQ_result_spec_auto_from_type ("denom_pub_hash",
                                             denom_hash),
-      &is_denom_pub_hash_null),
+      &no_denom_pub_hash),
     GNUNET_PQ_result_spec_allow_null (
       GNUNET_PQ_result_spec_auto_from_type ("age_commitment_hash",
                                             h_age_commitment),
-      &is_age_hash_null),
+      &no_age_commitment_hash),
     GNUNET_PQ_result_spec_end
   };
 
@@ -136,17 +136,17 @@ TEH_PG_ensure_coin_known (void *cls,
     break; /* continued below */
   }
 
-  if ( (! is_denom_pub_hash_null) &&
-       (0 != GNUNET_memcmp (&denom_hash->hash,
-                            &coin->denom_pub_hash.hash)) )
+  if ( (! no_denom_pub_hash) &&
+       (0 != GNUNET_memcmp (denom_hash,
+                            &coin->denom_pub_hash)) )
   {
     GNUNET_break_op (0);
     return TALER_EXCHANGEDB_CKS_DENOM_CONFLICT;
   }
 
-  if (is_age_hash_null != coin->no_age_commitment)
+  if (no_age_commitment_hash != coin->no_age_commitment)
   {
-    if (is_age_hash_null)
+    if (no_age_commitment_hash)
     {
       GNUNET_break_op (0);
       return TALER_EXCHANGEDB_CKS_AGE_CONFLICT_EXPECTED_NULL;
@@ -157,7 +157,7 @@ TEH_PG_ensure_coin_known (void *cls,
       return TALER_EXCHANGEDB_CKS_AGE_CONFLICT_EXPECTED_NON_NULL;
     }
   }
-  else if ( (! is_age_hash_null) &&
+  else if ( (! no_age_commitment_hash) &&
             (0 != GNUNET_memcmp (h_age_commitment,
                                  &coin->h_age_commitment)) )
   {
