@@ -256,6 +256,12 @@ add_coin_melt (void *cls,
                                               &melt->h_denom_pub),
         GNUNET_PQ_result_spec_auto_from_type ("old_coin_sig",
                                               &melt->coin_sig),
+        GNUNET_PQ_result_spec_auto_from_type ("refresh_seed",
+                                              &melt->refresh_seed),
+        GNUNET_PQ_result_spec_allow_null (
+          GNUNET_PQ_result_spec_auto_from_type ("blinding_seed",
+                                                &melt->blinding_seed),
+          &melt->no_blinding_seed),
         TALER_PQ_RESULT_SPEC_AMOUNT ("amount_with_fee",
                                      &melt->amount_with_fee),
         TALER_PQ_RESULT_SPEC_AMOUNT ("fee_refresh",
@@ -264,7 +270,7 @@ add_coin_melt (void *cls,
           GNUNET_PQ_result_spec_auto_from_type ("age_commitment_hash",
                                                 &melt->h_age_commitment),
           &melt->no_age_commitment),
-        GNUNET_PQ_result_spec_uint64 ("melt_serial_id",
+        GNUNET_PQ_result_spec_uint64 ("refresh_id",
                                       &serial_id),
         GNUNET_PQ_result_spec_end
       };
@@ -705,8 +711,8 @@ handle_history_entry (void *cls,
       "get_deposit_with_coin_pub",
       &add_coin_deposit },
     [TALER_EXCHANGEDB_TT_MELT] =
-    { "refresh_commitments",
-      "get_refresh_session_by_coin",
+    { "refresh",
+      "get_refresh_by_coin",
       &add_coin_melt },
     [TALER_EXCHANGEDB_TT_PURSE_DEPOSIT] =
     { "purse_deposits",
@@ -890,22 +896,24 @@ TEH_PG_get_coin_transactions (
            " WHERE cdep.coin_pub=$1"
            "   AND cdep.coin_deposit_serial_id=$2;");
   PREPARE (pg,
-           "get_refresh_session_by_coin",
+           "get_refresh_by_coin",
            "SELECT"
            " rc"
+           ",refresh_seed"
+           ",blinding_seed"
            ",old_coin_sig"
            ",amount_with_fee"
            ",denoms.denom_pub_hash"
            ",denoms.fee_refresh"
            ",kc.age_commitment_hash"
-           ",melt_serial_id"
-           " FROM refresh_commitments"
+           ",refresh_id"
+           " FROM refresh"
            " JOIN known_coins kc"
-           "   ON (refresh_commitments.old_coin_pub = kc.coin_pub)"
+           "   ON (refresh.old_coin_pub = kc.coin_pub)"
            " JOIN denominations denoms"
            "   USING (denominations_serial)"
            " WHERE old_coin_pub=$1"
-           "   AND melt_serial_id=$2;");
+           "   AND refresh_id=$2;");
   PREPARE (pg,
            "get_purse_deposit_by_coin_pub",
            "SELECT"
@@ -985,12 +993,10 @@ TEH_PG_get_coin_transactions (
            " JOIN denominations denoms"
            "   USING (denominations_serial)"
            " WHERE recoup_refresh_uuid=$2"
-           "   AND rrc_serial IN"
-           "   (SELECT rrc.rrc_serial"
-           "    FROM refresh_commitments melt"
-           "    JOIN refresh_revealed_coins rrc"
-           "      USING (melt_serial_id)"
-           "    WHERE melt.old_coin_pub=$1);");
+           "   AND refresh_id IN"
+           "   (SELECT refresh_id"
+           "    FROM refresh"
+           "    WHERE refresh.old_coin_pub=$1);");
   PREPARE (pg,
            "recoup_by_coin",
            "SELECT"
@@ -1002,10 +1008,10 @@ TEH_PG_get_coin_transactions (
            ",rcp.recoup_timestamp"
            ",rcp.recoup_uuid"
            " FROM recoup rcp"
-           " JOIN reserves_out ro"
-           "   USING (reserve_out_serial_id)"
+           " JOIN withdraw ro"
+           "   USING (withdraw_id)"
            " JOIN reserves res"
-           "   USING (reserve_uuid)"
+           "   USING (reserve_pub)"
            " JOIN known_coins coins"
            "   USING (coin_pub)"
            " JOIN denominations denoms"
@@ -1026,10 +1032,8 @@ TEH_PG_get_coin_transactions (
            ",coins.denom_sig"
            ",recoup_refresh_uuid"
            " FROM recoup_refresh rr"
-           "    JOIN refresh_revealed_coins rrc"
-           "      USING (rrc_serial)"
-           "    JOIN refresh_commitments rfc"
-           "      ON (rrc.melt_serial_id = rfc.melt_serial_id)"
+           "    JOIN refresh rfc"
+           "      ON (rr.refresh_id = rfc.refresh_id)"
            "    JOIN known_coins old_coins"
            "      ON (rfc.old_coin_pub = old_coins.coin_pub)"
            "    JOIN known_coins coins"
