@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -17,6 +17,7 @@
  * @file exchangedb/pg_get_old_coin_by_h_blind.c
  * @brief Implementation of the get_old_coin_by_h_blind function for Postgres
  * @author Christian Grothoff
+ * @author Özgür Kesim
  */
 #include "platform.h"
 #include "taler_error_codes.h"
@@ -31,7 +32,7 @@ TEH_PG_get_old_coin_by_h_blind (
   void *cls,
   const struct TALER_BlindedCoinHashP *h_blind_ev,
   struct TALER_CoinSpendPublicKeyP *old_coin_pub,
-  uint64_t *rrc_serial)
+  uint64_t *refresh_id)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
@@ -41,8 +42,8 @@ TEH_PG_get_old_coin_by_h_blind (
   struct GNUNET_PQ_ResultSpec rs[] = {
     GNUNET_PQ_result_spec_auto_from_type ("old_coin_pub",
                                           old_coin_pub),
-    GNUNET_PQ_result_spec_uint64 ("rrc_serial",
-                                  rrc_serial),
+    GNUNET_PQ_result_spec_uint64 ("refresh_id",
+                                  refresh_id),
     GNUNET_PQ_result_spec_end
   };
 
@@ -51,11 +52,10 @@ TEH_PG_get_old_coin_by_h_blind (
            "old_coin_by_h_blind",
            "SELECT"
            " okc.coin_pub AS old_coin_pub"
-           ",rrc_serial"
-           " FROM refresh_revealed_coins rrc"
-           " JOIN refresh_commitments rcom USING (melt_serial_id)"
-           " JOIN known_coins okc ON (rcom.old_coin_pub = okc.coin_pub)"
-           " WHERE h_coin_ev=$1"
+           ",refresh_id"
+           " FROM refresh "
+           " JOIN known_coins okc ON (refresh.old_coin_pub = okc.coin_pub)"
+           " WHERE $1=ANY(h_blind_evs)"
            " LIMIT 1;");
   return GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                    "old_coin_by_h_blind",
