@@ -112,7 +112,8 @@ add_revealed_coins (void *cls,
         GNUNET_PQ_result_spec_end
       };
 
-      if (TALER_DENOMINATION_INVALID != rrc->blinded_planchet.cipher)
+      if (NULL !=
+          rrc->blinded_planchet.blinded_message)
       {
         /* duplicate offset, not allowed */
         GNUNET_break (0);
@@ -205,6 +206,7 @@ cleanup:
 
     TALER_blinded_denom_sig_free (&rrc->coin_sig);
     TALER_blinded_planchet_free (&rrc->blinded_planchet);
+    TALER_denom_ewv_free (&rrc->exchange_vals);
   }
   GNUNET_free (grctx.rrcs);
   return qs;
