@@ -173,33 +173,58 @@ add_bank_to_exchange (void *cls,
  * @param num_results number of rows in @a result
  */
 static void
-add_withdraw_coin (void *cls,
-                   PGresult *result,
-                   unsigned int num_results)
+add_withdraw (void *cls,
+              PGresult *result,
+              unsigned int num_results)
 {
   struct ReserveHistoryContext *rhc = cls;
   struct PostgresClosure *pg = rhc->pg;
 
   while (0 < num_results)
   {
-    struct TALER_EXCHANGEDB_CollectableBlindcoin *cbc;
+    struct TALER_EXCHANGEDB_Withdraw *wd;
     struct TALER_EXCHANGEDB_ReserveHistory *tail;
 
-    cbc = GNUNET_new (struct TALER_EXCHANGEDB_CollectableBlindcoin);
+    wd = GNUNET_new (struct TALER_EXCHANGEDB_Withdraw);
     {
+      bool no_noreveal_index;
+      bool no_max_age;
+      bool no_selected_h;
+      size_t num_denom_hs;
+      size_t num_denom_serials;
+      uint64_t *my_denom_serials = NULL;
+      struct TALER_DenominationHashP *my_denom_pub_hashes = NULL;
       struct GNUNET_PQ_ResultSpec rs[] = {
-        GNUNET_PQ_result_spec_auto_from_type ("h_blind_ev",
-                                              &cbc->h_coin_envelope),
-        GNUNET_PQ_result_spec_auto_from_type ("denom_pub_hash",
-                                              &cbc->denom_pub_hash),
-        TALER_PQ_result_spec_blinded_denom_sig ("denom_sig",
-                                                &cbc->sig),
+        GNUNET_PQ_result_spec_auto_from_type  ("planchets_h",
+                                               &wd->planchets_h),
         GNUNET_PQ_result_spec_auto_from_type ("reserve_sig",
-                                              &cbc->reserve_sig),
+                                              &wd->reserve_sig),
         TALER_PQ_RESULT_SPEC_AMOUNT ("amount_with_fee",
-                                     &cbc->amount_with_fee),
-        TALER_PQ_RESULT_SPEC_AMOUNT ("fee_withdraw",
-                                     &cbc->withdraw_fee),
+                                     &wd->amount_with_fee),
+        GNUNET_PQ_result_spec_allow_null (
+          GNUNET_PQ_result_spec_uint16 ("max_age",
+                                        &wd->max_age),
+          &no_max_age),
+        GNUNET_PQ_result_spec_allow_null (
+          GNUNET_PQ_result_spec_uint16 ("noreveal_index",
+                                        &wd->noreveal_index),
+          &no_noreveal_index),
+        GNUNET_PQ_result_spec_allow_null (
+          GNUNET_PQ_result_spec_auto_from_type ("blinding_seed",
+                                                &wd->blinding_seed),
+          &wd->no_blinding_seed),
+        GNUNET_PQ_result_spec_allow_null (
+          GNUNET_PQ_result_spec_auto_from_type ("selected_h",
+                                                &wd->selected_h),
+          &no_selected_h),
+        TALER_PQ_result_spec_array_denom_hash (pg->conn,
+                                               "denom_pub_hashes",
+                                               &num_denom_hs,
+                                               &my_denom_pub_hashes),
+        GNUNET_PQ_result_spec_array_uint64 (pg->conn,
+                                            "denom_serials",
+                                            &num_denom_serials,
+                                            &my_denom_serials),
         GNUNET_PQ_result_spec_end
       };
 
@@ -209,19 +234,44 @@ add_withdraw_coin (void *cls,
                                     --num_results))
       {
         GNUNET_break (0);
-        GNUNET_free (cbc);
+        GNUNET_free (wd);
         rhc->failed = true;
+        GNUNET_PQ_cleanup_result (rs);
         return;
       }
+
+      if (num_denom_hs != num_denom_serials)
+      {
+        GNUNET_break (0);
+        GNUNET_free (wd);
+        rhc->failed = true;
+        GNUNET_PQ_cleanup_result (rs);
+        return;
+      }
+
+      if ((no_noreveal_index != no_max_age) ||
+          (no_noreveal_index != no_selected_h))
+      {
+        GNUNET_break (0);
+        GNUNET_free (wd);
+        rhc->failed = true;
+        GNUNET_PQ_cleanup_result (rs);
+        return;
+      }
+      wd->age_proof_required = ! no_max_age;
+      wd->num_coins = num_denom_serials;
+      wd->reserve_pub = *rhc->reserve_pub;
+      wd->denom_serials = my_denom_serials;
+      wd->denom_pub_hashes = my_denom_pub_hashes;
+      /* prevent cleanup from destroying our actual result */
+      my_denom_serials = NULL;
+      my_denom_pub_hashes = NULL;
+      GNUNET_PQ_cleanup_result (rs);
     }
-    GNUNET_assert (0 <=
-                   TALER_amount_add (&rhc->balance_out,
-                                     &rhc->balance_out,
-                                     &cbc->amount_with_fee));
-    cbc->reserve_pub = *rhc->reserve_pub;
+
     tail = append_rh (rhc);
-    tail->type = TALER_EXCHANGEDB_RO_WITHDRAW_COIN;
-    tail->details.withdraw = cbc;
+    tail->type = TALER_EXCHANGEDB_RO_WITHDRAW_COINS;
+    tail->details.withdraw = wd;
   }
 }
 
@@ -582,10 +632,10 @@ handle_history_entry (void *cls,
     { "reserves_in",
       "reserves_in_get_transactions",
       add_bank_to_exchange },
-    /** #TALER_EXCHANGEDB_RO_WITHDRAW_COIN */
-    { "reserves_out",
-      "get_reserves_out",
-      &add_withdraw_coin },
+    /** #TALER_EXCHANGEDB_RO_WITHDRAW_COINS */
+    { "withdraw",
+      "get_withdraw_details",
+      &add_withdraw },
     /** #TALER_EXCHANGEDB_RO_RECOUP_COIN */
     { "recoup",
       "recoup_by_reserve",
@@ -666,7 +716,7 @@ handle_history_entry (void *cls,
     if (! found)
     {
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  "Coin history includes unsupported table `%s`\n",
+                  "Reserve history includes unsupported table `%s`\n",
                   table_name);
       rhc->failed = true;
     }
@@ -732,7 +782,6 @@ TEH_PG_get_reserve_history (
            " WHERE reserve_pub=$1"
            "   AND reserve_history_serial_id > $2"
            " ORDER BY reserve_history_serial_id DESC;");
-
   PREPARE (pg,
            "reserves_in_get_transactions",
            "SELECT"
@@ -745,6 +794,28 @@ TEH_PG_get_reserve_history (
            "   ON (wire_source_h_payto = wire_target_h_payto)"
            " WHERE ri.reserve_pub=$1"
            "   AND ri.reserve_in_serial_id=$2;");
+  PREPARE (pg,
+           "get_withdraw_details",
+           "SELECT"
+           " planchets_h"
+           ",amount_with_fee"
+           ",reserve_sig"
+           ",max_age"
+           ",noreveal_index"
+           ",selected_h"
+           ",blinding_seed"
+           ",denom_serials"
+           ",ARRAY("
+           "  SELECT denominations.denom_pub_hash FROM ("
+           "    SELECT UNNEST(denom_serials) AS id,"
+           "           generate_subscripts(denom_serials, 1) AS nr" /* for order */
+           "  ) AS denoms"
+           "  LEFT JOIN denominations ON denominations.denominations_serial=denoms.id"
+           ") AS denom_pub_hashes"
+           " FROM withdraw "
+           " WHERE withdraw_id=$2"
+           " AND reserve_pub=$1;");
+/* FIXME: remove "get_reserves_out" etc. once reserves_out is phased out */
   PREPARE (pg,
            "get_reserves_out",
            "SELECT"
@@ -773,10 +844,10 @@ TEH_PG_get_reserve_history (
            ",denom.denom_pub_hash"
            ",kc.denom_sig"
            " FROM recoup rec"
-           " JOIN reserves_out ro"
-           "   USING (reserve_out_serial_id)"
+           " JOIN withdraw ro"
+           "   USING (withdraw_id)"
            " JOIN reserves res"
-           "   USING (reserve_uuid)"
+           "   USING (reserve_pub)"
            " JOIN known_coins kc"
            "   USING (coin_pub)"
            " JOIN denominations denom"
