@@ -31,6 +31,7 @@
  * @param cls closure
  * @param type type of wire transfer the fee applies for
  * @param date for which date do we want the fee?
+ * @param[out] rowid set to row in the database with the wire fee
  * @param[out] start_date when does the fee go into effect
  * @param[out] end_date when does the fee end being valid
  * @param[out] fees how high are the wire fees
@@ -38,12 +39,14 @@
  * @return status of the transaction
  */
 enum GNUNET_DB_QueryStatus
-TEH_PG_get_wire_fee (void *cls,
-                     const char *type,
-                     struct GNUNET_TIME_Timestamp date,
-                     struct GNUNET_TIME_Timestamp *start_date,
-                     struct GNUNET_TIME_Timestamp *end_date,
-                     struct TALER_WireFeeSet *fees,
-                     struct TALER_MasterSignatureP *master_sig);
+TEH_PG_get_wire_fee (
+  void *cls,
+  const char *type,
+  struct GNUNET_TIME_Timestamp date,
+  uint64_t *rowid,
+  struct GNUNET_TIME_Timestamp *start_date,
+  struct GNUNET_TIME_Timestamp *end_date,
+  struct TALER_WireFeeSet *fees,
+  struct TALER_MasterSignatureP *master_sig);
 
 #endif
