@@ -1,6 +1,6 @@
 /*
    This file is part of GNUnet
-   Copyright (C) 2020-2024 Taler Systems SA
+   Copyright (C) 2020-2025 Taler Systems SA
 
    GNUnet is free software: you can redistribute it and/or modify it
    under the terms of the GNU Affero General Public License as published
@@ -834,139 +834,81 @@ irbt_cb_table_known_coins (struct PostgresClosure *pg,
 
 
 /**
- * Function called with refresh_commitments records to insert into table.
+ * Function called with refresh records to insert into table.
  *
  * @param pg plugin context
  * @param td record to insert
  */
 static enum GNUNET_DB_QueryStatus
-irbt_cb_table_refresh_commitments (struct PostgresClosure *pg,
-                                   const struct TALER_EXCHANGEDB_TableData *td)
+irbt_cb_table_refresh (struct PostgresClosure *pg,
+                       const struct TALER_EXCHANGEDB_TableData *td)
 {
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&td->serial),
-    GNUNET_PQ_query_param_auto_from_type (&td->details.refresh_commitments.rc),
-    GNUNET_PQ_query_param_auto_from_type (
-      &td->details.refresh_commitments.old_coin_sig),
+    GNUNET_PQ_query_param_auto_from_type (&td->details.refresh.rc),
+    GNUNET_PQ_query_param_auto_from_type (&td->details.refresh.execution_date),
     TALER_PQ_query_param_amount (
       pg->conn,
-      &td->details.refresh_commitments.amount_with_fee),
-    GNUNET_PQ_query_param_uint32 (
-      &td->details.refresh_commitments.noreveal_index),
+      &td->details.refresh.amount_with_fee),
     GNUNET_PQ_query_param_auto_from_type (
-      &td->details.refresh_commitments.old_coin_pub),
+      &td->details.refresh.old_coin_pub),
+    GNUNET_PQ_query_param_auto_from_type (
+      &td->details.refresh.old_coin_sig),
+    GNUNET_PQ_query_param_auto_from_type (
+      &td->details.refresh.refresh_seed),
+    GNUNET_PQ_query_param_uint32 (
+      &td->details.refresh.noreveal_index),
+    GNUNET_PQ_query_param_auto_from_type (
+      &td->details.refresh.planchets_h),
+    GNUNET_PQ_query_param_auto_from_type (
+      &td->details.refresh.selected_h),
+    td->details.refresh.no_blinding_seed
+       ? GNUNET_PQ_query_param_null ()
+       : GNUNET_PQ_query_param_auto_from_type (
+      &td->details.refresh.blinding_seed),
+    td->details.refresh.no_blinding_seed
+       ? GNUNET_PQ_query_param_null ()
+       : TALER_PQ_query_param_array_cs_r_pub (
+      td->details.refresh.num_cs_r_values,
+      td->details.refresh.cs_r_values,
+      pg->conn),
+    td->details.refresh.no_blinding_seed
+       ? GNUNET_PQ_query_param_null ()
+       : GNUNET_PQ_query_param_uint64 (
+      &td->details.refresh.cs_r_choices),
+    GNUNET_PQ_query_param_array_uint64 (
+      td->details.refresh.num_coins,
+      td->details.refresh.denom_serials,
+      pg->conn),
+    TALER_PQ_query_param_array_blinded_denom_sig (
+      td->details.refresh.num_coins,
+      td->details.refresh.denom_sigs,
+      pg->conn),
     GNUNET_PQ_query_param_end
   };
 
   PREPARE (pg,
-           "insert_into_table_refresh_commitments",
-           "INSERT INTO refresh_commitments"
-           "(melt_serial_id"
+           "insert_into_table_refresh",
+           "INSERT INTO refresh"
+           "(refresh_id"
            ",rc"
-           ",old_coin_sig"
+           ",execution_date"
            ",amount_with_fee"
-           ",noreveal_index"
            ",old_coin_pub"
+           ",old_coin_sig"
+           ",refresh_seed"
+           ",noreveal_index"
+           ",planchets_h"
+           ",selected_h"
+           ",blinding_seed"
+           ",cs_r_values"
+           ",cs_r_choices"
+           ",denom_serials"
+           ",denom_sigs"
            ") VALUES "
-           "($1, $2, $3, $4, $5, $6);");
+           "($1, $2, $3, $4, $5, $6,$7,$8,$9,$10,$11,$12,$13,$14,$15);");
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
-                                             "insert_into_table_refresh_commitments",
-                                             params);
-}
-
-
-/**
- * Function called with refresh_revealed_coins records to insert into table.
- *
- * @param pg plugin context
- * @param td record to insert
- */
-static enum GNUNET_DB_QueryStatus
-irbt_cb_table_refresh_revealed_coins (
-  struct PostgresClosure *pg,
-  const struct TALER_EXCHANGEDB_TableData *td)
-{
-  struct GNUNET_HashCode h_coin_ev;
-  struct GNUNET_PQ_QueryParam params[] = {
-    GNUNET_PQ_query_param_uint64 (&td->serial),
-    GNUNET_PQ_query_param_uint32 (
-      &td->details.refresh_revealed_coins.freshcoin_index),
-    GNUNET_PQ_query_param_auto_from_type (
-      &td->details.refresh_revealed_coins.link_sig),
-    GNUNET_PQ_query_param_fixed_size (
-      td->details.refresh_revealed_coins.coin_ev,
-      td->details.refresh_revealed_coins.
-      coin_ev_size),
-    GNUNET_PQ_query_param_auto_from_type (&h_coin_ev),
-    TALER_PQ_query_param_blinded_denom_sig (
-      &td->details.refresh_revealed_coins.ev_sig),
-    TALER_PQ_query_param_exchange_withdraw_values (
-      &td->details.refresh_revealed_coins.ewv),
-    GNUNET_PQ_query_param_uint64 (
-      &td->details.refresh_revealed_coins.denominations_serial),
-    GNUNET_PQ_query_param_uint64 (
-      &td->details.refresh_revealed_coins.melt_serial_id),
-    GNUNET_PQ_query_param_end
-  };
-
-  PREPARE (pg,
-           "insert_into_table_refresh_revealed_coins",
-           "INSERT INTO refresh_revealed_coins"
-           "(rrc_serial"
-           ",freshcoin_index"
-           ",link_sig"
-           ",coin_ev"
-           ",h_coin_ev"
-           ",ev_sig"
-           ",ewv"
-           ",denominations_serial"
-           ",melt_serial_id"
-           ") VALUES "
-           "($1, $2, $3, $4, $5, $6, $7, $8, $9);");
-  GNUNET_CRYPTO_hash (td->details.refresh_revealed_coins.coin_ev,
-                      td->details.refresh_revealed_coins.coin_ev_size,
-                      &h_coin_ev);
-  return GNUNET_PQ_eval_prepared_non_select (pg->conn,
-                                             "insert_into_table_refresh_revealed_coins",
-                                             params);
-}
-
-
-/**
- * Function called with refresh_transfer_keys records to insert into table.
- *
- * @param pg plugin context
- * @param td record to insert
- */
-static enum GNUNET_DB_QueryStatus
-irbt_cb_table_refresh_transfer_keys (
-  struct PostgresClosure *pg,
-  const struct TALER_EXCHANGEDB_TableData *td)
-{
-  struct GNUNET_PQ_QueryParam params[] = {
-    GNUNET_PQ_query_param_uint64 (&td->serial),
-    GNUNET_PQ_query_param_auto_from_type (
-      &td->details.refresh_transfer_keys.tp),
-    GNUNET_PQ_query_param_fixed_size (
-      &td->details.refresh_transfer_keys.tprivs[0],
-      (TALER_CNC_KAPPA - 1)
-      * sizeof (struct TALER_TransferPrivateKeyP)),
-    GNUNET_PQ_query_param_uint64 (
-      &td->details.refresh_transfer_keys.melt_serial_id),
-    GNUNET_PQ_query_param_end
-  };
-
-  PREPARE (pg,
-           "insert_into_table_refresh_transfer_keys",
-           "INSERT INTO refresh_transfer_keys"
-           "(rtc_serial"
-           ",transfer_pub"
-           ",transfer_privs"
-           ",melt_serial_id"
-           ") VALUES "
-           "($1, $2, $3, $4);");
-  return GNUNET_PQ_eval_prepared_non_select (pg->conn,
-                                             "insert_into_table_refresh_transfer_keys",
+                                             "insert_into_table_refresh",
                                              params);
 }
 
@@ -1311,7 +1253,7 @@ irbt_cb_table_recoup (struct PostgresClosure *pg,
     GNUNET_PQ_query_param_timestamp (&td->details.recoup.timestamp),
     GNUNET_PQ_query_param_auto_from_type (
       &td->details.recoup.coin_pub),
-    GNUNET_PQ_query_param_uint64 (&td->details.recoup.reserve_out_serial_id),
+    GNUNET_PQ_query_param_uint64 (&td->details.recoup.withdraw_serial_id),
     GNUNET_PQ_query_param_end
   };
 
@@ -1324,7 +1266,7 @@ irbt_cb_table_recoup (struct PostgresClosure *pg,
            ",amount"
            ",recoup_timestamp"
            ",coin_pub"
-           ",reserve_out_serial_id"
+           ",withdraw_serial_id"
            ") VALUES "
            "($1, $2, $3, $4, $5, $6, $7);");
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
@@ -2254,49 +2196,67 @@ irbt_cb_table_purse_deletion (struct PostgresClosure *pg,
 
 
 /**
- * Function called with age_withdraw records to insert into table.
+ * Function called with withdraw records to insert into table.
  *
  * @param pg plugin context
  * @param td record to insert
  */
 static enum GNUNET_DB_QueryStatus
-irbt_cb_table_age_withdraw (
+irbt_cb_table_withdraw (
   struct PostgresClosure *pg,
   const struct TALER_EXCHANGEDB_TableData *td)
 {
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&td->serial),
     GNUNET_PQ_query_param_auto_from_type (
-      &td->details.age_withdraw.h_commitment),
+      &td->details.withdraw.h_planchets),
     TALER_PQ_query_param_amount (
       pg->conn,
-      &td->details.age_withdraw.amount_with_fee),
-    GNUNET_PQ_query_param_uint16 (
-      &td->details.age_withdraw.max_age),
+      &td->details.withdraw.amount_with_fee),
+    td->details.withdraw.age_proof_required
+       ? GNUNET_PQ_query_param_uint16 (
+      &td->details.withdraw.max_age)
+       : GNUNET_PQ_query_param_null (),
+    td->details.withdraw.age_proof_required
+       ? GNUNET_PQ_query_param_uint32 (
+      &td->details.withdraw.noreveal_index)
+       : GNUNET_PQ_query_param_null (),
     GNUNET_PQ_query_param_auto_from_type (
-      &td->details.age_withdraw.reserve_pub),
+      &td->details.withdraw.reserve_pub),
     GNUNET_PQ_query_param_auto_from_type (
-      &td->details.age_withdraw.reserve_sig),
-    GNUNET_PQ_query_param_uint32 (
-      &td->details.age_withdraw.noreveal_index),
-    /* FIXME[oec]: other fields, too! */
+      &td->details.withdraw.reserve_sig),
+    GNUNET_PQ_query_param_timestamp (
+      &td->details.withdraw.execution_date),
+    td->details.withdraw.no_blinding_seed
+      ? GNUNET_PQ_query_param_null ()
+      : GNUNET_PQ_query_param_auto_from_type (
+      &td->details.withdraw.blinding_seed),
+    (0 < td->details.withdraw.num_cs_r_pubs)
+      ? TALER_PQ_query_param_array_cs_r_pub (
+      td->details.withdraw.num_cs_r_pubs,
+      td->details.withdraw.cs_r_pubs,
+      pg->conn)
+      : GNUNET_PQ_query_param_null (),
     GNUNET_PQ_query_param_end
   };
 
   PREPARE (pg,
-           "insert_into_table_age_withdraw",
-           "INSERT INTO age_withdraw"
-           "(age_withdraw_commitment_id"
-           ",h_commitment"
+           "insert_into_table_withdraw",
+           "INSERT INTO withdraw"
+           "(withdraw_id"
+           ",h_planchets"
            ",amount_with_fee"
            ",max_age"
+           ",noreveal_index"
            ",reserve_pub"
            ",reserve_sig"
-           ",noreveal_index"
+           ",execution_date"
+           ",blinding_seed"
+           ",cs_r_pubs"
            ") VALUES "
-           "($1, $2, $3, $4, $5, $6, $7, $8);");
+           "($1, $2, $3, $4, $5, $6, $7, $8, $9, $10);");
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
-                                             "insert_into_table_age_withdraw",
+                                             "insert_into_table_withdraw",
                                              params);
 }
 
@@ -2355,14 +2315,8 @@ TEH_PG_insert_records_by_table (void *cls,
   case TALER_EXCHANGEDB_RT_KNOWN_COINS:
     rh = &irbt_cb_table_known_coins;
     break;
-  case TALER_EXCHANGEDB_RT_REFRESH_COMMITMENTS:
-    rh = &irbt_cb_table_refresh_commitments;
-    break;
-  case TALER_EXCHANGEDB_RT_REFRESH_REVEALED_COINS:
-    rh = &irbt_cb_table_refresh_revealed_coins;
-    break;
-  case TALER_EXCHANGEDB_RT_REFRESH_TRANSFER_KEYS:
-    rh = &irbt_cb_table_refresh_transfer_keys;
+  case TALER_EXCHANGEDB_RT_REFRESH:
+    rh = &irbt_cb_table_refresh;
     break;
   case TALER_EXCHANGEDB_RT_BATCH_DEPOSITS:
     rh = &irbt_cb_table_batch_deposits;
@@ -2442,8 +2396,8 @@ TEH_PG_insert_records_by_table (void *cls,
   case TALER_EXCHANGEDB_RT_PURSE_DELETION:
     rh = &irbt_cb_table_purse_deletion;
     break;
-  case TALER_EXCHANGEDB_RT_AGE_WITHDRAW:
-    rh = &irbt_cb_table_age_withdraw;
+  case TALER_EXCHANGEDB_RT_WITHDRAW:
+    rh = &irbt_cb_table_withdraw;
     break;
   case TALER_EXCHANGEDB_RT_LEGITIMIZATION_MEASURES:
     rh = &irbt_cb_table_legitimization_measures;
