@@ -52,10 +52,12 @@ TEH_PG_insert_wire_fee (void *cls,
   struct GNUNET_TIME_Timestamp sd;
   struct GNUNET_TIME_Timestamp ed;
   enum GNUNET_DB_QueryStatus qs;
+  uint64_t rowid;
 
   qs = TEH_PG_get_wire_fee (pg,
                             type,
                             start_date,
+                            &rowid,
                             &sd,
                             &ed,
                             &wx,
