@@ -69,7 +69,10 @@ domination_cb_helper (void *cls,
     struct TALER_EXCHANGEDB_DenominationKeyInformation issue;
     struct TALER_DenominationPublicKey denom_pub;
     struct TALER_DenominationHashP denom_hash;
+    uint64_t denom_serial;
     struct GNUNET_PQ_ResultSpec rs[] = {
+      GNUNET_PQ_result_spec_uint64 ("denominations_serial",
+                                    &denom_serial),
       GNUNET_PQ_result_spec_auto_from_type ("master_sig",
                                             &issue.signature),
       GNUNET_PQ_result_spec_auto_from_type ("denom_pub_hash",
@@ -124,6 +127,7 @@ domination_cb_helper (void *cls,
     else
     {
       dic->cb (dic->cb_cls,
+               denom_serial,
                &denom_pub,
                &issue);
     }
@@ -158,7 +162,8 @@ TEH_PG_iterate_denomination_info (void *cls,
   PREPARE (pg,
            "denomination_iterate",
            "SELECT"
-           " master_sig"
+           " denominations_serial"
+           ",master_sig"
            ",denom_pub_hash"
            ",valid_from"
            ",expire_withdraw"
