@@ -34,6 +34,7 @@
  * @param provider_name
  * @param provider_legitimization_id legi to look up
  * @param[out] h_payto where to write the result
+ * @param[out] is_wallet set to true if @a h_payto is for a wallet
  * @param[out] process_row where to write the row of the entry
  * @return database transaction status
  */
@@ -43,6 +44,7 @@ TEH_PG_kyc_provider_account_lookup (
   const char *provider_name,
   const char *provider_legitimization_id,
   struct TALER_NormalizedPaytoHashP *h_payto,
+  bool *is_wallet,
   uint64_t *process_row);
 
 #endif
