@@ -38,6 +38,7 @@
  *    set to token for access control that must match
  * @param[out] h_payto set to the the hash of the
  *    payto URI of the account undergoing legitimization
+ * @param[out] is_wallet set to true if @a h_payto is for a wallet
  * @param[out] jmeasures set to the legitimization
  *    measures that were put on the account
  * @param[out] is_finished set to true if the legitimization was
@@ -56,6 +57,7 @@ TEH_PG_lookup_completed_legitimization (
   uint32_t measure_index,
   struct TALER_AccountAccessTokenP *access_token,
   struct TALER_NormalizedPaytoHashP *h_payto,
+  bool *is_wallet,
   json_t **jmeasures,
   bool *is_finished,
   size_t *encrypted_attributes_len,
