@@ -30,30 +30,42 @@ enum GNUNET_DB_QueryStatus
 TEH_PG_lookup_h_payto_by_access_token (
   void *cls,
   const struct TALER_AccountAccessTokenP *access_token,
-  struct TALER_NormalizedPaytoHashP *h_payto)
+  struct TALER_NormalizedPaytoHashP *h_payto,
+  bool *is_wallet)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_auto_from_type (access_token),
     GNUNET_PQ_query_param_end
   };
+  char *payto;
   struct GNUNET_PQ_ResultSpec rs[] = {
     GNUNET_PQ_result_spec_auto_from_type (
       "h_normalized_payto",
       h_payto),
+    GNUNET_PQ_result_spec_string (
+      "payto_uri",
+      &payto),
     GNUNET_PQ_result_spec_end
   };
+  enum GNUNET_DB_QueryStatus qs;
 
+  *is_wallet = false;
   PREPARE (pg,
            "lookup_h_payto_by_access_token",
            "SELECT "
            "  h_normalized_payto"
+           " ,payto_uri"
            " FROM wire_targets"
            " WHERE (access_token = $1);");
-  return GNUNET_PQ_eval_prepared_singleton_select (
+  qs = GNUNET_PQ_eval_prepared_singleton_select (
     pg->conn,
     "lookup_h_payto_by_access_token",
     params,
     rs);
-
+  if (qs <= 0)
+    return qs;
+  *is_wallet = TALER_payto_is_wallet (payto);
+  GNUNET_free (payto);
+  return qs;
 }
