@@ -34,12 +34,15 @@
  *    set to token for access control
  * @param[out] h_payto set to the the hash of the
  *    payto URI of the account (if found)
+ * @param[out] is_wallet set to true if @a h_payto
+ *    is for a wallet
  * @return database transaction status
  */
 enum GNUNET_DB_QueryStatus
 TEH_PG_lookup_h_payto_by_access_token (
   void *cls,
   const struct TALER_AccountAccessTokenP *access_token,
-  struct TALER_NormalizedPaytoHashP *h_payto);
+  struct TALER_NormalizedPaytoHashP *h_payto,
+  bool *is_wallet);
 
 #endif
