@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -34,7 +34,8 @@ TEH_PG_lookup_kyc_process_by_account (
   uint64_t *process_row,
   struct GNUNET_TIME_Absolute *expiration,
   char **provider_account_id,
-  char **provider_legitimization_id)
+  char **provider_legitimization_id,
+  bool *is_wallet)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
@@ -42,6 +43,7 @@ TEH_PG_lookup_kyc_process_by_account (
     GNUNET_PQ_query_param_string (provider_name),
     GNUNET_PQ_query_param_end
   };
+  char *payto_uri;
   struct GNUNET_PQ_ResultSpec rs[] = {
     GNUNET_PQ_result_spec_uint64 (
       "legitimization_process_serial_id",
@@ -59,19 +61,27 @@ TEH_PG_lookup_kyc_process_by_account (
         "provider_legitimization_id",
         provider_legitimization_id),
       NULL),
+    GNUNET_PQ_result_spec_string (
+      "payto_uri",
+      &payto_uri),
     GNUNET_PQ_result_spec_end
   };
+  enum GNUNET_DB_QueryStatus qs;
 
   *provider_account_id = NULL;
   *provider_legitimization_id = NULL;
+  *is_wallet = false;
   PREPARE (pg,
            "lookup_process_by_account",
            "SELECT "
-           " legitimization_process_serial_id"
-           ",expiration_time"
-           ",provider_user_id"
-           ",provider_legitimization_id"
-           " FROM legitimization_processes"
+           " lp.legitimization_process_serial_id"
+           ",lp.expiration_time"
+           ",lp.provider_user_id"
+           ",lp.provider_legitimization_id"
+           ",wt.payto_uri"
+           " FROM legitimization_processes lp"
+           " JOIN wire_targets wt"
+           "   ON (lp.h_payto = wt.h_normalized_payto)"
            " WHERE h_payto=$1"
            "   AND provider_name=$2"
            "   AND NOT finished"
@@ -79,9 +89,14 @@ TEH_PG_lookup_kyc_process_by_account (
               match, so this is just to be safe(r): */
            " ORDER BY expiration_time DESC"
            " LIMIT 1;");
-  return GNUNET_PQ_eval_prepared_singleton_select (
+  qs = GNUNET_PQ_eval_prepared_singleton_select (
     pg->conn,
     "lookup_process_by_account",
     params,
     rs);
+  if (qs <= 0)
+    return qs;
+  *is_wallet = TALER_payto_is_wallet (payto_uri);
+  GNUNET_free (payto_uri);
+  return qs;
 }
