@@ -36,6 +36,7 @@
  * @param[out] expiration how long is this KYC check set to be valid (in the past if invalid)
  * @param[out] provider_account_id provider account ID
  * @param[out] provider_legitimization_id provider legitimization ID
+ * @param[out] is_wallet set to true if @a h_payto is for a wallet
  * @return database transaction status
  */
 enum GNUNET_DB_QueryStatus
@@ -46,6 +47,7 @@ TEH_PG_lookup_kyc_process_by_account (
   uint64_t *process_row,
   struct GNUNET_TIME_Absolute *expiration,
   char **provider_account_id,
-  char **provider_legitimization_id);
+  char **provider_legitimization_id,
+  bool *is_wallet);
 
 #endif
