@@ -31,8 +31,10 @@ TEH_PG_lookup_kyc_requirement_by_row (
   void *cls,
   const struct TALER_NormalizedPaytoHashP *h_payto,
   union TALER_AccountPublicKeyP *account_pub,
+  bool *is_wallet,
   struct TALER_ReservePublicKeyP *reserve_pub,
   struct TALER_AccountAccessTokenP *access_token,
+  uint64_t *rule_gen,
   json_t **jrules,
   bool *aml_review,
   bool *kyc_required)
@@ -43,6 +45,7 @@ TEH_PG_lookup_kyc_requirement_by_row (
     GNUNET_PQ_query_param_end
   };
   bool not_found;
+  char *payto = NULL;
   struct GNUNET_PQ_ResultSpec rs[] = {
     GNUNET_PQ_result_spec_allow_null (
       GNUNET_PQ_result_spec_auto_from_type ("account_pub",
@@ -61,11 +64,20 @@ TEH_PG_lookup_kyc_requirement_by_row (
       TALER_PQ_result_spec_json ("jrules",
                                  jrules),
       NULL),
+    GNUNET_PQ_result_spec_allow_null (
+      /* can be NULL due to LEFT JOIN */
+      GNUNET_PQ_result_spec_string ("payto",
+                                    &payto),
+      NULL),
     GNUNET_PQ_result_spec_allow_null (
       /* can be NULL due to LEFT JOIN */
       GNUNET_PQ_result_spec_bool ("aml_review",
                                   aml_review),
       NULL),
+    GNUNET_PQ_result_spec_allow_null (
+      GNUNET_PQ_result_spec_uint64 ("rule_gen",
+                                    rule_gen),
+      NULL),
     GNUNET_PQ_result_spec_bool ("kyc_required",
                                 kyc_required),
     GNUNET_PQ_result_spec_bool ("not_found",
@@ -76,6 +88,8 @@ TEH_PG_lookup_kyc_requirement_by_row (
 
   *jrules = NULL;
   *aml_review = false;
+  *is_wallet = false;
+  *rule_gen = 0;
   memset (account_pub,
           0,
           sizeof (*account_pub));
@@ -92,9 +106,11 @@ TEH_PG_lookup_kyc_requirement_by_row (
            ",out_reserve_pub AS reserve_pub"
            ",out_access_token AS access_token"
            ",out_jrules AS jrules"
+           ",out_payto AS payto"
            ",out_not_found AS not_found"
            ",out_aml_review AS aml_review"
            ",out_kyc_required AS kyc_required"
+           ",out_rule_gen AS rule_gen"
            " FROM exchange_do_lookup_kyc_requirement_by_row"
            " ($1);");
   qs = GNUNET_PQ_eval_prepared_singleton_select (
@@ -104,6 +120,11 @@ TEH_PG_lookup_kyc_requirement_by_row (
     rs);
   if (qs <= 0)
     return qs;
+  if (NULL != payto)
+  {
+    *is_wallet = TALER_payto_is_wallet (payto);
+    GNUNET_free (payto);
+  }
   if (not_found)
     return GNUNET_DB_STATUS_SUCCESS_NO_RESULTS;
   return qs;
