@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2024 Taler Systems SA
+   Copyright (C) 2024, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -33,13 +33,15 @@ TEH_PG_lookup_pending_legitimization (
   struct TALER_AccountAccessTokenP *access_token,
   struct TALER_NormalizedPaytoHashP *h_payto,
   json_t **jmeasures,
-  bool *is_finished)
+  bool *is_finished,
+  bool *is_wallet)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&legitimization_measure_serial_id),
     GNUNET_PQ_query_param_end
   };
+  char *payto_uri;
   struct GNUNET_PQ_ResultSpec rs[] = {
     TALER_PQ_result_spec_json (
       "jmeasures",
@@ -53,23 +55,34 @@ TEH_PG_lookup_pending_legitimization (
     GNUNET_PQ_result_spec_bool (
       "is_finished",
       is_finished),
+    GNUNET_PQ_result_spec_string (
+      "payto_uri",
+      &payto_uri),
     GNUNET_PQ_result_spec_end
   };
+  enum GNUNET_DB_QueryStatus qs;
 
+  *is_wallet = false;
   PREPARE (pg,
            "lookup_pending_legitimization",
            "SELECT "
            " lm.jmeasures"
            ",wt.h_normalized_payto"
+           ",wt.payto_uri"
            ",lm.access_token"
            ",lm.is_finished"
            " FROM legitimization_measures lm"
            " JOIN wire_targets wt"
            "   ON (lm.access_token = wt.access_token)"
            " WHERE lm.legitimization_measure_serial_id=$1;");
-  return GNUNET_PQ_eval_prepared_singleton_select (
+  qs = GNUNET_PQ_eval_prepared_singleton_select (
     pg->conn,
     "lookup_pending_legitimization",
     params,
     rs);
+  if (qs <= 0)
+    return qs;
+  *is_wallet = TALER_payto_is_wallet (payto_uri);
+  GNUNET_free (payto_uri);
+  return qs;
 }
