@@ -40,6 +40,7 @@
  *    measures that were put on the account
  * @param[out] is_finished set to true if the legitimization was
  *    already finished
+ * @param[out] is_wallet set to true if @a h_payto is for a wallet
  * @return database transaction status
  */
 enum GNUNET_DB_QueryStatus
@@ -49,6 +50,7 @@ TEH_PG_lookup_pending_legitimization (
   struct TALER_AccountAccessTokenP *access_token,
   struct TALER_NormalizedPaytoHashP *h_payto,
   json_t **jmeasures,
-  bool *is_finished);
+  bool *is_finished,
+  bool *is_wallet);
 
 #endif
