@@ -173,28 +173,12 @@ TEH_PG_lookup_serial_by_table (void *cls,
               " ORDER BY known_coin_id DESC"
               " LIMIT 1;");
     break;
-  case TALER_EXCHANGEDB_RT_REFRESH_COMMITMENTS:
-    XPREPARE ("select_serial_by_table_refresh_commitments",
+  case TALER_EXCHANGEDB_RT_REFRESH:
+    XPREPARE ("select_serial_by_table_refresh",
               "SELECT"
-              " melt_serial_id AS serial"
-              " FROM refresh_commitments"
-              " ORDER BY melt_serial_id DESC"
-              " LIMIT 1;");
-    break;
-  case TALER_EXCHANGEDB_RT_REFRESH_REVEALED_COINS:
-    XPREPARE ("select_serial_by_table_refresh_revealed_coins",
-              "SELECT"
-              " rrc_serial AS serial"
-              " FROM refresh_revealed_coins"
-              " ORDER BY rrc_serial DESC"
-              " LIMIT 1;");
-    break;
-  case TALER_EXCHANGEDB_RT_REFRESH_TRANSFER_KEYS:
-    XPREPARE ("select_serial_by_table_refresh_transfer_keys",
-              "SELECT"
-              " rtc_serial AS serial"
-              " FROM refresh_transfer_keys"
-              " ORDER BY rtc_serial DESC"
+              " refresh_id AS serial"
+              " FROM refresh"
+              " ORDER BY refresh_id DESC"
               " LIMIT 1;");
     break;
   case TALER_EXCHANGEDB_RT_BATCH_DEPOSITS:
@@ -408,14 +392,14 @@ TEH_PG_lookup_serial_by_table (void *cls,
               " LIMIT 1;");
     statement = "select_serial_by_table_purse_deletion";
     break;
-  case TALER_EXCHANGEDB_RT_AGE_WITHDRAW:
-    XPREPARE ("select_serial_by_table_age_withdraw",
+  case TALER_EXCHANGEDB_RT_WITHDRAW:
+    XPREPARE ("select_serial_by_table_withdraw",
               "SELECT"
-              " age_withdraw_id AS serial"
-              " FROM age_withdraw"
-              " ORDER BY age_withdraw_id DESC"
+              " withdraw_id AS serial"
+              " FROM withdraw"
+              " ORDER BY withdraw_id DESC"
               " LIMIT 1;");
-    statement = "select_serial_by_table_age_withdraw";
+    statement = "select_serial_by_table_withdraw";
     break;
   case TALER_EXCHANGEDB_RT_LEGITIMIZATION_MEASURES:
     XPREPARE ("select_serial_by_table_legitimization_measures",
