@@ -42,7 +42,7 @@
  * @param[out] amount_with_fee set to the total deposited amount
  * @param[out] deposit_fee set to how much the exchange did charge for the deposit
  * @param[out] kyc set to the kyc status of the receiver (if @a pending)
- * @param[out] aml_decision set to the AML status of the receiver
+ * @param[out] account_pub set to public key that is authorized to start the KYC process; unchanged if no such key is known
  * @return transaction status code
  */
 enum GNUNET_DB_QueryStatus
@@ -58,6 +58,6 @@ TEH_PG_lookup_transfer_by_deposit (
   struct TALER_Amount *amount_with_fee,
   struct TALER_Amount *deposit_fee,
   struct TALER_EXCHANGEDB_KycStatus *kyc,
-  enum TALER_AmlDecisionState *aml_decision);
+  union TALER_AccountPublicKeyP *account_pub);
 
 #endif
