@@ -29,7 +29,7 @@
 enum GNUNET_DB_QueryStatus
 TEH_PG_select_aggregation_transient (
   void *cls,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_FullPaytoHashP *h_payto,
   const struct TALER_MerchantPublicKeyP *merchant_pub,
   const char *exchange_account_section,
   struct TALER_WireTransferIdentifierRawP *wtid,
@@ -49,7 +49,7 @@ TEH_PG_select_aggregation_transient (
                                           wtid),
     GNUNET_PQ_result_spec_end
   };
-  /* Used in #postgres_select_aggregation_transient() */
+
   PREPARE (pg,
            "select_aggregation_transient",
            "SELECT"
