@@ -77,6 +77,7 @@ handle_aml_result (void *cls,
     struct GNUNET_TIME_Timestamp decision_time;
     struct GNUNET_TIME_Absolute expiration_time;
     json_t *jproperties = NULL;
+    char *payto;
     bool to_investigate;
     bool is_active;
     json_t *account_rules;
@@ -85,6 +86,8 @@ handle_aml_result (void *cls,
                                     &rowid),
       GNUNET_PQ_result_spec_auto_from_type ("h_payto",
                                             &h_payto),
+      GNUNET_PQ_result_spec_string ("payto_uri",
+                                    &payto),
       GNUNET_PQ_result_spec_allow_null (
         GNUNET_PQ_result_spec_string ("justification",
                                       &justification),
@@ -117,6 +120,12 @@ handle_aml_result (void *cls,
     }
     if (GNUNET_TIME_absolute_is_past (expiration_time))
       is_active = false;
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Returning AML decisions for `%s' (%s)\n",
+                payto,
+                TALER_payto_is_wallet (payto)
+                ? "wallet"
+                : "account");
     ctx->cb (ctx->cb_cls,
              rowid,
              justification,
@@ -126,6 +135,7 @@ handle_aml_result (void *cls,
              jproperties,
              to_investigate,
              is_active,
+             TALER_payto_is_wallet (payto),
              account_rules);
     GNUNET_PQ_cleanup_result (rs);
   }
@@ -185,7 +195,10 @@ TEH_PG_select_aml_decisions (
            ",lo.to_investigate"
            ",lo.is_active"
            ",lo.jnew_rules"
+           ",wt.payto_uri"
            " FROM legitimization_outcomes lo"
+           " JOIN wire_targets wt"
+           "   ON (lo.h_payto = wt.h_normalized_payto)"
            " LEFT JOIN aml_history ah"
            "   USING (outcome_serial_id)"
            " WHERE (outcome_serial_id > $7)"
@@ -206,7 +219,10 @@ TEH_PG_select_aml_decisions (
            ",lo.to_investigate"
            ",lo.is_active"
            ",lo.jnew_rules"
+           ",wt.payto_uri"
            " FROM legitimization_outcomes lo"
+           " JOIN wire_targets wt"
+           "   ON (lo.h_payto = wt.h_normalized_payto)"
            " LEFT JOIN aml_history ah"
            "   USING (outcome_serial_id)"
            " WHERE lo.outcome_serial_id < $7"
