@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2024 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -49,7 +49,7 @@ struct GetAttributesContext
   /**
    * Key of our query.
    */
-  const struct TALER_PaytoHashP *h_payto;
+  const struct TALER_NormalizedPaytoHashP *h_payto;
 
   /**
    * Flag set to #GNUNET_OK as long as everything is fine.
@@ -117,7 +117,7 @@ get_attributes_cb (void *cls,
 enum GNUNET_DB_QueryStatus
 TEH_PG_select_kyc_attributes (
   void *cls,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_NormalizedPaytoHashP *h_payto,
   TALER_EXCHANGEDB_AttributeCallback cb,
   void *cb_cls)
 {
