@@ -135,20 +135,20 @@ TEH_PG_select_withdraw_amounts_for_kyc_check (
   PREPARE (pg,
            "select_kyc_relevant_withdraw_events",
            "SELECT"
-           " ro.amount_with_fee AS amount"
-           ",ro.execution_date AS date"
+           " wd.amount_with_fee AS amount"
+           ",wd.execution_date AS date"
            " FROM reserves_in ri"
            " JOIN reserve_history rh"
            "   ON (rh.reserve_pub = ri.reserve_pub)"
-           " JOIN reserves_out ro"
-           "   ON (ro.reserve_out_serial_id = rh.serial_id)"
+           " JOIN withdraw wd"
+           "   ON (wd.withdraw_id = rh.serial_id)"
            " WHERE ri.wire_source_h_payto IN ("
            "   SELECT wire_target_h_payto"
            "     FROM wire_targets"
            "    WHERE h_normalized_payto=$1"
            "   )"
            "   AND rh.table_name='reserves_out'"
-           "   AND ro.execution_date >= $2"
+           "   AND wd.execution_date >= $2"
            " ORDER BY rh.reserve_history_serial_id DESC");
   qs = GNUNET_PQ_eval_prepared_multi_select (
     pg->conn,
