@@ -17,6 +17,7 @@
  * @file exchangedb/pg_select_withdrawals_above_serial_id.c
  * @brief Implementation of the select_withdrawals_above_serial_id function for Postgres
  * @author Christian Grothoff
+ * @author Özgür Kesim
  */
 #include "platform.h"
 #include "taler_error_codes.h"
@@ -26,9 +27,9 @@
 #include "pg_helper.h"
 
 /**
- * Closure for #reserves_out_serial_helper_cb().
+ * Closure for #withdraw_serial_helper_cb().
  */
-struct ReservesOutSerialContext
+struct WithdrawSerialContext
 {
 
   /**
@@ -57,42 +58,69 @@ struct ReservesOutSerialContext
  * Helper function to be called with the results of a SELECT statement
  * that has returned @a num_results results.
  *
- * @param cls closure of type `struct ReservesOutSerialContext`
+ * @param cls closure of type `struct WithdrawSerialContext`
  * @param result the postgres result
  * @param num_results the number of results in @a result
  */
 static void
-reserves_out_serial_helper_cb (void *cls,
-                               PGresult *result,
-                               unsigned int num_results)
+withdraw_serial_helper_cb (void *cls,
+                           PGresult *result,
+                           unsigned int num_results)
 {
-  struct ReservesOutSerialContext *rosc = cls;
+  struct WithdrawSerialContext *rosc = cls;
   struct PostgresClosure *pg = rosc->pg;
 
   for (unsigned int i = 0; i<num_results; i++)
   {
-    struct TALER_BlindedCoinHashP h_blind_ev;
-    struct TALER_DenominationPublicKey denom_pub;
+    size_t num_evs;
+    struct TALER_BlindedCoinHashP *h_blind_evs = NULL;
+    size_t num_denom_serials;
+    uint64_t *denom_serials = NULL;
     struct TALER_ReservePublicKeyP reserve_pub;
     struct TALER_ReserveSignatureP reserve_sig;
     struct GNUNET_TIME_Timestamp execution_date;
+    struct TALER_HashBlindedPlanchetsP h_planchets;
+    struct TALER_BlindingMasterSeedP blinding_seed;
     struct TALER_Amount amount_with_fee;
     uint64_t rowid;
+    uint16_t max_age;
+    uint16_t noreveal_index;
+    bool no_noreveal_index;
+    bool no_max_age;
+    bool no_blinding_seed;
     struct GNUNET_PQ_ResultSpec rs[] = {
-      GNUNET_PQ_result_spec_auto_from_type ("h_blind_ev",
-                                            &h_blind_ev),
-      TALER_PQ_result_spec_denom_pub ("denom_pub",
-                                      &denom_pub),
+      TALER_PQ_result_spec_array_blinded_coin_hash (pg->conn,
+                                                    "h_blind_evs",
+                                                    &num_evs,
+                                                    &h_blind_evs),
+      GNUNET_PQ_result_spec_array_uint64 (pg->conn,
+                                          "denom_serials",
+                                          &num_denom_serials,
+                                          &denom_serials),
       GNUNET_PQ_result_spec_auto_from_type ("reserve_pub",
                                             &reserve_pub),
       GNUNET_PQ_result_spec_auto_from_type ("reserve_sig",
                                             &reserve_sig),
+      GNUNET_PQ_result_spec_auto_from_type ("h_planchets",
+                                            &h_planchets),
       GNUNET_PQ_result_spec_timestamp ("execution_date",
                                        &execution_date),
       TALER_PQ_RESULT_SPEC_AMOUNT ("amount_with_fee",
                                    &amount_with_fee),
-      GNUNET_PQ_result_spec_uint64 ("reserve_out_serial_id",
+      GNUNET_PQ_result_spec_uint64 ("withdraw_id",
                                     &rowid),
+      GNUNET_PQ_result_spec_allow_null (
+        GNUNET_PQ_result_spec_uint16 ("max_age",
+                                      &max_age),
+        &no_max_age),
+      GNUNET_PQ_result_spec_allow_null (
+        GNUNET_PQ_result_spec_uint16 ("noreveal_index",
+                                      &noreveal_index),
+        &no_noreveal_index),
+      GNUNET_PQ_result_spec_allow_null (
+        GNUNET_PQ_result_spec_auto_from_type ("blinding_seed",
+                                              &blinding_seed),
+        &no_blinding_seed),
       GNUNET_PQ_result_spec_end
     };
     enum GNUNET_GenericReturnValue ret;
@@ -104,12 +132,42 @@ reserves_out_serial_helper_cb (void *cls,
     {
       GNUNET_break (0);
       rosc->status = GNUNET_SYSERR;
+      GNUNET_PQ_cleanup_result (rs);
+      return;
+    }
+    if (num_denom_serials != num_evs)
+    {
+      GNUNET_break (0);
+      rosc->status = GNUNET_SYSERR;
+      GNUNET_PQ_cleanup_result (rs);
+      return;
+    }
+    if (no_max_age != no_noreveal_index)
+    {
+      GNUNET_break (0);
+      rosc->status = GNUNET_SYSERR;
+      GNUNET_PQ_cleanup_result (rs);
+      return;
+    }
+
+    if ((! no_max_age) &&
+        ((255 <= noreveal_index) || (255 <= max_age)))
+    {
+      GNUNET_break (0);
+      rosc->status = GNUNET_SYSERR;
+      GNUNET_PQ_cleanup_result (rs);
       return;
     }
     ret = rosc->cb (rosc->cb_cls,
                     rowid,
-                    &h_blind_ev,
-                    &denom_pub,
+                    num_evs,
+                    h_blind_evs,
+                    denom_serials,
+                    &h_planchets,
+                    no_blinding_seed ? NULL : &blinding_seed,
+                    ! no_max_age,
+                    (uint8_t) max_age,
+                    (uint8_t) noreveal_index,
                     &reserve_pub,
                     &reserve_sig,
                     execution_date,
@@ -133,7 +191,7 @@ TEH_PG_select_withdrawals_above_serial_id (
     GNUNET_PQ_query_param_uint64 (&serial_id),
     GNUNET_PQ_query_param_end
   };
-  struct ReservesOutSerialContext rosc = {
+  struct WithdrawSerialContext rosc = {
     .cb = cb,
     .cb_cls = cb_cls,
     .pg = pg,
@@ -143,26 +201,26 @@ TEH_PG_select_withdrawals_above_serial_id (
 
   /* Fetch deposits with rowid '\geq' the given parameter */
   PREPARE (pg,
-           "audit_get_reserves_out_incr",
+           "audit_get_withdraw_incr",
            "SELECT"
-           " h_blind_ev"
-           ",denom.denom_pub"
+           " withdraw_id"
+           ",h_planchets"
+           ",blinding_seed"
+           ",h_blind_evs"
+           ",max_age"
+           ",noreveal_index"
+           ",denom_serials"
            ",reserve_sig"
-           ",reserves.reserve_pub"
+           ",reserve_pub"
            ",execution_date"
            ",amount_with_fee"
-           ",reserve_out_serial_id"
-           " FROM reserves_out"
-           "    JOIN reserves"
-           "      USING (reserve_uuid)"
-           "    JOIN denominations denom"
-           "      USING (denominations_serial)"
-           " WHERE reserve_out_serial_id>=$1"
-           " ORDER BY reserve_out_serial_id ASC;");
+           " FROM withdraw"
+           " WHERE withdraw_id>=$1"
+           " ORDER BY withdraw_id ASC;");
   qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
-                                             "audit_get_reserves_out_incr",
+                                             "audit_get_withdraw_incr",
                                              params,
-                                             &reserves_out_serial_helper_cb,
+                                             &withdraw_serial_helper_cb,
                                              &rosc);
   if (GNUNET_OK != rosc.status)
     return GNUNET_DB_STATUS_HARD_ERROR;
