@@ -25,12 +25,13 @@
 #include "pg_store_wire_transfer_out.h"
 #include "pg_helper.h"
 
+
 enum GNUNET_DB_QueryStatus
 TEH_PG_store_wire_transfer_out (
   void *cls,
   struct GNUNET_TIME_Timestamp date,
   const struct TALER_WireTransferIdentifierRawP *wtid,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_FullPaytoHashP *h_payto,
   const char *exchange_account_section,
   const struct TALER_Amount *amount)
 {
