@@ -42,13 +42,12 @@ TEH_COMMON_free_reserve_history (
         GNUNET_free (bt);
         break;
       }
-    case TALER_EXCHANGEDB_RO_WITHDRAW_COIN:
+    case TALER_EXCHANGEDB_RO_WITHDRAW_COINS:
       {
-        struct TALER_EXCHANGEDB_CollectableBlindcoin *cbc;
-
-        cbc = rh->details.withdraw;
-        TALER_blinded_denom_sig_free (&cbc->sig);
-        GNUNET_free (cbc);
+        struct TALER_EXCHANGEDB_Withdraw *wd;
+        wd = rh->details.withdraw;
+        GNUNET_free (wd->denom_pub_hashes);
+        GNUNET_free (wd);
         break;
       }
     case TALER_EXCHANGEDB_RO_RECOUP_COIN:
