@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2014--2023 Taler Systems SA
+   Copyright (C) 2014--2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -44,9 +44,8 @@
 #include "pg_create_tables.h"
 #include "pg_delete_aggregation_transient.h"
 #include "pg_delete_shard_locks.h"
-#include "pg_do_age_withdraw.h"
-#include "pg_do_batch_withdraw.h"
-#include "pg_do_batch_withdraw_insert.h"
+#include "pg_disable_rules.h"
+#include "pg_do_withdraw.h"
 #include "pg_do_check_deposit_idempotent.h"
 #include "pg_do_deposit.h"
 #include "pg_do_melt.h"
@@ -55,11 +54,13 @@
 #include "pg_do_purse_merge.h"
 #include "pg_do_recoup.h"
 #include "pg_do_recoup_refresh.h"
+#include "pg_do_refresh.h"
 #include "pg_do_refund.h"
 #include "pg_do_reserve_open.h"
 #include "pg_do_reserve_purse.h"
 #include "pg_drain_kyc_alert.h"
 #include "pg_drop_tables.h"
+#include "pg_enable_rules.h"
 #include "pg_ensure_coin_known.h"
 #include "pg_event_listen.h"
 #include "pg_event_listen_cancel.h"
@@ -67,10 +68,11 @@
 #include "pg_expire_purse.h"
 #include "pg_find_aggregation_transient.h"
 #include "pg_gc.h"
-#include "pg_get_age_withdraw.h"
+#include "pg_get_withdraw.h"
 #include "pg_get_coin_denomination.h"
 #include "pg_get_coin_transactions.h"
 #include "pg_get_denomination_info.h"
+#include "pg_get_denomination_by_serial.h"
 #include "pg_get_denomination_revocation.h"
 #include "pg_get_drain_profit.h"
 #include "pg_get_expired_reserves.h"
@@ -79,17 +81,16 @@
 #include "pg_get_global_fees.h"
 #include "pg_get_known_coin.h"
 #include "pg_get_kyc_rules.h"
-#include "pg_get_link_data.h"
-#include "pg_get_melt.h"
 #include "pg_get_old_coin_by_h_blind.h"
 #include "pg_get_pending_kyc_requirement_process.h"
 #include "pg_get_policy_details.h"
 #include "pg_get_purse_deposit.h"
 #include "pg_get_purse_request.h"
 #include "pg_get_ready_deposit.h"
+#include "pg_get_refresh.h"
 #include "pg_get_refresh_reveal.h"
 #include "pg_get_reserve_balance.h"
-#include "pg_get_reserve_by_h_blind.h"
+#include "pg_get_reserve_by_h_planchets.h"
 #include "pg_get_reserve_history.h"
 #include "pg_get_signature_for_known_coin.h"
 #include "pg_get_unfinished_close_requests.h"
@@ -97,7 +98,6 @@
 #include "pg_get_wire_fee.h"
 #include "pg_get_wire_fees.h"
 #include "pg_get_wire_hash_for_contract.h"
-#include "pg_get_withdraw_info.h"
 #include "pg_have_deposit2.h"
 #include "pg_helper.h"
 #include "pg_inject_auditor_triggers.h"
@@ -118,7 +118,6 @@
 #include "pg_insert_partner.h"
 #include "pg_insert_purse_request.h"
 #include "pg_insert_records_by_table.h"
-#include "pg_insert_refresh_reveal.h"
 #include "pg_insert_refund.h"
 #include "pg_insert_reserve_closed.h"
 #include "pg_insert_reserve_open_deposit.h"
@@ -187,6 +186,8 @@
 #include "pg_select_contract.h"
 #include "pg_select_contract_by_purse.h"
 #include "pg_select_deposit_amounts_for_kyc_check.h"
+#include "pg_select_exchange_credit_transfers.h"
+#include "pg_select_exchange_debit_transfers.h"
 #include "pg_select_kyc_attributes.h"
 #include "pg_select_merge_amounts_for_kyc_check.h"
 #include "pg_select_purse.h"
@@ -402,8 +403,6 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_insert_close_request;
   plugin->delete_aggregation_transient
     = &TEH_PG_delete_aggregation_transient;
-  plugin->get_link_data
-    = &TEH_PG_get_link_data;
   plugin->iterate_reserve_close_info
     = &TEH_PG_iterate_reserve_close_info;
   plugin->iterate_kyc_reference
@@ -500,8 +499,6 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_start_read_only;
   plugin->insert_denomination_info
     = &TEH_PG_insert_denomination_info;
-  plugin->do_batch_withdraw_insert
-    = &TEH_PG_do_batch_withdraw_insert;
   plugin->lookup_wire_fee_by_time
     = &TEH_PG_lookup_wire_fee_by_time;
   plugin->start
@@ -518,6 +515,8 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_event_notify;
   plugin->get_denomination_info
     = &TEH_PG_get_denomination_info;
+  plugin->get_denomination_by_serial
+    = &TEH_PG_get_denomination_by_serial;
   plugin->iterate_denomination_info
     = &TEH_PG_iterate_denomination_info;
   plugin->iterate_denominations
@@ -536,14 +535,10 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_drain_kyc_alert;
   plugin->reserves_in_insert
     = &TEH_PG_reserves_in_insert;
-  plugin->get_withdraw_info
-    = &TEH_PG_get_withdraw_info;
-  plugin->do_batch_withdraw
-    = &TEH_PG_do_batch_withdraw;
-  plugin->do_age_withdraw
-    = &TEH_PG_do_age_withdraw;
-  plugin->get_age_withdraw
-    = &TEH_PG_get_age_withdraw;
+  plugin->do_withdraw
+    = &TEH_PG_do_withdraw;
+  plugin->get_withdraw
+    = &TEH_PG_get_withdraw;
   plugin->wad_in_insert
     = &TEH_PG_wad_in_insert;
   plugin->kycauth_in_insert
@@ -558,8 +553,8 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_get_wire_hash_for_contract;
   plugin->add_policy_fulfillment_proof
     = &TEH_PG_add_policy_fulfillment_proof;
-  plugin->do_melt
-    = &TEH_PG_do_melt;
+  plugin->do_refresh
+    = &TEH_PG_do_refresh;
   plugin->do_refund
     = &TEH_PG_do_refund;
   plugin->do_recoup
@@ -598,12 +593,8 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_select_refunds_by_coin;
   plugin->select_aml_measures
     = &TEH_PG_select_aml_measures;
-  plugin->get_melt
-    = &TEH_PG_get_melt;
-  plugin->insert_refresh_reveal
-    = &TEH_PG_insert_refresh_reveal;
-  plugin->get_refresh_reveal
-    = &TEH_PG_get_refresh_reveal;
+  plugin->get_refresh
+    = &TEH_PG_get_refresh;
   plugin->lookup_wire_transfer
     = &TEH_PG_lookup_wire_transfer;
   plugin->lookup_transfer_by_deposit
@@ -662,8 +653,8 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_select_recoup_above_serial_id;
   plugin->select_recoup_refresh_above_serial_id
     = &TEH_PG_select_recoup_refresh_above_serial_id;
-  plugin->get_reserve_by_h_blind
-    = &TEH_PG_get_reserve_by_h_blind;
+  plugin->get_reserve_by_h_planchets
+    = &TEH_PG_get_reserve_by_h_planchets;
   plugin->get_old_coin_by_h_blind
     = &TEH_PG_get_old_coin_by_h_blind;
   plugin->insert_denomination_revocation
@@ -724,6 +715,10 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_lookup_h_payto_by_access_token;
   plugin->insert_sanction_list_hit
     = &TEH_PG_insert_sanction_list_hit;
+  plugin->select_exchange_debit_transfers
+    = &TEH_PG_select_exchange_debit_transfers;
+  plugin->select_exchange_credit_transfers
+    = &TEH_PG_select_exchange_credit_transfers;
   plugin->select_all_kyc_attributes
     = &TEH_PG_select_all_kyc_attributes;
   plugin->begin_shard
@@ -754,6 +749,10 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_select_kyc_attributes;
   plugin->insert_aml_officer
     = &TEH_PG_insert_aml_officer;
+  plugin->enable_rules
+    = &TEH_PG_enable_rules;
+  plugin->disable_rules
+    = &TEH_PG_disable_rules;
   plugin->test_aml_officer
     = &TEH_PG_test_aml_officer;
   plugin->lookup_aml_officer
