@@ -1263,8 +1263,6 @@ struct TALER_AUDITORDB_Plugin
     void *cb_cls);
 
 
-  // MARK: CRUD
-
   /**
    * Get information about arithmetic inconsistencies from the database.
    *
@@ -1368,6 +1366,24 @@ struct TALER_AUDITORDB_Plugin
     TALER_AUDITORDB_ClosureLagsCallback cb,
     void *cb_cls);
 
+  /**
+   * A previously missing wire transfer may have been found. Remove an alert
+   * (if we raised one).
+   *
+   * @param cls plugin closure
+   * @param amount wire transfer amount
+   * @param wtid wire transfer subject
+   * @param credit_account_uri destination account
+   * @return #GNUNET_DB_STATUS_SUCCESS_NO_RESULTS if no matching alert was
+   *   found
+   */
+  enum GNUNET_DB_QueryStatus
+    (*delete_auditor_closure_lag)(
+    void *cls,
+    const struct TALER_Amount *amount,
+    const struct TALER_WireTransferIdentifierRawP *wtid,
+    struct TALER_FullPayto credit_account_uri);
+
   enum GNUNET_DB_QueryStatus
     (*get_refreshes_hanging)(
     void *cls,
@@ -1872,6 +1888,41 @@ struct TALER_AUDITORDB_Plugin
                         const struct TALER_ReservePublicKeyP *reserve_pub);
 
 
+  /**
+   * Insert new row into the early aggregation table.  This can happen simply
+   * because of when the taler-helper-auditor-transfer looks at which of the
+   * two tables. If it is cleared in the next iteration, this is perfectly
+   * expected.
+   *
+   * @param cls the @e cls of this struct with the plugin-specific state
+   * @param batch_deposit_serial_id where in the batch deposit table are we
+   * @param tracking_serial_id where in the tracking table are we
+   * @param total_amount value of all missing deposits, including fees
+   * @return transaction status code
+   */
+  enum GNUNET_DB_QueryStatus
+    (*insert_early_aggregation)(
+    void *cls,
+    uint64_t batch_deposit_serial_id,
+    uint64_t tracking_serial_id,
+    const struct TALER_Amount *total_amount);
+
+
+  /**
+   * Delete a row from the early aggregation table.
+   * Usually done when the expected aggregation
+   * was finally detected.
+   *
+   * @param cls the @e cls of this struct with the plugin-specific state
+   * @param batch_deposit_serial_id which entry to delete
+   * @return transaction status code
+   */
+  enum GNUNET_DB_QueryStatus
+    (*delete_early_aggregation)(
+    void *cls,
+    uint64_t batch_deposit_serial_id);
+
+
   /**
    * Insert new row into the pending deposits table.
    *
