@@ -29,6 +29,15 @@
 #include "taler_kyclogic_lib.h"
 #include "taler_util.h"
 
+/**
+ * Detailed status for persisting an AML program result.
+ */
+enum TALER_EXCHANGEDB_PersistProgramResultStatus
+{
+  TALER_EXCHANGEDB_PPRS_OK = 0,
+  TALER_EXCHANGEDB_PPRS_BAD_OUTCOME = 1,
+};
+
 
 /**
  * Initialize the plugin.
@@ -230,6 +239,11 @@ struct TALER_EXCHANGEDB_HistoryBuilderContext
    * Key to use to decrypt KYC attributes.
    */
   struct TALER_AttributeEncryptionKeyP *attribute_key;
+
+  /**
+   * True if @e account is for a wallet.
+   */
+  bool is_wallet;
 };
 
 
@@ -344,6 +358,7 @@ typedef void
  * @param plugin database plugin to use
  * @param attribute_key key to use to decrypt attributes
  * @param account account to get the rule set for
+ * @param is_wallet true if @a account is a wallet
  * @param cb function to call with the result
  * @param cb_cls closure for @a cb
  * @return handle to cancel the operation
@@ -353,6 +368,7 @@ TALER_EXCHANGEDB_update_rules (
   struct TALER_EXCHANGEDB_Plugin *plugin,
   const struct TALER_AttributeEncryptionKeyP *attribute_key,
   const struct TALER_NormalizedPaytoHashP *account,
+  bool is_wallet,
   TALER_EXCHANGEDB_CurrentRulesCallback cb,
   void *cb_cls);
 
@@ -378,6 +394,7 @@ TALER_EXCHANGEDB_update_rules_cancel (
  *        expiration triggering something) and we should simply
  *        create a new row
  * @param account_id hash of account the result is about
+ * @param ret_pprs
  * @param apr AML program result to persist
  */
 enum GNUNET_DB_QueryStatus
@@ -385,7 +402,8 @@ TALER_EXCHANGEDB_persist_aml_program_result (
   struct TALER_EXCHANGEDB_Plugin *plugin,
   uint64_t process_row,
   const struct TALER_NormalizedPaytoHashP *account_id,
-  const struct TALER_KYCLOGIC_AmlProgramResult *apr);
+  const struct TALER_KYCLOGIC_AmlProgramResult *apr,
+  enum TALER_EXCHANGEDB_PersistProgramResultStatus *ret_pprs);
 
 
 #endif
