@@ -21,92 +21,11 @@
 #ifndef TALER_KYCLOGIC_LIB_H
 #define TALER_KYCLOGIC_LIB_H
 
-#include <microhttpd.h>
 #include "taler_exchangedb_plugin.h"
+#include "taler_util.h"
 #include "taler_kyclogic_plugin.h"
 
 
-/**
- * Enumeration of possible events that may trigger
- * KYC requirements.
- */
-enum TALER_KYCLOGIC_KycTriggerEvent
-{
-
-  /**
-   * Reserved value for invalid event types.
-   */
-  TALER_KYCLOGIC_KYC_TRIGGER_NONE = 0,
-
-  /**
-   * Customer withdraws coins.
-   */
-  TALER_KYCLOGIC_KYC_TRIGGER_WITHDRAW = 1,
-
-  /**
-   * Merchant deposits coins.
-   */
-  TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT = 2,
-
-  /**
-   * Wallet receives P2P payment.
-   */
-  TALER_KYCLOGIC_KYC_TRIGGER_P2P_RECEIVE = 3,
-
-  /**
-   * Wallet balance exceeds threshold. The timeframe is
-   * irrelevant for this limit.
-   */
-  TALER_KYCLOGIC_KYC_TRIGGER_WALLET_BALANCE = 4,
-
-  /**
-   * Reserve is being closed by force.
-   */
-  TALER_KYCLOGIC_KYC_TRIGGER_RESERVE_CLOSE = 5,
-
-  /**
-   * Deposits have been aggregated, we are wiring a
-   * certain amount into a (merchant) bank account.
-   */
-  TALER_KYCLOGIC_KYC_TRIGGER_AGGREGATE = 6,
-
-  /**
-   * Limit per transaction.  The timeframe is
-   * irrelevant for this limit.
-   */
-  TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION = 7,
-
-  /**
-   * Limit per refund.  The timeframe is
-   * irrelevant for this limit.
-   */
-  TALER_KYCLOGIC_KYC_TRIGGER_REFUND = 8
-
-};
-
-
-/**
- * Types of KYC checks.
- */
-enum TALER_KYCLOGIC_CheckType
-{
-  /**
-   * Wait for staff or contact staff out-of-band.
-   */
-  TALER_KYCLOGIC_CT_INFO,
-
-  /**
-   * SPA should show an inline form.
-   */
-  TALER_KYCLOGIC_CT_FORM,
-
-  /**
-   * SPA may start external KYC process.
-   */
-  TALER_KYCLOGIC_CT_LINK
-};
-
-
 /**
  * KYC measure that can be taken.
  */
@@ -426,11 +345,15 @@ TALER_KYCLOGIC_get_aml_program_fallback (const char *prog_name);
  * has performed any operation.
  *
  * @param lrs rule set to investigate, NULL for default
- * @return LegitimizationMeasures, NULL on error
+ * @param is_wallet true to return measures for wallets,
+ *    false to return measures for accounts
+ * @return LegitimizationMeasures, NULL if there are no
+ *   zero measures
  */
 json_t *
 TALER_KYCLOGIC_zero_measures (
-  const struct TALER_KYCLOGIC_LegitimizationRuleSet *lrs);
+  const struct TALER_KYCLOGIC_LegitimizationRuleSet *lrs,
+  bool is_wallet);
 
 
 /**
@@ -563,11 +486,13 @@ TALER_KYCLOGIC_check_to_jmeasures (
  *
  * @param jrules a ``LegitimizationRuleSet`` with KYC rules;
  *     NULL to use default rules
+ * @param is_wallet true if this is for a wallet
  * @return set to JSON array with public limits
  *   of type ``AccountLimit``
  */
 json_t *
-TALER_KYCLOGIC_rules_to_limits (const json_t *jrules);
+TALER_KYCLOGIC_rules_to_limits (const json_t *jrules,
+                                bool is_wallet);
 
 
 /**
@@ -837,10 +762,12 @@ TALER_KYCLOGIC_get_instant_measure (
 /**
  * Return default legitimization rule set in JSON.
  *
+ * @param for_wallet true to return only rules that apply to
+ *         wallets, false to return only rules that apply to accounts
  * @return default legitimization rules
  */
-const json_t *
-TALER_KYCLOGIC_get_default_legi_rules (void);
+json_t *
+TALER_KYCLOGIC_get_default_legi_rules (bool for_wallet);
 
 /**
  * Check if there is a measure in @a lrs that is named @a measure.
@@ -998,6 +925,7 @@ typedef json_t *
  * @param jmeasures current KYC/AML rules to apply;
  *           they determine also the AML program and
  *           provide the context
+ * @param is_wallet true if this is for a wallet
  * @param measure_index which KYC measure yielded the
  *       @a attributes
  * @param current_attributes_cb function to get current KYC attributes
@@ -1021,6 +949,7 @@ typedef json_t *
 struct TALER_KYCLOGIC_AmlProgramRunnerHandle *
 TALER_KYCLOGIC_run_aml_program (
   const json_t *jmeasures,
+  bool is_wallet,
   unsigned int measure_index,
   TALER_KYCLOGIC_HistoryBuilderCallback current_attributes_cb,
   void *current_attributes_cb_cls,
@@ -1040,6 +969,7 @@ TALER_KYCLOGIC_run_aml_program (
  *
  * @param prog_name name of AML program to run
  * @param context context to run with
+ * @param is_wallet true if this is for a wallet
  * @param current_attributes_cb function to get current KYC attributes
  * @param current_attributes_cb_cls closure for @a current_attributes_cb
  * @param current_rules_cb callback to get current KYC rules that apply to the account
@@ -1062,6 +992,7 @@ struct TALER_KYCLOGIC_AmlProgramRunnerHandle *
 TALER_KYCLOGIC_run_aml_program2 (
   const char *prog_name,
   const json_t *context,
+  bool is_wallet,
   TALER_KYCLOGIC_HistoryBuilderCallback current_attributes_cb,
   void *current_attributes_cb_cls,
   TALER_KYCLOGIC_HistoryBuilderCallback current_rules_cb,
@@ -1079,6 +1010,7 @@ TALER_KYCLOGIC_run_aml_program2 (
  * Run AML program specified by the given
  * measure.
  *
+ * @param is_wallet true if this is for a wallet
  * @param measure measure with program name and context
  *         to run
  * @param current_attributes_cb function to get current KYC attributes
@@ -1101,6 +1033,7 @@ TALER_KYCLOGIC_run_aml_program2 (
  */
 struct TALER_KYCLOGIC_AmlProgramRunnerHandle *
 TALER_KYCLOGIC_run_aml_program3 (
+  bool is_wallet,
   const struct TALER_KYCLOGIC_Measure *measure,
   TALER_KYCLOGIC_HistoryBuilderCallback current_attributes_cb,
   void *current_attributes_cb_cls,
