@@ -22,6 +22,7 @@
 #define TALER_KYCLOGIC_PLUGIN_H
 
 #include <jansson.h>
+#include <microhttpd.h>
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_db_lib.h>
 #include "taler_util.h"
@@ -190,6 +191,7 @@ typedef void
  * @param cls closure
  * @param process_row legitimization process the webhook was about
  * @param account_id account the webhook was about
+ * @param is_wallet true if @a account_id is for a wallet
  * @param provider_name name of the provider that was run
  * @param provider_user_id set to user ID at the provider, or NULL if not supported or unknown
  * @param provider_legitimization_id set to legitimization process ID at the provider, or NULL if not supported or unknown
@@ -204,6 +206,7 @@ typedef void
   void *cls,
   uint64_t process_row,
   const struct TALER_NormalizedPaytoHashP *account_id,
+  bool is_wallet,
   const char *provider_name,
   const char *provider_user_id,
   const char *provider_legitimization_id,
@@ -223,6 +226,7 @@ typedef void
  * @param provider_name
  * @param provider_legitimization_id legi to look up
  * @param[out] h_payto where to write the result
+ * @param[out] is_wallet set to true if @e h_payto is for a wallet
  * @param[out] process_row where to write the row of the entry
  * @return database transaction status
  */
@@ -232,6 +236,7 @@ typedef enum GNUNET_DB_QueryStatus
   const char *provider_name,
   const char *provider_legitimization_id,
   struct TALER_NormalizedPaytoHashP *h_payto,
+  bool *is_wallet,
   uint64_t *process_row);
 
 
