@@ -62,6 +62,43 @@ enum TALER_MHD_GlobalOptions
 };
 
 
+#if MHD_VERSION < 0x00097701
+#define MHD_create_response_from_buffer_static(s, b)            \
+        MHD_create_response_from_buffer (s,                     \
+                                         (const char *) b,      \
+                                         MHD_RESPMEM_PERSISTENT)
+#endif
+
+
+/**
+ * Find out if an MHD connection is using HTTPS (either
+ * directly or via proxy).
+ *
+ * @param connection MHD connection
+ * @returns #GNUNET_YES if the MHD connection is using https,
+ *          #GNUNET_NO if the MHD connection is using http,
+ *          #GNUNET_SYSERR if the connection type couldn't be determined
+ */
+enum GNUNET_GenericReturnValue
+TALER_mhd_is_https (struct MHD_Connection *connection);
+
+
+/**
+ * Convert query argument to @a yna value.
+ *
+ * @param connection connection to take query argument from
+ * @param arg argument to try for
+ * @param default_val value to assign if the argument is not present
+ * @param[out] yna value to set
+ * @return true on success, false if the parameter was malformed
+ */
+bool
+TALER_MHD_arg_to_yna (struct MHD_Connection *connection,
+                      const char *arg,
+                      enum TALER_EXCHANGE_YesNoAll default_val,
+                      enum TALER_EXCHANGE_YesNoAll *yna);
+
+
 /**
  * Set global options for response generation within libtalermhd.
  *
@@ -132,23 +169,6 @@ TALER_MHD_reply_json_steal (struct MHD_Connection *connection,
                             unsigned int response_code);
 
 
-/**
- * Function to call to handle the request by building a JSON
- * reply from a format string and varargs.
- *
- * @param connection the MHD connection to handle
- * @param response_code HTTP response code to use
- * @param fmt format string for pack
- * @param ... varargs
- * @return MHD result code
- */
-MHD_RESULT
-TALER_MHD_reply_json_pack (struct MHD_Connection *connection,
-                           unsigned int response_code,
-                           const char *fmt,
-                           ...);
-
-
 /**
  * Function to call to handle the request by building a JSON
  * reply from varargs.
@@ -226,18 +246,6 @@ struct MHD_Response *
 TALER_MHD_make_json_steal (json_t *json);
 
 
-/**
- * Make JSON response object.
- *
- * @param fmt format string for pack
- * @param ... varargs
- * @return MHD response object
- */
-struct MHD_Response *
-TALER_MHD_make_json_pack (const char *fmt,
-                          ...);
-
-
 /**
  * Make JSON response object.
  *
@@ -517,10 +525,10 @@ TALER_MHD_parse_request_arg_timestamp (struct MHD_Connection *connection,
  */
 #define TALER_MHD_parse_request_yna(connection,name,def,ret) \
         do {                                        \
-          if (! (TALER_arg_to_yna (connection,      \
-                                   name,            \
-                                   def,             \
-                                   ret)) )          \
+          if (! (TALER_MHD_arg_to_yna (connection,      \
+                                       name,            \
+                                       def,             \
+                                       ret)) )          \
           {                                         \
             GNUNET_break_op (0);                    \
             return TALER_MHD_reply_with_error (     \
