@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2014-2022 Taler Systems SA
+  Copyright (C) 2014-2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU General Public License as published by the Free Software
@@ -33,7 +33,7 @@
 /**
  * API version. Bump on every change.
  */
-#define TALER_PQ_VERSION 0x09040000
+#define TALER_PQ_VERSION 0x0a040000
 
 /**
  * Generate query parameter (as record tuple) for an amount, consisting
@@ -117,14 +117,14 @@ TALER_PQ_query_param_blinded_denom_sig (
 
 /**
  * Generate query parameter for the exchange's contribution during a
- * withdraw. Internally, the various attributes of the @a alg_values will be
+ * withdraw. Internally, the various attributes of the @a blinding_values will be
  * serialized into on variable-size BLOB.
  *
- * @param alg_values pointer to the query parameter to pass
+ * @param blinding_values pointer to the query parameter to pass
  */
 struct GNUNET_PQ_QueryParam
-TALER_PQ_query_param_exchange_withdraw_values (
-  const struct TALER_ExchangeWithdrawValues *alg_values);
+TALER_PQ_query_param_exchange_blinding_values (
+  const struct TALER_ExchangeBlindingValues *blinding_values);
 
 
 /**
@@ -225,6 +225,19 @@ TALER_PQ_query_param_array_amount_with_currency (
   const struct TALER_Amount *amounts,
   struct GNUNET_PQ_Context *db);
 
+/**
+ * Generate query parameter for an array of public Clause-Schnorr R-values
+ *
+ * @param num of elements in @e cs_r_pubs
+ * @param cs_r_pubs continuous array of public R-values pairs
+ * @param db context fo db-connection, needed for OID-lookup
+ */
+struct GNUNET_PQ_QueryParam
+TALER_PQ_query_param_array_cs_r_pub (
+  size_t num,
+  const struct GNUNET_CRYPTO_CSPublicRPairP *cs_r_pubs,
+  struct GNUNET_PQ_Context *db);
+
 
 /**
  * Generate query parameter for a blind sign public key of variable size.
@@ -246,6 +259,9 @@ TALER_PQ_query_param_blind_sign_priv (
   const struct GNUNET_CRYPTO_BlindSignPrivateKey *private_key);
 
 
+/* ================  Result handler ==============================*/
+
+
 /**
  * Currency amount expected, from a record-field of (DB)
  * taler_amount_with_currency type. The currency must be stored in the
@@ -324,7 +340,7 @@ TALER_PQ_result_spec_blinded_denom_sig (
 struct GNUNET_PQ_ResultSpec
 TALER_PQ_result_spec_exchange_withdraw_values (
   const char *name,
-  struct TALER_ExchangeWithdrawValues *ewv);
+  struct TALER_ExchangeBlindingValues *ewv);
 
 
 /**
@@ -438,6 +454,22 @@ TALER_PQ_result_spec_array_amount (
   struct TALER_Amount **amounts);
 
 
+/**
+ * Array of public R-values for Clause-Schnorr
+ *
+ * @param db context of the database connection
+ * @param name name of the field in the table
+ * @param[out] num number of elements in @e cs_r_pubs
+ * @param[out] cs_r_pubs where to store the result
+ * @return array entry for the result specification to use
+ */
+struct GNUNET_PQ_ResultSpec
+TALER_PQ_result_spec_array_cs_r_pub (
+  struct GNUNET_PQ_Context *db,
+  const char *name,
+  size_t *num,
+  struct GNUNET_CRYPTO_CSPublicRPairP **cs_r_pubs);
+
 #endif  /* TALER_PQ_LIB_H_ */
 
 /* end of include/taler_pq_lib.h */
