@@ -409,6 +409,12 @@
 #define TALER_SIGNATURE_WALLET_TOKEN_USE 1222
 
 
+/**
+ * Signature over messages to delete in the mailbox service
+ */
+#define TALER_SIGNATURE_MAILBOX_MESSAGES_DELETE 1223
+
+
 /**
  * Signature on a denomination key announcement.
  */
