@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  (C) 2018-2024 Taler Systems SA
+  (C) 2018-2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as
@@ -24,6 +24,7 @@
  *        This library calls abort() if it runs out of memory. Be aware of these limitations.
  * @author Christian Grothoff <christian@grothoff.org>
  * @author Marcello Stanisci
+ * @author Özgür Kesim
  */
 #ifndef TALER_TESTING_LIB_H
 #define TALER_TESTING_LIB_H
@@ -34,6 +35,10 @@
 #include "taler_json_lib.h"
 #include "taler_auditor_service.h"
 #include "taler_bank_service.h"
+/**
+ * To get access to testing relevant API's
+ */
+#define TALER_TESTING_EXPORTS_DANGEROUS 1
 #include "taler_exchange_service.h"
 #include "taler_fakebank_lib.h"
 
@@ -320,10 +325,10 @@ struct TALER_TESTING_Command
    * @return #GNUNET_OK on success
    */
   enum GNUNET_GenericReturnValue
-    (*traits)(void *cls,
-              const void **ret,
-              const char *trait,
-              unsigned int index);
+  (*traits)(void *cls,
+            const void **ret,
+            const char *trait,
+            unsigned int index);
 
   /**
    * When did the execution of this command start?
@@ -1114,17 +1119,15 @@ TALER_TESTING_cmd_withdraw_amount (
 
 
 /**
- * Create a batch withdraw command, letting the caller specify the type of
- * conflict between the coins and the desired amounts as string.
- *
+ * Create a batch withdraw command, letting the caller specify
+ * the desired amounts as string.  Takes a variable, non-empty
+ * list of the denomination amounts via VARARGS.
  * Takes a variable, non-empty list of the denomination amounts via VARARGS,
  * similar to #TALER_TESTING_cmd_withdraw_amount(), just using a batch
  * withdraw.
  *
  * @param label command label.
  * @param reserve_reference command providing us with a reserve to withdraw from
- * @param conflict if true, enforce a conflict (same priv key, different denom and age commiment)
- * @param age if > 0, age restriction applies (same for all coins)
  * @param expected_response_code which HTTP response code
  *        we expect from the exchange.
  * @param amount how much we withdraw for the first coin
@@ -1132,48 +1135,16 @@ TALER_TESTING_cmd_withdraw_amount (
  * @return the withdraw command to be executed by the interpreter.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_batch_withdraw_with_conflict (
+TALER_TESTING_cmd_batch_withdraw (
   const char *label,
   const char *reserve_reference,
-  bool conflict,
-  uint8_t age,
   unsigned int expected_response_code,
   const char *amount,
   ...);
 
-/**
- * Create a batch withdraw command, letting the caller specify
- * the desired amounts as string.  Takes a variable, non-empty
- * list of the denomination amounts via VARARGS, similar to
- * #TALER_TESTING_cmd_withdraw_amount(), just using a batch withdraw.
- * The coins are generated without a conflict (different private keys).
- *
- * @param label command label.
- * @param reserve_reference command providing us with a reserve to withdraw from
- * @param age if > 0, age restriction applies (same for all coins)
- * @param expected_response_code which HTTP response code
- *        we expect from the exchange.
- * @param amount how much we withdraw for the first coin
- * @param ... NULL-terminated list of additional amounts to withdraw (one per coin)
- * @return the withdraw command to be executed by the interpreter.
- */
-#define TALER_TESTING_cmd_batch_withdraw(label, \
-                                         reserve_reference, \
-                                         age, \
-                                         expected_response_code, \
-                                         amount, \
-                                         ...) \
-        TALER_TESTING_cmd_batch_withdraw_with_conflict ( \
-          (label), \
-          (reserve_reference), \
-          false, \
-          (age), \
-          (expected_response_code), \
-          (amount), \
-          __VA_ARGS__)
 
 /**
- * Create an age-withdraw command, letting the caller specify
+ * Create an withdraw command with age proof, letting the caller specify
  * the maximum agend and desired amounts as string.  Takes a variable,
  * non-empty list of the denomination amounts via VARARGS, similar to
  * #TALER_TESTING_cmd_withdraw_amount(), just using a batch withdraw.
@@ -1188,7 +1159,7 @@ TALER_TESTING_cmd_batch_withdraw_with_conflict (
  * @return the withdraw command to be executed by the interpreter.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_age_withdraw (
+TALER_TESTING_cmd_withdraw_with_age_proof (
   const char *label,
   const char *reserve_reference,
   uint8_t max_age,
@@ -1196,8 +1167,9 @@ TALER_TESTING_cmd_age_withdraw (
   const char *amount,
   ...);
 
+
 /**
- * Create a "age-withdraw reveal" command.
+ * Create a "withdraw-reveal" command, in case of a withdraw with age proof.
  *
  * @param label command label.
  * @param age_withdraw_reference reference to a "age-withdraw" command.
@@ -1205,7 +1177,7 @@ TALER_TESTING_cmd_age_withdraw (
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_age_withdraw_reveal (
+TALER_TESTING_cmd_withdraw_reveal_age_proof (
   const char *label,
   const char *age_withdraw_reference,
   unsigned int expected_response_code);
@@ -1216,6 +1188,9 @@ TALER_TESTING_cmd_age_withdraw_reveal (
  * coin private key in the process (violating the specification,
  * which will result in an error when spending the coin!).
  *
+ * Note that in case of CS denominations, the blinding seed
+ * will still differ!
+ *
  * @param label command label.
  * @param reserve_reference command providing us with a reserve to withdraw from
  * @param amount how much we withdraw.
@@ -1236,6 +1211,33 @@ TALER_TESTING_cmd_withdraw_amount_reuse_key (
   unsigned int expected_response_code);
 
 
+/**
+ * Create a withdraw command, letting the caller specify
+ * the desired amount as string and also reusing an existing
+ * coin private key _and_ blinding seed in the process
+ * (violating the specification, which will result in an error
+ * when spending the coin!).
+ *
+ * @param label command label.
+ * @param reserve_reference command providing us with a reserve to withdraw from
+ * @param amount how much we withdraw.
+ * @param age if > 0, age restriction applies.
+ * @param coin_ref reference to (withdraw/reveal) command of a coin
+ *        from which we should reuse the private key
+ * @param expected_response_code which HTTP response code
+ *        we expect from the exchange.
+ * @return the withdraw command to be executed by the interpreter.
+ */
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_withdraw_amount_reuse_all_secrets (
+  const char *label,
+  const char *reserve_reference,
+  const char *amount,
+  uint8_t age,
+  const char *coin_ref,
+  unsigned int expected_response_code);
+
+
 /**
  * Create withdraw command, letting the caller specify the
  * amount by a denomination key.
@@ -1597,9 +1599,9 @@ TALER_TESTING_cmd_melt_with_retry (struct TALER_TESTING_Command cmd);
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_refresh_reveal (const char *label,
-                                  const char *melt_reference,
-                                  unsigned int expected_response_code);
+TALER_TESTING_cmd_melt_reveal (const char *label,
+                               const char *melt_reference,
+                               unsigned int expected_response_code);
 
 
 /**
@@ -1609,31 +1611,7 @@ TALER_TESTING_cmd_refresh_reveal (const char *label,
  * @return modified command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_refresh_reveal_with_retry (struct TALER_TESTING_Command cmd);
-
-
-/**
- * Create a "refresh link" command.
- *
- * @param label command label.
- * @param reveal_reference reference to a "refresh reveal" CMD.
- * @param expected_response_code expected HTTP response code
- * @return the "refresh link" command
- */
-struct TALER_TESTING_Command
-TALER_TESTING_cmd_refresh_link (const char *label,
-                                const char *reveal_reference,
-                                unsigned int expected_response_code);
-
-
-/**
- * Modify a "refresh link" command to enable retries.
- *
- * @param cmd command
- * @return modified command.
- */
-struct TALER_TESTING_Command
-TALER_TESTING_cmd_refresh_link_with_retry (struct TALER_TESTING_Command cmd);
+TALER_TESTING_cmd_melt_reveal_with_retry (struct TALER_TESTING_Command cmd);
 
 
 /**
@@ -2693,7 +2671,7 @@ TALER_TESTING_get_trait (const struct TALER_TESTING_Trait *traits,
         enum GNUNET_GenericReturnValue                          \
         TALER_TESTING_get_trait_ ## name (                    \
           const struct TALER_TESTING_Command *cmd,              \
-          type **ret);                                          \
+          type * *ret);                                          \
         struct TALER_TESTING_Trait                              \
         TALER_TESTING_make_trait_ ## name (                   \
           type * value);
@@ -2736,11 +2714,11 @@ TALER_TESTING_get_trait (const struct TALER_TESTING_Trait *traits,
         TALER_TESTING_get_trait_ ## name (                    \
           const struct TALER_TESTING_Command *cmd,              \
           unsigned int index,                                   \
-          type **ret);                                          \
+          type * *ret);                                          \
         struct TALER_TESTING_Trait                              \
         TALER_TESTING_make_trait_ ## name (                   \
           unsigned int index,                                   \
-          type *value);
+          type * value);
 
 
 /**
@@ -2801,6 +2779,10 @@ TALER_TESTING_get_trait (const struct TALER_TESTING_Trait *traits,
         op (account_priv, const union TALER_AccountPrivateKeyP)          \
         op (account_pub, const union TALER_AccountPublicKeyP)            \
         op (planchet_secret, const struct TALER_PlanchetMasterSecretP)   \
+        op (withdraw_seed, const struct TALER_WithdrawMasterSeedP)       \
+        op (blinding_seed, const struct TALER_BlindingMasterSeedP)       \
+        op (withdraw_commitment, const struct TALER_HashBlindedPlanchetsP)       \
+        op (kappa_seed, const struct TALER_KappaWithdrawMasterSeedP)     \
         op (refresh_secret, const struct TALER_RefreshMasterSecretP)     \
         op (reserve_pub, const struct TALER_ReservePublicKeyP)           \
         op (merchant_priv, const struct TALER_MerchantPrivateKeyP)       \
@@ -2839,7 +2821,7 @@ TALER_TESTING_get_trait (const struct TALER_TESTING_Trait *traits,
 /**
  * Call #op on all indexed traits.
  */
-#define TALER_TESTING_INDEXED_TRAITS(op)                                \
+#define TALER_TESTING_INDEXED_TRAITS(op)                                      \
         op (denom_pub, const struct TALER_EXCHANGE_DenomPublicKey)            \
         op (denom_sig, const struct TALER_DenominationSignature)              \
         op (amounts, const struct TALER_Amount)                               \
@@ -2849,10 +2831,10 @@ TALER_TESTING_get_trait (const struct TALER_TESTING_Trait *traits,
         op (age_commitment, const struct TALER_AgeCommitment)                 \
         op (age_commitment_proof, const struct TALER_AgeCommitmentProof)      \
         op (h_age_commitment, const struct TALER_AgeCommitmentHash)           \
-        op (reserve_history, const struct TALER_EXCHANGE_ReserveHistoryEntry) \
-        op (coin_history, const struct TALER_EXCHANGE_CoinHistoryEntry) \
+        op (coin_history, const struct TALER_EXCHANGE_CoinHistoryEntry)       \
         op (planchet_secrets, const struct TALER_PlanchetMasterSecretP)       \
-        op (exchange_wd_value, const struct TALER_ExchangeWithdrawValues)     \
+        op (kappa_seeds, const struct TALER_KappaWithdrawMasterSeedP)         \
+        op (exchange_blinding_values, const struct TALER_ExchangeBlindingValues)     \
         op (coin_priv, const struct TALER_CoinSpendPrivateKeyP)               \
         op (coin_pub, const struct TALER_CoinSpendPublicKeyP)                 \
         op (coin_sig, const struct TALER_CoinSpendSignatureP)                 \
@@ -2862,7 +2844,8 @@ TALER_TESTING_get_trait (const struct TALER_TESTING_Trait *traits,
         op (refund_deadline, const struct GNUNET_TIME_Timestamp)              \
         op (exchange_pub, const struct TALER_ExchangePublicKeyP)              \
         op (exchange_sig, const struct TALER_ExchangeSignatureP)              \
-        op (blinding_key, const union GNUNET_CRYPTO_BlindingSecretP)         \
+        op (reserve_history, const struct TALER_EXCHANGE_ReserveHistoryEntry) \
+        op (blinding_key, const union GNUNET_CRYPTO_BlindingSecretP)          \
         op (h_blinded_coin, const struct TALER_BlindedCoinHashP)
 
 TALER_TESTING_SIMPLE_TRAITS (TALER_TESTING_MAKE_DECL_SIMPLE_TRAIT)
