@@ -28,16 +28,9 @@
 #define __TALER_UTIL_LIB_H_INSIDE__
 
 #include <gnunet/gnunet_util_lib.h>
-#include <microhttpd.h>
 #include "taler_amount_lib.h"
 #include "taler_crypto_lib.h"
 
-#if MHD_VERSION < 0x00097701
-#define MHD_create_response_from_buffer_static(s, b)            \
-        MHD_create_response_from_buffer (s,                     \
-                                         (const char *) b,      \
-                                         MHD_RESPMEM_PERSISTENT)
-#endif
 
 /**
  * Version of the Taler API, in hex.
@@ -425,6 +418,16 @@ TALER_normalized_payto_cmp (const struct TALER_NormalizedPayto a,
                             const struct TALER_NormalizedPayto b);
 
 
+/**
+ * Check if payto URI identifies a Taler wallet.
+ *
+ * @param payto_uri (full or normalized) to check
+ * @return true if the payto URI is for a wallet
+ */
+bool
+TALER_payto_is_wallet (const char *payto_uri);
+
+
 /**
  * Test if the URL is a valid "http" (or "https")
  * URL (includes test for #TALER_url_valid_charset()).
@@ -452,19 +455,6 @@ TALER_pattern_matches (const char *pattern,
                        const char *value);
 
 
-/**
- * Find out if an MHD connection is using HTTPS (either
- * directly or via proxy).
- *
- * @param connection MHD connection
- * @returns #GNUNET_YES if the MHD connection is using https,
- *          #GNUNET_NO if the MHD connection is using http,
- *          #GNUNET_SYSERR if the connection type couldn't be determined
- */
-enum GNUNET_GenericReturnValue
-TALER_mhd_is_https (struct MHD_Connection *connection);
-
-
 /**
  * Make an absolute URL with query parameters.
  *
@@ -531,21 +521,6 @@ TALER_url_absolute_raw_va (const char *proto,
                            va_list args);
 
 
-/**
- * Make an absolute URL for a given MHD connection.
- *
- * @param connection the connection to get the URL for
- * @param path path of the url
- * @param ... NULL-terminated key-value pairs (char *) for query parameters,
- *        the value will be url-encoded
- * @returns the URL, must be freed with #GNUNET_free
- */
-char *
-TALER_url_absolute_mhd (struct MHD_Connection *connection,
-                        const char *path,
-                        ...);
-
-
 /**
  * Obtain the payment method from a @a payto_uri
  *
@@ -723,6 +698,87 @@ enum TALER_EXCHANGE_KycLongPollTarget
 };
 
 
+/**
+ * Enumeration of possible events that may trigger
+ * KYC requirements.
+ */
+enum TALER_KYCLOGIC_KycTriggerEvent
+{
+
+  /**
+   * Reserved value for invalid event types.
+   */
+  TALER_KYCLOGIC_KYC_TRIGGER_NONE = 0,
+
+  /**
+   * Customer withdraws coins.
+   */
+  TALER_KYCLOGIC_KYC_TRIGGER_WITHDRAW = 1,
+
+  /**
+   * Merchant deposits coins.
+   */
+  TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT = 2,
+
+  /**
+   * Wallet receives P2P payment.
+   */
+  TALER_KYCLOGIC_KYC_TRIGGER_P2P_RECEIVE = 3,
+
+  /**
+   * Wallet balance exceeds threshold. The timeframe is
+   * irrelevant for this limit.
+   */
+  TALER_KYCLOGIC_KYC_TRIGGER_WALLET_BALANCE = 4,
+
+  /**
+   * Reserve is being closed by force.
+   */
+  TALER_KYCLOGIC_KYC_TRIGGER_RESERVE_CLOSE = 5,
+
+  /**
+   * Deposits have been aggregated, we are wiring a
+   * certain amount into a (merchant) bank account.
+   */
+  TALER_KYCLOGIC_KYC_TRIGGER_AGGREGATE = 6,
+
+  /**
+   * Limit per transaction.  The timeframe is
+   * irrelevant for this limit.
+   */
+  TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION = 7,
+
+  /**
+   * Limit per refund.  The timeframe is
+   * irrelevant for this limit.
+   */
+  TALER_KYCLOGIC_KYC_TRIGGER_REFUND = 8
+
+};
+
+
+/**
+ * Types of KYC checks.
+ */
+enum TALER_KYCLOGIC_CheckType
+{
+  /**
+   * Wait for staff or contact staff out-of-band.
+   */
+  TALER_KYCLOGIC_CT_INFO,
+
+  /**
+   * SPA should show an inline form.
+   */
+  TALER_KYCLOGIC_CT_FORM,
+
+  /**
+   * SPA may start external KYC process.
+   */
+  TALER_KYCLOGIC_CT_LINK
+};
+
+
 /**
  * Possible values for a binary filter.
  */
@@ -745,22 +801,6 @@ enum TALER_EXCHANGE_YesNoAll
 };
 
 
-/**
- * Convert query argument to @a yna value.
- *
- * @param connection connection to take query argument from
- * @param arg argument to try for
- * @param default_val value to assign if the argument is not present
- * @param[out] yna value to set
- * @return true on success, false if the parameter was malformed
- */
-bool
-TALER_arg_to_yna (struct MHD_Connection *connection,
-                  const char *arg,
-                  enum TALER_EXCHANGE_YesNoAll default_val,
-                  enum TALER_EXCHANGE_YesNoAll *yna);
-
-
 /**
  * Convert YNA value to a string.
  *
