@@ -54,8 +54,8 @@ TALER_JSON_extract_i18n (const json_t *object,
     json_t *value;
 
     json_object_foreach (i18n, key, value) {
-      double q = TALER_language_matches (language_pattern,
-                                         key);
+      double q = TALER_pattern_matches (language_pattern,
+                                        key);
       if (q > quality)
       {
         quality = q;
