@@ -464,7 +464,7 @@ parse_age_commitment (void *cls,
   }
 
   age_commitment->num = num;
-  age_commitment->keys =
+  age_commitment->pubs =
     GNUNET_new_array (num,
                       struct TALER_AgeCommitmentPublicKeyP);
 
@@ -474,7 +474,7 @@ parse_age_commitment (void *cls,
     struct GNUNET_JSON_Specification pkspec[] = {
       GNUNET_JSON_spec_fixed_auto (
         NULL,
-        &age_commitment->keys[idx].pub),
+        &age_commitment->pubs[idx].pub),
       GNUNET_JSON_spec_end ()
     };
 
@@ -509,11 +509,12 @@ clean_age_commitment (void *cls,
   (void) cls;
 
   if (NULL == age_commitment ||
-      NULL == age_commitment->keys)
+      NULL == age_commitment->pubs)
     return;
 
   age_commitment->num = 0;
-  GNUNET_free (age_commitment->keys);
+  GNUNET_free (age_commitment->pubs);
+  age_commitment->pubs = NULL;
 }
 
 
@@ -947,9 +948,9 @@ TALER_JSON_spec_blinded_denom_sig (
 
 
 struct GNUNET_JSON_Specification
-TALER_JSON_spec_blinded_planchet (const char *field,
-                                  struct TALER_BlindedPlanchet *blinded_planchet
-                                  )
+TALER_JSON_spec_blinded_planchet (
+  const char *field,
+  struct TALER_BlindedPlanchet *blinded_planchet)
 {
   blinded_planchet->blinded_message = NULL;
   return GNUNET_JSON_spec_blinded_message (field,
@@ -966,11 +967,11 @@ TALER_JSON_spec_blinded_planchet (const char *field,
  * @return #GNUNET_OK upon successful parsing; #GNUNET_SYSERR upon error
  */
 static enum GNUNET_GenericReturnValue
-parse_exchange_withdraw_values (void *cls,
+parse_exchange_blinding_values (void *cls,
                                 json_t *root,
                                 struct GNUNET_JSON_Specification *spec)
 {
-  struct TALER_ExchangeWithdrawValues *ewv = spec->ptr;
+  struct TALER_ExchangeBlindingValues *ewv = spec->ptr;
   struct GNUNET_CRYPTO_BlindingInputValues *bi;
   const char *cipher;
   struct GNUNET_JSON_Specification dspec[] = {
@@ -1043,11 +1044,11 @@ parse_exchange_withdraw_values (void *cls,
  * @param[out] spec where to free the data
  */
 static void
-clean_exchange_withdraw_values (
+clean_exchange_blinding_values (
   void *cls,
   struct GNUNET_JSON_Specification *spec)
 {
-  struct TALER_ExchangeWithdrawValues *ewv = spec->ptr;
+  struct TALER_ExchangeBlindingValues *ewv = spec->ptr;
 
   (void) cls;
   TALER_denom_ewv_free (ewv);
@@ -1055,13 +1056,13 @@ clean_exchange_withdraw_values (
 
 
 struct GNUNET_JSON_Specification
-TALER_JSON_spec_exchange_withdraw_values (
+TALER_JSON_spec_exchange_blinding_values (
   const char *field,
-  struct TALER_ExchangeWithdrawValues *ewv)
+  struct TALER_ExchangeBlindingValues *ewv)
 {
   struct GNUNET_JSON_Specification ret = {
-    .parser = &parse_exchange_withdraw_values,
-    .cleaner = &clean_exchange_withdraw_values,
+    .parser = &parse_exchange_blinding_values,
+    .cleaner = &clean_exchange_blinding_values,
     .field = field,
     .ptr = ewv
   };
@@ -1734,4 +1735,375 @@ TALER_JSON_spec_kycte (const char *name,
 }
 
 
+/**
+ * Parser combinator of a tuple of parsers, for parsing
+ * an array of expected size and element types.
+ *
+ * @param cls closure, array of specs, NULL terminated
+ * @param root the json root
+ * @param[out] spec where to write the data
+ */
+static enum GNUNET_GenericReturnValue
+parse_tuple_of (void *cls,
+                json_t *root,
+                struct GNUNET_JSON_Specification *spec)
+{
+  struct GNUNET_JSON_Specification *specs = cls;
+  static size_t max_specs = 100;
+  bool found_end = false;
+
+  enum GNUNET_GenericReturnValue ret;
+
+  if (! json_is_array (root))
+  {
+    return GNUNET_SYSERR;
+  }
+
+  {
+    size_t num;
+    for (num = 0; num< max_specs; num++)
+    {
+      if (NULL == specs[num].parser)
+      {
+        found_end = true;
+        break;
+      }
+    }
+    GNUNET_assert (found_end);
+
+    if (num != json_array_size (root))
+    {
+      GNUNET_break_op (0);
+      return GNUNET_SYSERR;
+    }
+  }
+
+  {
+    json_t *j_entry;
+    size_t idx;
+
+    json_array_foreach (root, idx, j_entry) {
+      ret = GNUNET_JSON_parse (j_entry,
+                               &specs[idx],
+                               NULL,
+                               NULL);
+      if (GNUNET_OK != ret)
+      {
+        GNUNET_break_op (0);
+        return GNUNET_SYSERR;
+      }
+    }
+  }
+
+  return GNUNET_OK;
+}
+
+
+struct GNUNET_JSON_Specification
+TALER_JSON_spec_tuple_of (
+  const char *field,
+  struct GNUNET_JSON_Specification specs[])
+{
+  struct GNUNET_JSON_Specification ret = {
+    .parser = &parse_tuple_of,
+    .field = field,
+    .cls = specs
+  };
+
+  return ret;
+}
+
+
+/**
+ * Parser for an array of unknown length but
+ * of elements of the same type with the same
+ * fixed length.
+ *
+ * @param cls closure, entry_size
+ * @param root the json root
+ * @param spec the output spec
+ */
+static enum GNUNET_GenericReturnValue
+parse_array_fixed (void *cls,
+                   json_t *root,
+                   struct GNUNET_JSON_Specification *spec)
+{
+  enum GNUNET_GenericReturnValue ret;
+  size_t entry_size = (size_t) cls;
+  size_t num_entries;
+
+  GNUNET_assert (0< entry_size);
+  num_entries = spec->ptr_size / entry_size;
+  GNUNET_assert (0 < num_entries);
+
+
+  if (! json_is_array (root))
+  {
+    GNUNET_break_op (0);
+    return GNUNET_SYSERR;
+  }
+  if (num_entries != json_array_size (root))
+  {
+    GNUNET_break_op (0);
+    return GNUNET_SYSERR;
+  }
+
+  {
+    json_t *j_entry;
+    size_t idx;
+    void *ptr = spec->ptr;
+    void *end = spec->ptr + spec->ptr_size;
+
+    json_array_foreach (root, idx, j_entry) {
+      struct GNUNET_JSON_Specification esp[] = {
+        GNUNET_JSON_spec_fixed (NULL,
+                                ptr,
+                                entry_size),
+        GNUNET_JSON_spec_end ()
+      };
+      GNUNET_assert (ptr < end);
+      ret = GNUNET_JSON_parse (j_entry,
+                               esp,
+                               NULL,
+                               NULL);
+      if (GNUNET_OK != ret)
+      {
+        GNUNET_break_op (0);
+        return GNUNET_SYSERR;
+      }
+      ptr+=entry_size;
+    }
+  }
+  return GNUNET_OK;
+}
+
+
+struct GNUNET_JSON_Specification
+TALER_JSON_spec_array_fixed (
+  const char *field,
+  size_t num_entries,
+  void *entries,
+  size_t entry_size)
+{
+  struct GNUNET_JSON_Specification ret = {
+    .parser = &parse_array_fixed,
+    .ptr = entries,
+    .ptr_size = entry_size * num_entries,
+    .field = field,
+    .cls = (void *) entry_size,
+  };
+
+  GNUNET_assert ((num_entries <= 1) ||
+                 (entry_size * num_entries > entry_size));
+  return ret;
+}
+
+
+/**
+ * Closure for the parser of arrays of fixed size data
+ * of unknown array length
+ */
+struct closure_array_of_data
+{
+  /**
+   * Fixed (known) size per entry
+   */
+  size_t entry_size;
+
+  /**
+   * Pointer where to put the number of elements
+   * allocated, i.e. the number of elements in the
+   * json array.
+   */
+  size_t *num_entries;
+};
+
+/**
+ * Parser for an array of data of known element size,
+ * but unknown array length
+ */
+static enum GNUNET_GenericReturnValue
+parse_array_of_data (void *cls,
+                     json_t *root,
+                     struct GNUNET_JSON_Specification *spec)
+{
+  enum GNUNET_GenericReturnValue ret;
+  struct closure_array_of_data *info = cls;
+  size_t num_entries;
+
+  if (! json_is_array (root))
+  {
+    GNUNET_break_op (0);
+    return GNUNET_SYSERR;
+  }
+  num_entries = json_array_size (root);
+  *info->num_entries = num_entries;
+  if (0 == num_entries)
+  {
+    *(char **) spec->ptr = NULL;
+    return GNUNET_OK;
+  }
+
+  spec->ptr_size = num_entries * info->entry_size;
+  GNUNET_assert (spec->ptr_size > num_entries);
+  *((char **) spec->ptr) = GNUNET_malloc (spec->ptr_size);
+
+  {
+    json_t *j_entry;
+    size_t idx;
+    char *ptr = *(char **) spec->ptr;
+    char *end = ptr + spec->ptr_size;
+
+    json_array_foreach (root, idx, j_entry) {
+      struct GNUNET_JSON_Specification esp[] = {
+        GNUNET_JSON_spec_fixed (NULL,
+                                ptr,
+                                info->entry_size),
+        GNUNET_JSON_spec_end ()
+      };
+      GNUNET_assert (ptr < end);
+      ret = GNUNET_JSON_parse (j_entry,
+                               esp,
+                               NULL,
+                               NULL);
+      if (GNUNET_OK != ret)
+      {
+        GNUNET_break_op (0);
+        return GNUNET_SYSERR;
+      }
+      ptr+=info->entry_size;
+    }
+  }
+  return GNUNET_OK;
+}
+
+
+/**
+ * Cleanup data left from parsing an array of fixed size (but unknown length).
+ *
+ * @param cls closure_of_array_data
+ * @param[out] spec where to free the data
+ */
+static void
+cleaner_array_of_data (void *cls,
+                       struct GNUNET_JSON_Specification *spec)
+{
+  struct closure_array_of_data *info = cls;
+
+  GNUNET_free (*(void **) spec->ptr);
+  GNUNET_free (info);
+}
+
+
+struct GNUNET_JSON_Specification
+TALER_JSON_spec_array_of_data (
+  const char *field,
+  size_t entry_size,
+  size_t *num_entries,
+  void **entries)
+{
+  struct closure_array_of_data *cls;
+
+  GNUNET_assert (0< entry_size);
+  GNUNET_assert (NULL != entries);
+  cls = GNUNET_new (struct closure_array_of_data);
+  cls->num_entries = num_entries;
+  cls->entry_size = entry_size;
+  {
+    struct GNUNET_JSON_Specification ret = {
+      .parser = &parse_array_of_data,
+      .ptr = entries,
+      .field = field,
+      .cleaner = &cleaner_array_of_data,
+      .cls = (void *) cls,
+    };
+
+    return ret;
+  }
+}
+
+
+struct GNUNET_JSON_Specification
+TALER_JSON_spec_array_of_denom_pub_h (
+  const char *field,
+  size_t *num_entries,
+  struct TALER_DenominationHashP **entries)
+{
+  return TALER_JSON_spec_array_of_data (
+    field,
+    sizeof (struct TALER_DenominationHashP),
+    num_entries,
+    (void **) entries);
+}
+
+
+/**
+ * Parser for an array of blinded denomination signatures,
+ * of unknown array length
+ */
+static enum GNUNET_GenericReturnValue
+parse_array_of_blinded_denom_sigs (void *cls,
+                                   json_t *root,
+                                   struct GNUNET_JSON_Specification *spec)
+{
+  enum GNUNET_GenericReturnValue ret;
+  struct TALER_BlindedDenominationSignature *sigs = spec->ptr;
+  size_t expected_num_entries = (size_t) cls;
+  size_t num_entries;
+
+  if (! json_is_array (root))
+  {
+    GNUNET_break_op (0);
+    return GNUNET_SYSERR;
+  }
+  num_entries = json_array_size (root);
+  if (num_entries != expected_num_entries)
+  {
+    GNUNET_break_op (0);
+    return GNUNET_SYSERR;
+  }
+
+  {
+    json_t *j_entry;
+    size_t idx;
+    struct TALER_BlindedDenominationSignature *ptr = sigs;
+
+    json_array_foreach (root, idx, j_entry) {
+      struct GNUNET_JSON_Specification esp[] = {
+        TALER_JSON_spec_blinded_denom_sig (NULL,
+                                           ptr),
+        GNUNET_JSON_spec_end ()
+      };
+      ret = GNUNET_JSON_parse (j_entry,
+                               esp,
+                               NULL,
+                               NULL);
+      if (GNUNET_OK != ret)
+      {
+        GNUNET_break_op (0);
+        return GNUNET_SYSERR;
+      }
+      ptr++;
+    }
+  }
+  return GNUNET_OK;
+}
+
+
+struct GNUNET_JSON_Specification
+TALER_JSON_spec_array_of_blinded_denom_sigs (
+  const char *field,
+  size_t num_entries,
+  struct TALER_BlindedDenominationSignature *entries)
+{
+  struct GNUNET_JSON_Specification ret = {
+    .parser = &parse_array_of_blinded_denom_sigs,
+    .ptr = entries,
+    .field = field,
+    .cls = (void *) num_entries,
+  };
+  return ret;
+}
+
+
 /* end of json/json_helper.c */
