@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2021, 2022 Taler Systems SA
+  Copyright (C) 2021-2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU General Public License as published by the Free Software
@@ -17,6 +17,7 @@
  * @file json/json_pack.c
  * @brief helper functions for JSON object packing
  * @author Christian Grothoff
+ * @author Özgür Kesim
  */
 #include "platform.h"
 #include <gnunet/gnunet_util_lib.h>
@@ -84,8 +85,8 @@ TALER_JSON_pack_age_commitment (
        i++)
   {
     json_t *val;
-    val = GNUNET_JSON_from_data (&age_commitment->keys[i],
-                                 sizeof(age_commitment->keys[i]));
+    val = GNUNET_JSON_from_data (&age_commitment->pubs[i],
+                                 sizeof(age_commitment->pubs[i]));
     GNUNET_assert (NULL != val);
     GNUNET_assert (0 ==
                    json_array_append_new (keys, val));
@@ -268,9 +269,9 @@ TALER_JSON_pack_token_envelope (
 
 
 struct GNUNET_JSON_PackSpec
-TALER_JSON_pack_exchange_withdraw_values (
+TALER_JSON_pack_exchange_blinding_values (
   const char *name,
-  const struct TALER_ExchangeWithdrawValues *ewv)
+  const struct TALER_ExchangeBlindingValues *ewv)
 {
   const struct GNUNET_CRYPTO_BlindingInputValues *biv;
   struct GNUNET_JSON_PackSpec ps = {
@@ -309,6 +310,66 @@ TALER_JSON_pack_exchange_withdraw_values (
 }
 
 
+struct GNUNET_JSON_PackSpec
+TALER_JSON_pack_blinding_prepare_response (
+  const char *name,
+  const struct TALER_BlindingPrepareResponse *bpr)
+{
+  struct GNUNET_JSON_PackSpec ps = {
+    .field_name = name,
+  };
+  if (NULL == bpr)
+    return ps;
+  switch (bpr->cipher)
+  {
+  case GNUNET_CRYPTO_BSA_INVALID:
+    break;
+  case GNUNET_CRYPTO_BSA_RSA:
+    ps.object = GNUNET_JSON_PACK (
+      GNUNET_JSON_pack_string ("cipher",
+                               "RSA"));
+    return ps;
+  case GNUNET_CRYPTO_BSA_CS: {
+      json_t *j_rpubs = json_array ();
+
+      GNUNET_assert (NULL!=j_rpubs);
+
+      for (size_t i = 0; i < bpr->num; i++)
+      {
+        struct GNUNET_CRYPTO_CSPublicRPairP *pair =
+          &bpr->details.cs[i];
+        json_t *j_pubs[2];
+        json_t *j_pair;
+
+        j_pair =  json_array ();
+        GNUNET_assert (NULL != j_pair);
+
+        j_pubs[0] = GNUNET_JSON_from_data (
+          &pair->r_pub[0],
+          sizeof(pair->r_pub[0]));
+        GNUNET_assert (NULL != j_pubs[0]);
+
+        j_pubs[1] = GNUNET_JSON_from_data (
+          &pair->r_pub[1],
+          sizeof(pair->r_pub[1]));
+        GNUNET_assert (NULL != j_pubs[1]);
+
+        GNUNET_assert (0 == json_array_append_new (j_pair, j_pubs[0]));
+        GNUNET_assert (0 == json_array_append_new (j_pair, j_pubs[1]));
+        GNUNET_assert (0 == json_array_append_new (j_rpubs, j_pair));
+      }
+
+      ps.object = GNUNET_JSON_PACK (
+        GNUNET_JSON_pack_string ("cipher", "CS"),
+        GNUNET_JSON_pack_array_steal ("r_pubs", j_rpubs));
+      return ps;
+    }
+  }
+  GNUNET_assert (0);
+  return ps;
+}
+
+
 struct GNUNET_JSON_PackSpec
 TALER_JSON_pack_blinded_denom_sig (
   const char *name,
@@ -399,4 +460,75 @@ TALER_JSON_pack_normalized_payto (
 }
 
 
+struct GNUNET_JSON_PackSpec
+TALER_JSON_pack_tuple (
+  const char *name,
+  const struct GNUNET_JSON_PackSpec packers[])
+{
+  static size_t max_packers = 256;
+  struct GNUNET_JSON_PackSpec ps = {
+    .field_name = name,
+  };
+  size_t idx;
+  json_t *j_array = json_array ();
+
+  GNUNET_assert (NULL!=j_array);
+
+  for (idx = 0; idx < max_packers; idx++)
+  {
+    if (NULL == packers[idx].object)
+      break;
+
+    GNUNET_assert (0 ==
+                   json_array_append_new (j_array,
+                                          packers[idx].object));
+  }
+
+  GNUNET_assert (idx != max_packers);
+
+  ps.object = j_array;
+  return ps;
+
+}
+
+
+struct GNUNET_JSON_PackSpec
+TALER_JSON_pack_array_of_data (
+  const char *name,
+  size_t num,
+  const void *data,
+  size_t size)
+{
+  const char *blob = data;
+  struct GNUNET_JSON_PackSpec ps = {
+    .field_name = name,
+  };
+  json_t *j_array = json_array ();
+
+  GNUNET_assert (NULL!=j_array);
+  if (0 == num)
+  {
+    ps.object = j_array;
+    return ps;
+  }
+  GNUNET_assert ((0 == size) ||
+                 (num == 1) ||
+                 (num * size > size));
+
+  for (size_t idx = 0; idx < num; idx++)
+  {
+    GNUNET_assert (0 ==
+                   json_array_append_new (
+                     j_array,
+                     GNUNET_JSON_from_data (
+                       blob,
+                       size)));
+    blob += size;
+  }
+
+  ps.object = j_array;
+  return ps;
+}
+
+
 /* End of json/json_pack.c */
