@@ -288,6 +288,11 @@ struct TALER_KYCLOGIC_WebhookHandle
    * HTTP response code to return asynchronously.
    */
   unsigned int response_code;
+
+  /**
+   * True if @e h_payto is for a wallet.
+   */
+  bool is_wallet;
 };
 
 
@@ -857,6 +862,7 @@ webhook_conversion_cb (void *cls,
     wh->cb (wh->cb_cls,
             wh->process_row,
             &wh->h_payto,
+            wh->is_wallet,
             wh->pd->section,
             wh->applicant_id,
             wh->verification_id,
@@ -885,6 +891,7 @@ webhook_conversion_cb (void *cls,
     wh->cb (wh->cb_cls,
             wh->process_row,
             &wh->h_payto,
+            wh->is_wallet,
             wh->pd->section,
             wh->applicant_id,
             wh->verification_id,
@@ -902,6 +909,7 @@ webhook_conversion_cb (void *cls,
   wh->cb (wh->cb_cls,
           wh->process_row,
           &wh->h_payto,
+          wh->is_wallet,
           wh->pd->section,
           wh->applicant_id,
           wh->verification_id,
@@ -961,6 +969,7 @@ handle_webhook_finished (void *cls,
         wh->cb (wh->cb_cls,
                 wh->process_row,
                 &wh->h_payto,
+                wh->is_wallet,
                 wh->pd->section,
                 wh->applicant_id,
                 wh->verification_id,
@@ -998,6 +1007,7 @@ handle_webhook_finished (void *cls,
         wh->cb (wh->cb_cls,
                 wh->process_row,
                 &wh->h_payto,
+                wh->is_wallet,
                 wh->pd->section,
                 wh->applicant_id,
                 wh->verification_id,
@@ -1026,6 +1036,7 @@ handle_webhook_finished (void *cls,
     wh->cb (wh->cb_cls,
             wh->process_row,
             &wh->h_payto,
+            wh->is_wallet,
             wh->pd->section,
             wh->applicant_id,
             wh->verification_id,
@@ -1048,6 +1059,7 @@ handle_webhook_finished (void *cls,
     wh->cb (wh->cb_cls,
             wh->process_row,
             &wh->h_payto,
+            wh->is_wallet,
             wh->pd->section,
             wh->applicant_id,
             wh->verification_id,
@@ -1066,6 +1078,7 @@ handle_webhook_finished (void *cls,
     wh->cb (wh->cb_cls,
             wh->process_row,
             &wh->h_payto,
+            wh->is_wallet,
             wh->pd->section,
             wh->applicant_id,
             wh->verification_id,
@@ -1090,6 +1103,7 @@ handle_webhook_finished (void *cls,
     wh->cb (wh->cb_cls,
             wh->process_row,
             &wh->h_payto,
+            wh->is_wallet,
             wh->pd->section,
             wh->applicant_id,
             wh->verification_id,
@@ -1108,6 +1122,7 @@ handle_webhook_finished (void *cls,
     wh->cb (wh->cb_cls,
             wh->process_row,
             &wh->h_payto,
+            wh->is_wallet,
             wh->pd->section,
             wh->applicant_id,
             wh->verification_id,
@@ -1126,6 +1141,7 @@ handle_webhook_finished (void *cls,
     wh->cb (wh->cb_cls,
             wh->process_row,
             &wh->h_payto,
+            wh->is_wallet,
             wh->pd->section,
             wh->applicant_id,
             wh->verification_id,
@@ -1150,6 +1166,7 @@ handle_webhook_finished (void *cls,
     wh->cb (wh->cb_cls,
             wh->process_row,
             &wh->h_payto,
+            wh->is_wallet,
             wh->pd->section,
             wh->applicant_id,
             wh->verification_id,
@@ -1180,6 +1197,7 @@ async_webhook_reply (void *cls)
           (0 == wh->process_row)
           ? NULL
           : &wh->h_payto,
+          wh->is_wallet,
           wh->pd->section,
           wh->applicant_id, /* provider user ID */
           wh->verification_id, /* provider legi ID */
@@ -1314,6 +1332,7 @@ kycaid_webhook (void *cls,
             pd->section,
             verification_id,
             &wh->h_payto,
+            &wh->is_wallet,
             &wh->process_row);
   if (qs < 0)
   {
