@@ -27,6 +27,11 @@
 #include <regex.h>
 #include "taler_util.h"
 
+/**
+ * Set to 1 to get extra-verbose, possibly privacy-sensitive
+ * data in the logs.
+ */
+#define DEBUG 0
 
 /**
  * Saves the state of a plugin.
@@ -176,7 +181,7 @@ struct TALER_KYCLOGIC_InitiateHandle
   void *cb_cls;
 
   /**
-   * Initial address to pass to the KYC provider on /setup.
+   * Initial address to pass to the KYC provider on ``/setup``.
    */
   json_t *initial_address;
 
@@ -729,8 +734,6 @@ initiate_task (void *cls)
   struct TALER_KYCLOGIC_InitiateHandle *ih = cls;
   const struct TALER_KYCLOGIC_ProviderDetails *pd = ih->pd;
   struct PluginState *ps = pd->ps;
-  char *hdr;
-  struct curl_slist *slist;
   CURL *eh;
 
   ih->task = NULL;
@@ -757,19 +760,40 @@ initiate_task (void *cls)
                  curl_easy_setopt (eh,
                                    CURLOPT_URL,
                                    pd->setup_url));
+#if DEBUG
   GNUNET_assert (CURLE_OK ==
                  curl_easy_setopt (eh,
-                                   CURLOPT_POST,
+                                   CURLOPT_VERBOSE,
                                    1));
+#endif
   if (NULL == ih->initial_address)
   {
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Staring OAuth 2.0 without initial address\n");
+    GNUNET_assert (CURLE_OK ==
+                   curl_easy_setopt (eh,
+                                     CURLOPT_POST,
+                                     1));
     GNUNET_assert (CURLE_OK ==
                    curl_easy_setopt (eh,
                                      CURLOPT_POSTFIELDS,
                                      ""));
+    GNUNET_assert (CURLE_OK ==
+                   curl_easy_setopt (eh,
+                                     CURLOPT_POSTFIELDSIZE,
+                                     (long) 0));
   }
   else
   {
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Staring OAuth 2.0 with initial address\n");
+#if DEBUG
+    json_dumpf (ih->initial_address,
+                stderr,
+                JSON_INDENT (2));
+    fprintf (stderr,
+             "\n");
+#endif
     if (GNUNET_OK !=
         TALER_curl_easy_post (&ih->ctx,
                               eh,
@@ -794,19 +818,26 @@ initiate_task (void *cls)
                  curl_easy_setopt (eh,
                                    CURLOPT_MAXREDIRS,
                                    5L));
-  GNUNET_asprintf (&hdr,
-                   "%s: Bearer %s",
-                   MHD_HTTP_HEADER_AUTHORIZATION,
-                   pd->client_secret);
-  slist = curl_slist_append (NULL,
-                             hdr);
   ih->job = GNUNET_CURL_job_add2 (ps->curl_ctx,
                                   eh,
-                                  slist,
+                                  ih->ctx.headers,
                                   &handle_curl_setup_finished,
                                   ih);
-  curl_slist_free_all (slist);
-  GNUNET_free (hdr);
+  {
+    char *hdr;
+    struct curl_slist *slist;
+
+    GNUNET_asprintf (&hdr,
+                     "%s: Bearer %s",
+                     MHD_HTTP_HEADER_AUTHORIZATION,
+                     pd->client_secret);
+    slist = curl_slist_append (NULL,
+                               hdr);
+    GNUNET_CURL_extend_headers (ih->job,
+                                slist);
+    curl_slist_free_all (slist);
+    GNUNET_free (hdr);
+  }
 }
 
 
@@ -843,8 +874,19 @@ oauth2_initiate (void *cls,
   ih->task = GNUNET_SCHEDULER_add_now (&initiate_task,
                                        ih);
   if (NULL != context)
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Initiating OAuth2 validation with context\n");
+#if DEBUG
+    json_dumpf (context,
+                stderr,
+                JSON_INDENT (2));
+    fprintf (stderr,
+             "\n");
+#endif
     ih->initial_address = json_incref (json_object_get (context,
                                                         "initial_address"));
+  }
   return ih;
 }
 
@@ -895,11 +937,27 @@ static void
 return_proof_response (void *cls)
 {
   struct TALER_KYCLOGIC_ProofHandle *ph = cls;
+  const char *provider_name;
 
   ph->task = NULL;
+  provider_name = ph->pd->section;
+  if (0 !=
+      strncasecmp (provider_name,
+                   "KYC-PROVIDER-",
+                   strlen ("KYC-PROVIDER-")))
+  {
+    GNUNET_break (0);
+  }
+  else
+  {
+    provider_name += strlen ("KYC-PROVIDER-");
+  }
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Returning KYC proof from `%s'\n",
+              provider_name);
   ph->cb (ph->cb_cls,
           ph->status,
-          ph->pd->section,
+          provider_name,
           ph->provider_user_id,
           ph->provider_legitimization_id,
           GNUNET_TIME_relative_to_absolute (ph->pd->validity),
@@ -1049,11 +1107,13 @@ converted_proof_cb (void *cls,
   }
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Attribute conversion output is:\n");
+#if DEBUG
   json_dumpf (attr,
               stderr,
               JSON_INDENT (2));
   fprintf (stderr,
            "\n");
+#endif
   {
     const char *id;
     struct GNUNET_JSON_Specification ispec[] = {
@@ -1139,9 +1199,11 @@ parse_proof_success_reply (struct TALER_KYCLOGIC_ProofHandle *ph,
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Calling converter `%s' with JSON\n",
               pd->conversion_binary);
+#if DEBUG
   json_dumpf (j,
               stderr,
               JSON_INDENT (2));
+#endif
   ph->ec = TALER_JSON_external_conversion_start (
     j,
     &converted_proof_cb,
@@ -1666,6 +1728,7 @@ wh_return_not_found (void *cls)
   wh->cb (wh->cb_cls,
           0LLU,
           NULL,
+          false,
           NULL,
           NULL,
           NULL,
