@@ -357,6 +357,11 @@ struct TALER_KYCLOGIC_WebhookHandle
    * HTTP response code to return asynchronously.
    */
   unsigned int response_code;
+
+  /**
+   * True if @e h_payto is for a wallet.
+   */
+  bool is_wallet;
 };
 
 
@@ -1578,6 +1583,7 @@ webhook_generic_reply (struct TALER_KYCLOGIC_WebhookHandle *wh,
   wh->cb (wh->cb_cls,
           wh->process_row,
           &wh->h_payto,
+          wh->is_wallet,
           wh->pd->section,
           account_id,
           inquiry_id,
@@ -1905,6 +1911,7 @@ async_webhook_reply (void *cls)
           (0 == wh->process_row)
           ? NULL
           : &wh->h_payto,
+          wh->is_wallet,
           wh->pd->section,
           NULL,
           wh->inquiry_id, /* provider legi ID */
@@ -2108,6 +2115,7 @@ persona_webhook (void *cls,
             wh->pd->section,
             persona_inquiry_id,
             &wh->h_payto,
+            &wh->is_wallet,
             &wh->process_row);
   if (qs < 0)
   {
