@@ -30,17 +30,17 @@ J=$(jq '{"first":.data.attributes."name-first","middle":.data.attributes."name-m
 
 # Next, combine some fields into larger values.
 FULLNAME=$(echo "$J" | jq -r '[.first,.middle,.last]|join(" ")')
-STREET=$(echo $J | jq -r '[."street-1",."street-2"]|join(" ")')
-CITY=$(echo $J | jq -r '[.postcode,.city,."address-subdivision,.cc"]|join(" ")')
+STREET=$(echo "$J" | jq -r '[."street-1",."street-2"]|join(" ")')
+CITY=$(echo "$J" | jq -r '[.postcode,.city,."address-subdivision,.cc"]|join(" ")')
 
 # Download and base32-encode the photo
 PHOTO_URL=$(echo "$J" | jq -r '.photo')
 PHOTO_FILE=$(mktemp -t tmp.XXXXXXXXXX)
 if [ -z "${TOKEN:-}" ]
 then
-    wget -q --output-document=- "$PHOTO_URL" | gnunet-base32 > ${PHOTO_FILE}
+    wget -q --output-document=- "$PHOTO_URL" | gnunet-base32 > "${PHOTO_FILE}"
 else
-    wget -q --output-document=- --header "Authorization: Bearer $TOKEN" "$PHOTO_URL" | gnunet-base32  > ${PHOTO_FILE}
+    wget -q --output-document=- --header "Authorization: Bearer $TOKEN" "$PHOTO_URL" | gnunet-base32  > "${PHOTO_FILE}"
 fi
 
 # Combine into final result.
