@@ -278,6 +278,11 @@ static unsigned int kyc_row_id = 42;
  */
 static int print_h_payto;
 
+/**
+ * -W command-line option.
+ */
+static int cmd_line_is_wallet;
+
 /**
  * -w command-line option.
  */
@@ -442,6 +447,7 @@ kyc_webhook_cleanup (void)
  * @param cls closure
  * @param process_row legitimization process request the webhook was about
  * @param account_id account the webhook was about
+ * @param is_wallet true if @a account_id is for a wallet
  * @param provider_section configuration section of the logic
  * @param provider_user_id set to user ID at the provider, or NULL if not supported or unknown
  * @param provider_legitimization_id set to legitimization process ID at the provider, or NULL if not supported or unknown
@@ -456,6 +462,7 @@ webhook_finished_cb (
   void *cls,
   uint64_t process_row,
   const struct TALER_NormalizedPaytoHashP *account_id,
+  bool is_wallet,
   const char *provider_section,
   const char *provider_user_id,
   const char *provider_legitimization_id,
@@ -470,6 +477,7 @@ webhook_finished_cb (
   (void) expiration;
   (void) provider_section;
   kwh->wh = NULL;
+  GNUNET_break (is_wallet);
   if ( (NULL != account_id) &&
        (0 != GNUNET_memcmp (account_id,
                             &cmd_line_h_payto)) )
@@ -558,6 +566,7 @@ clean_kwh (struct TEKT_RequestContext *rc)
  * @param provider_section
  * @param provider_legitimization_id legi to look up
  * @param[out] h_payto where to write the result
+ * @param[out] is_wallet set to true if @a h_payto is for a wallet
  * @param[out] legi_row where to write the row ID for the legitimization ID
  * @return database transaction status
  */
@@ -567,6 +576,7 @@ kyc_provider_account_lookup (
   const char *provider_section,
   const char *provider_legitimization_id,
   struct TALER_NormalizedPaytoHashP *h_payto,
+  bool *is_wallet,
   uint64_t *legi_row)
 {
   (void) cls;
@@ -576,6 +586,7 @@ kyc_provider_account_lookup (
               provider_legitimization_id);
   *h_payto = cmd_line_h_payto;
   *legi_row = kyc_row_id;
+  *is_wallet = (0 != cmd_line_is_wallet);
   return GNUNET_DB_STATUS_SUCCESS_ONE_RESULT;
 }
 
@@ -1832,6 +1843,11 @@ main (int argc,
       "run-webservice",
       "run the integrated HTTP service",
       &run_webservice),
+    GNUNET_GETOPT_option_flag (
+      'W',
+      "wallet-payto",
+      "simulate that the address the KYC process is about is a wallet",
+      &cmd_line_is_wallet),
     GNUNET_GETOPT_OPTION_END
   };
   enum GNUNET_GenericReturnValue ret;
