@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2014-2023 Taler Systems SA
+   Copyright (C) 2014-2024 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -435,10 +435,105 @@ handle_deposit_finished (void *cls,
        happen, we should pass the JSON reply to the application */
     break;
   case MHD_HTTP_CONFLICT:
+    {
+      dr->hr.ec = TALER_JSON_get_error_code (j);
+      dr->hr.hint = TALER_JSON_get_error_hint (j);
+      switch (dr->hr.ec)
+      {
+      case TALER_EC_EXCHANGE_GENERIC_INSUFFICIENT_FUNDS:
+        {
+          struct GNUNET_JSON_Specification spec[] = {
+            GNUNET_JSON_spec_fixed_auto (
+              "coin_pub",
+              &dr->details.conflict.details
+              .insufficient_funds.coin_pub),
+            GNUNET_JSON_spec_end ()
+          };
+
+          if (GNUNET_OK !=
+              GNUNET_JSON_parse (j,
+                                 spec,
+                                 NULL, NULL))
+          {
+            GNUNET_break_op (0);
+            dr->hr.http_status = 0;
+            dr->hr.ec = TALER_EC_GENERIC_REPLY_MALFORMED;
+            break;
+          }
+        }
+        break;
+      case TALER_EC_EXCHANGE_GENERIC_COIN_CONFLICTING_AGE_HASH:
+        {
+          struct GNUNET_JSON_Specification spec[] = {
+            GNUNET_JSON_spec_fixed_auto (
+              "coin_pub",
+              &dr->details.conflict.details
+              .coin_conflicting_age_hash.coin_pub),
+            GNUNET_JSON_spec_end ()
+          };
+
+          if (GNUNET_OK !=
+              GNUNET_JSON_parse (j,
+                                 spec,
+                                 NULL, NULL))
+          {
+            GNUNET_break_op (0);
+            dr->hr.http_status = 0;
+            dr->hr.ec = TALER_EC_GENERIC_REPLY_MALFORMED;
+            break;
+          }
+        }
+        break;
+      case TALER_EC_EXCHANGE_GENERIC_COIN_CONFLICTING_DENOMINATION_KEY:
+        {
+          struct GNUNET_JSON_Specification spec[] = {
+            GNUNET_JSON_spec_fixed_auto (
+              "coin_pub",
+              &dr->details.conflict.details
+              .coin_conflicting_denomination_key.coin_pub),
+            GNUNET_JSON_spec_end ()
+          };
+
+          if (GNUNET_OK !=
+              GNUNET_JSON_parse (j,
+                                 spec,
+                                 NULL, NULL))
+          {
+            GNUNET_break_op (0);
+            dr->hr.http_status = 0;
+            dr->hr.ec = TALER_EC_GENERIC_REPLY_MALFORMED;
+            break;
+          }
+        }
+        break;
+      case TALER_EC_EXCHANGE_DEPOSIT_CONFLICTING_CONTRACT:
+        break;
+      default:
+        GNUNET_break_op (0);
+        break;
+      }
+    }
+    break;
+  case MHD_HTTP_GONE:
+    /* could happen if denomination was revoked */
+    /* Note: one might want to check /keys for revocation
+       signature here, alas tricky in case our /keys
+       is outdated => left to clients */
+    dr->hr.ec = TALER_JSON_get_error_code (j);
+    dr->hr.hint = TALER_JSON_get_error_hint (j);
+    break;
+  case MHD_HTTP_UNAVAILABLE_FOR_LEGAL_REASONS:
     {
       struct GNUNET_JSON_Specification spec[] = {
-        GNUNET_JSON_spec_fixed_auto ("coin_pub",
-                                     &dr->details.conflict.coin_pub),
+        GNUNET_JSON_spec_fixed_auto (
+          "h_payto",
+          &dr->details.unavailable_for_legal_reasons.h_payto),
+        GNUNET_JSON_spec_uint64 (
+          "requirement_row",
+          &dr->details.unavailable_for_legal_reasons.requirement_row),
+        GNUNET_JSON_spec_bool (
+          "bad_kyc_auth",
+          &dr->details.unavailable_for_legal_reasons.bad_kyc_auth),
         GNUNET_JSON_spec_end ()
       };
 
@@ -452,18 +547,8 @@ handle_deposit_finished (void *cls,
         dr->hr.ec = TALER_EC_GENERIC_REPLY_MALFORMED;
         break;
       }
-      dr->hr.ec = TALER_JSON_get_error_code (j);
-      dr->hr.hint = TALER_JSON_get_error_hint (j);
     }
     break;
-  case MHD_HTTP_GONE:
-    /* could happen if denomination was revoked */
-    /* Note: one might want to check /keys for revocation
-       signature here, alas tricky in case our /keys
-       is outdated => left to clients */
-    dr->hr.ec = TALER_JSON_get_error_code (j);
-    dr->hr.hint = TALER_JSON_get_error_hint (j);
-    break;
   case MHD_HTTP_INTERNAL_SERVER_ERROR:
     dr->hr.ec = TALER_JSON_get_error_code (j);
     dr->hr.hint = TALER_JSON_get_error_hint (j);
@@ -583,6 +668,10 @@ TALER_EXCHANGE_batch_deposit (
       json_decref (deposits);
       return NULL;
     }
+    if (! GNUNET_is_zero (&dcd->merchant_sig))
+    {
+      /* FIXME #9185: check merchant_sig!? */
+    }
     if (GNUNET_is_zero (&cdd->h_age_commitment))
       h_age_commitmentp = NULL;
     else
@@ -627,8 +716,8 @@ TALER_EXCHANGE_batch_deposit (
     wallet_data_hashp = &dcd->wallet_data_hash;
 
   deposit_obj = GNUNET_JSON_PACK (
-    GNUNET_JSON_pack_string ("merchant_payto_uri",
-                             dcd->merchant_payto_uri),
+    TALER_JSON_pack_full_payto ("merchant_payto_uri",
+                                dcd->merchant_payto_uri),
     GNUNET_JSON_pack_data_auto ("wire_salt",
                                 &dcd->wire_salt),
     GNUNET_JSON_pack_data_auto ("h_contract_terms",
@@ -645,6 +734,8 @@ TALER_EXCHANGE_batch_deposit (
                                 dcd->wallet_timestamp),
     GNUNET_JSON_pack_data_auto ("merchant_pub",
                                 &dcd->merchant_pub),
+    GNUNET_JSON_pack_data_auto ("merchant_sig",
+                                &dcd->merchant_sig),
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_timestamp ("refund_deadline",
                                   dcd->refund_deadline)),
