@@ -1175,9 +1175,9 @@ TALER_EXCHANGE_check_coin_signature_conflict (
 }
 
 
-#if FIXME_IMPLEMENT
+#if FIXME_IMPLEMENT /* #9422 */
 /**
- * FIXME-Oec: we need some specific routines that show
+ * FIXME-Oec-#9422: we need some specific routines that show
  * that certain coin operations are indeed in conflict,
  * for example that the coin is of a different denomination
  * or different age restrictions.
@@ -1195,7 +1195,7 @@ TALER_EXCHANGE_check_coin_signature_conflict (
  * @param required balance required on the coin for the operation
  * @return #GNUNET_OK if @a proof holds
  */
-// FIXME: should be properly defined and implemented!
+// FIXME-#9422: should be properly defined and implemented!
 enum GNUNET_GenericReturnValue
 TALER_EXCHANGE_check_coin_conflict_ (
   const struct TALER_EXCHANGE_Keys *keys,
@@ -1214,7 +1214,7 @@ TALER_EXCHANGE_check_coin_conflict_ (
        checked in the GET /coins/$COIN_PUB handler */
     break;
   case TALER_EC_EXCHANGE_GENERIC_COIN_CONFLICTING_DENOMINATION_KEY:
-    // FIXME: write check!
+    // FIXME-#9422: write check!
     break;
   default:
     GNUNET_break_op (0);
