@@ -40,12 +40,12 @@
  * Which version of the Taler protocol is implemented
  * by this library?  Used to determine compatibility.
  */
-#define EXCHANGE_PROTOCOL_CURRENT 24
+#define EXCHANGE_PROTOCOL_CURRENT 26
 
 /**
  * How many versions are we backwards compatible with?
  */
-#define EXCHANGE_PROTOCOL_AGE 5
+#define EXCHANGE_PROTOCOL_AGE 0
 
 /**
  * Set to 1 for extra debug logging.
@@ -521,6 +521,9 @@ parse_json_denomkey_partially (
             &denom_key->fees,
             master_key,
             &denom_key->master_sig));
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "Learned denomination key %s\n",
+              GNUNET_h2s (&denom_key->h_key.hash));
   return GNUNET_OK;
 EXITIF_exit:
   GNUNET_JSON_parse_free (spec);
@@ -1545,9 +1548,9 @@ keys_completed_cb (void *cls,
         TALER_denom_pub_copy (&kd->denom_keys[i].key,
                               &kd_old->denom_keys[i].key);
       kd->num_auditors = kd_old->num_auditors;
-      kd->auditors = GNUNET_new_array (kd->num_auditors,
-                                       struct TALER_EXCHANGE_AuditorInformation)
-      ;
+      kd->auditors
+        = GNUNET_new_array (kd->num_auditors,
+                            struct TALER_EXCHANGE_AuditorInformation);
       /* Now the necessary deep copy... */
       for (unsigned int i = 0; i<kd_old->num_auditors; i++)
       {
@@ -1973,6 +1976,7 @@ TALER_EXCHANGE_get_denomination_key_by_hash (
   const struct TALER_EXCHANGE_Keys *keys,
   const struct TALER_DenominationHashP *hc)
 {
+  /* FIXME-optimization: should we maybe use a hash map here? */
   for (unsigned int i = 0; i<keys->num_denom_keys; i++)
     if (0 == GNUNET_memcmp (hc,
                             &keys->denom_keys[i].h_key))
