@@ -70,6 +70,8 @@ parse_account_status (
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_bool ("aml_review",
                            &status->aml_review),
+    GNUNET_JSON_spec_uint64 ("rule_gen",
+                             &status->rule_gen),
     GNUNET_JSON_spec_fixed_auto ("access_token",
                                  &status->access_token),
     GNUNET_JSON_spec_mark_optional (
@@ -258,6 +260,7 @@ TALER_EXCHANGE_kyc_check (
   const char *url,
   const struct TALER_NormalizedPaytoHashP *h_payto,
   const union TALER_AccountPrivateKeyP *account_priv,
+  uint64_t known_rule_gen,
   enum TALER_EXCHANGE_KycLongPollTarget lpt,
   struct GNUNET_TIME_Relative timeout,
   TALER_EXCHANGE_KycStatusCallback cb,
@@ -268,6 +271,7 @@ TALER_EXCHANGE_kyc_check (
   char arg_str[128];
   char timeout_ms[32];
   char lpt_str[32];
+  char krg_str[32];
   struct curl_slist *job_headers = NULL;
   unsigned long long tms;
 
@@ -289,6 +293,10 @@ TALER_EXCHANGE_kyc_check (
                    sizeof (timeout_ms),
                    "%llu",
                    tms);
+  GNUNET_snprintf (krg_str,
+                   sizeof (krg_str),
+                   "%llu",
+                   (unsigned long long) known_rule_gen);
   GNUNET_snprintf (lpt_str,
                    sizeof (lpt_str),
                    "%d",
@@ -304,6 +312,10 @@ TALER_EXCHANGE_kyc_check (
         GNUNET_TIME_relative_is_zero (timeout)
         ? NULL
         : timeout_ms,
+        "min_rule",
+        0 == known_rule_gen
+        ? NULL
+        : krg_str,
         "lpt",
         TALER_EXCHANGE_KLPT_NONE == lpt
         ? NULL
