@@ -477,7 +477,7 @@ struct TALER_EXCHANGE_LookupAmlDecisions *
 TALER_EXCHANGE_lookup_aml_decisions (
   struct GNUNET_CURL_Context *ctx,
   const char *exchange_url,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_NormalizedPaytoHashP *h_payto,
   enum TALER_EXCHANGE_YesNoAll investigation_only,
   enum TALER_EXCHANGE_YesNoAll active_only,
   uint64_t offset,
