@@ -114,7 +114,7 @@ struct TALER_EXCHANGE_PurseCreateDepositHandle
   struct TALER_Amount purse_value_after_fees;
 
   /**
-   * Our encryped contract (if we had any).
+   * Our encrypted contract (if we had any).
    */
   struct TALER_EncryptedContract econtract;
 
@@ -281,7 +281,7 @@ handle_purse_create_deposit_finished (void *cls,
            checked in the GET /coins/$COIN_PUB handler */
         break;
       case TALER_EC_EXCHANGE_GENERIC_COIN_CONFLICTING_DENOMINATION_KEY:
-        // FIXME: write check (add to exchange_api_common! */
+        // FIXME #7267: write check (add to exchange_api_common! */
         break;
       case TALER_EC_EXCHANGE_PURSE_DEPOSIT_CONFLICTING_META_DATA:
         {
@@ -512,6 +512,10 @@ TALER_EXCHANGE_purse_create_with_deposit (
                                        &attest))
       {
         GNUNET_break (0);
+        GNUNET_array_grow (pch->deposits,
+                           pch->num_deposits,
+                           0);
+        GNUNET_free (pch->url);
         json_decref (deposit_arr);
         GNUNET_free (pch);
         return NULL;
@@ -606,7 +610,9 @@ TALER_EXCHANGE_purse_create_with_deposit (
       curl_easy_cleanup (eh);
     json_decref (create_obj);
     GNUNET_free (pch->econtract.econtract);
-    GNUNET_free (pch->deposits);
+    GNUNET_array_grow (pch->deposits,
+                       pch->num_deposits,
+                       0);
     GNUNET_free (pch->url);
     GNUNET_free (pch);
     return NULL;
@@ -638,7 +644,9 @@ TALER_EXCHANGE_purse_create_with_deposit_cancel (
   GNUNET_free (pch->econtract.econtract);
   GNUNET_free (pch->exchange_url);
   GNUNET_free (pch->url);
-  GNUNET_free (pch->deposits);
+  GNUNET_array_grow (pch->deposits,
+                     pch->num_deposits,
+                     0);
   TALER_EXCHANGE_keys_decref (pch->keys);
   TALER_curl_easy_post_finished (&pch->ctx);
   GNUNET_free (pch);
