@@ -234,8 +234,9 @@ TALER_EXCHANGE_recoup (
   struct TALER_EXCHANGE_Keys *keys,
   const struct TALER_EXCHANGE_DenomPublicKey *pk,
   const struct TALER_DenominationSignature *denom_sig,
-  const struct TALER_ExchangeWithdrawValues *exchange_vals,
+  const struct TALER_ExchangeBlindingValues *blinding_values,
   const struct TALER_PlanchetMasterSecretP *ps,
+  const struct TALER_HashBlindedPlanchetsP *h_planchets,
   TALER_EXCHANGE_RecoupResultCallback recoup_cb,
   void *recoup_cb_cls)
 {
@@ -249,10 +250,10 @@ TALER_EXCHANGE_recoup (
 
   ph = GNUNET_new (struct TALER_EXCHANGE_RecoupHandle);
   TALER_planchet_setup_coin_priv (ps,
-                                  exchange_vals,
+                                  blinding_values,
                                   &coin_priv);
   TALER_planchet_blinding_secret_create (ps,
-                                         exchange_vals,
+                                         blinding_values,
                                          &bks);
   GNUNET_CRYPTO_eddsa_key_get_public (&coin_priv.eddsa_priv,
                                       &ph->coin_pub.eddsa_pub);
@@ -267,10 +268,12 @@ TALER_EXCHANGE_recoup (
                                 &h_denom_pub),
     TALER_JSON_pack_denom_sig ("denom_sig",
                                denom_sig),
-    TALER_JSON_pack_exchange_withdraw_values ("ewv",
-                                              exchange_vals),
+    TALER_JSON_pack_exchange_blinding_values ("ewv",
+                                              blinding_values),
     GNUNET_JSON_pack_data_auto ("coin_sig",
                                 &ph->coin_sig),
+    GNUNET_JSON_pack_data_auto ("h_planchets",
+                                h_planchets),
     GNUNET_JSON_pack_data_auto ("coin_blind_key_secret",
                                 &bks));
   switch (denom_sig->unblinded_sig->cipher)
