@@ -222,7 +222,7 @@ TALER_EXCHANGE_recoup_refresh (
   struct TALER_EXCHANGE_Keys *keys,
   const struct TALER_EXCHANGE_DenomPublicKey *pk,
   const struct TALER_DenominationSignature *denom_sig,
-  const struct TALER_ExchangeWithdrawValues *exchange_vals,
+  const struct TALER_ExchangeBlindingValues *blinding_values,
   const struct TALER_RefreshMasterSecretP *rms,
   const struct TALER_PlanchetMasterSecretP *ps,
   unsigned int idx,
@@ -246,10 +246,10 @@ TALER_EXCHANGE_recoup_refresh (
   ph->cb = recoup_cb;
   ph->cb_cls = recoup_cb_cls;
   TALER_planchet_setup_coin_priv (ps,
-                                  exchange_vals,
+                                  blinding_values,
                                   &coin_priv);
   TALER_planchet_blinding_secret_create (ps,
-                                         exchange_vals,
+                                         blinding_values,
                                          &bks);
   GNUNET_CRYPTO_eddsa_key_get_public (&coin_priv.eddsa_priv,
                                       &ph->coin_pub.eddsa_pub);
@@ -264,8 +264,8 @@ TALER_EXCHANGE_recoup_refresh (
                                 &h_denom_pub),
     TALER_JSON_pack_denom_sig ("denom_sig",
                                denom_sig),
-    TALER_JSON_pack_exchange_withdraw_values ("ewv",
-                                              exchange_vals),
+    TALER_JSON_pack_exchange_blinding_values ("ewv",
+                                              blinding_values),
     GNUNET_JSON_pack_data_auto ("coin_sig",
                                 &ph->coin_sig),
     GNUNET_JSON_pack_data_auto ("coin_blind_key_secret",
