@@ -117,7 +117,7 @@ struct FreshCoinData
 /**
  * Melt data in non-serialized format for convenient processing.
  */
-struct MeltData
+struct MeltData_v27
 {
 
   /**
@@ -130,6 +130,41 @@ struct MeltData
    */
   struct MeltedCoin melted_coin;
 
+  /**
+   * Number of coins we are creating
+   */
+  uint16_t num_fresh_coins;
+
+  /**
+   * If true, no blinding seed is used in the melt request
+   */
+  bool no_blinding_seed;
+
+  /**
+   * The seed for blinding, derived from the refresh master secret;
+   */
+  struct TALER_BlindingMasterSeedP blinding_seed;
+
+  /**
+   * The master seed from which we derive the kappa nonces for
+   * for signing with the @e melted_coin.
+   * The seed itself is derived from the refresh master secret;
+   */
+  struct TALER_PublicRefreshMasterSeedP refresh_seed;
+
+  /**
+   * The tuple of kappa nonces which we sign with the melted coin.
+   * From those signatures, all the planchet seeds are derived from.
+   */
+  struct TALER_KappaPublicRefreshNoncesP kappa_nonces;
+
+  /**
+   * The tuple of kappa signatures of the @e kappa_nonces, signed
+   * by the @e melted_coin, from which we derive all
+   * kappa * @e num_fresh_coins planchet secrets.
+   */
+  struct TALER_PrivateRefreshNonceSignatureP signatures[TALER_CNC_KAPPA];
+
   /**
    * Array of length @e num_fresh_coins with information
    * about each fresh coin.
@@ -137,54 +172,39 @@ struct MeltData
   struct FreshCoinData *fcds;
 
   /**
-   * Transfer secrets, one per cut and choose.
+   * Array of @e num_fresh_coins denominations of the fresh coins.
    */
-  struct TALER_TransferSecretP trans_sec[TALER_CNC_KAPPA];
+  const struct TALER_DenominationPublicKey **denom_pubs;
 
   /**
-   * Transfer private keys for each cut-and-choose dimension.
+   * Array of @e num_fresh_coins of hashes of the public key of the denominations.
    */
-  struct TALER_TransferPrivateKeyP transfer_priv[TALER_CNC_KAPPA];
+  struct TALER_DenominationHashP  *denoms_h;
 
   /**
-   * Transfer public key of this commitment.
+   * Blinded planchets of the fresh coins, depending on the cut-and-choose.
+   * Array of length @e num_fresh_coins.
    */
-  struct TALER_TransferPublicKeyP transfer_pub[TALER_CNC_KAPPA];
-
-  /**
-   * Transfer secrets, one per cut and choose.
-   */
-  struct TALER_RefreshCommitmentEntry rce[TALER_CNC_KAPPA];
-
-  /**
-   * Blinded planchets and denominations of the fresh coins, depending on the cut-and-choose.  Array of length
-   * @e num_fresh_coins.
-   */
-  struct TALER_RefreshCoinData *rcd[TALER_CNC_KAPPA];
-
-  /**
-   * Number of coins we are creating
-   */
-  uint16_t num_fresh_coins;
-
+  struct TALER_BlindedPlanchet *kappa_blinded_planchets[TALER_CNC_KAPPA];
 };
 
-
 /**
- * Compute the melt data from the refresh data and secret.
+ * Compute the melt data from the refresh data and secret
+ * for v27 of the protocol.
  *
  * @param rms secret internals of the refresh-reveal operation
  * @param rd refresh data with the characteristics of the operation
+ * @param blinding_seed seed for blinding in case of CS denominations, can be NULL
  * @param alg_values contributions from the exchange into the melt
  * @param[out] md where to write the derived melt data
  */
 enum GNUNET_GenericReturnValue
-TALER_EXCHANGE_get_melt_data_ (
+TALER_EXCHANGE_get_melt_data_v27 (
   const struct TALER_RefreshMasterSecretP *rms,
-  const struct TALER_EXCHANGE_RefreshData *rd,
-  const struct TALER_ExchangeWithdrawValues *alg_values,
-  struct MeltData *md);
-
+  const struct TALER_EXCHANGE_MeltInput *rd,
+  const struct TALER_BlindingMasterSeedP *blinding_seed,
+  const struct TALER_ExchangeBlindingValues *alg_values,
+  struct MeltData_v27 *md);
 
 /**
  * Free all information associated with a melting session.  Note
@@ -196,6 +216,6 @@ TALER_EXCHANGE_get_melt_data_ (
  *           freed (as it is typically not allocated by itself)
  */
 void
-TALER_EXCHANGE_free_melt_data_ (struct MeltData *md);
+TALER_EXCHANGE_free_melt_data_v27 (struct MeltData_v27 *md);
 
 #endif
