@@ -188,7 +188,7 @@ parse_credit (struct TALER_EXCHANGE_ReserveHistoryEntry *rh,
 
 
 /**
- * Parse "credit" reserve history entry.
+ * Parse "withdraw" reserve history entry.
  *
  * @param[in,out] rh entry to parse
  * @param uc our context
@@ -200,19 +200,52 @@ parse_withdraw (struct TALER_EXCHANGE_ReserveHistoryEntry *rh,
                 struct HistoryParseContext *uc,
                 const json_t *transaction)
 {
-  struct TALER_ReserveSignatureP sig;
-  struct TALER_DenominationHashP h_denom_pub;
-  struct TALER_BlindedCoinHashP bch;
+  uint16_t num_coins;
   struct TALER_Amount withdraw_fee;
+  struct TALER_Amount withdraw_amount;
+  struct TALER_Amount amount_without_fee;
+  uint8_t max_age = 0;
+  uint8_t noreveal_index = 0;
+  struct TALER_HashBlindedPlanchetsP planchets_h;
+  struct TALER_HashBlindedPlanchetsP selected_h;
+  struct TALER_ReserveSignatureP reserve_sig;
+  struct TALER_BlindingMasterSeedP blinding_seed;
+  struct TALER_DenominationHashP *denom_pub_hashes;
+  size_t num_denom_pub_hashes;
+  bool no_max_age;
+  bool no_noreveal_index;
+  bool no_blinding_seed;
+  bool no_selected_h;
   struct GNUNET_JSON_Specification withdraw_spec[] = {
     GNUNET_JSON_spec_fixed_auto ("reserve_sig",
-                                 &sig),
+                                 &reserve_sig),
+    GNUNET_JSON_spec_uint16 ("num_coins",
+                             &num_coins),
+    GNUNET_JSON_spec_fixed_auto ("planchets_h",
+                                 &planchets_h),
+    TALER_JSON_spec_amount_any ("amount",
+                                &withdraw_amount),
     TALER_JSON_spec_amount_any ("withdraw_fee",
                                 &withdraw_fee),
-    GNUNET_JSON_spec_fixed_auto ("h_denom_pub",
-                                 &h_denom_pub),
-    GNUNET_JSON_spec_fixed_auto ("h_coin_envelope",
-                                 &bch),
+    TALER_JSON_spec_array_of_denom_pub_h ("denom_pub_hashes",
+                                          &num_denom_pub_hashes,
+                                          &denom_pub_hashes),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_fixed_auto ("selected_h",
+                                   &selected_h),
+      &no_selected_h),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_uint8 ("max_age",
+                              &max_age),
+      &no_max_age),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_fixed_auto ("blinding_seed",
+                                   &blinding_seed),
+      &no_blinding_seed),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_uint8 ("noreveal_index",
+                              &noreveal_index),
+      &no_noreveal_index),
     GNUNET_JSON_spec_end ()
   };
 
@@ -226,32 +259,101 @@ parse_withdraw (struct TALER_EXCHANGE_ReserveHistoryEntry *rh,
     return GNUNET_SYSERR;
   }
 
-  /* Check that the signature is a valid withdraw request */
-  if (GNUNET_OK !=
-      TALER_wallet_withdraw_verify (&h_denom_pub,
-                                    &rh->amount,
-                                    &bch,
-                                    uc->reserve_pub,
-                                    &sig))
+  if ((no_max_age != no_noreveal_index) ||
+      (no_max_age != no_selected_h))
   {
     GNUNET_break_op (0);
     GNUNET_JSON_parse_free (withdraw_spec);
     return GNUNET_SYSERR;
   }
+  rh->details.withdraw.age_restricted = ! no_max_age;
+
+  if (num_coins != num_denom_pub_hashes)
+  {
+    GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (withdraw_spec);
+    return GNUNET_SYSERR;
+  }
+
+  /* Check that the signature is a valid withdraw request */
+  if (0>TALER_amount_subtract (
+        &amount_without_fee,
+        &withdraw_amount,
+        &withdraw_fee))
+  {
+    GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (withdraw_spec);
+    return GNUNET_SYSERR;
+  }
+
+  if (GNUNET_OK !=
+      TALER_wallet_withdraw_verify (
+        &amount_without_fee,
+        &withdraw_fee,
+        &planchets_h,
+        no_blinding_seed ? NULL : &blinding_seed,
+        no_max_age ? NULL : &uc->keys->age_mask,
+        no_max_age ? 0 : max_age,
+        uc->reserve_pub,
+        &reserve_sig))
+  {
+    GNUNET_break_op (0);
+    GNUNET_JSON_parse_free (withdraw_spec);
+    return GNUNET_SYSERR;
+  }
+
+  rh->details.withdraw.num_coins = num_coins;
+  rh->details.withdraw.age_restricted = ! no_max_age;
+  rh->details.withdraw.max_age = max_age;
+  rh->details.withdraw.planchets_h = planchets_h;
+  rh->details.withdraw.selected_h = selected_h;
+  rh->details.withdraw.noreveal_index = noreveal_index;
+  rh->details.withdraw.no_blinding_seed = no_blinding_seed;
+  if (! no_blinding_seed)
+    rh->details.withdraw.blinding_seed = blinding_seed;
+
   /* check that withdraw fee matches expectations! */
   {
     const struct TALER_EXCHANGE_Keys *key_state;
-    const struct TALER_EXCHANGE_DenomPublicKey *dki;
+    struct TALER_Amount fee_acc;
+    struct TALER_Amount amount_acc;
+
+    GNUNET_assert (GNUNET_OK ==
+                   TALER_amount_set_zero (withdraw_amount.currency,
+                                          &fee_acc));
+    GNUNET_assert (GNUNET_OK ==
+                   TALER_amount_set_zero (withdraw_amount.currency,
+                                          &amount_acc));
 
     key_state = uc->keys;
-    dki = TALER_EXCHANGE_get_denomination_key_by_hash (key_state,
-                                                       &h_denom_pub);
+
+    /* accumulate the withdraw fees */
+    for (size_t i=0; i < num_coins; i++)
+    {
+      const struct TALER_EXCHANGE_DenomPublicKey *dki;
+
+      dki = TALER_EXCHANGE_get_denomination_key_by_hash (key_state,
+                                                         &denom_pub_hashes[i]);
+      if (NULL == dki)
+      {
+        GNUNET_break_op (0);
+        GNUNET_JSON_parse_free (withdraw_spec);
+        return GNUNET_SYSERR;
+      }
+      TALER_amount_add (&fee_acc,
+                        &fee_acc,
+                        &dki->fees.withdraw);
+      TALER_amount_add (&amount_acc,
+                        &amount_acc,
+                        &dki->value);
+    }
+
     if ( (GNUNET_YES !=
-          TALER_amount_cmp_currency (&withdraw_fee,
-                                     &dki->fees.withdraw)) ||
+          TALER_amount_cmp_currency (&fee_acc,
+                                     &withdraw_fee)) ||
          (0 !=
-          TALER_amount_cmp (&withdraw_fee,
-                            &dki->fees.withdraw)) )
+          TALER_amount_cmp (&amount_acc,
+                            &amount_without_fee)) )
     {
       GNUNET_break_op (0);
       GNUNET_JSON_parse_free (withdraw_spec);
@@ -259,6 +361,8 @@ parse_withdraw (struct TALER_EXCHANGE_ReserveHistoryEntry *rh,
     }
     rh->details.withdraw.fee = withdraw_fee;
   }
+
+  #pragma message "is out_authorization_sig still needed? Not set anywhere"
   rh->details.withdraw.out_authorization_sig
     = json_object_get (transaction,
                        "signature");
@@ -267,8 +371,8 @@ parse_withdraw (struct TALER_EXCHANGE_ReserveHistoryEntry *rh,
        "uuid" array to remember the hashes of all
        signatures, and compare the hashes to find
        duplicates. */
-  GNUNET_CRYPTO_hash (&sig,
-                      sizeof (sig),
+  GNUNET_CRYPTO_hash (&reserve_sig,
+                      sizeof (reserve_sig),
                       &uc->uuids[uc->uuid_off]);
   for (unsigned int i = 0; i<uc->uuid_off; i++)
   {
@@ -292,6 +396,7 @@ parse_withdraw (struct TALER_EXCHANGE_ReserveHistoryEntry *rh,
     GNUNET_JSON_parse_free (withdraw_spec);
     return GNUNET_SYSERR;
   }
+  GNUNET_JSON_parse_free (withdraw_spec);
   return GNUNET_OK;
 }
 
@@ -667,8 +772,6 @@ free_reserve_history (
       break;
     case TALER_EXCHANGE_RTT_WITHDRAWAL:
       break;
-    case TALER_EXCHANGE_RTT_AGEWITHDRAWAL:
-      break;
     case TALER_EXCHANGE_RTT_RECOUP:
       break;
     case TALER_EXCHANGE_RTT_CLOSING:
