@@ -77,7 +77,8 @@ TALER_EXCHANGE_test_account_allowed (
           GNUNET_break_op (0);
           return GNUNET_SYSERR;
         }
-        if (regexec (&ex,
+        if (0 ==
+            regexec (&ex,
                      payto_uri.normalized_payto,
                      0, NULL,
                      0))
