@@ -428,7 +428,7 @@ TALER_PQ_query_param_blinded_planchet (
  * @return -1 on error, number of offsets used in @a scratch otherwise
  */
 static int
-qconv_exchange_withdraw_values (void *cls,
+qconv_exchange_blinding_values (void *cls,
                                 const void *data,
                                 size_t data_len,
                                 void *param_values[],
@@ -438,9 +438,9 @@ qconv_exchange_withdraw_values (void *cls,
                                 void *scratch[],
                                 unsigned int scratch_length)
 {
-  const struct TALER_ExchangeWithdrawValues *alg_values = data;
+  const struct TALER_ExchangeBlindingValues *blinding_values = data;
   const struct GNUNET_CRYPTO_BlindingInputValues *bi =
-    alg_values->blinding_inputs;
+    blinding_values->blinding_inputs;
   size_t tlen;
   size_t len;
   uint32_t be[2];
@@ -490,12 +490,12 @@ qconv_exchange_withdraw_values (void *cls,
 
 
 struct GNUNET_PQ_QueryParam
-TALER_PQ_query_param_exchange_withdraw_values (
-  const struct TALER_ExchangeWithdrawValues *alg_values)
+TALER_PQ_query_param_exchange_blinding_values (
+  const struct TALER_ExchangeBlindingValues *blinding_values)
 {
   struct GNUNET_PQ_QueryParam res = {
-    .conv = &qconv_exchange_withdraw_values,
-    .data = alg_values,
+    .conv = &qconv_exchange_blinding_values,
+    .data = blinding_values,
     .num_params = 1
   };
 
@@ -949,6 +949,15 @@ qconv_array (
                          sizeof(struct GNUNET_HashCode));
           break;
         }
+      case TALER_PQ_array_of_cs_r_pub:
+        {
+          const struct GNUNET_CRYPTO_CSPublicRPairP *cs_r_pubs = data;
+
+          GNUNET_memcpy (out,
+                         &cs_r_pubs[i],
+                         sizeof(struct GNUNET_CRYPTO_CSPublicRPairP));
+          break;
+        }
       default:
         {
           GNUNET_assert (0);
@@ -1162,4 +1171,28 @@ TALER_PQ_query_param_array_amount_with_currency (
 }
 
 
+struct GNUNET_PQ_QueryParam
+TALER_PQ_query_param_array_cs_r_pub (
+  size_t num,
+  const struct GNUNET_CRYPTO_CSPublicRPairP *cs_r_pubs,
+  struct GNUNET_PQ_Context *db)
+{
+  Oid oid;
+
+  GNUNET_assert (GNUNET_OK ==
+                 GNUNET_PQ_get_oid_by_name (db,
+                                            "bytea",
+                                            &oid));
+  return query_param_array_generic (
+    num,
+    true,
+    cs_r_pubs,
+    NULL,
+    sizeof(struct GNUNET_CRYPTO_CSPublicRPairP),
+    TALER_PQ_array_of_cs_r_pub,
+    oid,
+    db);
+}
+
+
 /* end of pq/pq_query_helper.c */
