@@ -989,7 +989,7 @@ extract_exchange_withdraw_values (void *cls,
                                   size_t *dst_size,
                                   void *dst)
 {
-  struct TALER_ExchangeWithdrawValues *alg_values = dst;
+  struct TALER_ExchangeBlindingValues *alg_values = dst;
   struct GNUNET_CRYPTO_BlindingInputValues *bi;
   size_t len;
   const char *res;
@@ -1071,7 +1071,7 @@ extract_exchange_withdraw_values (void *cls,
 struct GNUNET_PQ_ResultSpec
 TALER_PQ_result_spec_exchange_withdraw_values (
   const char *name,
-  struct TALER_ExchangeWithdrawValues *ewv)
+  struct TALER_ExchangeBlindingValues *ewv)
 {
   struct GNUNET_PQ_ResultSpec res = {
     .conv = &extract_exchange_withdraw_values,
@@ -1173,6 +1173,11 @@ extract_array_generic (
   col_num = PQfnumber (result, fname);
   FAIL_IF (0 > col_num);
 
+  if (PQgetisnull (result, row, col_num))
+  {
+    return GNUNET_NO;
+  }
+
   data_sz = PQgetlength (result, row, col_num);
   FAIL_IF (0 > data_sz);
   FAIL_IF (sizeof(header) > (size_t) data_sz);
@@ -1318,6 +1323,30 @@ extract_array_generic (
       }
       return GNUNET_OK;
 
+    case TALER_PQ_array_of_cs_r_pub:
+      if (NULL != dst_size)
+        *dst_size = sizeof(struct GNUNET_CRYPTO_CSPublicRPairP) * (header.dim);
+      out = GNUNET_new_array (header.dim,
+                              struct GNUNET_CRYPTO_CSPublicRPairP);
+      *((void **) dst) = out;
+      for (uint32_t i = 0; i < header.dim; i++)
+      {
+        uint32_t val;
+        size_t sz;
+
+        GNUNET_memcpy (&val,
+                       in,
+                       sizeof(val));
+        sz =  ntohl (val);
+        FAIL_IF (sz != sizeof(struct GNUNET_CRYPTO_CSPublicRPairP));
+        in += sizeof(uint32_t);
+        *(struct GNUNET_CRYPTO_CSPublicRPairP *) out =
+          *(struct GNUNET_CRYPTO_CSPublicRPairP *) in;
+        in += sz;
+        out += sz;
+      }
+      return GNUNET_OK;
+
     case TALER_PQ_array_of_blinded_denom_sig:
       {
         struct TALER_BlindedDenominationSignature *denom_sigs;
@@ -1410,20 +1439,21 @@ array_cleanup (void *cls,
   struct ArrayResultCls *info = cls;
   void **dst = rd;
 
-  if ((0 == info->same_size) &&
-      (NULL != info->sizes))
+  if ( (0 == info->same_size) &&
+       (NULL != info->sizes) )
     GNUNET_free (*(info->sizes));
 
   /* Clean up signatures, if applicable */
-  if (TALER_PQ_array_of_blinded_denom_sig == info->typ)
+  if ((TALER_PQ_array_of_blinded_denom_sig == info->typ) &&
+      (NULL != *dst))
   {
     struct TALER_BlindedDenominationSignature *denom_sigs = *dst;
+
     GNUNET_assert (NULL != info->num);
     for (size_t i = 0; i < *info->num; i++)
       GNUNET_free (denom_sigs[i].blinded_sig);
   }
-
-  GNUNET_free (cls);
+  GNUNET_free (info);
   GNUNET_free (*dst);
   *dst = NULL;
 }
@@ -1447,7 +1477,7 @@ TALER_PQ_result_spec_array_blinded_denom_sig (
   {
     struct GNUNET_PQ_ResultSpec res = {
       .conv = extract_array_generic,
-      .cleaner = array_cleanup,
+      .cleaner = &array_cleanup,
       .dst = (void *) denom_sigs,
       .fname = name,
       .cls = info
@@ -1476,7 +1506,7 @@ TALER_PQ_result_spec_array_blinded_coin_hash (
   {
     struct GNUNET_PQ_ResultSpec res = {
       .conv = extract_array_generic,
-      .cleaner = array_cleanup,
+      .cleaner = &array_cleanup,
       .dst = (void *) h_coin_evs,
       .fname = name,
       .cls = info
@@ -1505,7 +1535,7 @@ TALER_PQ_result_spec_array_denom_hash (
   {
     struct GNUNET_PQ_ResultSpec res = {
       .conv = extract_array_generic,
-      .cleaner = array_cleanup,
+      .cleaner = &array_cleanup,
       .dst = (void *) denom_hs,
       .fname = name,
       .cls = info
@@ -1544,7 +1574,7 @@ TALER_PQ_result_spec_array_amount (
   {
     struct GNUNET_PQ_ResultSpec res = {
       .conv = extract_array_generic,
-      .cleaner = array_cleanup,
+      .cleaner = &array_cleanup,
       .dst = (void *) amounts,
       .fname = name,
       .cls = info,
@@ -1574,7 +1604,7 @@ TALER_PQ_result_spec_array_hash_code (
   {
     struct GNUNET_PQ_ResultSpec res = {
       .conv = extract_array_generic,
-      .cleaner = array_cleanup,
+      .cleaner = &array_cleanup,
       .dst = (void *) hashes,
       .fname = name,
       .cls = info,
@@ -1585,4 +1615,33 @@ TALER_PQ_result_spec_array_hash_code (
 }
 
 
+struct GNUNET_PQ_ResultSpec
+TALER_PQ_result_spec_array_cs_r_pub (
+  struct GNUNET_PQ_Context *db,
+  const char *name,
+  size_t *num,
+  struct GNUNET_CRYPTO_CSPublicRPairP **cs_r_pubs)
+{
+  struct ArrayResultCls *info = GNUNET_new (struct ArrayResultCls);
+
+  info->num = num;
+  info->typ = TALER_PQ_array_of_cs_r_pub;
+  GNUNET_assert (GNUNET_OK ==
+                 GNUNET_PQ_get_oid_by_name (db,
+                                            "bytea",
+                                            &info->oid));
+  {
+    struct GNUNET_PQ_ResultSpec res = {
+      .conv = extract_array_generic,
+      .cleaner = &array_cleanup,
+      .dst = (void *) cs_r_pubs,
+      .fname = name,
+      .cls = info
+    };
+
+    return res;
+  }
+}
+
+
 /* end of pq_result_helper.c */
