@@ -42,8 +42,9 @@ postgres_prepare (struct GNUNET_PQ_Context *db)
                             ",tamountc"
                             ",hash"
                             ",hashes"
+                            ",cs_r_pubs"
                             ") VALUES "
-                            "($1, $2, $3, $4, $5, $6);"),
+                            "($1, $2, $3, $4, $5, $6, $7);"),
     GNUNET_PQ_make_prepare ("test_select",
                             "SELECT"
                             " tamount"
@@ -52,6 +53,7 @@ postgres_prepare (struct GNUNET_PQ_Context *db)
                             ",tamountc"
                             ",hash"
                             ",hashes"
+                            ",cs_r_pubs"
                             " FROM test_pq;"),
     GNUNET_PQ_PREPARED_STATEMENT_END
   };
@@ -86,6 +88,7 @@ run_queries (struct GNUNET_PQ_Context *conn)
      0xdeadbeaf,0xdeadbeaf,0xdeadbeaf,0xdeadbeaf,
      0xdeadbeaf,0xdeadbeaf,0xdeadbeaf,0xdeadbeaf,
      0xdeadbeaf,0xdeadbeaf,0xdeadbeaf,0xdeadbeaf,}}};
+  struct GNUNET_CRYPTO_CSPublicRPairP in_cs_r_pubs[5];
   json_t *json;
 
   GNUNET_assert (GNUNET_OK ==
@@ -109,6 +112,9 @@ run_queries (struct GNUNET_PQ_Context *conn)
                  json_object_set_new (json,
                                       "foo",
                                       json_integer (42)));
+  GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK,
+                              in_cs_r_pubs,
+                              sizeof(struct GNUNET_CRYPTO_CSPublicRPairP) * 5);
   {
     struct GNUNET_PQ_QueryParam params_insert[] = {
       TALER_PQ_query_param_amount (conn,
@@ -124,6 +130,9 @@ run_queries (struct GNUNET_PQ_Context *conn)
       TALER_PQ_query_param_array_hash_code (2,
                                             hcs,
                                             conn),
+      TALER_PQ_query_param_array_cs_r_pub (5,
+                                           in_cs_r_pubs,
+                                           conn),
       GNUNET_PQ_query_param_end
     };
     PGresult *result;
@@ -131,6 +140,15 @@ run_queries (struct GNUNET_PQ_Context *conn)
     result = GNUNET_PQ_exec_prepared (conn,
                                       "test_insert",
                                       params_insert);
+    for (uint8_t i = 0; i < 5; i++)
+    {
+      printf (" in_cs_r_pubs[%d]=%s\n",
+              i,
+              GNUNET_STRINGS_data_to_string_alloc (
+                &in_cs_r_pubs[i],
+                sizeof(in_cs_r_pubs[i])));
+    }
+
     if (PGRES_COMMAND_OK != PQresultStatus (result))
     {
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
@@ -148,8 +166,10 @@ run_queries (struct GNUNET_PQ_Context *conn)
     struct TALER_Amount *pamount;
     struct GNUNET_HashCode hc2;
     struct GNUNET_HashCode *hcs2;
+    struct GNUNET_CRYPTO_CSPublicRPairP *out_cs_r_pubs;
     size_t npamount;
     size_t nhcs;
+    size_t n_rpubs;
     json_t *json2;
     struct GNUNET_PQ_QueryParam params_select[] = {
       GNUNET_PQ_query_param_end
@@ -173,6 +193,10 @@ run_queries (struct GNUNET_PQ_Context *conn)
                                             "hashes",
                                             &nhcs,
                                             &hcs2),
+      TALER_PQ_result_spec_array_cs_r_pub (conn,
+                                           "cs_r_pubs",
+                                           &n_rpubs,
+                                           &out_cs_r_pubs),
       GNUNET_PQ_result_spec_end
     };
 
@@ -208,6 +232,18 @@ run_queries (struct GNUNET_PQ_Context *conn)
                     GNUNET_memcmp (&hcs[i],
                                    &hcs2[i]));
     }
+    GNUNET_break (5 == n_rpubs);
+    for (uint8_t i = 0; i < 5; i++)
+    {
+      GNUNET_break (0 ==
+                    GNUNET_memcmp (&in_cs_r_pubs[i],
+                                   &out_cs_r_pubs[i]));
+      printf ("out_cs_r_pubs[%d]=%s\n",
+              i,
+              GNUNET_STRINGS_data_to_string_alloc (
+                &out_cs_r_pubs[i],
+                sizeof(out_cs_r_pubs[i])));
+    }
     GNUNET_PQ_cleanup_result (results_select);
   }
   return 0;
@@ -250,6 +286,7 @@ main (int argc,
                             ",tamountc taler_amount_currency"
                             ",hash gnunet_hashcode"
                             ",hashes gnunet_hashcode[]"
+                            ",cs_r_pubs BYTEA[]"
                             ")"),
     GNUNET_PQ_EXECUTE_STATEMENT_END
   };
