@@ -203,6 +203,34 @@ TALER_TEMPLATING_fill (const char *tmpl,
 }
 
 
+int
+TALER_TEMPLATING_fill2 (const void *tmpl,
+                        size_t tmpl_len,
+                        const json_t *root,
+                        void **result,
+                        size_t *result_size)
+{
+  int eno;
+
+  if (0 !=
+      (eno = mustach_jansson_mem (tmpl,
+                                  tmpl_len,
+                                  (json_t *) root,
+                                  Mustach_With_AllExtensions,
+                                  (char **) result,
+                                  result_size)))
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "mustach failed on template with error %d\n",
+                eno);
+    *result = NULL;
+    *result_size = 0;
+    return eno;
+  }
+  return eno;
+}
+
+
 enum GNUNET_GenericReturnValue
 TALER_TEMPLATING_build (struct MHD_Connection *connection,
                         unsigned int *http_status,
