@@ -85,6 +85,7 @@ START_WIREWATCH=0
 START_DEPOSITCHECK=0
 START_MERCHANT_EXCHANGE=0
 START_MERCHANT_WIREWATCH=0
+START_MERCHANT_DONAUKEYUPDATE=0
 USE_ACCOUNT="exchange-account-1"
 USE_VALGRIND=""
 WIRE_DOMAIN="x-taler-bank"
@@ -93,7 +94,7 @@ LOGLEVEL="DEBUG"
 DEFAULT_SLEEP="0.2"
 
 # Parse command-line options
-while getopts ':abc:d:DeEfghkL:mMnr:stu:vwWz' OPTION; do
+while getopts ':abc:d:DeEfghkL:mMnr:stu:vwWzZ' OPTION; do
     case "$OPTION" in
         a)
             START_AUDITOR="1"
@@ -149,6 +150,7 @@ while getopts ':abc:d:DeEfghkL:mMnr:stu:vwWz' OPTION; do
             echo '  -w           -- start taler-exchange-wirewatch'
             echo '  -W           -- wait for signal'
             echo '  -z           -- start taler-merchant-wirewatch'
+            echo '  -Z           -- start taler-merchant-donaukeyupdate'
             exit 0
             ;;
         g)
@@ -194,6 +196,9 @@ while getopts ':abc:d:DeEfghkL:mMnr:stu:vwWz' OPTION; do
         z)
             START_MERCHANT_WIREWATCH="1"
             ;;
+        Z)
+            START_MERCHANT_DONAUKEYUPDATE="1"
+            ;;
         ?)
         exit_fail "Unrecognized command line option"
         ;;
@@ -509,7 +514,9 @@ then
         echo -n " patching master_pub ($MASTER_PUB)..."
         taler-exchange-config -c "$CONF" -s exchange -o MASTER_PUBLIC_KEY -V "$MASTER_PUB"
     fi
-    taler-exchange-dbinit -c "$CONF" --reset
+    taler-exchange-dbinit \
+        -c "$CONF" \
+        --reset
     $USE_VALGRIND taler-exchange-secmod-eddsa \
                   -c "$CONF" \
                   -L "$LOGLEVEL" \
@@ -655,6 +662,14 @@ then
                       -L "$LOGLEVEL" 2> taler-merchant-depositcheck.log &
         echo " DONE"
     fi
+    if [ "1" = "$START_MERCHANT_DONAUKEYUPDATE" ]
+    then
+        echo -n "Starting taler-merchant-donaukeyupdate..."
+        $USE_VALGRIND taler-merchant-donaukeyupdate \
+                      -c "$CONF" \
+                      -L "$LOGLEVEL" 2> taler-merchant-donaukeyupdate.log &
+        echo " DONE"
+    fi
 fi
 
 STAGE="sync"
