@@ -190,9 +190,9 @@ run (void *cls,
     /**
      * Complete (successful) melt operation, and withdraw the coins
      */
-    TALER_TESTING_cmd_refresh_reveal ("refresh-reveal-1",
-                                      "refresh-melt-1",
-                                      MHD_HTTP_OK),
+    TALER_TESTING_cmd_melt_reveal ("refresh-reveal-1",
+                                   "refresh-melt-1",
+                                   MHD_HTTP_OK),
     /**
      * Try to spend a refreshed EUR:0.1 coin
      */
@@ -385,6 +385,7 @@ run (void *cls,
     TALER_TESTING_cmd_end ()
   };
 
+#if FIXME_9828
   struct TALER_TESTING_Command recoup[] = {
     /**
      * Fill reserve with EUR:5.01, as withdraw fee is 1 ct per
@@ -478,7 +479,7 @@ run (void *cls,
                               "EUR:0.5"),
     TALER_TESTING_cmd_end ()
   };
-
+#endif
 
   struct TALER_TESTING_Command massive_deposit_confirms[] = {
 
@@ -678,8 +679,10 @@ run (void *cls,
                              unaggregation),
     TALER_TESTING_cmd_batch ("refund",
                              refund),
+#if FIXME_9828
     TALER_TESTING_cmd_batch ("recoup",
                              recoup),
+#endif
     // CMD_RUN_AUDITOR ("normal-auditor"),
     TALER_TESTING_cmd_end ()
   };
