@@ -145,14 +145,27 @@ run (void *cls,
                                        0, /* age restriction off */
                                        MHD_HTTP_OK),
     /**
-     * Withdraw EUR:1 using the SAME private coin key as for the previous coin
-     * (in violation of the specification, to be detected on spending!).
-     * However, note that this does NOT work with 'CS', as for a different
-     * denomination we get different R0/R1 values from the exchange, and
-     * thus will generate a different coin private key as R0/R1 are hashed
-     * into the coin priv. So here, we fail to 'reuse' the key due to the
-     * cryptographic construction!
+     * Idempotent withdrawal.  Note that in the case of CS, this is _not_
+     * idempotent because the blinding nonces still differ, so instead,
+     * it is an overcharging of the reserve.
      */
+    TALER_TESTING_cmd_withdraw_amount_reuse_key ("withdraw-coin-1-idem",
+                                                 "create-reserve-1",
+                                                 "EUR:5",
+                                                 0, /* age restriction off */
+                                                 "withdraw-coin-1",
+                                                 (uses_cs)
+                                                 ? MHD_HTTP_CONFLICT
+                                                 : MHD_HTTP_OK),
+    /**
+    * Withdraw EUR:1 using the SAME private coin key as for the previous coin
+    * (in violation of the specification, to be detected on spending!).
+    * However, note that this does NOT work with 'CS', as for a different
+    * denomination we get different R0/R1 values from the exchange, and
+    * thus will generate a different coin private key as R0/R1 are hashed
+    * into the coin priv. So here, we fail to 'reuse' the key due to the
+    * cryptographic construction!
+    */
     TALER_TESTING_cmd_withdraw_amount_reuse_key ("withdraw-coin-1x",
                                                  "create-reserve-1",
                                                  "EUR:1",
@@ -344,24 +357,17 @@ run (void *cls,
      * Complete (successful) melt operation, and
      * withdraw the coins
      */
-    TALER_TESTING_cmd_refresh_reveal (
+    TALER_TESTING_cmd_melt_reveal (
       "refresh-reveal-1",
       "refresh-melt-1",
       MHD_HTTP_OK),
     /**
      * Do it again to check idempotency
      */
-    TALER_TESTING_cmd_refresh_reveal (
+    TALER_TESTING_cmd_melt_reveal (
       "refresh-reveal-1-idempotency",
       "refresh-melt-1",
       MHD_HTTP_OK),
-    /**
-     * Test that /refresh/link works
-     */
-    TALER_TESTING_cmd_refresh_link (
-      "refresh-link-1",
-      "refresh-reveal-1",
-      MHD_HTTP_OK),
     /**
      * Try to spend a refreshed EUR:1 coin
      */
@@ -636,24 +642,17 @@ run (void *cls,
      * Complete (successful) melt operation, and
      * withdraw the coins
      */
-    TALER_TESTING_cmd_refresh_reveal (
+    TALER_TESTING_cmd_melt_reveal (
       "refresh-reveal-age-1",
       "refresh-melt-age-1",
       MHD_HTTP_OK),
     /**
      * Do it again to check idempotency
      */
-    TALER_TESTING_cmd_refresh_reveal (
+    TALER_TESTING_cmd_melt_reveal (
       "refresh-reveal-age-1-idempotency",
       "refresh-melt-age-1",
       MHD_HTTP_OK),
-    /**
-     * Test that /refresh/link works
-     */
-    TALER_TESTING_cmd_refresh_link (
-      "refresh-link-age-1",
-      "refresh-reveal-age-1",
-      MHD_HTTP_OK),
     /**
      * Try to spend a refreshed EUR:1 coin
      */
@@ -913,6 +912,7 @@ run (void *cls,
     TALER_TESTING_cmd_end ()
   };
 
+#if FIXME_9828
   struct TALER_TESTING_Command recoup[] = {
     /**
      * Fill reserve with EUR:5.01, as withdraw fee is 1 ct per
@@ -952,7 +952,7 @@ run (void *cls,
       MHD_HTTP_OK,
       "EUR:5",
       NULL),
-    TALER_TESTING_cmd_refresh_reveal (
+    TALER_TESTING_cmd_melt_reveal (
       "recoup-reveal-coin-1b",
       "recoup-melt-coin-1b",
       MHD_HTTP_OK),
@@ -988,7 +988,7 @@ run (void *cls,
       MHD_HTTP_OK,
       "EUR:1",
       NULL),
-    TALER_TESTING_cmd_refresh_reveal (
+    TALER_TESTING_cmd_melt_reveal (
       "recoup-reveal-coin-1a",
       "recoup-remelt-coin-1a",
       MHD_HTTP_OK),
@@ -1217,6 +1217,7 @@ run (void *cls,
 
     TALER_TESTING_cmd_end ()
   };
+#endif
 
   /**
    * Test batch withdrawal plus spending.
@@ -1255,7 +1256,6 @@ run (void *cls,
     TALER_TESTING_cmd_batch_withdraw (
       "batch-withdraw-coin-1",
       "create-batch-reserve-1",
-      0,                                  /* age restriction off */
       MHD_HTTP_OK,
       "EUR:5",
       "EUR:1",
@@ -1366,8 +1366,10 @@ run (void *cls,
                                refund),
       TALER_TESTING_cmd_batch ("batch-withdraw",
                                batch_withdraw),
+#if FIXME_9828
       TALER_TESTING_cmd_batch ("recoup",
                                recoup),
+#endif
       TALER_TESTING_cmd_batch ("reserve-open-close",
                                reserve_open_close),
       /* End the suite. */
