@@ -136,6 +136,16 @@ run (void *cls,
       "EUR:5",
       13,
       MHD_HTTP_OK),
+    /**
+     * Idempotent withdrawal.
+     */
+    TALER_TESTING_cmd_withdraw_amount_reuse_all_secrets (
+      "withdraw-coin-age-idem-1",
+      "create-reserve-age",
+      "EUR:5",
+      13,
+      "withdraw-coin-age-1",
+      MHD_HTTP_OK),
 
     TALER_TESTING_cmd_end ()
   };
@@ -235,24 +245,17 @@ run (void *cls,
      * Complete (successful) melt operation, and
      * withdraw the coins
      */
-    TALER_TESTING_cmd_refresh_reveal (
+    TALER_TESTING_cmd_melt_reveal (
       "refresh-reveal-age-1",
       "refresh-melt-age-1",
       MHD_HTTP_OK),
     /**
      * Do it again to check idempotency
      */
-    TALER_TESTING_cmd_refresh_reveal (
+    TALER_TESTING_cmd_melt_reveal (
       "refresh-reveal-age-1-idempotency",
       "refresh-melt-age-1",
       MHD_HTTP_OK),
-    /**
-     * Test that /refresh/link works
-     */
-    TALER_TESTING_cmd_refresh_link (
-      "refresh-link-age-1",
-      "refresh-reveal-age-1",
-      MHD_HTTP_OK),
     /**
      * Try to spend a refreshed EUR:1 coin
      */
@@ -349,23 +352,23 @@ run (void *cls,
       "EUR:10",
       0,   /* age restriction off */
       MHD_HTTP_CONFLICT),
-    TALER_TESTING_cmd_age_withdraw (
+    TALER_TESTING_cmd_withdraw_with_age_proof (
       "age-withdraw-coin-1-too-low",
       "create-reserve-kyc-1",
       18,      /* Too high */
       MHD_HTTP_CONFLICT,
       "EUR:10",
       NULL),
-    TALER_TESTING_cmd_age_withdraw (
+    TALER_TESTING_cmd_withdraw_with_age_proof (
       "age-withdraw-coins-1",
       "create-reserve-kyc-1",
       8,
-      MHD_HTTP_OK,
+      MHD_HTTP_CREATED,
       "EUR:10",
       "EUR:10",
       "EUR:5",
       NULL),
-    TALER_TESTING_cmd_age_withdraw_reveal (
+    TALER_TESTING_cmd_withdraw_reveal_age_proof (
       "age-withdraw-coins-reveal-1",
       "age-withdraw-coins-1",
       MHD_HTTP_OK),
