@@ -117,31 +117,31 @@ run (void *cls,
                                     MHD_HTTP_NO_CONTENT,
                                     false),
     TALER_TESTING_cmd_wire_add ("add-wire-account",
-                                "payto://x-taler-bank/localhost/42?receiver-name=42",
+                                cred.user42_payto,
                                 MHD_HTTP_NO_CONTENT,
                                 false),
     TALER_TESTING_cmd_wire_add ("add-wire-account-idempotent",
-                                "payto://x-taler-bank/localhost/42?receiver-name=42",
+                                cred.user42_payto,
                                 MHD_HTTP_NO_CONTENT,
                                 false),
     TALER_TESTING_cmd_wire_add ("add-wire-account-another",
-                                "payto://x-taler-bank/localhost/43?receiver-name=43",
+                                cred.user43_payto,
                                 MHD_HTTP_NO_CONTENT,
                                 false),
     TALER_TESTING_cmd_wire_add ("add-wire-account-bad-signature",
-                                "payto://x-taler-bank/localhost/44?receiver-name=44",
+                                cred.user44_payto,
                                 MHD_HTTP_FORBIDDEN,
                                 true),
     TALER_TESTING_cmd_wire_del ("del-wire-account-not-found",
-                                "payto://x-taler-bank/localhost/44?receiver-name=44",
+                                cred.user44_payto,
                                 MHD_HTTP_NOT_FOUND,
                                 false),
     TALER_TESTING_cmd_wire_del ("del-wire-account-bad-signature",
-                                "payto://x-taler-bank/localhost/43?receiver-name=43",
+                                cred.user43_payto,
                                 MHD_HTTP_FORBIDDEN,
                                 true),
     TALER_TESTING_cmd_wire_del ("del-wire-account-ok",
-                                "payto://x-taler-bank/localhost/43?receiver-name=43",
+                                cred.user43_payto,
                                 MHD_HTTP_NO_CONTENT,
                                 false),
     TALER_TESTING_cmd_exec_offline_sign_keys ("download-future-keys",
