@@ -121,15 +121,25 @@ run (void *cls,
       MHD_HTTP_OK),
     TALER_TESTING_cmd_end ()
   };
+
   /**
    * Test withdraw with KYC.
    */
   struct TALER_TESTING_Command withdraw_kyc[] = {
-    CMD_EXEC_WIREWATCH ("wirewatch-1"),
+    CMD_TRANSFER_TO_EXCHANGE (
+      "create-reserve-kyc",
+      "EUR:15.02"),
+    TALER_TESTING_cmd_check_bank_admin_transfer (
+      "check-create-reserve-kyc",
+      "EUR:15.02",
+      cred.user42_payto,
+      cred.exchange_payto,
+      "create-reserve-kyc"),
+    CMD_EXEC_WIREWATCH ("wirewatch-kyc"),
     TALER_TESTING_cmd_withdraw_amount (
       "withdraw-coin-1-lacking-kyc",
-      "create-reserve-1",
-      "EUR:5",
+      "create-reserve-kyc",
+      "EUR:10",
       0,     /* age restriction off */
       MHD_HTTP_UNAVAILABLE_FOR_LEGAL_REASONS),
     TALER_TESTING_cmd_admin_add_kycauth (
@@ -161,27 +171,22 @@ run (void *cls,
       "test-oauth2",
       "pass",
       MHD_HTTP_SEE_OTHER),
-#if FIXME_OEC
-    TALER_TESTING_cmd_withdraw_amount (
-      "withdraw-coin-1-with-kyc",
-      "create-reserve-1",
-      "EUR:5",
-      0, /* age restriction off -- also fails with other values! */
-      MHD_HTTP_OK),
-#else
-    TALER_TESTING_cmd_age_withdraw (
-      "withdraw-coin-1-with-kyc",
-      "create-reserve-1",
+    TALER_TESTING_cmd_withdraw_with_age_proof (
+      "age-withdraw-coin-1-with-kyc",
+      "create-reserve-kyc",
       1,
-      MHD_HTTP_OK,
+      MHD_HTTP_CREATED,
       "EUR:5",
       NULL),
-#endif
+    TALER_TESTING_cmd_withdraw_reveal_age_proof (
+      "reveal-age-withdraw-coin-1-with-kyc",
+      "age-withdraw-coin-1-with-kyc",
+      MHD_HTTP_OK),
     /* Attestations above are bound to the originating *bank* account,
        not to the reserve (!). Hence, they are NOT found here! */
     TALER_TESTING_cmd_reserve_get_attestable (
       "reserve-get-attestable",
-      "create-reserve-1",
+      "create-reserve-kyc",
       MHD_HTTP_NOT_FOUND,
       NULL),
     TALER_TESTING_cmd_end ()
@@ -230,6 +235,7 @@ run (void *cls,
     TALER_TESTING_cmd_end ()
   };
 
+
   struct TALER_TESTING_Command track[] = {
     CMD_EXEC_AGGREGATOR ("run-aggregator-before-kyc"),
     TALER_TESTING_cmd_check_bank_empty (
@@ -764,8 +770,8 @@ run (void *cls,
       "wallet-post-kyc-form",
       "get-kyc-info-form",
       0,  /* requirement index */
-      "application/x-www-form-urlencoded",
-      "full_name=Bob&birthdate=1990-00-00",
+      "application/json",
+      "{\"form_id\":\"test\",\"full_name\":\"Bob\",\"birthdate\":\"1990-00-00\"}",
       MHD_HTTP_NO_CONTENT),
     /* now this should be allowed */
     TALER_TESTING_cmd_wallet_kyc_get (
