@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2023, 2024 Taler Systems SA
+  Copyright (C) 2023-2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 */
 /**
  * @file testing/testing_api_cmd_age_withdraw.c
- * @brief implements the age-withdraw command
+ * @brief implements the withdraw command for age-restricted coins
  * @author Özgür Kesim
  */
 
@@ -39,20 +39,15 @@ struct CoinOutputState
 {
 
   /**
-   * The calculated details during "age-withdraw", for the selected coin.
+   * The calculated details during "withdraw", for the selected coin.
    */
-  struct TALER_EXCHANGE_AgeWithdrawCoinPrivateDetails details;
+  struct TALER_EXCHANGE_WithdrawCoinPrivateDetails details;
 
   /**
    * The (wanted) value of the coin, MUST be the same as input.denom_pub.value;
    */
   struct TALER_Amount amount;
 
-  /**
-   * Reserve history entry that corresponds to this coin.
-   * Will be of type #TALER_EXCHANGE_RTT_AGEWITHDRAWAL.
-   */
-  struct TALER_EXCHANGE_ReserveHistoryEntry reserve_history;
 };
 
 /**
@@ -70,7 +65,7 @@ struct AgeWithdrawState
   /**
    * The age-withdraw handle
    */
-  struct TALER_EXCHANGE_AgeWithdrawHandle *handle;
+  struct TALER_EXCHANGE_WithdrawHandle *handle;
 
   /**
    * Exchange base URL.  Only used as offered trait.
@@ -118,12 +113,26 @@ struct AgeWithdrawState
   size_t num_coins;
 
   /**
-   * The @e num_coins input that is provided to the
-   * `TALER_EXCHANGE_age_withdraw` API.
-   * Each contains kappa secrets, from which we will have
-   * to disclose kappa-1 in a subsequent age-withdraw-reveal operation.
+   * The @e num_coins denomination public keys that are provided
+   * to the `TALER_EXCHANGE_withdraw_with_age_proof` API.
    */
-  struct TALER_EXCHANGE_AgeWithdrawCoinInput *coin_inputs;
+  struct TALER_EXCHANGE_DenomPublicKey *denoms_pub;
+
+
+  /**
+   * The master seed from which all the other seeds are derived from
+   */
+  struct TALER_WithdrawMasterSeedP seed;
+
+  /**
+   * The #TALER_CNC_KAPPA seeds derived from @e seed
+   */
+  struct TALER_KappaWithdrawMasterSeedP kappa_seed;
+
+  /**
+   * The master seed from which all the other seeds are derived from
+   */
+  struct TALER_BlindingMasterSeedP blinding_seed;
 
   /**
    * The output state of @e num_coins coins, calculated during the
@@ -137,15 +146,15 @@ struct AgeWithdrawState
    */
   uint8_t noreveal_index;
 
-  /**
-   * The blinded hashes of the non-revealed (to keep) @e num_coins coins.
-   */
-  const struct TALER_BlindedCoinHashP *blinded_coin_hs;
-
   /**
    * The hash of the commitment, needed for the reveal step.
    */
-  struct TALER_AgeWithdrawCommitmentHashP h_commitment;
+  struct TALER_HashBlindedPlanchetsP planchets_h;
+
+  /**
+     *  The hash of the selected blinded planchets
+     */
+  struct TALER_HashBlindedPlanchetsP selected_h;
 
   /**
    * Set to the KYC requirement payto hash *if* the exchange replied with a
@@ -159,6 +168,11 @@ struct AgeWithdrawState
    */
   uint64_t requirement_row;
 
+  /**
+   * Reserve history entry that corresponds to this withdraw.
+   * Will be of type #TALER_EXCHANGE_RTT_WITHDRAWAL.
+   */
+  struct TALER_EXCHANGE_ReserveHistoryEntry reserve_history;
 };
 
 /**
@@ -171,7 +185,7 @@ struct AgeWithdrawState
 static void
 age_withdraw_cb (
   void *cls,
-  const struct TALER_EXCHANGE_AgeWithdrawResponse *response)
+  const struct TALER_EXCHANGE_WithdrawResponse *response)
 {
   struct AgeWithdrawState *aws = cls;
   struct TALER_TESTING_Interpreter *is = aws->is;
@@ -188,22 +202,26 @@ age_withdraw_cb (
 
   switch (response->hr.http_status)
   {
-  case MHD_HTTP_OK:
-    aws->noreveal_index = response->details.ok.noreveal_index;
-    aws->h_commitment = response->details.ok.h_commitment;
+  case MHD_HTTP_CREATED:
+    aws->noreveal_index = response->details.created.noreveal_index;
+    aws->planchets_h = response->details.created.planchets_h;
+    aws->selected_h = response->details.created.selected_h;
+    aws->reserve_history.details.withdraw.planchets_h = aws->planchets_h;
+    aws->reserve_history.details.withdraw.selected_h = aws->selected_h;
+    aws->reserve_history.details.withdraw.noreveal_index = aws->noreveal_index;
+    aws->kappa_seed = response->details.created.kappa_seed;
 
-    GNUNET_assert (aws->num_coins == response->details.ok.num_coins);
+    GNUNET_assert (aws->num_coins == response->details.created.num_coins);
     for (size_t n = 0; n < aws->num_coins; n++)
     {
-      aws->coin_outputs[n].details = response->details.ok.coin_details[n];
+      aws->coin_outputs[n].details = response->details.created.coin_details[n];
       TALER_age_commitment_proof_deep_copy (
         &aws->coin_outputs[n].details.age_commitment_proof,
-        &response->details.ok.coin_details[n].age_commitment_proof);
+        &response->details.created.coin_details[n].age_commitment_proof);
       TALER_denom_ewv_copy (
-        &aws->coin_outputs[n].details.alg_values,
-        &response->details.ok.coin_details[n].alg_values);
+        &aws->coin_outputs[n].details.blinding_values,
+        &response->details.created.coin_details[n].blinding_values);
     }
-    aws->blinded_coin_hs = response->details.ok.blinded_coin_hs;
     break;
   case MHD_HTTP_FORBIDDEN:
   case MHD_HTTP_NOT_FOUND:
@@ -277,19 +295,18 @@ age_withdraw_run (
     = TALER_reserve_make_payto (aws->exchange_url,
                                 &aws->reserve_pub);
 
-  aws->coin_inputs = GNUNET_new_array (
-    aws->num_coins,
-    struct TALER_EXCHANGE_AgeWithdrawCoinInput);
+  aws->denoms_pub = GNUNET_new_array (aws->num_coins,
+                                      struct TALER_EXCHANGE_DenomPublicKey);
+
+  GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK,
+                              &aws->seed,
+                              sizeof(aws->seed));
 
   for (unsigned int i = 0; i<aws->num_coins; i++)
   {
-    struct TALER_EXCHANGE_AgeWithdrawCoinInput *input = &aws->coin_inputs[i];
+    struct TALER_EXCHANGE_DenomPublicKey *denom_pub = &aws->denoms_pub[i];
     struct CoinOutputState *cos = &aws->coin_outputs[i];
 
-    /* randomly create the secrets for the kappa coin-candidates */
-    GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK,
-                                &input->secrets,
-                                sizeof(input->secrets));
     /* Find denomination */
     dpk = TALER_TESTING_find_pk (keys,
                                  &cos->amount,
@@ -303,26 +320,46 @@ age_withdraw_run (
       TALER_TESTING_interpreter_fail (is);
       return;
     }
+
     /* We copy the denomination key, as re-querying /keys
      * would free the old one. */
-    input->denom_pub = TALER_EXCHANGE_copy_denomination_key (dpk);
-    cos->reserve_history.type = TALER_EXCHANGE_RTT_AGEWITHDRAWAL;
-    GNUNET_assert (0 <=
-                   TALER_amount_add (&cos->reserve_history.amount,
-                                     &cos->amount,
-                                     &input->denom_pub->fees.withdraw));
-    cos->reserve_history.details.withdraw.fee = input->denom_pub->fees.withdraw;
-  }
+    *denom_pub = *dpk;
+    TALER_denom_pub_copy (&denom_pub->key,
+                          &dpk->key);
 
-  /* Execute the age-withdraw protocol */
+    /* Accumulate the expected total amount and fee for the history */
+    GNUNET_assert (0 <=
+                   TALER_amount_add (&aws->reserve_history.amount,
+                                     &cos->amount,
+                                     &denom_pub->fees.withdraw));
+    if (i == 0)
+      GNUNET_assert (GNUNET_OK ==
+                     TALER_amount_set_zero (
+                       denom_pub->fees.withdraw.currency,
+                       &aws->reserve_history.details.withdraw.fee));
+
+    GNUNET_assert (0 <=
+                   TALER_amount_add (&aws->reserve_history.details.withdraw.fee,
+                                     &aws->reserve_history.details.withdraw.fee,
+                                     &denom_pub->fees.withdraw));
+
+  }
+  /* Save the expected history entry */
+  aws->reserve_history.type = TALER_EXCHANGE_RTT_WITHDRAWAL;
+  aws->reserve_history.details.withdraw.age_restricted = true;
+  aws->reserve_history.details.withdraw.max_age = aws->max_age;
+
+
+  /* Execute the age-restricted variant of withdraw protocol */
   aws->handle =
-    TALER_EXCHANGE_age_withdraw (
+    TALER_EXCHANGE_withdraw_with_age_proof (
       TALER_TESTING_interpreter_get_context (is),
       keys,
       TALER_TESTING_get_exchange_url (is),
       rp,
       aws->num_coins,
-      aws->coin_inputs,
+      aws->denoms_pub,
+      &aws->seed,
       aws->max_age,
       &age_withdraw_cb,
       aws);
@@ -354,33 +391,35 @@ age_withdraw_cleanup (
   {
     TALER_TESTING_command_incomplete (aws->is,
                                       cmd->label);
-    TALER_EXCHANGE_age_withdraw_cancel (aws->handle);
+    TALER_EXCHANGE_withdraw_cancel (aws->handle);
     aws->handle = NULL;
   }
 
-  if (NULL != aws->coin_inputs)
+  if (NULL != aws->denoms_pub)
+  {
+    for (size_t n = 0; n < aws->num_coins; n++)
+      TALER_denom_pub_free (&aws->denoms_pub[n].key);
+
+    GNUNET_free (aws->denoms_pub);
+    aws->denoms_pub = NULL;
+  }
+
+  if (NULL != aws->coin_outputs)
   {
     for (size_t n = 0; n < aws->num_coins; n++)
     {
-      struct TALER_EXCHANGE_AgeWithdrawCoinInput *in = &aws->coin_inputs[n];
       struct CoinOutputState *out = &aws->coin_outputs[n];
-
-      if (NULL != in && NULL != in->denom_pub)
-      {
-        TALER_EXCHANGE_destroy_denomination_key (in->denom_pub);
-        in->denom_pub = NULL;
-      }
-      if (NULL != out)
-      {
-        TALER_age_commitment_proof_free (&out->details.age_commitment_proof);
-        TALER_denom_ewv_free (&out->details.alg_values);
-      }
+      TALER_age_commitment_proof_free (&out->details.age_commitment_proof);
+      TALER_denom_ewv_free (&out->details.blinding_values);
     }
-    GNUNET_free (aws->coin_inputs);
+    GNUNET_free (aws->coin_outputs);
+    aws->coin_outputs = NULL;
   }
-  GNUNET_free (aws->coin_outputs);
+
   GNUNET_free (aws->exchange_url);
+  aws->exchange_url  = NULL;
   GNUNET_free (aws->reserve_payto_uri.normalized_payto);
+  aws->reserve_payto_uri.normalized_payto = NULL;
   GNUNET_free (aws);
 }
 
@@ -402,37 +441,37 @@ age_withdraw_traits (
   unsigned int idx)
 {
   struct AgeWithdrawState *aws = cls;
-  uint8_t k = aws->noreveal_index;
-  struct TALER_EXCHANGE_AgeWithdrawCoinInput *in = &aws->coin_inputs[idx];
   struct CoinOutputState *out = &aws->coin_outputs[idx];
-  struct TALER_EXCHANGE_AgeWithdrawCoinPrivateDetails *details =
+  struct TALER_EXCHANGE_WithdrawCoinPrivateDetails *details =
     &aws->coin_outputs[idx].details;
   struct TALER_TESTING_Trait traits[] = {
     /* history entry MUST be first due to response code logic below! */
     TALER_TESTING_make_trait_reserve_history (idx,
-                                              &out->reserve_history),
+                                              &aws->reserve_history),
     TALER_TESTING_make_trait_denom_pub (idx,
-                                        in->denom_pub),
+                                        &aws->denoms_pub[idx]),
     TALER_TESTING_make_trait_reserve_priv (&aws->reserve_priv),
     TALER_TESTING_make_trait_reserve_pub (&aws->reserve_pub),
+    TALER_TESTING_make_trait_withdraw_commitment (&aws->planchets_h),
     TALER_TESTING_make_trait_amounts (idx,
                                       &out->amount),
     /* FIXME[oec]: add legal requirement to response and handle it here, as well
     TALER_TESTING_make_trait_legi_requirement_row (&aws->requirement_row),
     TALER_TESTING_make_trait_h_payto (&aws->h_payto),
     */
-    TALER_TESTING_make_trait_h_blinded_coin (idx,
-                                             &aws->blinded_coin_hs[idx]),
     TALER_TESTING_make_trait_normalized_payto_uri (&aws->reserve_payto_uri),
     TALER_TESTING_make_trait_exchange_url (aws->exchange_url),
     TALER_TESTING_make_trait_coin_priv (idx,
                                         &details->coin_priv),
+    TALER_TESTING_make_trait_withdraw_seed (&aws->seed),
+    /* FIXME[oec]: needed!?
     TALER_TESTING_make_trait_planchet_secrets (idx,
-                                               &in->secrets[k]),
+                                               &aws->secrets[k][idx]),
+    */
     TALER_TESTING_make_trait_blinding_key (idx,
                                            &details->blinding_key),
-    TALER_TESTING_make_trait_exchange_wd_value (idx,
-                                                &details->alg_values),
+    TALER_TESTING_make_trait_exchange_blinding_values (idx,
+                                                       &details->blinding_values),
     TALER_TESTING_make_trait_age_commitment_proof (
       idx,
       &details->age_commitment_proof),
@@ -455,12 +494,13 @@ age_withdraw_traits (
 
 
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_age_withdraw (const char *label,
-                                const char *reserve_reference,
-                                uint8_t max_age,
-                                unsigned int expected_response_code,
-                                const char *amount,
-                                ...)
+TALER_TESTING_cmd_withdraw_with_age_proof (const char *label,
+                                           const char *reserve_reference,
+                                           uint8_t max_age,
+                                           unsigned int
+                                           expected_response_code,
+                                           const char *amount,
+                                           ...)
 {
   struct AgeWithdrawState *aws;
   unsigned int cnt;
@@ -519,7 +559,7 @@ TALER_TESTING_cmd_age_withdraw (const char *label,
 /**
  * The state for the age-withdraw-reveal operation
  */
-struct AgeWithdrawRevealState
+struct AgeRevealWithdrawState
 {
   /**
    * The reference to the CMD resembling the previous call to age-withdraw
@@ -545,7 +585,7 @@ struct AgeWithdrawRevealState
   /**
    * The handle to the reveal-operation
    */
-  struct TALER_EXCHANGE_AgeWithdrawRevealHandle *handle;
+  struct TALER_EXCHANGE_RevealWithdrawHandle *handle;
 
 
   /**
@@ -564,15 +604,15 @@ struct AgeWithdrawRevealState
 /**
  * Callback for the reveal response
  *
- * @param cls Closure of type `struct AgeWithdrawRevealState`
+ * @param cls Closure of type `struct AgeRevealWithdrawState`
  * @param response The response
  */
 static void
-age_withdraw_reveal_cb (
+age_reveal_withdraw_cb (
   void *cls,
-  const struct TALER_EXCHANGE_AgeWithdrawRevealResponse *response)
+  const struct TALER_EXCHANGE_RevealWithdrawResponse *response)
 {
-  struct AgeWithdrawRevealState *awrs = cls;
+  struct AgeRevealWithdrawState *awrs = cls;
   struct TALER_TESTING_Interpreter *is = awrs->is;
 
   awrs->handle = NULL;
@@ -600,8 +640,8 @@ age_withdraw_reveal_cb (
                          &response->details.ok.blinded_denom_sigs[n],
                          &aws->coin_outputs[n].details.blinding_key,
                          &aws->coin_outputs[n].details.h_coin_pub,
-                         &aws->coin_outputs[n].details.alg_values,
-                         &aws->coin_inputs[n].denom_pub->key));
+                         &aws->coin_outputs[n].details.blinding_values,
+                         &aws->denoms_pub[n].key));
         TALER_denom_sig_free (&awrs->denom_sigs[n]);
       }
 
@@ -633,12 +673,12 @@ age_withdraw_reveal_cb (
  * Run the command for age-withdraw-reveal
  */
 static void
-age_withdraw_reveal_run (
+age_reveal_withdraw_run (
   void *cls,
   const struct TALER_TESTING_Command *cmd,
   struct TALER_TESTING_Interpreter *is)
 {
-  struct AgeWithdrawRevealState *awrs = cls;
+  struct AgeRevealWithdrawState *awrs = cls;
   const struct TALER_TESTING_Command *age_withdraw_cmd;
   const struct AgeWithdrawState *aws;
 
@@ -662,17 +702,28 @@ age_withdraw_reveal_run (
   awrs->aws = aws;
   awrs->num_coins = aws->num_coins;
 
-  awrs->handle =
-    TALER_EXCHANGE_age_withdraw_reveal (
-      TALER_TESTING_interpreter_get_context (is),
-      TALER_TESTING_get_exchange_url (is),
-      aws->num_coins,
-      aws->coin_inputs,
-      aws->noreveal_index,
-      &aws->h_commitment,
-      &aws->reserve_pub,
-      age_withdraw_reveal_cb,
-      awrs);
+  {
+    struct TALER_RevealWithdrawMasterSeedsP revealed_seeds;
+    size_t j = 0;
+    for (uint8_t k = 0; k < TALER_CNC_KAPPA; k++)
+    {
+      if (aws->noreveal_index == k)
+        continue;
+
+      revealed_seeds.tuple[j] = aws->kappa_seed.tuple[k];
+      j++;
+    }
+
+    awrs->handle =
+      TALER_EXCHANGE_reveal_withdraw (
+        TALER_TESTING_interpreter_get_context (is),
+        TALER_TESTING_get_exchange_url (is),
+        aws->num_coins,
+        &aws->planchets_h,
+        &revealed_seeds,
+        age_reveal_withdraw_cb,
+        awrs);
+  }
 }
 
 
@@ -680,21 +731,21 @@ age_withdraw_reveal_run (
  * Free the state of a "age-withdraw-reveal" CMD, and possibly
  * cancel a pending operation thereof
  *
- * @param cls Closure of type `struct AgeWithdrawRevealState`
+ * @param cls Closure of type `struct AgeRevealWithdrawState`
  * @param cmd The command being freed.
  */
 static void
-age_withdraw_reveal_cleanup (
+age_reveal_withdraw_cleanup (
   void *cls,
   const struct TALER_TESTING_Command *cmd)
 {
-  struct AgeWithdrawRevealState *awrs = cls;
+  struct AgeRevealWithdrawState *awrs = cls;
 
   if (NULL != awrs->handle)
   {
     TALER_TESTING_command_incomplete (awrs->is,
                                       cmd->label);
-    TALER_EXCHANGE_age_withdraw_reveal_cancel (awrs->handle);
+    TALER_EXCHANGE_reveal_withdraw_cancel (awrs->handle);
     awrs->handle = NULL;
   }
   GNUNET_free (awrs->denom_sigs);
@@ -706,20 +757,20 @@ age_withdraw_reveal_cleanup (
 /**
  * Offer internal data of a "age withdraw reveal" CMD state to other commands.
  *
- * @param cls Closure of they `struct AgeWithdrawRevealState`
+ * @param cls Closure of they `struct AgeRevealWithdrawState`
  * @param[out] ret result (could be anything)
  * @param trait name of the trait
  * @param idx index number of the object to offer.
  * @return #GNUNET_OK on success
  */
 static enum GNUNET_GenericReturnValue
-age_withdraw_reveal_traits (
+age_reveal_withdraw_traits (
   void *cls,
   const void **ret,
   const char *trait,
   unsigned int idx)
 {
-  struct AgeWithdrawRevealState *awrs = cls;
+  struct AgeRevealWithdrawState *awrs = cls;
   struct TALER_TESTING_Trait traits[] = {
     TALER_TESTING_make_trait_denom_sig (idx,
                                         &awrs->denom_sigs[idx]),
@@ -739,13 +790,13 @@ age_withdraw_reveal_traits (
 
 
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_age_withdraw_reveal (
+TALER_TESTING_cmd_withdraw_reveal_age_proof (
   const char *label,
   const char *age_withdraw_reference,
   unsigned int expected_response_code)
 {
-  struct AgeWithdrawRevealState *awrs =
-    GNUNET_new (struct AgeWithdrawRevealState);
+  struct AgeRevealWithdrawState *awrs =
+    GNUNET_new (struct AgeRevealWithdrawState);
 
   awrs->age_withdraw_reference = age_withdraw_reference;
   awrs->expected_response_code = expected_response_code;
@@ -753,9 +804,9 @@ TALER_TESTING_cmd_age_withdraw_reveal (
     struct TALER_TESTING_Command cmd = {
       .cls = awrs,
       .label = label,
-      .run = age_withdraw_reveal_run,
-      .cleanup = age_withdraw_reveal_cleanup,
-      .traits = age_withdraw_reveal_traits,
+      .run = age_reveal_withdraw_run,
+      .cleanup = age_reveal_withdraw_cleanup,
+      .traits = age_reveal_withdraw_traits,
     };
 
     return cmd;
