@@ -62,15 +62,15 @@ struct AuditorAddState
  * if the response code is acceptable.
  *
  * @param cls closure.
- * @param aer response details
+ * @param r response details
  */
 static void
 auditor_add_cb (
   void *cls,
-  const struct TALER_EXCHANGE_ManagementAuditorEnableResponse *aer)
+  const struct TALER_EXCHANGE_ManagementAuditorEnableResponse *r)
 {
   struct AuditorAddState *ds = cls;
-  const struct TALER_EXCHANGE_HttpResponse *hr = &aer->hr;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &r->hr;
 
   ds->dh = NULL;
   if (ds->expected_response_code != hr->http_status)
