@@ -469,6 +469,9 @@ batch_deposit_run (void *cls,
       .refund_deadline = ds->refund_deadline
     };
 
+    TALER_merchant_contract_sign (&h_contract_terms,
+                                  &ds->account_priv.merchant_priv,
+                                  &dcd.merchant_sig);
     ds->dh = TALER_EXCHANGE_batch_deposit (
       TALER_TESTING_interpreter_get_context (is),
       exchange_url,
@@ -550,7 +553,10 @@ batch_deposit_traits (void *cls,
 
   if (index >= ds->num_coins)
   {
-    GNUNET_break (0);
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "[batch_deposit_traits] asked for index #%u while num_coins is #%u\n",
+                index,
+                ds->num_coins);
     return GNUNET_NO;
   }
   if (NULL == coin->coin_cmd)
