@@ -237,6 +237,10 @@ analyze_command (void *cls,
     struct TALER_TESTING_Command *cur;
     struct TALER_TESTING_Command *bcmd;
 
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Checking `%s' for history of coin `%s'\n",
+                cmd->label,
+                TALER_B2S (coin_pub));
     cur = TALER_TESTING_cmd_batch_get_current (cmd);
     if (GNUNET_OK !=
         TALER_TESTING_get_trait_batch_cmds (cmd,
@@ -255,7 +259,7 @@ analyze_command (void *cls,
       if (ac->failure)
       {
         GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                    "Entry for batch step `%s' missing in history\n",
+                    "Entry for batch step `%s' missing in coin history\n",
                     step->label);
         return;
       }
@@ -287,9 +291,10 @@ analyze_command (void *cls,
                        coin_pub))
     {
       GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                  "Command `%s#%u' is about another coin\n",
+                  "Command `%s#%u' is about another coin %s\n",
                   cmd->label,
-                  j);
+                  j,
+                  TALER_B2S (rp));
       continue; /* command affects some _other_ coin */
     }
     if (GNUNET_OK !=
@@ -547,7 +552,7 @@ history_traits (void *cls,
 {
   struct HistoryState *hs = cls;
   struct TALER_TESTING_Trait traits[] = {
-    TALER_TESTING_make_trait_coin_pub (0,
+    TALER_TESTING_make_trait_coin_pub (index,
                                        &hs->coin_pub),
     TALER_TESTING_trait_end ()
   };
