@@ -458,25 +458,45 @@ deposit_run (void *cls,
               stderr,
               JSON_INDENT (2));
 #endif
-  if ( (GNUNET_OK !=
-        TALER_TESTING_get_trait_coin_priv (coin_cmd,
-                                           ds->coin_index,
-                                           &coin_priv)) ||
-       (GNUNET_OK !=
-        TALER_TESTING_get_trait_h_age_commitment (coin_cmd,
-                                                  ds->coin_index,
-                                                  &phac)) ||
-       (GNUNET_OK !=
-        TALER_TESTING_get_trait_denom_pub (coin_cmd,
-                                           ds->coin_index,
-                                           &ds->denom_pub)) ||
-       (GNUNET_OK !=
-        TALER_TESTING_get_trait_denom_sig (coin_cmd,
-                                           ds->coin_index,
-                                           &denom_pub_sig)) ||
-       (GNUNET_OK !=
-        TALER_JSON_contract_hash (ds->contract_terms,
-                                  &h_contract_terms)) )
+  if (GNUNET_OK !=
+      TALER_TESTING_get_trait_coin_priv (coin_cmd,
+                                         ds->coin_index,
+                                         &coin_priv))
+  {
+    GNUNET_break (0);
+    TALER_TESTING_interpreter_fail (is);
+    return;
+  }
+  if (GNUNET_OK !=
+      TALER_TESTING_get_trait_h_age_commitment (coin_cmd,
+                                                ds->coin_index,
+                                                &phac))
+  {
+    GNUNET_break (0);
+    TALER_TESTING_interpreter_fail (is);
+    return;
+  }
+  if (GNUNET_OK !=
+      TALER_TESTING_get_trait_denom_pub (coin_cmd,
+                                         ds->coin_index,
+                                         &ds->denom_pub))
+  {
+    GNUNET_break (0);
+    TALER_TESTING_interpreter_fail (is);
+    return;
+  }
+  if (GNUNET_OK !=
+      TALER_TESTING_get_trait_denom_sig (coin_cmd,
+                                         ds->coin_index,
+                                         &denom_pub_sig))
+  {
+    GNUNET_break (0);
+    TALER_TESTING_interpreter_fail (is);
+    return;
+  }
+  if (GNUNET_OK !=
+      TALER_JSON_contract_hash (ds->contract_terms,
+                                &h_contract_terms))
   {
     GNUNET_break (0);
     TALER_TESTING_interpreter_fail (is);
@@ -539,6 +559,9 @@ deposit_run (void *cls,
       .refund_deadline = ds->refund_deadline
     };
 
+    TALER_merchant_contract_sign (&h_contract_terms,
+                                  &ds->account_priv.merchant_priv,
+                                  &dcd.merchant_sig);
     if (NULL != phac)
       cdd.h_age_commitment = *phac;
 
@@ -616,8 +639,8 @@ deposit_traits (void *cls,
   /* Will point to coin cmd internals. */
   const struct TALER_CoinSpendPrivateKeyP *coin_spent_priv;
   struct TALER_CoinSpendPublicKeyP coin_spent_pub;
-  const struct TALER_AgeCommitmentProof *age_commitment_proof;
-  const struct TALER_AgeCommitmentHash *h_age_commitment;
+  const struct TALER_AgeCommitmentProof *age_commitment_proof=NULL;
+  const struct TALER_AgeCommitmentHash *h_age_commitment=NULL;
 
   if (! ds->command_initialized)
   {
