@@ -199,6 +199,16 @@ insert_deposit_run (void *cls,
                        strlen (ids->merchant_name),
                        NULL,
                        0));
+  GNUNET_assert (
+    GNUNET_YES ==
+    GNUNET_CRYPTO_kdf (&bd.merchant_sig,
+                       sizeof (struct TALER_MerchantSignatureP),
+                       "merchant-sig",
+                       strlen ("merchant-sig"),
+                       ids->merchant_name,
+                       strlen (ids->merchant_name),
+                       NULL,
+                       0));
   GNUNET_CRYPTO_eddsa_key_get_public (&merchant_priv.eddsa_priv,
                                       &bd.merchant_pub.eddsa_pub);
   GNUNET_CRYPTO_hash_create_random (GNUNET_CRYPTO_QUALITY_WEAK,
@@ -224,7 +234,7 @@ insert_deposit_run (void *cls,
     struct TALER_BlindedDenominationSignature bds;
     struct TALER_PlanchetMasterSecretP ps;
     union GNUNET_CRYPTO_BlindingSecretP bks;
-    const struct TALER_ExchangeWithdrawValues *alg_values;
+    const struct TALER_ExchangeBlindingValues *alg_values;
 
     alg_values = TALER_denom_ewv_rsa_singleton ();
     TALER_planchet_blinding_secret_create (&ps,
