@@ -140,24 +140,11 @@ history_entry_cmp (
                             &h2->amount)) &&
          (0 ==
           TALER_amount_cmp (&h1->details.withdraw.fee,
-                            &h2->details.withdraw.fee)) )
-      /* testing_api_cmd_withdraw doesn't set the out_authorization_sig,
-         so we cannot test for it here. but if the amount matches,
-         that should be good enough. */
-      return 0;
-    return 1;
-  case TALER_EXCHANGE_RTT_AGEWITHDRAWAL:
-    /* testing_api_cmd_age_withdraw doesn't set the out_authorization_sig,
-       so we cannot test for it here. but if the amount matches,
-       that should be good enough. */
-    if ( (0 ==
-          TALER_amount_cmp (&h1->amount,
-                            &h2->amount)) &&
-         (0 ==
-          TALER_amount_cmp (&h1->details.age_withdraw.fee,
-                            &h2->details.age_withdraw.fee)) &&
-         (h1->details.age_withdraw.max_age ==
-          h2->details.age_withdraw.max_age))
+                            &h2->details.withdraw.fee)) &&
+         (h1->details.withdraw.age_restricted ==
+          h2->details.withdraw.age_restricted) &&
+         ((! h1->details.withdraw.age_restricted) ||
+          (h1->details.withdraw.max_age == h2->details.withdraw.max_age) ))
       return 0;
     return 1;
   case TALER_EXCHANGE_RTT_RECOUP:
@@ -303,7 +290,7 @@ analyze_command (void *cls,
       if (ac->failure)
       {
         GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                    "Entry for batch step `%s' missing in history\n",
+                    "Entry for batch step `%s' missing in reserve history\n",
                     step->label);
         return;
       }
@@ -315,6 +302,7 @@ analyze_command (void *cls,
 
   {
     const struct TALER_ReservePublicKeyP *rp;
+    bool matched = false;
 
     if (GNUNET_OK !=
         TALER_TESTING_get_trait_reserve_pub (cmd,
@@ -327,7 +315,6 @@ analyze_command (void *cls,
     for (unsigned int j = 0; true; j++)
     {
       const struct TALER_EXCHANGE_ReserveHistoryEntry *he;
-      bool matched = false;
 
       if (GNUNET_OK !=
           TALER_TESTING_get_trait_reserve_history (cmd,
@@ -335,10 +322,10 @@ analyze_command (void *cls,
                                                    &he))
       {
         /* NOTE: only for debugging... */
-        if (0 == j)
-          GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                      "Command `%s' has the reserve_pub, but lacks reserve history trait\n",
-                      cmd->label);
+        GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+                    "Command `%s' has the reserve_pub, but lacks reserve history trait for index #%u\n",
+                    cmd->label,
+                    j);
         return; /* command does nothing for reserves */
       }
       for (unsigned int i = 0; i<history_length; i++)
@@ -351,18 +338,20 @@ analyze_command (void *cls,
         {
           found[i] = true;
           matched = true;
+          ac->failure = false;
           break;
         }
       }
-      if (! matched)
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                    "Command `%s' reserve history entry #%u not found\n",
-                    cmd->label,
-                    j);
-        ac->failure = true;
-        return;
-      }
+      if (matched)
+        break;
+    }
+    if (! matched)
+    {
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "Command `%s' no relevant reserve history entry not found\n",
+                  cmd->label);
+      ac->failure = true;
+      ;
     }
   }
 }
