@@ -21,6 +21,7 @@
  * @brief main interpreter loop for testcases
  * @author Christian Grothoff
  * @author Marcello Stanisci
+ * @author Özgür Kesim
  */
 #include "platform.h"
 #include "taler_json_lib.h"
@@ -66,6 +67,12 @@ struct WithdrawState
    */
   const char *reuse_coin_key_ref;
 
+  /**
+   * If true and @e reuse_coin_key_ref is not NULL, also reuses
+   * the blinding_seed.
+   */
+  bool reuse_blinding_seed;
+
   /**
    * Our command.
    */
@@ -119,7 +126,7 @@ struct WithdrawState
    * Values contributed from the exchange during the
    * withdraw protocol.
    */
-  struct TALER_ExchangeWithdrawValues exchange_vals;
+  struct TALER_ExchangeBlindingValues exchange_vals;
 
   /**
    * Interpreter state (during command).
@@ -133,9 +140,14 @@ struct WithdrawState
   struct TALER_DenominationSignature sig;
 
   /**
-   * Private key material of the coin, set by the interpreter.
+   * Seed for the key material of the coin, set by the interpreter.
    */
-  struct TALER_PlanchetMasterSecretP ps;
+  struct TALER_WithdrawMasterSeedP seed;
+
+  /**
+   * Blinding seed for the blinding preparation for CS.
+   */
+  struct TALER_BlindingMasterSeedP blinding_seed;
 
   /**
    * An age > 0 signifies age restriction is required
@@ -158,7 +170,12 @@ struct WithdrawState
   /**
    * Withdraw handle (while operation is running).
    */
-  struct TALER_EXCHANGE_BatchWithdrawHandle *wsh;
+  struct TALER_EXCHANGE_WithdrawHandle *wsh;
+
+  /**
+   * The commitment for the withdraw operation, later needed for /recoup
+   */
+  struct TALER_HashBlindedPlanchetsP planchets_h;
 
   /**
    * Task scheduled to try later.
@@ -241,8 +258,8 @@ do_retry (void *cls)
  * @param wr withdraw response details
  */
 static void
-reserve_withdraw_cb (void *cls,
-                     const struct TALER_EXCHANGE_BatchWithdrawResponse *wr)
+withdraw_cb (void *cls,
+             const struct TALER_EXCHANGE_WithdrawResponse *wr)
 {
   struct WithdrawState *ws = cls;
   struct TALER_TESTING_Interpreter *is = ws->is;
@@ -292,13 +309,23 @@ reserve_withdraw_cb (void *cls,
   switch (wr->hr.http_status)
   {
   case MHD_HTTP_OK:
-    GNUNET_assert (1 == wr->details.ok.num_coins);
+    GNUNET_assert (1 == wr->details.ok.num_sigs);
     TALER_denom_sig_copy (&ws->sig,
-                          &wr->details.ok.coins[0].sig);
-    ws->coin_priv = wr->details.ok.coins[0].coin_priv;
-    ws->bks = wr->details.ok.coins[0].bks;
+                          &wr->details.ok.coin_details[0].denom_sig);
+    ws->coin_priv = wr->details.ok.coin_details[0].coin_priv;
+    ws->bks = wr->details.ok.coin_details[0].blinding_key;
     TALER_denom_ewv_copy (&ws->exchange_vals,
-                          &wr->details.ok.coins[0].exchange_vals);
+                          &wr->details.ok.coin_details[0].blinding_values);
+    ws->planchets_h = wr->details.ok.planchets_h;
+    if (0<ws->age)
+    {
+      /* copy the age-commitment data */
+      ws->h_age_commitment = wr->details.ok.coin_details[0].h_age_commitment;
+      TALER_age_commitment_proof_deep_copy (
+        &ws->age_commitment_proof,
+        &wr->details.ok.coin_details[0].age_commitment_proof);
+    }
+
     if (0 != ws->total_backoff.rel_value_us)
     {
       GNUNET_log (GNUNET_ERROR_TYPE_INFO,
@@ -383,13 +410,18 @@ withdraw_run (void *cls,
     = TALER_reserve_make_payto (ws->exchange_url,
                                 &ws->reserve_pub);
 
-  if (NULL == ws->reuse_coin_key_ref)
+  TALER_withdraw_master_seed_setup_random (&ws->seed);
+  TALER_cs_withdraw_seed_to_blinding_seed (&ws->seed,
+                                           &ws->blinding_seed);
+
+  /**
+   * In case of coin key material reuse, we _only_ reuse the
+   * master seed, but the blinding seed is still randomly chosen,
+   * see the lines prior to this.
+   */
+  if (NULL != ws->reuse_coin_key_ref)
   {
-    TALER_planchet_master_setup_random (&ws->ps);
-  }
-  else
-  {
-    const struct TALER_PlanchetMasterSecretP *ps;
+    const struct TALER_WithdrawMasterSeedP *seed;
     const struct TALER_TESTING_Command *cref;
     char *cstr;
     unsigned int index;
@@ -404,9 +436,13 @@ withdraw_run (void *cls,
     GNUNET_assert (NULL != cref);
     GNUNET_free (cstr);
     GNUNET_assert (GNUNET_OK ==
-                   TALER_TESTING_get_trait_planchet_secret (cref,
-                                                            &ps));
-    ws->ps = *ps;
+                   TALER_TESTING_get_trait_withdraw_seed (cref,
+                                                          &seed));
+    ws->seed = *seed;
+
+    if (ws->reuse_blinding_seed)
+      TALER_cs_withdraw_seed_to_blinding_seed (&ws->seed,
+                                               &ws->blinding_seed);
   }
 
   if (NULL == ws->pk)
@@ -437,24 +473,22 @@ withdraw_run (void *cls,
                  TALER_amount_add (&ws->reserve_history.amount,
                                    &ws->amount,
                                    &ws->pk->fees.withdraw));
-  ws->reserve_history.details.withdraw.fee = ws->pk->fees.withdraw;
-  {
-    struct TALER_EXCHANGE_WithdrawCoinInput wci = {
-      .pk = ws->pk,
-      .ps = &ws->ps,
-      .ach = 0 < ws->age ? &ws->h_age_commitment : NULL
-    };
+  ws->reserve_history.details.withdraw.fee =
+    ws->pk->fees.withdraw;
+
+  ws->wsh = TALER_EXCHANGE_withdraw_extra_blinding_seed (
+    TALER_TESTING_interpreter_get_context (is),
+    TALER_TESTING_get_keys (is),
+    TALER_TESTING_get_exchange_url (is),
+    rp,
+    1,
+    ws->pk,
+    &ws->seed,
+    &ws->blinding_seed,
+    ws->age,
+    &withdraw_cb,
+    ws);
 
-    ws->wsh = TALER_EXCHANGE_batch_withdraw (
-      TALER_TESTING_interpreter_get_context (is),
-      TALER_TESTING_get_exchange_url (is),
-      TALER_TESTING_get_keys (is),
-      rp,
-      1,
-      &wci,
-      &reserve_withdraw_cb,
-      ws);
-  }
   if (NULL == ws->wsh)
   {
     GNUNET_break (0);
@@ -481,7 +515,7 @@ withdraw_cleanup (void *cls,
   {
     TALER_TESTING_command_incomplete (ws->is,
                                       cmd->label);
-    TALER_EXCHANGE_batch_withdraw_cancel (ws->wsh);
+    TALER_EXCHANGE_withdraw_cancel (ws->wsh);
     ws->wsh = NULL;
   }
   if (NULL != ws->retry_task)
@@ -523,15 +557,17 @@ withdraw_traits (void *cls,
   struct WithdrawState *ws = cls;
   struct TALER_TESTING_Trait traits[] = {
     /* history entry MUST be first due to response code logic below! */
-    TALER_TESTING_make_trait_reserve_history (0,
+    TALER_TESTING_make_trait_reserve_history (0 /* only one coin */,
                                               &ws->reserve_history),
     TALER_TESTING_make_trait_coin_priv (0 /* only one coin */,
                                         &ws->coin_priv),
-    TALER_TESTING_make_trait_planchet_secret (&ws->ps),
+    TALER_TESTING_make_trait_withdraw_seed (&ws->seed),
+    TALER_TESTING_make_trait_blinding_seed (&ws->blinding_seed),
+    TALER_TESTING_make_trait_withdraw_commitment (&ws->planchets_h),
     TALER_TESTING_make_trait_blinding_key (0 /* only one coin */,
                                            &ws->bks),
-    TALER_TESTING_make_trait_exchange_wd_value (0 /* only one coin */,
-                                                &ws->exchange_vals),
+    TALER_TESTING_make_trait_exchange_blinding_values (0 /* only one coin */,
+                                                       &ws->exchange_vals),
     TALER_TESTING_make_trait_denom_pub (0 /* only one coin */,
                                         ws->pk),
     TALER_TESTING_make_trait_denom_sig (0 /* only one coin */,
@@ -574,23 +610,6 @@ TALER_TESTING_cmd_withdraw_amount (const char *label,
 
   ws = GNUNET_new (struct WithdrawState);
   ws->age = age;
-  if (0 < age)
-  {
-    struct GNUNET_HashCode seed;
-    struct TALER_AgeMask mask;
-
-    mask = TALER_extensions_get_age_restriction_mask ();
-    GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK,
-                                &seed,
-                                sizeof(seed));
-    TALER_age_restriction_commit (&mask,
-                                  age,
-                                  &seed,
-                                  &ws->age_commitment_proof);
-    TALER_age_commitment_hash (&ws->age_commitment_proof.commitment,
-                               &ws->h_age_commitment);
-  }
-
   ws->reserve_reference = reserve_reference;
   if (GNUNET_OK !=
       TALER_string_to_amount (amount,
@@ -642,6 +661,32 @@ TALER_TESTING_cmd_withdraw_amount_reuse_key (
 }
 
 
+struct TALER_TESTING_Command
+TALER_TESTING_cmd_withdraw_amount_reuse_all_secrets (
+  const char *label,
+  const char *reserve_reference,
+  const char *amount,
+  uint8_t age,
+  const char *coin_ref,
+  unsigned int expected_response_code)
+{
+  struct TALER_TESTING_Command cmd;
+
+  cmd = TALER_TESTING_cmd_withdraw_amount (label,
+                                           reserve_reference,
+                                           amount,
+                                           age,
+                                           expected_response_code);
+  {
+    struct WithdrawState *ws = cmd.cls;
+
+    ws->reuse_coin_key_ref = coin_ref;
+    ws->reuse_blinding_seed = true;
+  }
+  return cmd;
+}
+
+
 struct TALER_TESTING_Command
 TALER_TESTING_cmd_withdraw_denomination (
   const char *label,
