@@ -61,8 +61,8 @@ TALER_age_commitment_hash (
   for (size_t i = 0; i < commitment->num; i++)
   {
     GNUNET_CRYPTO_hash_context_read (hash_context,
-                                     &commitment->keys[i],
-                                     sizeof(commitment->keys[i]));
+                                     &commitment->pubs[i],
+                                     sizeof(commitment->pubs[i]));
   }
 
   GNUNET_CRYPTO_hash_context_finish (hash_context,
@@ -179,14 +179,14 @@ TALER_age_restriction_commit (
   ncp->commitment.mask.bits = mask->bits;
   ncp->commitment.num = num_pub;
   ncp->proof.num = num_priv;
-  ncp->proof.keys = NULL;
+  ncp->proof.privs = NULL;
 
-  ncp->commitment.keys = GNUNET_new_array (
+  ncp->commitment.pubs = GNUNET_new_array (
     num_pub,
     struct TALER_AgeCommitmentPublicKeyP);
 
   if (0 < num_priv)
-    ncp->proof.keys = GNUNET_new_array (
+    ncp->proof.privs = GNUNET_new_array (
       num_priv,
       struct TALER_AgeCommitmentPrivateKeyP);
 
@@ -201,20 +201,20 @@ TALER_age_restriction_commit (
 
     /* Only save the private keys for age groups less than num_priv */
     if (i < num_priv)
-      pkey = &ncp->proof.keys[i];
+      pkey = &ncp->proof.privs[i];
 
 #ifndef AGE_RESTRICTION_WITH_ECDSA
     GNUNET_CRYPTO_edx25519_key_create_from_seed (&seed_i,
                                                  sizeof(seed_i),
                                                  &pkey->priv);
     GNUNET_CRYPTO_edx25519_key_get_public (&pkey->priv,
-                                           &ncp->commitment.keys[i].pub);
+                                           &ncp->commitment.pubs[i].pub);
 #else
     ecdsa_create_from_seed (&seed_i,
                             sizeof(seed_i),
                             &pkey->priv);
     GNUNET_CRYPTO_ecdsa_key_get_public (&pkey->priv,
-                                        &ncp->commitment.keys[i].pub);
+                                        &ncp->commitment.pubs[i].pub);
 #endif
 
     seed_i.bits[0] += 1;
@@ -224,72 +224,132 @@ TALER_age_restriction_commit (
 
 enum GNUNET_GenericReturnValue
 TALER_age_commitment_derive (
+  const struct TALER_AgeCommitment *orig,
+  const struct GNUNET_HashCode *salt,
+  struct TALER_AgeCommitment *newac)
+{
+  GNUNET_assert (NULL != newac);
+  GNUNET_assert (((int) orig->num) ==
+                 __builtin_popcount (orig->mask.bits) - 1);
+
+  newac->mask = orig->mask;
+  newac->num = orig->num;
+  newac->pubs = GNUNET_new_array (
+    newac->num,
+    struct TALER_AgeCommitmentPublicKeyP);
+
+#ifndef AGE_RESTRICTION_WITH_ECDSA
+  /* Derive the public keys */
+  for (size_t i = 0; i < orig->num; i++)
+  {
+    GNUNET_CRYPTO_edx25519_public_key_derive (
+      &orig->pubs[i].pub,
+      salt,
+      sizeof(*salt),
+      &newac->pubs[i].pub);
+  }
+#else
+  {
+    const char *label = GNUNET_h2s (salt);
+
+    /* Derive the public keys */
+    for (size_t i = 0; i < orig->num; i++)
+    {
+      GNUNET_CRYPTO_ecdsa_public_key_derive (
+        &orig->pubs[i].pub,
+        label,
+        "age commitment derive",
+        &newac->pubs[i].pub);
+    }
+  }
+#endif
+
+  return GNUNET_OK;
+}
+
+
+enum GNUNET_GenericReturnValue
+TALER_age_commitment_derive_from_secret (
+  const struct TALER_AgeCommitment *orig,
+  const struct TALER_PlanchetMasterSecretP *secret,
+  struct TALER_AgeCommitment *newac)
+{
+  struct GNUNET_HashCode salt;
+  enum GNUNET_GenericReturnValue ret;
+
+  ret =      GNUNET_CRYPTO_kdf (&salt,
+                                sizeof (salt),
+                                "age commitment",
+                                strlen ("age commitment"),
+                                secret,
+                                sizeof(*secret),
+                                NULL, 0);
+  if (GNUNET_OK != ret)
+  {
+    GNUNET_break (0);
+    return ret;
+  }
+
+  return TALER_age_commitment_derive (
+    orig,
+    &salt,
+    newac);
+}
+
+
+enum GNUNET_GenericReturnValue
+TALER_age_commitment_proof_derive (
   const struct TALER_AgeCommitmentProof *orig,
   const struct GNUNET_HashCode *salt,
   struct TALER_AgeCommitmentProof *newacp)
 {
+  enum GNUNET_GenericReturnValue ret;
   GNUNET_assert (NULL != newacp);
   GNUNET_assert (orig->proof.num <=
                  orig->commitment.num);
   GNUNET_assert (((int) orig->commitment.num) ==
                  __builtin_popcount (orig->commitment.mask.bits) - 1);
 
-  newacp->commitment.mask = orig->commitment.mask;
-  newacp->commitment.num = orig->commitment.num;
-  newacp->commitment.keys = GNUNET_new_array (
-    newacp->commitment.num,
-    struct TALER_AgeCommitmentPublicKeyP);
+  ret = TALER_age_commitment_derive (
+    &orig->commitment,
+    salt,
+    &newacp->commitment);
+  if (GNUNET_OK != ret)
+  {
+    GNUNET_break (0);
+    return ret;
+  }
 
   newacp->proof.num = orig->proof.num;
-  newacp->proof.keys = NULL;
+  newacp->proof.privs = NULL;
   if (0 != newacp->proof.num)
-    newacp->proof.keys = GNUNET_new_array (
+    newacp->proof.privs = GNUNET_new_array (
       newacp->proof.num,
       struct TALER_AgeCommitmentPrivateKeyP);
 
 #ifndef AGE_RESTRICTION_WITH_ECDSA
-  /* 1. Derive the public keys */
-  for (size_t i = 0; i < orig->commitment.num; i++)
-  {
-    GNUNET_CRYPTO_edx25519_public_key_derive (
-      &orig->commitment.keys[i].pub,
-      salt,
-      sizeof(*salt),
-      &newacp->commitment.keys[i].pub);
-  }
-
-  /* 2. Derive the private keys */
+  /* Derive the private keys */
   for (size_t i = 0; i < orig->proof.num; i++)
   {
     GNUNET_CRYPTO_edx25519_private_key_derive (
-      &orig->proof.keys[i].priv,
+      &orig->proof.privs[i].priv,
       salt,
       sizeof(*salt),
-      &newacp->proof.keys[i].priv);
+      &newacp->proof.privs[i].priv);
   }
 #else
   {
     const char *label = GNUNET_h2s (salt);
 
-    /* 1. Derive the public keys */
-    for (size_t i = 0; i < orig->commitment.num; i++)
-    {
-      GNUNET_CRYPTO_ecdsa_public_key_derive (
-        &orig->commitment.keys[i].pub,
-        label,
-        "age commitment derive",
-        &newacp->commitment.keys[i].pub);
-    }
-
-    /* 2. Derive the private keys */
+    /* Derive the private keys */
     for (size_t i = 0; i < orig->proof.num; i++)
     {
       struct GNUNET_CRYPTO_EcdsaPrivateKey *priv;
       priv = GNUNET_CRYPTO_ecdsa_private_key_derive (
-        &orig->proof.keys[i].priv,
+        &orig->proof.privs[i].priv,
         label,
         "age commitment derive");
-      newacp->proof.keys[i].priv = *priv;
+      newacp->proof.privs[i].priv = *priv;
       GNUNET_free (priv);
     }
   }
@@ -299,6 +359,35 @@ TALER_age_commitment_derive (
 }
 
 
+enum GNUNET_GenericReturnValue
+TALER_age_commitment_proof_derive_from_secret (
+  const struct TALER_AgeCommitmentProof *orig,
+  const struct TALER_PlanchetMasterSecretP *secret,
+  struct TALER_AgeCommitmentProof *newacp)
+{
+  struct GNUNET_HashCode salt;
+  enum GNUNET_GenericReturnValue ret;
+
+  ret =      GNUNET_CRYPTO_kdf (&salt,
+                                sizeof (salt),
+                                "age commitment",
+                                strlen ("age commitment"),
+                                secret,
+                                sizeof(*secret),
+                                NULL, 0);
+  if (GNUNET_OK != ret)
+  {
+    GNUNET_break (0);
+    return ret;
+  }
+
+  return TALER_age_commitment_proof_derive (
+    orig,
+    &salt,
+    newacp);
+}
+
+
 GNUNET_NETWORK_STRUCT_BEGIN
 
 /**
@@ -377,7 +466,7 @@ TALER_age_commitment_attest (
 #else
   #define sign(a,b,c)  GNUNET_CRYPTO_ecdsa_sign (a,b,c)
 #endif
-    sign (&cp->proof.keys[group - 1].priv,
+    sign (&cp->proof.privs[group - 1].priv,
           &at,
           &attest->signature);
   }
@@ -429,7 +518,7 @@ TALER_age_commitment_verify (
     return verify (TALER_SIGNATURE_WALLET_AGE_ATTESTATION,
                    &at,
                    &attest->signature,
-                   &comm->keys[group - 1].pub);
+                   &comm->pubs[group - 1].pub);
   }
 #undef verify
 }
@@ -442,12 +531,11 @@ TALER_age_commitment_free (
   if (NULL == commitment)
     return;
 
-  if (NULL != commitment->keys)
+  if (NULL != commitment->pubs)
   {
-    GNUNET_free (commitment->keys);
-    commitment->keys = NULL;
+    GNUNET_free (commitment->pubs);
+    commitment->pubs = NULL;
   }
-  GNUNET_free (commitment);
 }
 
 
@@ -458,16 +546,15 @@ TALER_age_proof_free (
   if (NULL == proof)
     return;
 
-  if (NULL != proof->keys)
+  if (NULL != proof->privs)
   {
     GNUNET_CRYPTO_zero_keys (
-      proof->keys,
-      sizeof(*proof->keys) * proof->num);
+      proof->privs,
+      sizeof(*proof->privs) * proof->num);
 
-    GNUNET_free (proof->keys);
-    proof->keys = NULL;
+    GNUNET_free (proof->privs);
+    proof->privs = NULL;
   }
-  GNUNET_free (proof);
 }
 
 
@@ -478,20 +565,20 @@ TALER_age_commitment_proof_free (
   if (NULL == acp)
     return;
 
-  if (NULL != acp->proof.keys)
+  if (NULL != acp->proof.privs)
   {
     GNUNET_CRYPTO_zero_keys (
-      acp->proof.keys,
-      sizeof(*acp->proof.keys) * acp->proof.num);
+      acp->proof.privs,
+      sizeof(*acp->proof.privs) * acp->proof.num);
 
-    GNUNET_free (acp->proof.keys);
-    acp->proof.keys = NULL;
+    GNUNET_free (acp->proof.privs);
+    acp->proof.privs = NULL;
   }
 
-  if (NULL != acp->commitment.keys)
+  if (NULL != acp->commitment.pubs)
   {
-    GNUNET_free (acp->commitment.keys);
-    acp->commitment.keys = NULL;
+    GNUNET_free (acp->commitment.pubs);
+    acp->commitment.pubs = NULL;
   }
 }
 
@@ -513,6 +600,22 @@ TALER_age_commitment_proof_duplicate (
 }
 
 
+struct TALER_AgeCommitment *
+TALER_age_commitment_duplicate (
+  const struct TALER_AgeCommitment *ac)
+{
+  struct TALER_AgeCommitment *nac;
+
+  GNUNET_assert (NULL != ac);
+  GNUNET_assert (__builtin_popcount (ac->mask.bits) - 1 ==
+                 (int) ac->num);
+
+  nac = GNUNET_new (struct TALER_AgeCommitment);
+  TALER_age_commitment_deep_copy (nac, ac);
+  return nac;
+}
+
+
 void
 TALER_age_commitment_proof_deep_copy (
   struct TALER_AgeCommitmentProof *nacp,
@@ -523,18 +626,38 @@ TALER_age_commitment_proof_deep_copy (
                  (int) acp->commitment.num);
 
   *nacp = *acp;
-  nacp->commitment.keys =
+  nacp->commitment.pubs =
     GNUNET_new_array (acp->commitment.num,
                       struct TALER_AgeCommitmentPublicKeyP);
-  nacp->proof.keys =
+  nacp->proof.privs =
     GNUNET_new_array (acp->proof.num,
                       struct TALER_AgeCommitmentPrivateKeyP);
 
   for (size_t i = 0; i < acp->commitment.num; i++)
-    nacp->commitment.keys[i] = acp->commitment.keys[i];
+    nacp->commitment.pubs[i] = acp->commitment.pubs[i];
 
   for (size_t i = 0; i < acp->proof.num; i++)
-    nacp->proof.keys[i] = acp->proof.keys[i];
+    nacp->proof.privs[i] = acp->proof.privs[i];
+}
+
+
+void
+TALER_age_commitment_deep_copy (
+  struct TALER_AgeCommitment *nac,
+  const struct TALER_AgeCommitment *ac)
+{
+  GNUNET_assert (NULL != ac);
+  GNUNET_assert (__builtin_popcount (ac->mask.bits) - 1 ==
+                 (int) ac->num);
+
+  *nac = *ac;
+  nac->pubs =
+    GNUNET_new_array (ac->num,
+                      struct TALER_AgeCommitmentPublicKeyP);
+
+  for (size_t i = 0; i < ac->num; i++)
+    nac->pubs[i] = ac->pubs[i];
+
 }
 
 
@@ -670,12 +793,12 @@ TALER_age_restriction_from_secret (
   ncp->commitment.mask.bits = mask->bits;
   ncp->commitment.num = num_pub;
   ncp->proof.num = num_priv;
-  ncp->proof.keys = NULL;
-  ncp->commitment.keys = GNUNET_new_array (
+  ncp->proof.privs = NULL;
+  ncp->commitment.pubs = GNUNET_new_array (
     num_pub,
     struct TALER_AgeCommitmentPublicKeyP);
   if (0 < num_priv)
-    ncp->proof.keys = GNUNET_new_array (
+    ncp->proof.privs = GNUNET_new_array (
       num_priv,
       struct TALER_AgeCommitmentPrivateKeyP);
 
@@ -698,20 +821,20 @@ TALER_age_restriction_from_secret (
      * less than num_priv */
     if (i < num_priv)
     {
-      struct TALER_AgeCommitmentPrivateKeyP *pkey = &ncp->proof.keys[i];
+      struct TALER_AgeCommitmentPrivateKeyP *pkey = &ncp->proof.privs[i];
 
 #ifndef AGE_RESTRICTION_WITH_ECDSA
       GNUNET_CRYPTO_edx25519_key_create_from_seed (&seed_i,
                                                    sizeof(seed_i),
                                                    &pkey->priv);
       GNUNET_CRYPTO_edx25519_key_get_public (&pkey->priv,
-                                             &ncp->commitment.keys[i].pub);
+                                             &ncp->commitment.pubs[i].pub);
 #else
       ecdsa_create_from_seed (&seed_i,
                               sizeof(seed_i),
                               &pkey->priv);
       GNUNET_CRYPTO_ecdsa_key_get_public (&pkey->priv,
-                                          &ncp->commitment.keys[i].pub);
+                                          &ncp->commitment.pubs[i].pub);
 #endif
     }
     else
@@ -723,14 +846,14 @@ TALER_age_restriction_from_secret (
         &TALER_age_commitment_base_public_key,
         &seed_i,
         sizeof(seed_i),
-        &ncp->commitment.keys[i].pub);
+        &ncp->commitment.pubs[i].pub);
 #else
 
       GNUNET_CRYPTO_ecdsa_public_key_derive (
         &TALER_age_commitment_base_public_key,
         GNUNET_h2s (&seed_i),
         "age withdraw",
-        &ncp->commitment.keys[i].pub);
+        &ncp->commitment.pubs[i].pub);
 #endif
     }
   }
