@@ -42,13 +42,20 @@ invalidate (struct TALER_Amount *a)
 enum GNUNET_GenericReturnValue
 TALER_check_currency (const char *str)
 {
-  if (strlen (str) >= TALER_CURRENCY_LEN)
+  size_t len = strlen (str);
+  if (len >= TALER_CURRENCY_LEN)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Currency code name `%s' is too long\n",
                 str);
     return GNUNET_SYSERR;
   }
+  if (len == 0)
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Currency code name must be set\n");
+    return GNUNET_SYSERR;
+  }
   /* validate str has only legal characters in it! */
   for (unsigned int i = 0; '\0' != str[i]; i++)
   {
