@@ -146,6 +146,59 @@ TALER_link_recover_transfer_secret (
 }
 
 
+void
+TALER_withdraw_expand_secrets (
+  size_t num_coins,
+  const struct TALER_WithdrawMasterSeedP *seed,
+  struct TALER_PlanchetMasterSecretP secrets[static num_coins])
+{
+  _Static_assert (sizeof(seed->seed_data) == sizeof(secrets->key_data));
+  GNUNET_assert (0 < num_coins);
+
+  if (1 == num_coins)
+  {
+    GNUNET_memcpy (&secrets[0].key_data,
+                   &seed->seed_data,
+                   sizeof(secrets[0].key_data));
+  }
+  else
+  {
+    uint32_t be_salt = htonl (num_coins);
+
+    GNUNET_assert (GNUNET_OK ==
+                   GNUNET_CRYPTO_kdf (secrets,
+                                      sizeof (*secrets) * num_coins,
+                                      &be_salt,
+                                      sizeof (be_salt),
+                                      seed,
+                                      sizeof (*seed),
+                                      "taler-withdraw-secrets",
+                                      strlen ("taler-withdraw-secrets"),
+                                      NULL, 0));
+  }
+}
+
+
+void
+TALER_withdraw_expand_kappa_seed (
+  const struct TALER_WithdrawMasterSeedP *seed,
+  struct TALER_KappaWithdrawMasterSeedP *seeds)
+{
+  uint32_t be_salt = htonl (TALER_CNC_KAPPA);
+
+  GNUNET_assert (GNUNET_OK ==
+                 GNUNET_CRYPTO_kdf (seeds,
+                                    sizeof (*seeds),
+                                    &be_salt,
+                                    sizeof (be_salt),
+                                    seed,
+                                    sizeof (*seed),
+                                    "taler-kappa-seeds",
+                                    strlen ("taler-kappa-seeds"),
+                                    NULL, 0));
+}
+
+
 void
 TALER_planchet_master_setup_random (
   struct TALER_PlanchetMasterSecretP *ps)
@@ -156,6 +209,16 @@ TALER_planchet_master_setup_random (
 }
 
 
+void
+TALER_withdraw_master_seed_setup_random (
+  struct TALER_WithdrawMasterSeedP *seed)
+{
+  GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_STRONG,
+                              seed,
+                              sizeof (*seed));
+}
+
+
 void
 TALER_refresh_master_setup_random (
   struct TALER_RefreshMasterSecretP *rms)
@@ -228,6 +291,102 @@ TALER_cs_withdraw_nonce_derive (
 }
 
 
+void
+TALER_cs_withdraw_seed_to_blinding_seed (
+  const struct TALER_WithdrawMasterSeedP *seed,
+  struct TALER_BlindingMasterSeedP *blinding_seed)
+{
+  GNUNET_assert (GNUNET_YES ==
+                 GNUNET_CRYPTO_kdf (blinding_seed,
+                                    sizeof (*blinding_seed),
+                                    "withdraw-blinding",
+                                    strlen ("withdraw-blinding"),
+                                    seed,
+                                    sizeof(*seed),
+                                    NULL,
+                                    0));
+}
+
+
+void
+TALER_cs_refresh_secret_to_blinding_seed (
+  const struct TALER_RefreshMasterSecretP *secret,
+  struct TALER_BlindingMasterSeedP *blinding_seed)
+{
+  GNUNET_assert (GNUNET_YES ==
+                 GNUNET_CRYPTO_kdf (blinding_seed,
+                                    sizeof (*blinding_seed),
+                                    "refresh-blinding",
+                                    strlen ("refresh-blinding"),
+                                    secret,
+                                    sizeof(*secret),
+                                    NULL,
+                                    0));
+}
+
+
+void
+TALER_cs_nonce_derive_indexed (
+  const struct TALER_BlindingMasterSeedP *seed,
+  bool for_melt,
+  uint32_t index,
+  struct GNUNET_CRYPTO_CsSessionNonce *nonce)
+{
+  uint32_t be_salt = htonl (index);
+  const char *operation = for_melt ? "refresh-n" : "withdraw-n";
+
+  GNUNET_assert (GNUNET_YES ==
+                 GNUNET_CRYPTO_kdf (nonce,
+                                    sizeof (*nonce),
+                                    &be_salt,
+                                    sizeof (be_salt),
+                                    operation,
+                                    strlen (operation),
+                                    seed,
+                                    sizeof(*seed),
+                                    NULL,
+                                    0));
+}
+
+
+void
+TALER_cs_derive_nonces_from_seed (
+  const struct TALER_BlindingMasterSeedP *seed,
+  bool for_melt,
+  size_t num,
+  const uint32_t indices[static num],
+  struct GNUNET_CRYPTO_CsSessionNonce nonces[static num])
+{
+  GNUNET_assert (TALER_MAX_COINS > num);
+
+  for (size_t i = 0; i < num; i++)
+    TALER_cs_nonce_derive_indexed (
+      seed,
+      for_melt,
+      indices[i],
+      &nonces[i]);
+}
+
+
+void
+TALER_cs_derive_only_cs_blind_nonces_from_seed (
+  const struct TALER_BlindingMasterSeedP *seed,
+  bool for_melt,
+  size_t num,
+  const uint32_t indices[static num],
+  union GNUNET_CRYPTO_BlindSessionNonce nonces[static num])
+{
+  GNUNET_assert (TALER_MAX_COINS > num);
+
+  for (size_t i = 0; i < num; i++)
+    TALER_cs_nonce_derive_indexed (
+      seed,
+      for_melt,
+      indices[i],
+      &nonces[i].cs_nonce);
+}
+
+
 void
 TALER_cs_refresh_nonce_derive (
   const struct TALER_RefreshMasterSecretP *rms,
@@ -250,6 +409,51 @@ TALER_cs_refresh_nonce_derive (
 }
 
 
+bool
+TALER_cs_mark_indices (
+  size_t num,
+  const struct TALER_DenominationPublicKey denoms[static num],
+  bool is_cs[static num])
+{
+  bool found = false;
+  for (size_t i = 0; i < num; i++)
+  {
+    switch (denoms[i].bsign_pub_key->cipher)
+    {
+    case GNUNET_CRYPTO_BSA_INVALID:
+      GNUNET_assert (0);
+      break;
+    case GNUNET_CRYPTO_BSA_RSA:
+      is_cs[i] = false;
+    case GNUNET_CRYPTO_BSA_CS:
+      is_cs[i] = true;
+      found = true;
+    }
+  }
+  return found;
+}
+
+
+void
+TALER_cs_derive_blind_nonces_from_seed (
+  const struct TALER_BlindingMasterSeedP *seed,
+  bool for_melt,
+  size_t num,
+  const bool is_cs[static num],
+  union GNUNET_CRYPTO_BlindSessionNonce nonces[static num])
+{
+  for (size_t i = 0; i < num; i++)
+  {
+    if (is_cs[i])
+      TALER_cs_nonce_derive_indexed (
+        seed,
+        for_melt,
+        i,
+        &nonces[i].cs_nonce);
+  }
+}
+
+
 void
 TALER_rsa_pub_hash (const struct GNUNET_CRYPTO_RsaPublicKey *rsa,
                     struct TALER_RsaPubHashP *h_rsa)
@@ -272,18 +476,18 @@ TALER_cs_pub_hash (const struct GNUNET_CRYPTO_CsPublicKey *cs,
 
 enum GNUNET_GenericReturnValue
 TALER_planchet_prepare (const struct TALER_DenominationPublicKey *dk,
-                        const struct TALER_ExchangeWithdrawValues *alg_values,
+                        const struct
+                        TALER_ExchangeBlindingValues *blinding_values,
                         const union GNUNET_CRYPTO_BlindingSecretP *bks,
                         const union GNUNET_CRYPTO_BlindSessionNonce *nonce,
                         const struct TALER_CoinSpendPrivateKeyP *coin_priv,
                         const struct TALER_AgeCommitmentHash *ach,
                         struct TALER_CoinPubHashP *c_hash,
-                        struct TALER_PlanchetDetail *pd
-                        )
+                        struct TALER_PlanchetDetail *pd)
 {
   struct TALER_CoinSpendPublicKeyP coin_pub;
 
-  GNUNET_assert (alg_values->blinding_inputs->cipher ==
+  GNUNET_assert (blinding_values->blinding_inputs->cipher ==
                  dk->bsign_pub_key->cipher);
   GNUNET_CRYPTO_eddsa_key_get_public (&coin_priv->eddsa_priv,
                                       &coin_pub.eddsa_pub);
@@ -293,7 +497,7 @@ TALER_planchet_prepare (const struct TALER_DenominationPublicKey *dk,
                          nonce,
                          ach,
                          &coin_pub,
-                         alg_values,
+                         blinding_values,
                          c_hash,
                          &pd->blinded_planchet))
   {
@@ -321,7 +525,7 @@ TALER_planchet_to_coin (
   const struct TALER_CoinSpendPrivateKeyP *coin_priv,
   const struct TALER_AgeCommitmentHash *ach,
   const struct TALER_CoinPubHashP *c_hash,
-  const struct TALER_ExchangeWithdrawValues *alg_values,
+  const struct TALER_ExchangeBlindingValues *alg_values,
   struct TALER_FreshCoin *coin)
 {
   if (dk->bsign_pub_key->cipher !=
@@ -436,6 +640,116 @@ TALER_refresh_get_commitment (struct TALER_RefreshCommitmentP *rc,
 }
 
 
+void
+TALER_refresh_get_commitment_v27 (
+  struct TALER_RefreshCommitmentP *rc,
+  const struct TALER_PublicRefreshMasterSeedP *refresh_seed,
+  const struct TALER_BlindingMasterSeedP *blinding_seed,
+  const struct TALER_KappaHashBlindedPlanchetsP *k_bps_h,
+  const struct TALER_CoinSpendPublicKeyP *coin_pub,
+  const struct TALER_Amount *amount_with_fee)
+{
+  struct GNUNET_HashContext *hash_context;
+
+  hash_context = GNUNET_CRYPTO_hash_context_start ();
+
+  /* First, the refresh master seed (from which the nonces, then signatures
+     and finally private keys of the fresh coins are derived from) */
+  GNUNET_assert (NULL != refresh_seed);
+  GNUNET_CRYPTO_hash_context_read (hash_context,
+                                   refresh_seed,
+                                   sizeof (*refresh_seed));
+
+  /* Then, in case of CS denominations, the blinding_seed from which all
+     nonces are derived from, and therefore public R-values */
+  {
+    struct TALER_BlindingMasterSeedP blanko = {0};
+    const struct TALER_BlindingMasterSeedP *pbms = &blanko;
+
+    if (NULL != blinding_seed)
+      pbms = blinding_seed;
+    GNUNET_CRYPTO_hash_context_read (hash_context,
+                                     pbms,
+                                     sizeof(*pbms));
+  }
+
+  /* Next, add public key of coin and amount being refreshed */
+  {
+    struct TALER_AmountNBO melt_amountn;
+
+    GNUNET_CRYPTO_hash_context_read (hash_context,
+                                     coin_pub,
+                                     sizeof (struct TALER_CoinSpendPublicKeyP));
+    TALER_amount_hton (&melt_amountn,
+                       amount_with_fee);
+    GNUNET_CRYPTO_hash_context_read (hash_context,
+                                     &melt_amountn,
+                                     sizeof (struct TALER_AmountNBO));
+  }
+
+  /* Finally, add all the hashes of the blinded coins
+   * (containing information about denominations), depths first */
+  for (unsigned int k = 0; k<TALER_CNC_KAPPA; k++)
+    GNUNET_CRYPTO_hash_context_read (hash_context,
+                                     &k_bps_h->tuple[k],
+                                     sizeof(k_bps_h->tuple[k]));
+
+  /* Conclude */
+  GNUNET_CRYPTO_hash_context_finish (hash_context,
+                                     &rc->session_hash);
+}
+
+
+void
+TALER_refresh_master_secret_to_refresh_seed (
+  const struct TALER_RefreshMasterSecretP *rms,
+  struct TALER_PublicRefreshMasterSeedP *r_seed)
+{
+  GNUNET_assert (GNUNET_OK ==
+                 GNUNET_CRYPTO_kdf (r_seed,
+                                    sizeof (*r_seed),
+                                    "refresh-seed",
+                                    strlen ("refresh-seed"),
+                                    rms,
+                                    sizeof (*rms),
+                                    NULL, 0));
+}
+
+
+void
+TALER_refresh_expand_kappa_nonces (
+  const struct TALER_PublicRefreshMasterSeedP *refresh_seed,
+  struct TALER_KappaPublicRefreshNoncesP *kappa_nonces)
+{
+  GNUNET_assert (GNUNET_OK ==
+                 GNUNET_CRYPTO_kdf (kappa_nonces,
+                                    sizeof (*kappa_nonces),
+                                    "refresh-kappa-nonces",
+                                    strlen ("refresh-kappa-nonces"),
+                                    refresh_seed,
+                                    sizeof (*refresh_seed),
+                                    NULL, 0));
+}
+
+
+void
+TALER_refresh_signature_to_secrets (
+  const struct TALER_PrivateRefreshNonceSignatureP *sig,
+  size_t num_secrets,
+  struct TALER_PlanchetMasterSecretP secrets[static num_secrets])
+{
+  GNUNET_assert (GNUNET_YES ==
+                 GNUNET_CRYPTO_kdf (secrets,
+                                    sizeof (*secrets) * num_secrets,
+                                    "refresh-planchet-secret",
+                                    strlen ("refresh-planchet-secret"),
+                                    sig,
+                                    sizeof(*sig),
+                                    NULL,
+                                    0));
+}
+
+
 void
 TALER_coin_pub_hash (const struct TALER_CoinSpendPublicKeyP *coin_pub,
                      const struct TALER_AgeCommitmentHash *ach,
