@@ -230,7 +230,7 @@ handle_mt_avail (struct TALER_CRYPTO_RsaDenominationHelper *dh,
     GNUNET_CRYPTO_rsa_public_key_hash (bs_pub->details.rsa_public_key,
                                        &bs_pub->pub_key_hash);
     h_rsa.hash = bs_pub->pub_key_hash;
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Received RSA key %s (%s)\n",
                 GNUNET_h2s (&bs_pub->pub_key_hash),
                 section_name);
@@ -351,7 +351,7 @@ more:
     msize = ntohs (hdr->size);
     if (off < msize)
       continue;
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Received message of type %u and length %u\n",
                 (unsigned int) ntohs (hdr->type),
                 (unsigned int) msize);
