@@ -71,7 +71,7 @@ TALER_denom_sig_unblind (
   const struct TALER_BlindedDenominationSignature *bdenom_sig,
   const union GNUNET_CRYPTO_BlindingSecretP *bks,
   const struct TALER_CoinPubHashP *c_hash,
-  const struct TALER_ExchangeWithdrawValues *alg_values,
+  const struct TALER_ExchangeBlindingValues *alg_values,
   const struct TALER_DenominationPublicKey *denom_pub)
 {
   denom_sig->unblinded_sig
@@ -135,13 +135,13 @@ TALER_denom_pub_hash (const struct TALER_DenominationPublicKey *denom_pub,
 }
 
 
-const struct TALER_ExchangeWithdrawValues *
+const struct TALER_ExchangeBlindingValues *
 TALER_denom_ewv_rsa_singleton ()
 {
   static struct GNUNET_CRYPTO_BlindingInputValues bi = {
     .cipher = GNUNET_CRYPTO_BSA_RSA
   };
-  static struct TALER_ExchangeWithdrawValues alg_values = {
+  static struct TALER_ExchangeBlindingValues alg_values = {
     .blinding_inputs = &bi
   };
   return &alg_values;
@@ -155,7 +155,7 @@ TALER_denom_blind (
   const union GNUNET_CRYPTO_BlindSessionNonce *nonce,
   const struct TALER_AgeCommitmentHash *ach,
   const struct TALER_CoinSpendPublicKeyP *coin_pub,
-  const struct TALER_ExchangeWithdrawValues *alg_values,
+  const struct TALER_ExchangeBlindingValues *alg_values,
   struct TALER_CoinPubHashP *c_hash,
   struct TALER_BlindedPlanchet *blinded_planchet)
 {
@@ -233,7 +233,7 @@ TALER_blinded_denom_sig_free (
 
 
 void
-TALER_denom_ewv_free (struct TALER_ExchangeWithdrawValues *ewv)
+TALER_denom_ewv_free (struct TALER_ExchangeBlindingValues *ewv)
 {
   if (ewv == TALER_denom_ewv_rsa_singleton ())
     return;
@@ -252,8 +252,8 @@ TALER_denom_ewv_free (struct TALER_ExchangeWithdrawValues *ewv)
 
 
 void
-TALER_denom_ewv_copy (struct TALER_ExchangeWithdrawValues *bi_dst,
-                      const struct TALER_ExchangeWithdrawValues *bi_src)
+TALER_denom_ewv_copy (struct TALER_ExchangeBlindingValues *bi_dst,
+                      const struct TALER_ExchangeBlindingValues *bi_src)
 {
   if (bi_src == TALER_denom_ewv_rsa_singleton ())
   {
@@ -373,7 +373,7 @@ TALER_blinded_planchet_hash_ (const struct TALER_BlindedPlanchet *bp,
 void
 TALER_planchet_blinding_secret_create (
   const struct TALER_PlanchetMasterSecretP *ps,
-  const struct TALER_ExchangeWithdrawValues *alg_values,
+  const struct TALER_ExchangeBlindingValues *alg_values,
   union GNUNET_CRYPTO_BlindingSecretP *bks)
 {
   const struct GNUNET_CRYPTO_BlindingInputValues *bi =
@@ -416,7 +416,7 @@ TALER_planchet_blinding_secret_create (
 void
 TALER_planchet_setup_coin_priv (
   const struct TALER_PlanchetMasterSecretP *ps,
-  const struct TALER_ExchangeWithdrawValues *alg_values,
+  const struct TALER_ExchangeBlindingValues *alg_values,
   struct TALER_CoinSpendPrivateKeyP *coin_priv)
 {
   const struct GNUNET_CRYPTO_BlindingInputValues *bi
