@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2021-2024 Taler Systems SA
+  Copyright (C) 2021-2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU General Public License as published by the Free Software
@@ -380,12 +380,13 @@ GNUNET_NETWORK_STRUCT_BEGIN
 
 /**
  * @brief Format of the block signed by the Exchange in response to a
- * successful "/reserves/$RESERVE_PUB/age-withdraw" request.  Hereby the
- * exchange affirms that the commitment along with the maximum age group and
+ * successful "/withdraw" request.
+ * If age restriction is set, the exchange hereby also
+ * affirms that the commitment along with the maximum age group and
  * the amount were accepted.  This also commits the exchange to a particular
  * index to not be revealed during the reveal.
  */
-struct TALER_AgeWithdrawConfirmationPS
+struct TALER_WithdrawConfirmationPS
 {
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW.   Signed by a
@@ -394,13 +395,17 @@ struct TALER_AgeWithdrawConfirmationPS
   struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
 
   /**
-   * Commitment made in the /reserves/$RESERVE_PUB/age-withdraw.
+   * Commitment made in the /withdraw call.
    */
-  struct TALER_AgeWithdrawCommitmentHashP h_commitment GNUNET_PACKED;
+  struct TALER_HashBlindedPlanchetsP h_planchets GNUNET_PACKED;
 
   /**
-   * Index that the client will not have to reveal, in NBO.
-   * Must be smaller than #TALER_CNC_KAPPA.
+   * If age restriction does not apply to this withdrawal,
+   * (i.e. max_age was not set during the request)
+   * MUST be 0xFFFFFFFF.
+   * Otherwise (i.e. age restriction applies):
+   * index that the client will not have to reveal, in NBO,
+   * MUST be smaller than #TALER_CNC_KAPPA.
    */
   uint32_t noreveal_index GNUNET_PACKED;
 
@@ -409,18 +414,18 @@ struct TALER_AgeWithdrawConfirmationPS
 GNUNET_NETWORK_STRUCT_END
 
 enum TALER_ErrorCode
-TALER_exchange_online_age_withdraw_confirmation_sign (
+TALER_exchange_online_withdraw_age_confirmation_sign (
   TALER_ExchangeSignCallback scb,
-  const struct TALER_AgeWithdrawCommitmentHashP *h_commitment,
+  const struct TALER_HashBlindedPlanchetsP *h_planchets,
   uint32_t noreveal_index,
   struct TALER_ExchangePublicKeyP *pub,
   struct TALER_ExchangeSignatureP *sig)
 {
 
-  struct TALER_AgeWithdrawConfirmationPS confirm = {
+  struct TALER_WithdrawConfirmationPS confirm = {
     .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW),
     .purpose.size = htonl (sizeof (confirm)),
-    .h_commitment = *h_commitment,
+    .h_planchets = *h_planchets,
     .noreveal_index = htonl (noreveal_index)
   };
 
@@ -430,17 +435,38 @@ TALER_exchange_online_age_withdraw_confirmation_sign (
 }
 
 
+enum TALER_ErrorCode
+TALER_exchange_online_withdraw_confirmation_sign (
+  TALER_ExchangeSignCallback scb,
+  const struct TALER_HashBlindedPlanchetsP *h_planchets,
+  struct TALER_ExchangePublicKeyP *pub,
+  struct TALER_ExchangeSignatureP *sig)
+{
+
+  struct TALER_WithdrawConfirmationPS confirm = {
+    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW),
+    .purpose.size = htonl (sizeof (confirm)),
+    .h_planchets = *h_planchets,
+    .noreveal_index = htonl (0xFFFFFFFF)
+  };
+
+  return scb (&confirm.purpose,
+              pub,
+              sig);
+}
+
+
 enum GNUNET_GenericReturnValue
-TALER_exchange_online_age_withdraw_confirmation_verify (
-  const struct TALER_AgeWithdrawCommitmentHashP *h_commitment,
+TALER_exchange_online_withdraw_age_confirmation_verify (
+  const struct TALER_HashBlindedPlanchetsP *h_planchets,
   uint32_t noreveal_index,
   const struct TALER_ExchangePublicKeyP *exchange_pub,
   const struct TALER_ExchangeSignatureP *exchange_sig)
 {
-  struct TALER_AgeWithdrawConfirmationPS confirm = {
+  struct TALER_WithdrawConfirmationPS confirm = {
     .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW),
     .purpose.size = htonl (sizeof (confirm)),
-    .h_commitment = *h_commitment,
+    .h_planchets = *h_planchets,
     .noreveal_index = htonl (noreveal_index)
   };
 
@@ -458,7 +484,31 @@ TALER_exchange_online_age_withdraw_confirmation_verify (
 }
 
 
-/* FIXME[oec] add signature for age-withdraw, age-reveal */
+enum GNUNET_GenericReturnValue
+TALER_exchange_online_withdraw_confirmation_verify (
+  const struct TALER_HashBlindedPlanchetsP *h_planchets,
+  const struct TALER_ExchangePublicKeyP *exchange_pub,
+  const struct TALER_ExchangeSignatureP *exchange_sig)
+{
+  struct TALER_WithdrawConfirmationPS confirm = {
+    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW),
+    .purpose.size = htonl (sizeof (confirm)),
+    .h_planchets = *h_planchets,
+    .noreveal_index = htonl (0xFFFFFFFF)
+  };
+
+  if (GNUNET_OK !=
+      GNUNET_CRYPTO_eddsa_verify (
+        TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW,
+        &confirm,
+        &exchange_sig->eddsa_signature,
+        &exchange_pub->eddsa_pub))
+  {
+    GNUNET_break_op (0);
+    return GNUNET_SYSERR;
+  }
+  return GNUNET_OK;
+}
 
 
 GNUNET_NETWORK_STRUCT_BEGIN
