@@ -44,6 +44,19 @@ TALER_full_payto_cmp (const struct TALER_FullPayto a,
 }
 
 
+bool
+TALER_payto_is_wallet (const char *payto_uri)
+{
+  return
+    (0 == strncasecmp (payto_uri,
+                       "payto://taler-reserve/",
+                       strlen ("payto://taler-reserve/"))) ||
+    (0 == strncasecmp (payto_uri,
+                       "payto://taler-reserve-http/",
+                       strlen ("payto://taler-reserve-http/")));
+}
+
+
 int
 TALER_normalized_payto_cmp (const struct TALER_NormalizedPayto a,
                             const struct TALER_NormalizedPayto b)
