@@ -892,7 +892,7 @@ handle_batch_sign_request (struct TES_Client *client,
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Handling batch sign request of size %u\n",
               (unsigned int) bs);
-  if (bs > TALER_MAX_FRESH_COINS)
+  if (bs > TALER_MAX_COINS)
   {
     GNUNET_break_op (0);
     return GNUNET_SYSERR;
@@ -958,7 +958,7 @@ handle_batch_derive_request (struct TES_Client *client,
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Handling batch derivation request of size %u\n",
               (unsigned int) bs);
-  if (bs > TALER_MAX_FRESH_COINS)
+  if (bs > TALER_MAX_COINS)
   {
     GNUNET_break_op (0);
     return GNUNET_SYSERR;
