@@ -725,7 +725,7 @@ handle_batch_sign_request (struct TES_Client *client,
   struct BatchJob jobs[bs];
   bool failure = false;
 
-  if (bs > TALER_MAX_FRESH_COINS)
+  if (bs > TALER_MAX_COINS)
   {
     GNUNET_break_op (0);
     return GNUNET_SYSERR;
@@ -1980,9 +1980,6 @@ TALER_SECMOD_rsa_run (void *cls,
     GNUNET_free (secname);
     return;
   }
-  GNUNET_asprintf (&secname,
-                   "%s-secmod-rsa",
-                   opt->section);
   opt->global_ret = TES_listen_start (cfg,
                                       secname,
                                       &cb);
