@@ -317,11 +317,9 @@ test_attestation (void)
     uint8_t age_group = TALER_get_age_group (&age_mask, age);
     struct GNUNET_HashCode seed;
 
-
     GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK,
                                 &seed,
                                 sizeof(seed));
-
     TALER_age_restriction_commit (&age_mask,
                                   age,
                                   &seed,
@@ -340,9 +338,9 @@ test_attestation (void)
                                   &salt,
                                   sizeof (salt));
       GNUNET_assert (GNUNET_OK ==
-                     TALER_age_commitment_derive (&acp[i],
-                                                  &salt,
-                                                  &acp[i + 1]));
+                     TALER_age_commitment_proof_derive (&acp[i],
+                                                        &salt,
+                                                        &acp[i + 1]));
     }
 
     for (uint8_t i = 0; i < 3; i++)
@@ -350,11 +348,9 @@ test_attestation (void)
       for (uint8_t min = 0; min < 22; min++)
       {
         uint8_t min_group = TALER_get_age_group (&age_mask, min);
-
         ret = TALER_age_commitment_attest (&acp[i],
                                            min,
                                            &at);
-
         printf (
           "[%s]: attest(min:%d, age:%d) == %d; age_group: %d, min_group: %d\n",
           i == 0 ? "commit" : "derive",
@@ -369,6 +365,7 @@ test_attestation (void)
         {
           GNUNET_break (0);
           ret = GNUNET_SYSERR;
+          break;
         }
 
         if (min_group > age_group &&
@@ -376,6 +373,7 @@ test_attestation (void)
         {
           GNUNET_break (0);
           ret = GNUNET_SYSERR;
+          break;
         }
 
         if (min_group > age_group)
@@ -384,7 +382,6 @@ test_attestation (void)
         ret = TALER_age_commitment_verify (&acp[i].commitment,
                                            min,
                                            &at);
-
         printf (
           "[%s]: verify(min:%d, age:%d) == %d; age_group:%d, min_group: %d\n",
           i == 0 ? "commit" : "derive",
@@ -400,7 +397,6 @@ test_attestation (void)
           break;
         }
       }
-
       TALER_age_commitment_proof_free (&acp[i]);
     }
 
