@@ -46,10 +46,10 @@ test_high_level (void)
   struct GNUNET_CRYPTO_BlindingInputValues bi = {
     .cipher = GNUNET_CRYPTO_BSA_RSA
   };
-  struct TALER_ExchangeWithdrawValues alg1 = {
+  struct TALER_ExchangeBlindingValues alg1 = {
     .blinding_inputs = &bi
   };
-  struct TALER_ExchangeWithdrawValues alg2 = {
+  struct TALER_ExchangeBlindingValues alg2 = {
     .blinding_inputs = &bi
   };
 
@@ -124,7 +124,7 @@ test_planchets_rsa (uint8_t age)
   union GNUNET_CRYPTO_BlindingSecretP bks;
   struct TALER_DenominationPrivateKey dk_priv;
   struct TALER_DenominationPublicKey dk_pub;
-  const struct TALER_ExchangeWithdrawValues *alg_values;
+  const struct TALER_ExchangeBlindingValues *alg_values;
   struct TALER_PlanchetDetail pd;
   struct TALER_BlindedDenominationSignature blind_sig;
   struct TALER_FreshCoin coin;
@@ -227,12 +227,12 @@ test_planchets_cs (uint8_t age)
   union GNUNET_CRYPTO_BlindSessionNonce nonce;
   struct TALER_BlindedDenominationSignature blind_sig;
   struct TALER_FreshCoin coin;
-  struct TALER_ExchangeWithdrawValues alg_values;
+  struct TALER_ExchangeBlindingValues alg_values;
   struct TALER_AgeCommitmentHash *ach = NULL;
+  struct TALER_AgeCommitmentHash ah = {0};
 
   if (0 < age)
   {
-    struct TALER_AgeCommitmentHash ah = {0};
     struct TALER_AgeCommitmentProof acp;
     struct GNUNET_HashCode seed;
 
@@ -256,6 +256,7 @@ test_planchets_cs (uint8_t age)
                  TALER_denom_priv_create (&dk_priv,
                                           &dk_pub,
                                           GNUNET_CRYPTO_BSA_CS));
+#pragma message "phase out TALER_cs_withdraw_nonce_derive"
   TALER_cs_withdraw_nonce_derive (
     &ps,
     &nonce.cs_nonce);
