@@ -273,7 +273,7 @@ test_r_derive (struct TALER_CRYPTO_CsDenominationHelper *dh)
   struct GNUNET_CRYPTO_BlindingInputValues bi = {
     .cipher = GNUNET_CRYPTO_BSA_CS
   };
-  struct TALER_ExchangeWithdrawValues alg_values = {
+  struct TALER_ExchangeBlindingValues alg_values = {
     .blinding_inputs = &bi
   };
   union GNUNET_CRYPTO_BlindSessionNonce nonce;
@@ -287,6 +287,7 @@ test_r_derive (struct TALER_CRYPTO_CsDenominationHelper *dh)
       continue;
     GNUNET_assert (GNUNET_CRYPTO_BSA_CS ==
                    keys[i].denom_pub.bsign_pub_key->cipher);
+#pragma message "phase out TALER_cs_withdraw_nonce_derive"
     TALER_cs_withdraw_nonce_derive (
       &ps,
       &nonce.cs_nonce);
@@ -433,7 +434,7 @@ test_signing (struct TALER_CRYPTO_CsDenominationHelper *dh)
   struct GNUNET_CRYPTO_BlindingInputValues bi = {
     .cipher = GNUNET_CRYPTO_BSA_CS
   };
-  struct TALER_ExchangeWithdrawValues alg_values = {
+  struct TALER_ExchangeBlindingValues alg_values = {
     .blinding_inputs = &bi
   };
   union GNUNET_CRYPTO_BlindSessionNonce nonce;
@@ -631,7 +632,7 @@ test_batch_signing (struct TALER_CRYPTO_CsDenominationHelper *dh,
   union GNUNET_CRYPTO_BlindingSecretP bks[batch_size];
   struct TALER_CoinPubHashP c_hash[batch_size];
   struct GNUNET_CRYPTO_BlindingInputValues bi[batch_size];
-  struct TALER_ExchangeWithdrawValues alg_values[batch_size];
+  struct TALER_ExchangeBlindingValues alg_values[batch_size];
   union GNUNET_CRYPTO_BlindSessionNonce nonces[batch_size];
 
   for (unsigned int i = 0; i<batch_size; i++)
@@ -849,7 +850,7 @@ perf_signing (struct TALER_CRYPTO_CsDenominationHelper *dh,
   struct GNUNET_CRYPTO_BlindingInputValues bv = {
     .cipher = GNUNET_CRYPTO_BSA_CS
   };
-  struct TALER_ExchangeWithdrawValues alg_values = {
+  struct TALER_ExchangeBlindingValues alg_values = {
     .blinding_inputs = &bv
   };
 
@@ -1066,11 +1067,11 @@ run_test (void)
                               true);
   if (0 == ret)
     ret = test_batch_signing (dh,
-                              256,
+                              64,
                               true);
-  for (unsigned int i = 0; i<5; i++)
+  for (unsigned int i = 0; i<4; i++)
   {
-    static unsigned int batches[] = { 1, 4, 16, 64, 256 };
+    static unsigned int batches[] = { 1, 4, 16, 64 };
     unsigned int batch_size = batches[i];
     struct GNUNET_TIME_Absolute start;
     struct GNUNET_TIME_Relative duration;
