@@ -349,7 +349,6 @@ par_signing (struct GNUNET_CONFIGURATION_Handle *cfg)
   struct GNUNET_TIME_Absolute start;
   struct GNUNET_TIME_Relative duration;
   pid_t pids[NUM_CORES];
-  struct TALER_CRYPTO_ExchangeSignHelper *esh;
 
   memset (keys,
           0,
@@ -362,6 +361,7 @@ par_signing (struct GNUNET_CONFIGURATION_Handle *cfg)
     GNUNET_assert (-1 != pids[i]);
     if (0 == pids[i])
     {
+      struct TALER_CRYPTO_ExchangeSignHelper *esh;
       int ret;
 
       esh = TALER_CRYPTO_helper_esign_connect (cfg,
@@ -376,7 +376,6 @@ par_signing (struct GNUNET_CONFIGURATION_Handle *cfg)
       ret = perf_signing (esh,
                           "parallel");
       TALER_CRYPTO_helper_esign_disconnect (esh);
-      esh = NULL;
       exit (ret);
     }
   }
@@ -394,7 +393,7 @@ par_signing (struct GNUNET_CONFIGURATION_Handle *cfg)
            "%u (parallel) signature operations took %s (total real time)\n",
            (unsigned int) NUM_SIGN_PERFS * NUM_CORES,
            GNUNET_STRINGS_relative_time_to_string (duration,
-                                                   GNUNET_YES));
+                                                   true));
   return 0;
 }
 
