@@ -268,7 +268,7 @@ test_signing (struct TALER_CRYPTO_RsaDenominationHelper *dh)
   enum TALER_ErrorCode ec;
   bool success = false;
   struct TALER_PlanchetMasterSecretP ps;
-  const struct TALER_ExchangeWithdrawValues *alg_values
+  const struct TALER_ExchangeBlindingValues *alg_values
     = TALER_denom_ewv_rsa_singleton ();
   struct TALER_AgeCommitmentHash ach;
   struct TALER_CoinPubHashP c_hash;
@@ -462,7 +462,7 @@ test_batch_signing (struct TALER_CRYPTO_RsaDenominationHelper *dh,
   enum TALER_ErrorCode ec;
   bool success = false;
   struct TALER_PlanchetMasterSecretP ps[batch_size];
-  const struct TALER_ExchangeWithdrawValues *alg_values;
+  const struct TALER_ExchangeBlindingValues *alg_values;
   struct TALER_AgeCommitmentHash ach[batch_size];
   struct TALER_CoinPubHashP c_hash[batch_size];
   struct TALER_CoinSpendPrivateKeyP coin_priv[batch_size];
@@ -683,7 +683,7 @@ perf_signing (struct TALER_CRYPTO_RsaDenominationHelper *dh,
   struct TALER_CoinSpendPrivateKeyP coin_priv;
   struct TALER_AgeCommitmentHash ach;
   union GNUNET_CRYPTO_BlindingSecretP bks;
-  const struct TALER_ExchangeWithdrawValues *alg_values
+  const struct TALER_ExchangeBlindingValues *alg_values
     = TALER_denom_ewv_rsa_singleton ();
 
   TALER_planchet_master_setup_random (&ps);
@@ -892,11 +892,11 @@ run_test (void)
                               true);
   if (0 == ret)
     ret = test_batch_signing (dh,
-                              256,
+                              64,
                               true);
-  for (unsigned int i = 0; i<5; i++)
+  for (unsigned int i = 0; i<4; i++)
   {
-    static unsigned int batches[] = { 1, 4, 16, 64, 256 };
+    static unsigned int batches[] = { 1, 4, 16, 64 };
     unsigned int batch_size = batches[i];
     struct GNUNET_TIME_Absolute start;
     struct GNUNET_TIME_Relative duration;
