@@ -530,14 +530,113 @@ TALER_wallet_melt_verify (
 }
 
 
+GNUNET_NETWORK_STRUCT_BEGIN
+
+/**
+ * @brief Format used for to generate the signature on a refresh nonce,
+ *  a) to prove ownership of the old coin's private key and
+ *  b) to derive the planchet master secrets for the batch of fresh coins
+ */
+struct TALER_RefreshNonceSignaturePS
+{
+
+  /**
+   * Purpose must be #TALER_SIGNATURE_WALLET_COIN_LINK
+   */
+  struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
+
+  /**
+   * The nonce to sign
+   */
+  struct TALER_PublicRefreshNonceP nonce GNUNET_PACKED;
+
+  /**
+   * The running hash of the (hashes of) denomination public keys
+   */
+  struct GNUNET_HashCode h_denoms_h GNUNET_PACKED;
+
+  /**
+   * The kappa index for this signature, in NBO
+   */
+  uint32_t kappa_index GNUNET_PACKED;
+};
+
+GNUNET_NETWORK_STRUCT_END
+
+
+void
+TALER_wallet_refresh_nonce_sign (
+  const struct TALER_CoinSpendPrivateKeyP *old_coin_priv,
+  const struct TALER_PublicRefreshNonceP *nonce,
+  size_t num_denoms_h,
+  const struct TALER_DenominationHashP *denoms_h[static num_denoms_h],
+  uint8_t kappa_index,
+  struct TALER_PrivateRefreshNonceSignatureP *sig)
+{
+  struct TALER_RefreshNonceSignaturePS req = {
+    .purpose.size = htonl (sizeof (req)),
+    .purpose.purpose = htonl (TALER_SIGNATURE_WALLET_COIN_LINK),
+    .nonce = *nonce,
+    .kappa_index = htonl (kappa_index),
+  };
+  struct GNUNET_HashContext *ctx = GNUNET_CRYPTO_hash_context_start ();
+  GNUNET_assert (ctx);
+
+  for (size_t i = 0; i<num_denoms_h; i++)
+    GNUNET_CRYPTO_hash_context_read (ctx,
+                                     denoms_h[i],
+                                     sizeof(*denoms_h[i]));
+
+  GNUNET_CRYPTO_hash_context_finish (ctx,
+                                     &req.h_denoms_h);
+  GNUNET_CRYPTO_eddsa_sign (&old_coin_priv->eddsa_priv,
+                            &req,
+                            &sig->coin_sig.eddsa_signature);
+}
+
+
+enum GNUNET_GenericReturnValue
+TALER_wallet_refresh_nonce_verify (
+  const struct TALER_CoinSpendPublicKeyP *old_coin_pub,
+  const struct TALER_PublicRefreshNonceP *nonce,
+  size_t num_denoms_h,
+  struct TALER_DenominationHashP *const denoms_h[static num_denoms_h],
+  uint8_t kappa_index,
+  const struct TALER_PrivateRefreshNonceSignatureP *sig)
+{
+  struct TALER_RefreshNonceSignaturePS req = {
+    .purpose.size = htonl (sizeof (req)),
+    .purpose.purpose = htonl (TALER_SIGNATURE_WALLET_COIN_LINK),
+    .nonce = *nonce,
+    .kappa_index = htonl (kappa_index),
+  };
+  struct GNUNET_HashContext *ctx = GNUNET_CRYPTO_hash_context_start ();
+  GNUNET_assert (ctx);
+
+  for (size_t i = 0; i<num_denoms_h; i++)
+    GNUNET_CRYPTO_hash_context_read (ctx,
+                                     denoms_h[i],
+                                     sizeof(*denoms_h[i]));
+
+  GNUNET_CRYPTO_hash_context_finish (ctx,
+                                     &req.h_denoms_h);
+  return GNUNET_CRYPTO_eddsa_verify (
+    TALER_SIGNATURE_WALLET_COIN_LINK,
+    &req,
+    &sig->coin_sig.eddsa_signature,
+    &old_coin_pub->eddsa_pub);
+}
+
+
 GNUNET_NETWORK_STRUCT_BEGIN
 
 
 /**
  * @brief Format used for to generate the signature on a request to withdraw
  * coins from a reserve.
+ * @note: deprecated.  Will be removed at some point after v24 of the protocol.
  */
-struct TALER_WithdrawRequestPS
+struct TALER_WithdrawCommitmentPre24PS
 {
 
   /**
@@ -570,14 +669,14 @@ struct TALER_WithdrawRequestPS
 GNUNET_NETWORK_STRUCT_END
 
 void
-TALER_wallet_withdraw_sign (
+TALER_wallet_withdraw_sign_pre26 (
   const struct TALER_DenominationHashP *h_denom_pub,
   const struct TALER_Amount *amount_with_fee,
   const struct TALER_BlindedCoinHashP *bch,
   const struct TALER_ReservePrivateKeyP *reserve_priv,
   struct TALER_ReserveSignatureP *reserve_sig)
 {
-  struct TALER_WithdrawRequestPS req = {
+  struct TALER_WithdrawCommitmentPre24PS req = {
     .purpose.size = htonl (sizeof (req)),
     .purpose.purpose = htonl (TALER_SIGNATURE_WALLET_RESERVE_WITHDRAW),
     .h_denomination_pub = *h_denom_pub,
@@ -593,25 +692,25 @@ TALER_wallet_withdraw_sign (
 
 
 enum GNUNET_GenericReturnValue
-TALER_wallet_withdraw_verify (
+TALER_wallet_withdraw_verify_pre26 (
   const struct TALER_DenominationHashP *h_denom_pub,
   const struct TALER_Amount *amount_with_fee,
   const struct TALER_BlindedCoinHashP *bch,
   const struct TALER_ReservePublicKeyP *reserve_pub,
   const struct TALER_ReserveSignatureP *reserve_sig)
 {
-  struct TALER_WithdrawRequestPS wsrd = {
-    .purpose.size = htonl (sizeof (wsrd)),
+  struct TALER_WithdrawCommitmentPre24PS req = {
+    .purpose.size = htonl (sizeof (req)),
     .purpose.purpose = htonl (TALER_SIGNATURE_WALLET_RESERVE_WITHDRAW),
     .h_denomination_pub = *h_denom_pub,
     .h_coin_envelope = *bch
   };
 
-  TALER_amount_hton (&wsrd.amount_with_fee,
+  TALER_amount_hton (&req.amount_with_fee,
                      amount_with_fee);
   return GNUNET_CRYPTO_eddsa_verify (
     TALER_SIGNATURE_WALLET_RESERVE_WITHDRAW,
-    &wsrd,
+    &req,
     &reserve_sig->eddsa_signature,
     &reserve_pub->eddsa_pub);
 }
@@ -620,101 +719,222 @@ TALER_wallet_withdraw_verify (
 GNUNET_NETWORK_STRUCT_BEGIN
 
 /**
- * @brief Format used for to generate the signature on a request to
- * age-withdraw from a reserve.
+ * @brief Format used for to generate the signature on a request to withdraw
+ * coins from a reserve.
+ *
  */
-struct TALER_AgeWithdrawRequestPS
+struct TALER_WithdrawRequestPS
 {
-
   /**
-   * Purpose must be #TALER_SIGNATURE_WALLET_RESERVE_WITHDRAW.
-   * Used with an EdDSA signature of a `struct TALER_ReservePublicKeyP`.
+   * Purpose is #TALER_SIGNATURE_WALLET_WITHDRAW
    */
   struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
 
   /**
-   * The reserve's public key
+   * Total value of all coins being exchanged (matching the denomination keys),
+   * without the fee.
+   * Note that the reserve must have a value of at least amount+fee.
    */
-  struct TALER_ReservePublicKeyP reserve_pub;
+  struct TALER_AmountNBO amount;
 
   /**
-   * Value of the coin being exchanged (matching the denomination key)
-   * plus the transaction fee.  We include this in what is being
-   * signed so that we can verify a reserve's remaining total balance
-   * without needing to access the respective denomination key
-   * information each time.
+   * Total fee for the withdrawal.
+   * Note that the reserve must have a value of at least amount+fee.
    */
-  struct TALER_AmountNBO amount_with_fee;
+  struct TALER_AmountNBO fee;
 
   /**
-   * Running SHA512 hash of the commitment of n*kappa coins
+   * Running SHA512 hash of all TALER_BlindedCoinHashP's
+   * of the of n coins, or n*kappa candidate coins in case of age restriction.
+   * In the later case, the coins' hashes are arranged [0..num_coins)...[0..num_coins),
+   * i.e. the coins are grouped per kappa-index.
+   * Note that each coin's TALER_BlindedCoinHashP also captures
+   * the hash of the public key of the corresponding denomination.
    */
-  struct TALER_AgeWithdrawCommitmentHashP h_commitment;
+  struct TALER_HashBlindedPlanchetsP h_planchets GNUNET_PACKED;
 
   /**
-   * The mask that defines the age groups.  MUST be the same for all denominations.
+   * If any of the denominations is of cipher type Clause-Schnorr,
+   * the client had to call /blinding-prepare prior to the withdraw
+   * to retrieve public R-values for the CS signature scheme.
+   * The input seed for that request must be provided here.
+   * Otherwise, if no CS denomination is used, the struct must be all zeros.
    */
-  struct TALER_AgeMask mask;
+  struct TALER_BlindingMasterSeedP blinding_seed;
 
   /**
    * Maximum age group that the coins are going to be restricted to.
+   * MUST be 0 if no age restriction applies.
    */
-  uint8_t max_age_group;
+  uint32_t max_age_group;
+
+  /**
+   * The mask that defines the age groups.
+   * MUST be the same for all denominations.
+   * MUST be 0 if no age restriction applies.
+   */
+  struct TALER_AgeMask mask;
+
 };
 
 
 GNUNET_NETWORK_STRUCT_END
 
 void
-TALER_wallet_age_withdraw_sign (
-  const struct TALER_AgeWithdrawCommitmentHashP *h_commitment,
-  const struct TALER_Amount *amount_with_fee,
+TALER_wallet_blinded_planchets_hash (
+  size_t num_planchets,
+  const struct TALER_BlindedPlanchet blinded_planchets[static num_planchets],
+  const struct TALER_DenominationHashP h_denom_pubs[static num_planchets],
+  struct TALER_HashBlindedPlanchetsP *h_planchets)
+{
+  struct TALER_BlindedCoinHashP bch;
+  struct GNUNET_HashContext *coins_hctx;
+
+  GNUNET_assert (num_planchets > 0);
+  GNUNET_assert (NULL != h_planchets);
+
+  coins_hctx = GNUNET_CRYPTO_hash_context_start ();
+  GNUNET_assert (NULL != coins_hctx);
+
+  for (size_t i = 0; i < num_planchets; i++)
+  {
+    TALER_coin_ev_hash (
+      &blinded_planchets[i],
+      &h_denom_pubs[i],
+      &bch);
+    GNUNET_CRYPTO_hash_context_read (
+      coins_hctx,
+      &bch,
+      sizeof(bch));
+  }
+
+  GNUNET_CRYPTO_hash_context_finish (
+    coins_hctx,
+    &h_planchets->hash);
+}
+
+
+void
+TALER_wallet_blinded_planchet_details_hash (
+  size_t num_planchets,
+  const struct TALER_PlanchetDetail planchet_details[static num_planchets],
+  struct TALER_HashBlindedPlanchetsP *h_planchets)
+{
+  struct TALER_BlindedCoinHashP bch;
+  struct GNUNET_HashContext *coins_hctx;
+
+  GNUNET_assert (num_planchets > 0);
+  GNUNET_assert (NULL != h_planchets);
+
+  coins_hctx = GNUNET_CRYPTO_hash_context_start ();
+  GNUNET_assert (NULL != coins_hctx);
+
+  for (size_t i = 0; i < num_planchets; i++)
+  {
+    TALER_coin_ev_hash (
+      &planchet_details[i].blinded_planchet,
+      &planchet_details[i].denom_pub_hash,
+      &bch);
+    GNUNET_CRYPTO_hash_context_read (
+      coins_hctx,
+      &bch,
+      sizeof(bch));
+  }
+
+  GNUNET_CRYPTO_hash_context_finish (
+    coins_hctx,
+    &h_planchets->hash);
+}
+
+
+struct TALER_HashReservePublicKeyP
+TALER_wallet_hash_reserve_pub (
+  const struct TALER_ReservePublicKeyP *reserve_pub)
+{
+  struct TALER_HashReservePublicKeyP hr;
+
+  GNUNET_CRYPTO_hash (reserve_pub,
+                      sizeof(*reserve_pub),
+                      &hr.hash);
+  return hr;
+}
+
+
+void
+TALER_wallet_withdraw_sign (
+  const struct TALER_Amount *amount,
+  const struct TALER_Amount *fee,
+  const struct TALER_HashBlindedPlanchetsP *h_planchets,
+  const struct TALER_BlindingMasterSeedP *blinding_seed,
   const struct TALER_AgeMask *mask,
   uint8_t max_age,
   const struct TALER_ReservePrivateKeyP *reserve_priv,
   struct TALER_ReserveSignatureP *reserve_sig)
 {
-  struct TALER_AgeWithdrawRequestPS req = {
-    .purpose.size = htonl (sizeof (req)),
-    .purpose.purpose = htonl (TALER_SIGNATURE_WALLET_RESERVE_AGE_WITHDRAW),
-    .h_commitment = *h_commitment,
-    .mask = *mask,
-    .max_age_group = TALER_get_age_group (mask, max_age)
+  struct TALER_WithdrawRequestPS req = {
+    .purpose.size = htonl (sizeof(req)),
+    .purpose.purpose = htonl (TALER_SIGNATURE_WALLET_RESERVE_WITHDRAW),
   };
 
-  GNUNET_CRYPTO_eddsa_key_get_public (&reserve_priv->eddsa_priv,
-                                      &req.reserve_pub.eddsa_pub);
-  TALER_amount_hton (&req.amount_with_fee,
-                     amount_with_fee);
-  GNUNET_CRYPTO_eddsa_sign (&reserve_priv->eddsa_priv,
-                            &req,
-                            &reserve_sig->eddsa_signature);
+  GNUNET_assert (NULL != h_planchets);
+  req.h_planchets = *h_planchets;
+  if (NULL != mask)
+  {
+    req.mask = *mask;
+    req.max_age_group =
+      TALER_get_age_group (mask,
+                           max_age);
+  }
+  TALER_amount_hton (&req.amount,
+                     amount);
+  TALER_amount_hton (&req.fee,
+                     fee);
+  if (NULL != blinding_seed)
+    req.blinding_seed = *blinding_seed;
+
+  GNUNET_CRYPTO_eddsa_sign (
+    &reserve_priv->eddsa_priv,
+    &req,
+    &reserve_sig->eddsa_signature);
+
 }
 
 
 enum GNUNET_GenericReturnValue
-TALER_wallet_age_withdraw_verify (
-  const struct TALER_AgeWithdrawCommitmentHashP *h_commitment,
-  const struct TALER_Amount *amount_with_fee,
+TALER_wallet_withdraw_verify (
+  const struct TALER_Amount *amount,
+  const struct TALER_Amount *fee,
+  const struct TALER_HashBlindedPlanchetsP *h_planchets,
+  const struct TALER_BlindingMasterSeedP *blinding_seed,
   const struct TALER_AgeMask *mask,
   uint8_t max_age,
   const struct TALER_ReservePublicKeyP *reserve_pub,
   const struct TALER_ReserveSignatureP *reserve_sig)
 {
-  struct TALER_AgeWithdrawRequestPS awsrd = {
-    .purpose.size = htonl (sizeof (awsrd)),
-    .purpose.purpose = htonl (TALER_SIGNATURE_WALLET_RESERVE_AGE_WITHDRAW),
-    .reserve_pub = *reserve_pub,
-    .h_commitment = *h_commitment,
-    .mask = *mask,
-    .max_age_group = TALER_get_age_group (mask, max_age)
+  struct TALER_WithdrawRequestPS req = {
+    .purpose.size = htonl (sizeof(req)),
+    .purpose.purpose = htonl (TALER_SIGNATURE_WALLET_RESERVE_WITHDRAW),
   };
 
-  TALER_amount_hton (&awsrd.amount_with_fee,
-                     amount_with_fee);
+  GNUNET_assert (NULL != h_planchets);
+  req.h_planchets = *h_planchets;
+  if (NULL != mask)
+  {
+    req.mask = *mask;
+    req.max_age_group =
+      TALER_get_age_group (mask,
+                           max_age);
+  }
+  TALER_amount_hton (&req.amount,
+                     amount);
+  TALER_amount_hton (&req.fee,
+                     fee);
+  if (NULL != blinding_seed)
+    req.blinding_seed = *blinding_seed;
+
   return GNUNET_CRYPTO_eddsa_verify (
-    TALER_SIGNATURE_WALLET_RESERVE_AGE_WITHDRAW,
-    &awsrd,
+    TALER_SIGNATURE_WALLET_RESERVE_WITHDRAW,
+    &req,
     &reserve_sig->eddsa_signature,
     &reserve_pub->eddsa_pub);
 }
